@@ -24,26 +24,25 @@ part of dart._engine;
 /// can be reused, [CanvasPool] will move canvas(s) from pool to reusablePool
 /// to prevent reallocation.
 class CanvasPool extends _SaveStackTracking {
-  html.CanvasRenderingContext2D? _context;
+  /// Initializes canvas pool for target size and dpi.
+  CanvasPool(this._widthInBitmapPixels, this._heightInBitmapPixels, this._density);
+
+  DomCanvasRenderingContext2D? _context;
   ContextStateHandle? _contextHandle;
   final int _widthInBitmapPixels, _heightInBitmapPixels;
   // List of canvases that have been allocated and used in this paint cycle.
-  List<html.CanvasElement>? _activeCanvasList;
+  List<DomCanvasElement>? _activeCanvasList;
   // List of canvases available to reuse from prior paint cycle.
-  List<html.CanvasElement>? _reusablePool;
+  List<DomCanvasElement>? _reusablePool;
   // Current canvas element or null if marked for lazy allocation.
-  html.CanvasElement? _canvas;
+  DomCanvasElement? _canvas;
 
-  html.HtmlElement? _rootElement;
+  DomHTMLElement? _rootElement;
   int _saveContextCount = 0;
   final double _density;
 
-  /// Initializes canvas pool for target size and dpi.
-  CanvasPool(this._widthInBitmapPixels, this._heightInBitmapPixels,
-      this._density);
-
   /// Initializes canvas pool to be hosted on a surface.
-  void mount(html.HtmlElement rootElement) {
+  void mount(DomHTMLElement rootElement) {
     _rootElement = rootElement;
   }
 
@@ -55,23 +54,16 @@ class CanvasPool extends _SaveStackTracking {
     translate(transform.dx, transform.dy);
   }
 
-  /// Returns true if no canvas has been allocated yet.
-  bool get isEmpty => _canvas == null;
-
-  /// Returns true if a canvas has been allocated for use.
-  bool get isNotEmpty => _canvas != null;
-
-
   /// Returns [CanvasRenderingContext2D] api to draw into this canvas.
-  html.CanvasRenderingContext2D get context {
-    html.CanvasRenderingContext2D? ctx = _context;
+  DomCanvasRenderingContext2D get context {
+    DomCanvasRenderingContext2D? ctx = _context;
     if (ctx == null) {
       _createCanvas();
-      ctx = _context!;
+      ctx = _context;
       assert(_context != null);
       assert(_canvas != null);
     }
-    return ctx;
+    return ctx!;
   }
 
   /// Returns [ContextStateHandle] API to efficiently update state of
@@ -85,19 +77,35 @@ class CanvasPool extends _SaveStackTracking {
     return _contextHandle!;
   }
 
-  /// Prevents active canvas to be used for rendering and prepares a new
-  /// canvas allocation on next drawing request that will require one.
+  /// Returns true if a canvas is currently available for drawing.
   ///
-  /// Saves current canvas so we can dispose
-  /// and replay the clip/transform stack on top of new canvas.
-  void closeCurrentCanvas() {
+  /// Calling [contextHandle] or, transitively, any of the `draw*` methods while
+  /// this returns true will reuse the existing canvas. Otherwise, a new canvas
+  /// will be allocated.
+  ///
+  /// Previously allocated and closed canvases (see [closeCanvas]) are not
+  /// considered by this getter.
+  bool get hasCanvas => _canvas != null;
+
+  /// Stops the currently available canvas from receiving any further drawing
+  /// commands.
+  ///
+  /// After calling this method, a subsequent call to [contextHandle] or,
+  /// transitively, any of the `draw*` methods will cause a new canvas to be
+  /// allocated.
+  ///
+  /// The closed canvas becomes an "active" canvas, that is a canvas that's used
+  /// to render picture content in the current frame. Active canvases may be
+  /// reused in other pictures if their contents are no longer needed for this
+  /// picture.
+  void closeCanvas() {
     assert(_rootElement != null);
     // Place clean copy of current canvas with context stack restored and paint
     // reset into pool.
     if (_canvas != null) {
       _restoreContextSave();
       _contextHandle!.reset();
-      _activeCanvasList ??= <html.CanvasElement>[];
+      _activeCanvasList ??= <DomCanvasElement>[];
       _activeCanvasList!.add(_canvas!);
       _canvas = null;
       _context = null;
@@ -108,7 +116,7 @@ class CanvasPool extends _SaveStackTracking {
   void _createCanvas() {
     bool requiresClearRect = false;
     bool reused = false;
-    html.CanvasElement? canvas;
+    DomCanvasElement? canvas;
     if (_canvas != null) {
       _canvas!.width = 0;
       _canvas!.height = 0;
@@ -126,9 +134,9 @@ class CanvasPool extends _SaveStackTracking {
       // * To make sure that when we scale the canvas by devicePixelRatio (see
       //   _initializeViewport below) the pixels line up.
       final double cssWidth =
-          _widthInBitmapPixels / EnginePlatformDispatcher.browserDevicePixelRatio;
+          _widthInBitmapPixels / EngineFlutterDisplay.instance.browserDevicePixelRatio;
       final double cssHeight =
-          _heightInBitmapPixels / EnginePlatformDispatcher.browserDevicePixelRatio;
+          _heightInBitmapPixels / EngineFlutterDisplay.instance.browserDevicePixelRatio;
       canvas = _allocCanvas(_widthInBitmapPixels, _heightInBitmapPixels);
       _canvas = canvas;
 
@@ -183,13 +191,10 @@ class CanvasPool extends _SaveStackTracking {
     _replayClipStack();
   }
 
-  html.CanvasElement? _allocCanvas(int width, int height) {
+  DomCanvasElement? _allocCanvas(int width, int height) {
     // The dartdocs for `tryCreateCanvasElement` on why we don't use the
-    // `html.CanvasElement` constructor.
-    return tryCreateCanvasElement(
-      (width * _density).ceil(),
-      (height * _density).ceil(),
-    );
+    // `DomCanvasElement` constructor.
+    return tryCreateCanvasElement((width * _density).ceil(), (height * _density).ceil());
   }
 
   @override
@@ -198,7 +203,7 @@ class CanvasPool extends _SaveStackTracking {
 
     if (_canvas != null) {
       // Restore to the state where we have only applied the scaling.
-      final html.CanvasRenderingContext2D? ctx = _context;
+      final DomCanvasRenderingContext2D? ctx = _context;
       if (ctx != null) {
         try {
           ctx.font = '';
@@ -214,13 +219,15 @@ class CanvasPool extends _SaveStackTracking {
     reuse();
   }
 
-  int _replaySingleSaveEntry(int clipDepth, Matrix4 prevTransform,
-      Matrix4 transform, List<SaveClipEntry>? clipStack) {
-    final html.CanvasRenderingContext2D ctx = context;
+  int _replaySingleSaveEntry(
+    int clipDepth,
+    Matrix4 prevTransform,
+    Matrix4 transform,
+    List<SaveClipEntry>? clipStack,
+  ) {
+    final DomCanvasRenderingContext2D ctx = context;
     if (clipStack != null) {
-      for (final int clipCount = clipStack.length;
-          clipDepth < clipCount;
-          clipDepth++) {
+      for (final int clipCount = clipStack.length; clipDepth < clipCount; clipDepth++) {
         final SaveClipEntry clipEntry = clipStack[clipDepth];
         final Matrix4 clipTimeTransform = clipEntry.currentTransform;
         // If transform for entry recording change since last element, update.
@@ -234,12 +241,13 @@ class CanvasPool extends _SaveStackTracking {
           final double ratio = dpi;
           ctx.setTransform(ratio, 0, 0, ratio, 0, 0);
           ctx.transform(
-              clipTimeTransform[0],
-              clipTimeTransform[1],
-              clipTimeTransform[4],
-              clipTimeTransform[5],
-              clipTimeTransform[12],
-              clipTimeTransform[13]);
+            clipTimeTransform[0],
+            clipTimeTransform[1],
+            clipTimeTransform[4],
+            clipTimeTransform[5],
+            clipTimeTransform[12],
+            clipTimeTransform[13],
+          );
           prevTransform = clipTimeTransform;
         }
         if (clipEntry.rect != null) {
@@ -267,28 +275,37 @@ class CanvasPool extends _SaveStackTracking {
         transform[13] != prevTransform[13]) {
       final double ratio = dpi;
       ctx.setTransform(ratio, 0, 0, ratio, 0, 0);
-      ctx.transform(transform[0], transform[1], transform[4], transform[5],
-          transform[12], transform[13]);
+      ctx.transform(
+        transform[0],
+        transform[1],
+        transform[4],
+        transform[5],
+        transform[12],
+        transform[13],
+      );
     }
     return clipDepth;
   }
 
   void _replayClipStack() {
     // Replay save/clip stack on this canvas now.
-    final html.CanvasRenderingContext2D ctx = context;
+    final DomCanvasRenderingContext2D ctx = context;
     int clipDepth = 0;
     Matrix4 prevTransform = Matrix4.identity();
     final int len = _saveStack.length;
     for (int saveStackIndex = 0; saveStackIndex < len; saveStackIndex++) {
       final SaveStackEntry saveEntry = _saveStack[saveStackIndex];
       clipDepth = _replaySingleSaveEntry(
-          clipDepth, prevTransform, saveEntry.transform, saveEntry.clipStack);
+        clipDepth,
+        prevTransform,
+        saveEntry.transform,
+        saveEntry.clipStack,
+      );
       prevTransform = saveEntry.transform;
       ctx.save();
       ++_saveContextCount;
     }
-    _replaySingleSaveEntry(
-        clipDepth, prevTransform, _currentTransform, clipStack);
+    _replaySingleSaveEntry(clipDepth, prevTransform, _currentTransform, clipStack);
   }
 
   /// Marks this pool for reuse.
@@ -296,7 +313,7 @@ class CanvasPool extends _SaveStackTracking {
     if (_canvas != null) {
       _restoreContextSave();
       _contextHandle!.reset();
-      _activeCanvasList ??= <html.CanvasElement>[];
+      _activeCanvasList ??= <DomCanvasElement>[];
       _activeCanvasList!.add(_canvas!);
       _context = null;
       _contextHandle = null;
@@ -313,8 +330,8 @@ class CanvasPool extends _SaveStackTracking {
   /// that are reused from last instance can be cleanup.
   void endOfPaint() {
     if (_reusablePool != null) {
-      for (final html.CanvasElement e in _reusablePool!) {
-        if (browserEngine == BrowserEngine.webkit) {
+      for (final DomCanvasElement e in _reusablePool!) {
+        if (ui_web.browser.browserEngine == ui_web.BrowserEngine.webkit) {
           e.width = e.height = 0;
         }
         e.remove();
@@ -335,7 +352,7 @@ class CanvasPool extends _SaveStackTracking {
   /// coordinate system, and the pixel ratio is applied such that CSS pixels are
   /// translated to bitmap pixels.
   void _initializeViewport(bool clearCanvas) {
-    final html.CanvasRenderingContext2D ctx = context;
+    final DomCanvasRenderingContext2D ctx = context;
     // Save the canvas state with top-level transforms so we can undo
     // any clips later when we reuse the canvas.
     ctx.save();
@@ -345,8 +362,7 @@ class CanvasPool extends _SaveStackTracking {
     // is applied on the DOM elements.
     ctx.setTransform(1, 0, 0, 1, 0, 0);
     if (clearCanvas) {
-      ctx.clearRect(0, 0, _widthInBitmapPixels * _density,
-          _heightInBitmapPixels * _density);
+      ctx.clearRect(0, 0, _widthInBitmapPixels * _density, _heightInBitmapPixels * _density);
     }
 
     // This scale makes sure that 1 CSS pixel is translated to the correct
@@ -355,11 +371,10 @@ class CanvasPool extends _SaveStackTracking {
   }
 
   /// Returns effective dpi (browser DPI and pixel density due to transform).
-  double get dpi =>
-      EnginePlatformDispatcher.browserDevicePixelRatio * _density;
+  double get dpi => EngineFlutterDisplay.instance.browserDevicePixelRatio * _density;
 
   void _resetTransform() {
-    final html.CanvasElement? canvas = _canvas;
+    final DomCanvasElement? canvas = _canvas;
     if (canvas != null) {
       canvas.style.transformOrigin = '';
       canvas.style.transform = '';
@@ -368,7 +383,12 @@ class CanvasPool extends _SaveStackTracking {
 
   /// Returns a "data://" URI containing a representation of the image in this
   /// canvas in PNG format.
-  String toDataUrl() => _canvas?.toDataUrl() ?? '';
+  String toDataUrl() {
+    if (_canvas == null) {
+      _createCanvas();
+    }
+    return _canvas!.toDataURL();
+  }
 
   @override
   void save() {
@@ -454,8 +474,7 @@ class CanvasPool extends _SaveStackTracking {
     // This matrix is sufficient to represent 2D rotates, translates, scales,
     // and skews.
     if (_canvas != null) {
-      context.transform(matrix4[0], matrix4[1], matrix4[4], matrix4[5],
-          matrix4[12], matrix4[13]);
+      context.transform(matrix4[0], matrix4[1], matrix4[4], matrix4[5], matrix4[12], matrix4[13]);
     }
   }
 
@@ -467,7 +486,7 @@ class CanvasPool extends _SaveStackTracking {
     }
   }
 
-  void _clipRect(html.CanvasRenderingContext2D ctx, ui.Rect rect) {
+  void _clipRect(DomCanvasRenderingContext2D ctx, ui.Rect rect) {
     ctx.beginPath();
     ctx.rect(rect.left, rect.top, rect.width, rect.height);
     ctx.clip();
@@ -481,7 +500,7 @@ class CanvasPool extends _SaveStackTracking {
     }
   }
 
-  void _clipRRect(html.CanvasRenderingContext2D ctx, ui.RRect rrect) {
+  void _clipRRect(DomCanvasRenderingContext2D ctx, ui.RRect rrect) {
     final ui.Path path = ui.Path()..addRRect(rrect);
     _runPath(ctx, path as SurfacePath);
     ctx.clip();
@@ -491,7 +510,7 @@ class CanvasPool extends _SaveStackTracking {
   void clipPath(ui.Path path) {
     super.clipPath(path);
     if (_canvas != null) {
-      final html.CanvasRenderingContext2D ctx = context;
+      final DomCanvasRenderingContext2D ctx = context;
       _runPath(ctx, path as SurfacePath);
       if (path.fillType == ui.PathFillType.nonZero) {
         ctx.clip();
@@ -503,9 +522,9 @@ class CanvasPool extends _SaveStackTracking {
 
   /// Fill a virtually infinite rect with a color and optional blendMode.
   void drawColor(ui.Color color, ui.BlendMode blendMode) {
-    final html.CanvasRenderingContext2D ctx = context;
+    final DomCanvasRenderingContext2D ctx = context;
     contextHandle.blendMode = blendMode;
-    contextHandle.fillStyle = colorToCssString(color);
+    contextHandle.fillStyle = color.toCssString();
     contextHandle.strokeStyle = '';
     ctx.beginPath();
     // Fill a virtually infinite rect with the color.
@@ -517,7 +536,7 @@ class CanvasPool extends _SaveStackTracking {
 
   /// Fill a virtually infinite rect with the color.
   void fill() {
-    final html.CanvasRenderingContext2D ctx = context;
+    final DomCanvasRenderingContext2D ctx = context;
     ctx.beginPath();
     // We can't use (0, 0, width, height) because the current transform can
     // cause it to not fill the entire clip.
@@ -526,7 +545,7 @@ class CanvasPool extends _SaveStackTracking {
 
   /// Draws a line from [p1] to [p2].
   void strokeLine(ui.Offset p1, ui.Offset p2) {
-    final html.CanvasRenderingContext2D ctx = context;
+    final DomCanvasRenderingContext2D ctx = context;
     ctx.beginPath();
     final ui.Rect? shaderBounds = contextHandle._shaderBounds;
     if (shaderBounds == null) {
@@ -542,7 +561,7 @@ class CanvasPool extends _SaveStackTracking {
   /// Draws a set of points with given radius, lines between points or
   /// a polygon.
   void drawPoints(ui.PointMode pointMode, Float32List points, double radius) {
-    final html.CanvasRenderingContext2D ctx = context;
+    final DomCanvasRenderingContext2D ctx = context;
     final int len = points.length;
     final ui.Rect? shaderBounds = contextHandle._shaderBounds;
     final double offsetX = shaderBounds == null ? 0 : -shaderBounds.left;
@@ -556,7 +575,6 @@ class CanvasPool extends _SaveStackTracking {
           ctx.arc(x, y, radius, 0, 2.0 * math.pi);
           ctx.fill();
         }
-        break;
       case ui.PointMode.lines:
         ctx.beginPath();
         for (int i = 0; i < (len - 2); i += 4) {
@@ -564,7 +582,6 @@ class CanvasPool extends _SaveStackTracking {
           ctx.lineTo(points[i + 2] + offsetX, points[i + 3] + offsetY);
           ctx.stroke();
         }
-        break;
       case ui.PointMode.polygon:
         ctx.beginPath();
         ctx.moveTo(points[0] + offsetX, points[1] + offsetY);
@@ -572,15 +589,14 @@ class CanvasPool extends _SaveStackTracking {
           ctx.lineTo(points[i] + offsetX, points[i + 1] + offsetY);
         }
         ctx.stroke();
-        break;
     }
   }
 
   // Float buffer used for path iteration.
-  static Float32List _runBuffer = Float32List(PathRefIterator.kMaxBufferSize);
+  static final Float32List _runBuffer = Float32List(PathRefIterator.kMaxBufferSize);
 
   /// 'Runs' the given [path] by applying all of its commands to the canvas.
-  void _runPath(html.CanvasRenderingContext2D ctx, SurfacePath path) {
+  void _runPath(DomCanvasRenderingContext2D ctx, SurfacePath path) {
     ctx.beginPath();
     final Float32List p = _runBuffer;
     final PathRefIterator iter = PathRefIterator(path.pathRef);
@@ -589,16 +605,12 @@ class CanvasPool extends _SaveStackTracking {
       switch (verb) {
         case SPath.kMoveVerb:
           ctx.moveTo(p[0], p[1]);
-          break;
         case SPath.kLineVerb:
           ctx.lineTo(p[2], p[3]);
-          break;
         case SPath.kCubicVerb:
           ctx.bezierCurveTo(p[2], p[3], p[4], p[5], p[6], p[7]);
-          break;
         case SPath.kQuadVerb:
           ctx.quadraticCurveTo(p[2], p[3], p[4], p[5]);
-          break;
         case SPath.kConicVerb:
           final double w = iter.conicWeight;
           final Conic conic = Conic(p[0], p[1], p[2], p[3], p[4], p[5], w);
@@ -611,10 +623,8 @@ class CanvasPool extends _SaveStackTracking {
             final double p2y = points[i + 1].dy;
             ctx.quadraticCurveTo(p1x, p1y, p2x, p2y);
           }
-          break;
         case SPath.kCloseVerb:
           ctx.closePath();
-          break;
         default:
           throw UnimplementedError('Unknown path verb $verb');
       }
@@ -628,8 +638,12 @@ class CanvasPool extends _SaveStackTracking {
     if (shaderBounds == null) {
       context.rect(rect.left, rect.top, rect.width, rect.height);
     } else {
-      context.rect(rect.left - shaderBounds.left, rect.top - shaderBounds.top,
-          rect.width, rect.height);
+      context.rect(
+        rect.left - shaderBounds.left,
+        rect.top - shaderBounds.top,
+        rect.width,
+        rect.height,
+      );
     }
     contextHandle.paint(style);
   }
@@ -637,8 +651,12 @@ class CanvasPool extends _SaveStackTracking {
   /// Applies path to drawing context, preparing for fill and other operations.
   ///
   /// WARNING: Don't refactor _runPath/_runPathWithOffset. Latency sensitive
-  void _runPathWithOffset(html.CanvasRenderingContext2D ctx, SurfacePath path,
-      double offsetX, double offsetY) {
+  void _runPathWithOffset(
+    DomCanvasRenderingContext2D ctx,
+    SurfacePath path,
+    double offsetX,
+    double offsetY,
+  ) {
     ctx.beginPath();
     final Float32List p = _runBuffer;
     final PathRefIterator iter = PathRefIterator(path.pathRef);
@@ -647,18 +665,19 @@ class CanvasPool extends _SaveStackTracking {
       switch (verb) {
         case SPath.kMoveVerb:
           ctx.moveTo(p[0] + offsetX, p[1] + offsetY);
-          break;
         case SPath.kLineVerb:
           ctx.lineTo(p[2] + offsetX, p[3] + offsetY);
-          break;
         case SPath.kCubicVerb:
-          ctx.bezierCurveTo(p[2] + offsetX, p[3] + offsetY,
-              p[4] + offsetX, p[5] + offsetY, p[6] + offsetX, p[7] + offsetY);
-          break;
+          ctx.bezierCurveTo(
+            p[2] + offsetX,
+            p[3] + offsetY,
+            p[4] + offsetX,
+            p[5] + offsetY,
+            p[6] + offsetX,
+            p[7] + offsetY,
+          );
         case SPath.kQuadVerb:
-          ctx.quadraticCurveTo(p[2] + offsetX, p[3] + offsetY,
-              p[4] + offsetX, p[5] + offsetY);
-          break;
+          ctx.quadraticCurveTo(p[2] + offsetX, p[3] + offsetY, p[4] + offsetX, p[5] + offsetY);
         case SPath.kConicVerb:
           final double w = iter.conicWeight;
           final Conic conic = Conic(p[0], p[1], p[2], p[3], p[4], p[5], w);
@@ -669,13 +688,10 @@ class CanvasPool extends _SaveStackTracking {
             final double p1y = points[i].dy;
             final double p2x = points[i + 1].dx;
             final double p2y = points[i + 1].dy;
-            ctx.quadraticCurveTo(p1x + offsetX, p1y + offsetY,
-                p2x + offsetX, p2y + offsetY);
+            ctx.quadraticCurveTo(p1x + offsetX, p1y + offsetY, p2x + offsetX, p2y + offsetY);
           }
-          break;
         case SPath.kCloseVerb:
           ctx.closePath();
-          break;
         default:
           throw UnimplementedError('Unknown path verb $verb');
       }
@@ -686,8 +702,10 @@ class CanvasPool extends _SaveStackTracking {
   void drawRRect(ui.RRect roundRect, ui.PaintingStyle? style) {
     final ui.Rect? shaderBounds = contextHandle._shaderBounds;
     RRectToCanvasRenderer(context).render(
-        shaderBounds == null ? roundRect
-            : roundRect.shift(ui.Offset(-shaderBounds.left, -shaderBounds.top)));
+      shaderBounds == null
+          ? roundRect
+          : roundRect.shift(ui.Offset(-shaderBounds.left, -shaderBounds.top)),
+    );
     contextHandle.paint(style);
   }
 
@@ -712,12 +730,9 @@ class CanvasPool extends _SaveStackTracking {
   void drawOval(ui.Rect rect, ui.PaintingStyle? style) {
     context.beginPath();
     final ui.Rect? shaderBounds = contextHandle._shaderBounds;
-    final double cx = shaderBounds == null ? rect.center.dx :
-        rect.center.dx - shaderBounds.left;
-    final double cy = shaderBounds == null ? rect.center.dy :
-        rect.center.dy - shaderBounds.top;
-    drawEllipse(context, cx, cy, rect.width / 2,
-        rect.height / 2, 0, 0, 2.0 * math.pi, false);
+    final double cx = shaderBounds == null ? rect.center.dx : rect.center.dx - shaderBounds.left;
+    final double cy = shaderBounds == null ? rect.center.dy : rect.center.dy - shaderBounds.top;
+    drawEllipse(context, cx, cy, rect.width / 2, rect.height / 2, 0, 0, 2.0 * math.pi, false);
     contextHandle.paint(style);
   }
 
@@ -737,15 +752,17 @@ class CanvasPool extends _SaveStackTracking {
     if (shaderBounds == null) {
       _runPath(context, path as SurfacePath);
     } else {
-      _runPathWithOffset(context, path as SurfacePath,
-          -shaderBounds.left, -shaderBounds.top);
+      _runPathWithOffset(context, path as SurfacePath, -shaderBounds.left, -shaderBounds.top);
     }
     contextHandle.paintPath(style, path.fillType);
   }
 
+  void drawImage(DomHTMLImageElement element, ui.Offset p) {
+    context.drawImage(element, p.dx, p.dy);
+  }
+
   /// Draws a shadow for a Path representing the given material elevation.
-  void drawShadow(ui.Path path, ui.Color color, double elevation,
-      bool transparentOccluder) {
+  void drawShadow(ui.Path path, ui.Color color, double elevation, bool transparentOccluder) {
     final SurfaceShadowData? shadow = computeShadow(path.getBounds(), elevation);
     if (shadow != null) {
       // On April 2020 Web canvas 2D did not support shadow color alpha. So
@@ -764,7 +781,7 @@ class CanvasPool extends _SaveStackTracking {
 
       // TODO(hterkelsen): Shadows with transparent occluders are not supported
       // on webkit since filter is unsupported.
-      if (transparentOccluder && browserEngine != BrowserEngine.webkit) {
+      if (transparentOccluder && ui_web.browser.browserEngine != ui_web.BrowserEngine.webkit) {
         // We paint shadows using a path and a mask filter instead of the
         // built-in shadow* properties. This is because the color alpha of the
         // paint is added to the shadow. The effect we're looking for is to just
@@ -773,7 +790,8 @@ class CanvasPool extends _SaveStackTracking {
         // which is undesirable.
         context.translate(shadow.offset.dx, shadow.offset.dy);
         context.filter = maskFilterToCanvasFilter(
-            ui.MaskFilter.blur(ui.BlurStyle.normal, shadow.blurWidth));
+          ui.MaskFilter.blur(ui.BlurStyle.normal, shadow.blurWidth),
+        );
         context.strokeStyle = '';
         context.fillStyle = solidColor;
       } else {
@@ -818,7 +836,7 @@ class CanvasPool extends _SaveStackTracking {
     // towards the threshold. Setting width and height to zero tricks Webkit
     // into thinking that this canvas has a zero size so it doesn't count it
     // towards the threshold.
-    if (browserEngine == BrowserEngine.webkit && _canvas != null) {
+    if (ui_web.browser.browserEngine == ui_web.BrowserEngine.webkit && _canvas != null) {
       _canvas!.width = _canvas!.height = 0;
     }
     _clearActiveCanvasList();
@@ -826,8 +844,8 @@ class CanvasPool extends _SaveStackTracking {
 
   void _clearActiveCanvasList() {
     if (_activeCanvasList != null) {
-      for (final html.CanvasElement c in _activeCanvasList!) {
-        if (browserEngine == BrowserEngine.webkit) {
+      for (final DomCanvasElement c in _activeCanvasList!) {
+        if (ui_web.browser.browserEngine == ui_web.BrowserEngine.webkit) {
           c.width = c.height = 0;
         }
         c.remove();
@@ -842,14 +860,15 @@ class CanvasPool extends _SaveStackTracking {
 /// See https://www.w3.org/TR/2dcontext/ for defaults used in this class
 /// to initialize current values.
 class ContextStateHandle {
-  /// Associated canvas element context tracked by this context state.
-  final html.CanvasRenderingContext2D context;
-  final CanvasPool _canvasPool;
-  /// Dpi of context.
-  final double density;
-
   /// Initializes context state for a [CanvasPool].
   ContextStateHandle(this._canvasPool, this.context, this.density);
+
+  /// Associated canvas element context tracked by this context state.
+  final DomCanvasRenderingContext2D context;
+  final CanvasPool _canvasPool;
+
+  /// Dpi of context.
+  final double density;
   ui.BlendMode? _currentBlendMode = ui.BlendMode.srcOver;
   ui.StrokeCap? _currentStrokeCap = ui.StrokeCap.butt;
   ui.StrokeJoin? _currentStrokeJoin = ui.StrokeJoin.miter;
@@ -859,16 +878,15 @@ class ContextStateHandle {
   Object? _currentStrokeStyle;
   double _currentLineWidth = 1.0;
 
-  /// See [html.CanvasRenderingContext2D].
+  /// See [DomCanvasRenderingContext2D].
   set blendMode(ui.BlendMode? blendMode) {
     if (blendMode != _currentBlendMode) {
       _currentBlendMode = blendMode;
-      context.globalCompositeOperation =
-          blendModeToCssMixBlendMode(blendMode) ?? 'source-over';
+      context.globalCompositeOperation = blendModeToCssMixBlendMode(blendMode) ?? 'source-over';
     }
   }
 
-  /// See [html.CanvasRenderingContext2D].
+  /// See [DomCanvasRenderingContext2D].
   set strokeCap(ui.StrokeCap? strokeCap) {
     strokeCap ??= ui.StrokeCap.butt;
     if (strokeCap != _currentStrokeCap) {
@@ -877,7 +895,7 @@ class ContextStateHandle {
     }
   }
 
-  /// See [html.CanvasRenderingContext2D].
+  /// See [DomCanvasRenderingContext2D].
   set lineWidth(double lineWidth) {
     if (lineWidth != _currentLineWidth) {
       _currentLineWidth = lineWidth;
@@ -885,7 +903,7 @@ class ContextStateHandle {
     }
   }
 
-  /// See [html.CanvasRenderingContext2D].
+  /// See [DomCanvasRenderingContext2D].
   set strokeJoin(ui.StrokeJoin? strokeJoin) {
     strokeJoin ??= ui.StrokeJoin.miter;
     if (strokeJoin != _currentStrokeJoin) {
@@ -894,7 +912,7 @@ class ContextStateHandle {
     }
   }
 
-  /// See [html.CanvasRenderingContext2D].
+  /// See [DomCanvasRenderingContext2D].
   set fillStyle(Object? colorOrGradient) {
     if (!identical(colorOrGradient, _currentFillStyle)) {
       _currentFillStyle = colorOrGradient;
@@ -902,7 +920,7 @@ class ContextStateHandle {
     }
   }
 
-  /// See [html.CanvasRenderingContext2D].
+  /// See [DomCanvasRenderingContext2D].
   set strokeStyle(Object? colorOrGradient) {
     if (!identical(colorOrGradient, _currentStrokeStyle)) {
       _currentStrokeStyle = colorOrGradient;
@@ -932,16 +950,19 @@ class ContextStateHandle {
   /// This is used in screenshot tests to test Safari codepaths.
   static bool debugEmulateWebKitMaskFilter = false;
 
-  bool get _renderMaskFilterForWebkit => browserEngine == BrowserEngine.webkit || debugEmulateWebKitMaskFilter;
+  bool get _renderMaskFilterForWebkit =>
+      ui_web.browser.browserEngine == ui_web.BrowserEngine.webkit || debugEmulateWebKitMaskFilter;
 
   /// Sets paint properties on the current canvas.
   ///
   /// [tearDownPaint] must be called after calling this method.
   void setUpPaint(SurfacePaintData paint, ui.Rect? shaderBounds) {
-    if (assertionsEnabled) {
-      assert(!_debugIsPaintSetUp);
+    assert(() {
+      final bool wasPaintSetUp = _debugIsPaintSetUp;
       _debugIsPaintSetUp = true;
-    }
+      // When setting up paint, the previous paint must be torn down.
+      return !wasPaintSetUp;
+    }());
 
     _lastUsedPaint = paint;
     lineWidth = paint.strokeWidth ?? 1.0;
@@ -952,9 +973,11 @@ class ContextStateHandle {
     if (paint.shader != null) {
       if (paint.shader is EngineGradient) {
         final EngineGradient engineShader = paint.shader! as EngineGradient;
-        final Object paintStyle =
-            engineShader.createPaintStyle(_canvasPool.context, shaderBounds,
-                density);
+        final Object paintStyle = engineShader.createPaintStyle(
+          _canvasPool.context,
+          shaderBounds,
+          density,
+        );
         fillStyle = paintStyle;
         strokeStyle = paintStyle;
         _shaderBounds = shaderBounds;
@@ -962,9 +985,11 @@ class ContextStateHandle {
         context.translate(shaderBounds!.left, shaderBounds.top);
       } else if (paint.shader is EngineImageShader) {
         final EngineImageShader imageShader = paint.shader! as EngineImageShader;
-        final Object paintStyle =
-            imageShader.createPaintStyle(_canvasPool.context, shaderBounds,
-                density);
+        final Object paintStyle = imageShader.createPaintStyle(
+          _canvasPool.context,
+          shaderBounds,
+          density,
+        );
         fillStyle = paintStyle;
         strokeStyle = paintStyle;
         if (imageShader.requiresTileOffset) {
@@ -973,13 +998,10 @@ class ContextStateHandle {
           context.translate(shaderBounds!.left, shaderBounds.top);
         }
       }
-    } else if (paint.color != null) {
-      final String? colorString = colorToCssString(paint.color);
+    } else {
+      final String colorString = colorValueToCssString(paint.color);
       fillStyle = colorString;
       strokeStyle = colorString;
-    } else {
-      fillStyle = '#000000';
-      strokeStyle = '#000000';
     }
 
     final ui.MaskFilter? maskFilter = paint.maskFilter;
@@ -998,12 +1020,8 @@ class ContextStateHandle {
       if (maskFilter != null) {
         context.save();
         context.shadowBlur = convertSigmaToRadius(maskFilter.webOnlySigma);
-        if (paint.color != null) {
-          // Shadow color must be fully opaque.
-          context.shadowColor = colorToCssString(paint.color!.withAlpha(255))!;
-        } else {
-          context.shadowColor = colorToCssString(const ui.Color(0xFF000000))!;
-        }
+        // Shadow color must be fully opaque.
+        context.shadowColor = ui.Color(paint.color).withAlpha(255).toCssString();
 
         // On the web a shadow must always be painted together with the shape
         // that casts it. In order to paint just the shadow, we offset the shape
@@ -1022,7 +1040,7 @@ class ContextStateHandle {
         //
         // transformedShadowDelta = M*shadowDelta - M*origin.
         final Float32List tempVector = Float32List(2);
-        tempVector[0] = kOutsideTheBoundsOffset * window.devicePixelRatio;
+        tempVector[0] = kOutsideTheBoundsOffset * EngineFlutterDisplay.instance.devicePixelRatio;
         _canvasPool.currentTransform.transform2(tempVector);
         final double shadowOffsetX = tempVector[0];
         final double shadowOffsetY = tempVector[1];
@@ -1043,10 +1061,12 @@ class ContextStateHandle {
   ///
   /// Must be called after calling [setUpPaint].
   void tearDownPaint() {
-    if (assertionsEnabled) {
-      assert(_debugIsPaintSetUp);
+    assert(() {
+      final bool wasPaintSetUp = _debugIsPaintSetUp;
       _debugIsPaintSetUp = false;
-    }
+      // When tearing down paint, we expect that it was set up before.
+      return wasPaintSetUp;
+    }());
 
     final ui.MaskFilter? maskFilter = _lastUsedPaint?.maskFilter;
     if (maskFilter != null && _renderMaskFilterForWebkit) {
@@ -1084,7 +1104,7 @@ class ContextStateHandle {
   }
 
   /// Resets drawing context state to defaults for
-  /// [html.CanvasRenderingContext2D].
+  /// [DomCanvasRenderingContext2D].
   void reset() {
     context.fillStyle = '';
     // Read back fillStyle/strokeStyle values from context so that input such
@@ -1112,9 +1132,6 @@ class ContextStateHandle {
 /// Provides save stack tracking functionality to implementations of
 /// [EngineCanvas].
 class _SaveStackTracking {
-  // !Warning: this vector should not be mutated.
-  static final Vector3 _unitZ = Vector3(0.0, 0.0, 1.0);
-
   final List<SaveStackEntry> _saveStack = <SaveStackEntry>[];
 
   /// The stack that maintains clipping operations used when text is painted
@@ -1140,11 +1157,12 @@ class _SaveStackTracking {
   /// Saves current clip and transform on the save stack.
   
   void save() {
-    _saveStack.add(SaveStackEntry(
-      transform: _currentTransform.clone(),
-      clipStack:
-          clipStack == null ? null : List<SaveClipEntry>.from(clipStack!),
-    ));
+    _saveStack.add(
+      SaveStackEntry(
+        transform: _currentTransform.clone(),
+        clipStack: clipStack == null ? null : List<SaveClipEntry>.from(clipStack!),
+      ),
+    );
   }
 
   /// Restores current clip and transform from the save stack.
@@ -1173,7 +1191,7 @@ class _SaveStackTracking {
   /// Rotates the [currentTransform] matrix.
   
   void rotate(double radians) {
-    _currentTransform.rotate(_unitZ, radians);
+    _currentTransform.rotate(kUnitZ, radians);
   }
 
   /// Skews the [currentTransform] matrix.
