@@ -38,8 +38,7 @@ class SurfaceFrame {
 /// created.
 class Surface extends DisplayCanvas {
   Surface({this.isDisplayCanvas = false})
-      : useOffscreenCanvas =
-            Surface.offscreenCanvasSupported && !isDisplayCanvas;
+    : useOffscreenCanvas = Surface.offscreenCanvasSupported && !isDisplayCanvas;
 
   CkSurface? _surface;
 
@@ -58,6 +57,10 @@ class Surface extends DisplayCanvas {
   bool _contextLost = false;
   bool get debugContextLost => _contextLost;
 
+  /// Forces AssertionError when attempting to create a CPU-based surface.
+  /// Only for tests.
+  bool debugThrowOnSoftwareSurfaceCreation = false;
+
   /// A cached copy of the most recently created `webglcontextlost` listener.
   ///
   /// We must cache this function because each time we access the tear-off it
@@ -81,7 +84,17 @@ class Surface extends DisplayCanvas {
   DomOffscreenCanvas? _offscreenCanvas;
 
   /// Returns the underlying OffscreenCanvas. Should only be used in tests.
-  DomOffscreenCanvas? get debugOffscreenCanvas => _offscreenCanvas;
+  DomOffscreenCanvas? debugGetOffscreenCanvas() {
+    bool assertsEnabled = false;
+    assert(() {
+      assertsEnabled = true;
+      return true;
+    }());
+    if (!assertsEnabled) {
+      throw StateError('debugGetOffscreenCanvas() can only be used in tests');
+    }
+    return _offscreenCanvas;
+  }
 
   /// The <canvas> backing this Surface in the case that OffscreenCanvas isn't
   /// supported.
@@ -119,8 +132,11 @@ class Surface extends DisplayCanvas {
     _surface!.flush();
   }
 
-  Future<void> rasterizeToCanvas(BitmapSize bitmapSize, RenderCanvas canvas,
-      List<CkPicture> pictures) async {
+  Future<void> rasterizeToCanvas(
+    BitmapSize bitmapSize,
+    RenderCanvas canvas,
+    List<CkPicture> pictures,
+  ) async {
     final CkCanvas skCanvas = getCanvas();
     skCanvas.clear(const ui.Color(0x00000000));
     pictures.forEach(skCanvas.drawPicture);
@@ -128,17 +144,18 @@ class Surface extends DisplayCanvas {
 
     if (browserSupportsCreateImageBitmap) {
       JSObject bitmapSource;
+      DomImageBitmap bitmap;
       if (useOffscreenCanvas) {
-        bitmapSource = _offscreenCanvas! as JSObject;
+        bitmap = _offscreenCanvas!.transferToImageBitmap();
       } else {
         bitmapSource = _canvasElement! as JSObject;
+        bitmap = await createImageBitmap(bitmapSource, (
+          x: 0,
+          y: _pixelHeight - bitmapSize.height,
+          width: bitmapSize.width,
+          height: bitmapSize.height,
+        ));
       }
-      final DomImageBitmap bitmap = await createImageBitmap(bitmapSource, (
-        x: 0,
-        y: _pixelHeight - bitmapSize.height,
-        width: bitmapSize.width,
-        height: bitmapSize.height,
-      ));
       canvas.render(bitmap);
     } else {
       // If the browser doesn't support `createImageBitmap` (e.g. Safari 14)
@@ -160,8 +177,7 @@ class Surface extends DisplayCanvas {
     final CkSurface surface = createOrUpdateSurface(BitmapSize.fromSize(size));
 
     // ignore: prefer_function_declarations_over_variables
-    final SubmitCallback submitCallback =
-        (SurfaceFrame surfaceFrame, CkCanvas canvas) {
+    final SubmitCallback submitCallback = (SurfaceFrame surfaceFrame, CkCanvas canvas) {
       return _presentSurface();
     };
 
@@ -169,13 +185,11 @@ class Surface extends DisplayCanvas {
   }
 
   BitmapSize? _currentCanvasPhysicalSize;
-  BitmapSize? _currentSurfaceSize;
 
   /// Sets the CSS size of the canvas so that canvas pixels are 1:1 with device
   /// pixels.
   void _updateLogicalHtmlCanvasSize() {
-    final double devicePixelRatio =
-        EngineFlutterDisplay.instance.devicePixelRatio;
+    final double devicePixelRatio = EngineFlutterDisplay.instance.devicePixelRatio;
     final double logicalWidth = _pixelWidth / devicePixelRatio;
     final double logicalHeight = _pixelHeight / devicePixelRatio;
     final DomCSSStyleDeclaration style = _canvasElement!.style;
@@ -190,16 +204,13 @@ class Surface extends DisplayCanvas {
   /// the top left of the window. We need to shift the canvas down so that the
   /// bottom left of the <canvas> is the the bottom left corner of the window.
   void positionToShowFrame(BitmapSize frameSize) {
-    assert(isDisplayCanvas,
-        'Should not position Surface if not used as a render canvas');
-    final double devicePixelRatio =
-        EngineFlutterDisplay.instance.devicePixelRatio;
+    assert(isDisplayCanvas, 'Should not position Surface if not used as a render canvas');
+    final double devicePixelRatio = EngineFlutterDisplay.instance.devicePixelRatio;
     final double logicalHeight = _pixelHeight / devicePixelRatio;
     final double logicalFrameHeight = frameSize.height / devicePixelRatio;
 
     // Shift the canvas up so the bottom left is in the window.
-    _canvasElement!.style.transform =
-        'translate(0px, ${logicalFrameHeight - logicalHeight}px)';
+    _canvasElement!.style.transform = 'translate(0px, ${logicalFrameHeight - logicalHeight}px)';
   }
 
   /// This is only valid after the first frame or if [ensureSurface] has been
@@ -224,7 +235,8 @@ class Surface extends DisplayCanvas {
     }
     // TODO(jonahwilliams): this is somewhat wasteful. We should probably
     // eagerly setup this surface instead of delaying until the first frame?
-    // Or at least cache the estimated window sizeThis is the first frame we have rendered with this canvas.
+    // Or at least cache the estimated window size.
+    // This is the first frame we have rendered with this canvas.
     createOrUpdateSurface(size);
   }
 
@@ -237,29 +249,24 @@ class Surface extends DisplayCanvas {
     if (!_forceNewContext) {
       // Check if the window is the same size as before, and if so, don't allocate
       // a new canvas as the previous canvas is big enough to fit everything.
-      final BitmapSize? previousSurfaceSize = _currentSurfaceSize;
+      final BitmapSize? previousSurfaceSize = _surface?._size;
       if (previousSurfaceSize != null &&
           size.width == previousSurfaceSize.width &&
           size.height == previousSurfaceSize.height) {
-        final double devicePixelRatio =
-            EngineFlutterDisplay.instance.devicePixelRatio;
+        final double devicePixelRatio = EngineFlutterDisplay.instance.devicePixelRatio;
         if (isDisplayCanvas && devicePixelRatio != _currentDevicePixelRatio) {
           _updateLogicalHtmlCanvasSize();
         }
         return _surface!;
       }
 
-      final BitmapSize? previousCanvasSize = _currentCanvasPhysicalSize;
-      // Initialize a new, larger, canvas. If the size is growing, then make the
-      // new canvas larger than required to avoid many canvas creations.
-      if (previousCanvasSize != null &&
-          (size.width > previousCanvasSize.width ||
-              size.height > previousCanvasSize.height)) {
-        final BitmapSize newSize = BitmapSize.fromSize(size.toSize() * 1.4);
+      if (_currentCanvasPhysicalSize != null &&
+          (size.width != _currentCanvasPhysicalSize!.width ||
+              size.height != _currentCanvasPhysicalSize!.height)) {
         _surface?.dispose();
         _surface = null;
-        _pixelWidth = newSize.width;
-        _pixelHeight = newSize.height;
+        _pixelWidth = size.width;
+        _pixelHeight = size.height;
         if (useOffscreenCanvas) {
           _offscreenCanvas!.width = _pixelWidth.toDouble();
           _offscreenCanvas!.height = _pixelHeight.toDouble();
@@ -274,10 +281,14 @@ class Surface extends DisplayCanvas {
       }
     }
 
+    // If we reached here, then either we are forcing a new context, or
+    // the size of the surface has changed so we need to make a new one.
+
+    _surface?.dispose();
+    _surface = null;
+
     // Either a new context is being forced or we've never had one.
     if (_forceNewContext || _currentCanvasPhysicalSize == null) {
-      _surface?.dispose();
-      _surface = null;
       _grContext?.releaseResourcesAndAbandonContext();
       _grContext?.delete();
       _grContext = null;
@@ -286,17 +297,15 @@ class Surface extends DisplayCanvas {
       _currentCanvasPhysicalSize = size;
     }
 
-    _currentSurfaceSize = size;
-    _surface?.dispose();
-    _surface = _createNewSurface(size);
-    return _surface!;
+    return _surface = _createNewSurface(size);
   }
 
   JSVoid _contextRestoredListener(DomEvent event) {
     assert(
-        _contextLost,
-        'Received "webglcontextrestored" event but never received '
-        'a "webglcontextlost" event.');
+      _contextLost,
+      'Received "webglcontextrestored" event but never received '
+      'a "webglcontextlost" event.',
+    );
     _contextLost = false;
     // Force the framework to rerender the frame.
     EnginePlatformDispatcher.instance.invokeOnMetricsChanged();
@@ -305,8 +314,10 @@ class Surface extends DisplayCanvas {
   }
 
   JSVoid _contextLostListener(DomEvent event) {
-    assert(event.target == _offscreenCanvas || event.target == _canvasElement,
-        'Received a context lost event for a disposed canvas');
+    assert(
+      event.target == _offscreenCanvas || event.target == _canvasElement,
+      'Received a context lost event for a disposed canvas',
+    );
     _contextLost = true;
     _forceNewContext = true;
     event.preventDefault();
@@ -323,11 +334,7 @@ class Surface extends DisplayCanvas {
         _cachedContextRestoredListener,
         false,
       );
-      _offscreenCanvas!.removeEventListener(
-        'webglcontextlost',
-        _cachedContextLostListener,
-        false,
-      );
+      _offscreenCanvas!.removeEventListener('webglcontextlost', _cachedContextLostListener, false);
       _offscreenCanvas = null;
       _cachedContextRestoredListener = null;
       _cachedContextLostListener = null;
@@ -337,11 +344,7 @@ class Surface extends DisplayCanvas {
         _cachedContextRestoredListener,
         false,
       );
-      _canvasElement!.removeEventListener(
-        'webglcontextlost',
-        _cachedContextLostListener,
-        false,
-      );
+      _canvasElement!.removeEventListener('webglcontextlost', _cachedContextLostListener, false);
       _canvasElement!.remove();
       _canvasElement = null;
       _cachedContextRestoredListener = null;
@@ -362,8 +365,10 @@ class Surface extends DisplayCanvas {
       _offscreenCanvas = offscreenCanvas;
       _canvasElement = null;
     } else {
-      final DomCanvasElement canvas =
-          createDomCanvasElement(width: _pixelWidth, height: _pixelHeight);
+      final DomCanvasElement canvas = createDomCanvasElement(
+        width: _pixelWidth,
+        height: _pixelHeight,
+      );
       htmlCanvas = canvas;
       _canvasElement = canvas;
       _offscreenCanvas = null;
@@ -381,19 +386,10 @@ class Surface extends DisplayCanvas {
     // notification. When we receive this notification we force a new context.
     //
     // See also: https://www.khronos.org/webgl/wiki/HandlingContextLost
-    _cachedContextRestoredListener =
-        createDomEventListener(_contextRestoredListener);
+    _cachedContextRestoredListener = createDomEventListener(_contextRestoredListener);
     _cachedContextLostListener = createDomEventListener(_contextLostListener);
-    htmlCanvas.addEventListener(
-      'webglcontextlost',
-      _cachedContextLostListener,
-      false,
-    );
-    htmlCanvas.addEventListener(
-      'webglcontextrestored',
-      _cachedContextRestoredListener,
-      false,
-    );
+    htmlCanvas.addEventListener('webglcontextlost', _cachedContextLostListener, false);
+    htmlCanvas.addEventListener('webglcontextrestored', _cachedContextRestoredListener, false);
     _forceNewContext = false;
     _contextLost = false;
 
@@ -406,15 +402,9 @@ class Surface extends DisplayCanvas {
         majorVersion: webGLVersion.toDouble(),
       );
       if (useOffscreenCanvas) {
-        glContext = canvasKit.GetOffscreenWebGLContext(
-          _offscreenCanvas!,
-          options,
-        ).toInt();
+        glContext = canvasKit.GetOffscreenWebGLContext(_offscreenCanvas!, options).toInt();
       } else {
-        glContext = canvasKit.GetWebGLContext(
-          _canvasElement!,
-          options,
-        ).toInt();
+        glContext = canvasKit.GetWebGLContext(_canvasElement!, options).toInt();
       }
 
       _glContext = glContext;
@@ -422,8 +412,10 @@ class Surface extends DisplayCanvas {
       if (_glContext != 0) {
         _grContext = canvasKit.MakeGrContext(glContext.toDouble());
         if (_grContext == null) {
-          throw CanvasKitError('Failed to initialize CanvasKit. '
-              'CanvasKit.MakeGrContext returned null.');
+          throw CanvasKitError(
+            'Failed to initialize CanvasKit. '
+            'CanvasKit.MakeGrContext returned null.',
+          );
         }
         if (_sampleCount == -1 || _stencilBits == -1) {
           _initWebglParams();
@@ -449,46 +441,50 @@ class Surface extends DisplayCanvas {
   CkSurface _createNewSurface(BitmapSize size) {
     assert(_offscreenCanvas != null || _canvasElement != null);
     if (webGLVersion == -1) {
-      return _makeSoftwareCanvasSurface('WebGL support not detected');
+      return _makeSoftwareCanvasSurface('WebGL support not detected', size);
     } else if (configuration.canvasKitForceCpuOnly) {
-      return _makeSoftwareCanvasSurface('CPU rendering forced by application');
+      return _makeSoftwareCanvasSurface('CPU rendering forced by application', size);
     } else if (_glContext == 0) {
-      return _makeSoftwareCanvasSurface('Failed to initialize WebGL context');
+      return _makeSoftwareCanvasSurface('Failed to initialize WebGL context', size);
     } else {
       final SkSurface? skSurface = canvasKit.MakeOnScreenGLSurface(
-          _grContext!,
-          size.width.toDouble(),
-          size.height.toDouble(),
-          SkColorSpaceSRGB,
-          _sampleCount,
-          _stencilBits);
+        _grContext!,
+        size.width.toDouble(),
+        size.height.toDouble(),
+        SkColorSpaceSRGB,
+        _sampleCount,
+        _stencilBits,
+      );
 
       if (skSurface == null) {
-        return _makeSoftwareCanvasSurface('Failed to initialize WebGL surface');
+        return _makeSoftwareCanvasSurface('Failed to initialize WebGL surface', size);
       }
 
-      return CkSurface(skSurface, _glContext);
+      return CkSurface(skSurface, _glContext, size);
     }
   }
 
   static bool _didWarnAboutWebGlInitializationFailure = false;
 
-  CkSurface _makeSoftwareCanvasSurface(String reason) {
+  CkSurface _makeSoftwareCanvasSurface(String reason, BitmapSize size) {
     if (!_didWarnAboutWebGlInitializationFailure) {
       printWarning('WARNING: Falling back to CPU-only rendering. $reason.');
       _didWarnAboutWebGlInitializationFailure = true;
     }
 
-    SkSurface surface;
-    if (useOffscreenCanvas) {
-      surface = canvasKit.MakeOffscreenSWCanvasSurface(_offscreenCanvas!);
-    } else {
-      surface = canvasKit.MakeSWCanvasSurface(_canvasElement!);
+    try {
+      assert(!debugThrowOnSoftwareSurfaceCreation);
+
+      SkSurface surface;
+      if (useOffscreenCanvas) {
+        surface = canvasKit.MakeOffscreenSWCanvasSurface(_offscreenCanvas!);
+      } else {
+        surface = canvasKit.MakeSWCanvasSurface(_canvasElement!);
+      }
+      return CkSurface(surface, null, size);
+    } catch (error) {
+      throw CanvasKitError('Failed to create CPU-based surface: $error.');
     }
-    return CkSurface(
-      surface,
-      null,
-    );
   }
 
   bool _presentSurface() {
@@ -506,10 +502,12 @@ class Surface extends DisplayCanvas {
 
   @override
   void dispose() {
+    _offscreenCanvas?.removeEventListener('webglcontextlost', _cachedContextLostListener, false);
     _offscreenCanvas?.removeEventListener(
-        'webglcontextlost', _cachedContextLostListener, false);
-    _offscreenCanvas?.removeEventListener(
-        'webglcontextrestored', _cachedContextRestoredListener, false);
+      'webglcontextrestored',
+      _cachedContextRestoredListener,
+      false,
+    );
     _cachedContextLostListener = null;
     _cachedContextRestoredListener = null;
     _surface?.dispose();
@@ -517,13 +515,12 @@ class Surface extends DisplayCanvas {
 
   /// Safari 15 doesn't support OffscreenCanvas at all. Safari 16 supports
   /// OffscreenCanvas, but only with the context2d API, not WebGL.
-  static bool get offscreenCanvasSupported =>
-      browserSupportsOffscreenCanvas && !isSafari;
+  static bool get offscreenCanvasSupported => browserSupportsOffscreenCanvas && !isSafari;
 }
 
-/// A Dart wrapper around Skia's CkSurface.
+/// A Dart wrapper around Skia's SkSurface.
 class CkSurface {
-  CkSurface(this.surface, this._glContext);
+  CkSurface(this.surface, this._glContext, this._size);
 
   CkCanvas getCanvas() {
     assert(!_isDisposed, 'Attempting to use the canvas of a disposed surface');
@@ -536,6 +533,8 @@ class CkSurface {
   /// at any moment. Storing it may lead to dangling pointer bugs.
   final SkSurface surface;
 
+  final BitmapSize _size;
+
   final int? _glContext;
 
   /// Flushes the graphics to be rendered on screen.
