@@ -113,9 +113,14 @@ class RawKeyboard {
         _lastMetaState |= modifierNumLock;
       } else if (event.key == 'ScrollLock') {
         _lastMetaState |= modifierScrollLock;
-      } else if (event.key == 'Meta' && operatingSystem == OperatingSystem.linux) {
+      } else if (event.key == 'Meta' &&
+          ui_web.browser.operatingSystem == ui_web.OperatingSystem.linux) {
         // On Chrome Linux, metaState can be wrong when a Meta key is pressed.
         _lastMetaState |= _modifierMeta;
+      } else if (event.code == 'MetaLeft' && event.key == 'Process') {
+        // When Meta key is pressed, browsers can emit an event whose key is 'Process'.
+        // See https://github.com/flutter/flutter/issues/141186.
+        _lastMetaState |= _modifierMeta;
       }
     }
     final Map<String, dynamic> eventData = <String, dynamic>{
@@ -128,12 +133,15 @@ class RawKeyboard {
       'keyCode': event.keyCode,
     };
 
-    EnginePlatformDispatcher.instance.invokeOnPlatformMessage('flutter/keyevent',
-      _messageCodec.encodeMessage(eventData), (ByteData? data) {
+    EnginePlatformDispatcher.instance.invokeOnPlatformMessage(
+      'flutter/keyevent',
+      _messageCodec.encodeMessage(eventData),
+      (ByteData? data) {
         if (data == null) {
           return;
         }
-        final Map<String, dynamic> jsonResponse = _messageCodec.decodeMessage(data) as Map<String, dynamic>;
+        final Map<String, dynamic> jsonResponse =
+            _messageCodec.decodeMessage(data) as Map<String, dynamic>;
         if (jsonResponse['handled'] as bool) {
           // If the framework handled it, then don't propagate it any further.
           event.preventDefault();
@@ -154,8 +162,11 @@ class RawKeyboard {
       'keyCode': event.keyCode,
     };
 
-    EnginePlatformDispatcher.instance.invokeOnPlatformMessage('flutter/keyevent',
-        _messageCodec.encodeMessage(eventData), _noopCallback);
+    EnginePlatformDispatcher.instance.invokeOnPlatformMessage(
+      'flutter/keyevent',
+      _messageCodec.encodeMessage(eventData),
+      _noopCallback,
+    );
   }
 
   /// After a keydown is received, this is the duration we wait for a repeat event
