@@ -2,6 +2,7 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
+import 'dart:ffi';
 import 'dart:io';
 
 import 'package:path/path.dart' as path;
@@ -35,6 +36,7 @@ class PluginTest {
     this.dartOnlyPlugin = false,
     this.sharedDarwinSource = false,
     this.template = 'plugin',
+    this.cocoapodsTransitiveFlutterDependency = false,
   });
 
   final String buildTarget;
@@ -44,10 +46,10 @@ class PluginTest {
   final bool dartOnlyPlugin;
   final bool sharedDarwinSource;
   final String template;
+  final bool cocoapodsTransitiveFlutterDependency;
 
   Future<TaskResult> call() async {
-    final Directory tempDir =
-        Directory.systemTemp.createTempSync('flutter_devicelab_plugin_test.');
+    final Directory tempDir = Directory.systemTemp.createTempSync('flutter_devicelab_plugin_test.');
     // FFI plugins do not have support for `flutter test`.
     // `flutter test` does not do a native build.
     // Supporting `flutter test` would require invoking a native build.
@@ -55,8 +57,13 @@ class PluginTest {
     try {
       section('Create plugin');
       final _FlutterProject plugin = await _FlutterProject.create(
-          tempDir, options, buildTarget,
-          name: 'plugintest', template: template, environment: pluginCreateEnvironment);
+        tempDir,
+        options,
+        buildTarget,
+        name: 'plugintest',
+        template: template,
+        environment: pluginCreateEnvironment,
+      );
       if (dartOnlyPlugin) {
         await plugin.convertDefaultPluginToDartPlugin();
       }
@@ -71,15 +78,30 @@ class PluginTest {
         }
       }
       section('Create Flutter app');
-      final _FlutterProject app = await _FlutterProject.create(tempDir, options, buildTarget,
-          name: 'plugintestapp', template: 'app', environment: appCreateEnvironment);
+      final _FlutterProject app = await _FlutterProject.create(
+        tempDir,
+        options,
+        buildTarget,
+        name: 'plugintestapp',
+        template: 'app',
+        environment: appCreateEnvironment,
+      );
       try {
+        if (cocoapodsTransitiveFlutterDependency) {
+          section('Disable Swift Package Manager');
+          await app.disableSwiftPackageManager();
+        }
+
         section('Add plugins');
-        await app.addPlugin('plugintest',
-            pluginPath: path.join('..', 'plugintest'));
+        await app.addPlugin('plugintest', pluginPath: path.join('..', 'plugintest'));
         await app.addPlugin('path_provider');
         section('Build app');
         await app.build(buildTarget, validateNativeBuildProject: !dartOnlyPlugin);
+        if (cocoapodsTransitiveFlutterDependency) {
+          section('Test app with Flutter as a transitive CocoaPods dependency');
+          await app.addCocoapodsTransitiveFlutterDependency();
+          await app.build(buildTarget, validateNativeBuildProject: !dartOnlyPlugin);
+        }
         if (runFlutterTest) {
           section('Test app');
           await app.runFlutterTest();
@@ -102,7 +124,10 @@ class PluginTest {
     }
   }
 
-  Future<void> _testLocalEngineConfiguration(_FlutterProject app, String fakeEngineSourcePath) async {
+  Future<void> _testLocalEngineConfiguration(
+    _FlutterProject app,
+    String fakeEngineSourcePath,
+  ) async {
     // The tool requires that a directory that looks like an engine build
     // actually exists when passing --local-engine, so create a fake skeleton.
     final Directory buildDir = Directory(path.join(fakeEngineSourcePath, 'out', 'foo'));
@@ -110,6 +135,12 @@ class PluginTest {
     // Currently this test is only implemented for macOS; it can be extended to
     // others as needed.
     if (buildTarget == 'macos') {
+      // When using a local engine, podhelper.rb will search for a "macos-"
+      // directory within the FlutterMacOS.xcframework, so create a dummy one.
+      Directory(
+        path.join(buildDir.path, 'FlutterMacOS.xcframework/macos-arm64_x86_64'),
+      ).createSync(recursive: true);
+
       // Clean before regenerating the config to ensure that the pod steps run.
       await inDirectory(Directory(app.rootPath), () async {
         await evalFlutter('clean');
@@ -133,15 +164,25 @@ class _FlutterProject {
     return _FlutterProject(Directory(path.join(rootPath)), 'example');
   }
 
+  Future<void> disableSwiftPackageManager() async {
+    final File pubspec = pubspecFile;
+    String content = await pubspec.readAsString();
+    content = content.replaceFirst(
+      '# The following section is specific to Flutter packages.\n'
+          'flutter:\n',
+      '# The following section is specific to Flutter packages.\n'
+          'flutter:\n'
+          '\n'
+          '  disable-swift-package-manager: true\n',
+    );
+    await pubspec.writeAsString(content, flush: true);
+  }
+
   Future<void> addPlugin(String plugin, {String? pluginPath}) async {
     final File pubspec = pubspecFile;
     String content = await pubspec.readAsString();
-    final String dependency =
-        pluginPath != null ? '$plugin:\n    path: $pluginPath' : '$plugin:';
-    content = content.replaceFirst(
-      '\ndependencies:\n',
-      '\ndependencies:\n  $dependency\n',
-    );
+    final String dependency = pluginPath != null ? '$plugin:\n    path: $pluginPath' : '$plugin:';
+    content = content.replaceFirst('\ndependencies:\n', '\ndependencies:\n  $dependency\n');
     await pubspec.writeAsString(content, flush: true);
   }
 
@@ -171,13 +212,7 @@ class $dartPluginClass {
     await dartCode.writeAsString(content, flush: true);
 
     // Remove any native plugin code.
-    const List<String> platforms = <String>[
-      'android',
-      'ios',
-      'linux',
-      'macos',
-      'windows',
-    ];
+    const List<String> platforms = <String>['android', 'ios', 'linux', 'macos', 'windows'];
     for (final String platform in platforms) {
       final Directory platformDir = Directory(path.join(rootPath, platform));
       if (platformDir.existsSync()) {
@@ -199,12 +234,12 @@ class $dartPluginClass {
       throw TaskResult.failure('Missing expected darwin platform plugin keys');
     }
     pubspecContent = pubspecContent.replaceAll(
-        originalIOSKey,
-        '$originalIOSKey        sharedDarwinSource: true\n'
+      originalIOSKey,
+      '$originalIOSKey        sharedDarwinSource: true\n',
     );
     pubspecContent = pubspecContent.replaceAll(
-        originalMacOSKey,
-        '$originalMacOSKey        sharedDarwinSource: true\n'
+      originalMacOSKey,
+      '$originalMacOSKey        sharedDarwinSource: true\n',
     );
     await pubspec.writeAsString(pubspecContent, flush: true);
 
@@ -225,14 +260,22 @@ class $dartPluginClass {
 
     // Remove "s.platform = :ios" to work on all platforms, including macOS.
     podspecContent = podspecContent.replaceFirst(RegExp(r'.*s\.platform.*'), '');
-    podspecContent = podspecContent.replaceFirst("s.dependency 'Flutter'", "s.ios.dependency 'Flutter'\ns.osx.dependency 'FlutterMacOS'");
+    podspecContent = podspecContent.replaceFirst(
+      "s.dependency 'Flutter'",
+      "s.ios.dependency 'Flutter'\ns.osx.dependency 'FlutterMacOS'",
+    );
 
     await podspec.writeAsString(podspecContent, flush: true);
 
     // Make PlugintestPlugin.swift compile on iOS and macOS with target conditionals.
+    // If SwiftPM is disabled, the file will be in `darwin/Classes/`.
+    // Otherwise, the file will be in `darwin/<plugin>/Sources/<plugin>/`.
     final String pluginClass = '${name[0].toUpperCase()}${name.substring(1)}Plugin';
     print('pluginClass: $pluginClass');
-    final File pluginRegister = File(path.join(darwinDir.path, 'Classes', '$pluginClass.swift'));
+    File pluginRegister = File(path.join(darwinDir.path, 'Classes', '$pluginClass.swift'));
+    if (!pluginRegister.existsSync()) {
+      pluginRegister = File(path.join(darwinDir.path, name, 'Sources', name, '$pluginClass.swift'));
+    }
     final String pluginRegisterContent = '''
 #if os(macOS)
 import FlutterMacOS
@@ -277,11 +320,12 @@ public class $pluginClass: NSObject, FlutterPlugin {
     switch (buildTarget) {
       case 'apk':
         if (await exec(
-          path.join('.', 'gradlew'),
-          <String>['testDebugUnitTest'],
-          workingDirectory: path.join(rootPath, 'android'),
-          canFail: true,
-        ) != 0) {
+              path.join('.', 'gradlew'),
+              <String>['testDebugUnitTest'],
+              workingDirectory: path.join(rootPath, 'android'),
+              canFail: true,
+            ) !=
+            0) {
           throw TaskResult.failure('Platform unit tests failed');
         }
       case 'ios':
@@ -304,10 +348,20 @@ public class $pluginClass: NSObject, FlutterPlugin {
         }
       case 'linux':
         if (await exec(
-          path.join(rootPath, 'build', 'linux', 'x64', 'release', 'plugins', 'plugintest', 'plugintest_test'),
-          <String>[],
-          canFail: true,
-        ) != 0) {
+              path.join(
+                rootPath,
+                'build',
+                'linux',
+                'x64',
+                'release',
+                'plugins',
+                'plugintest',
+                'plugintest_test',
+              ),
+              <String>[],
+              canFail: true,
+            ) !=
+            0) {
           throw TaskResult.failure('Platform unit tests failed');
         }
       case 'macos':
@@ -321,25 +375,35 @@ public class $pluginClass: NSObject, FlutterPlugin {
           throw TaskResult.failure('Platform unit tests failed');
         }
       case 'windows':
+        final String arch = Abi.current() == Abi.windowsX64 ? 'x64' : 'arm64';
         if (await exec(
-          path.join(rootPath, 'build', 'windows', 'x64', 'plugins', 'plugintest', 'Release', 'plugintest_test.exe'),
-          <String>[],
-          canFail: true,
-        ) != 0) {
+              path.join(
+                rootPath,
+                'build',
+                'windows',
+                arch,
+                'plugins',
+                'plugintest',
+                'Release',
+                'plugintest_test.exe',
+              ),
+              <String>[],
+              canFail: true,
+            ) !=
+            0) {
           throw TaskResult.failure('Platform unit tests failed');
         }
     }
   }
 
   static Future<_FlutterProject> create(
-      Directory directory,
-      List<String> options,
-      String target,
-      {
-        required String name,
-        required String template,
-        Map<String, String>? environment,
-      }) async {
+    Directory directory,
+    List<String> options,
+    String target, {
+    required String name,
+    required String template,
+    Map<String, String>? environment,
+  }) async {
     await inDirectory(directory, () async {
       await flutter(
         'create',
@@ -361,6 +425,52 @@ public class $pluginClass: NSObject, FlutterPlugin {
     return project;
   }
 
+  /// Creates a Pod that uses a Flutter plugin as a dependency and therefore
+  /// Flutter as a transitive dependency.
+  Future<void> addCocoapodsTransitiveFlutterDependency() async {
+    final String iosDirectoryPath = path.join(rootPath, 'ios');
+
+    final File nativePod = File(path.join(iosDirectoryPath, 'NativePod', 'NativePod.podspec'));
+    nativePod.createSync(recursive: true);
+    nativePod.writeAsStringSync('''
+Pod::Spec.new do |s|
+  s.name             = 'NativePod'
+  s.version          = '1.0.0'
+  s.summary          = 'A pod to test Flutter as a transitive dependency.'
+  s.homepage         = 'https://flutter.dev'
+  s.license          = { :type => 'BSD' }
+  s.author           = { 'Flutter Dev Team' => 'flutter-dev@googlegroups.com' }
+  s.source           = { :path => '.' }
+  s.source_files = "Classes", "Classes/**/*.{h,m}"
+  s.dependency 'plugintest'
+end
+''');
+
+    final File nativePodClass = File(
+      path.join(iosDirectoryPath, 'NativePod', 'Classes', 'NativePodTest.m'),
+    );
+    nativePodClass.createSync(recursive: true);
+    nativePodClass.writeAsStringSync('''
+#import <Flutter/Flutter.h>
+
+@interface NativePodTest : NSObject
+
+@end
+
+@implementation NativePodTest
+
+@end
+''');
+
+    final File podfileFile = File(path.join(iosDirectoryPath, 'Podfile'));
+    final List<String> podfileContents = podfileFile.readAsLinesSync();
+    final int index = podfileContents.indexWhere(
+      (String line) => line.contains('flutter_install_all_ios_pods'),
+    );
+    podfileContents.insert(index, "pod 'NativePod', :path => 'NativePod'");
+    podfileFile.writeAsStringSync(podfileContents.join('\n'));
+  }
+
   // Make the platform version artificially low to test that the "deployment
   // version too low" warning is never emitted.
   void _reduceDarwinPluginMinimumVersion(String plugin, String target) {
@@ -368,12 +478,13 @@ public class $pluginClass: NSObject, FlutterPlugin {
     if (!podspec.existsSync()) {
       throw TaskResult.failure('podspec file missing at ${podspec.path}');
     }
-    final String versionString = target == 'ios'
-        ? "s.platform = :ios, '11.0'"
-        : "s.platform = :osx, '10.11'";
+    final String versionString =
+        target == 'ios' ? "s.platform = :ios, '12.0'" : "s.platform = :osx, '10.11'";
     String podspecContent = podspec.readAsStringSync();
     if (!podspecContent.contains(versionString)) {
-      throw TaskResult.failure('Update this test to match plugin minimum $target deployment version');
+      throw TaskResult.failure(
+        'Update this test to match plugin minimum $target deployment version',
+      );
     }
     // Add transitive dependency on AppAuth 1.6 targeting iOS 8 and macOS 10.9, which no longer builds in Xcode
     // to test the version is forced higher and builds.
@@ -387,7 +498,10 @@ s.platform = :osx, '10.8'
 s.dependency 'AppAuth', '1.6.0'
 ''';
 
-    podspecContent = podspecContent.replaceFirst(versionString, target == 'ios' ? iosContent : macosContent);
+    podspecContent = podspecContent.replaceFirst(
+      versionString,
+      target == 'ios' ? iosContent : macosContent,
+    );
     podspec.writeAsStringSync(podspecContent, flush: true);
   }
 
@@ -398,22 +512,23 @@ s.dependency 'AppAuth', '1.6.0'
     Directory? localEngine,
   }) async {
     await inDirectory(Directory(rootPath), () async {
-      final String buildOutput =  await evalFlutter('build', options: <String>[
-        target,
-        '-v',
-        if (target == 'ios')
-          '--no-codesign',
-        if (configOnly)
-          '--config-only',
-        if (localEngine != null)
+      final String buildOutput = await evalFlutter(
+        'build',
+        options: <String>[
+          target,
+          '-v',
+          if (target == 'ios') '--no-codesign',
+          if (configOnly) '--config-only',
+          if (localEngine != null)
           // The engine directory is of the form <fake-source-path>/out/<fakename>,
           // which has to be broken up into the component flags.
           ...<String>[
             '--local-engine-src-path=${localEngine.parent.parent.path}',
             '--local-engine=${path.basename(localEngine.path)}',
             '--local-engine-host=${path.basename(localEngine.path)}',
-          ]
-      ]);
+          ],
+        ],
+      );
 
       if (target == 'ios' || target == 'macos') {
         // This warning is confusing and shouldn't be emitted. Plugins often support lower versions than the
@@ -422,48 +537,83 @@ s.dependency 'AppAuth', '1.6.0'
         // but the range of supported deployment target versions is 9.0 to 14.0.99.
         //
         // (or "The macOS deployment target 'MACOSX_DEPLOYMENT_TARGET'"...)
-        if (buildOutput.contains('is set to 10.0, but the range of supported deployment target versions') ||
-            buildOutput.contains('is set to 10.8, but the range of supported deployment target versions')) {
+        if (buildOutput.contains(
+              'is set to 10.0, but the range of supported deployment target versions',
+            ) ||
+            buildOutput.contains(
+              'is set to 10.8, but the range of supported deployment target versions',
+            )) {
           throw TaskResult.failure('Minimum plugin version warning present');
         }
 
         if (validateNativeBuildProject) {
-          final File podsProject = File(path.join(rootPath, target, 'Pods', 'Pods.xcodeproj', 'project.pbxproj'));
-          if (!podsProject.existsSync()) {
-            throw TaskResult.failure('Xcode Pods project file missing at ${podsProject.path}');
-          }
+          final File generatedSwiftManifest = File(
+            path.join(
+              rootPath,
+              target,
+              'Flutter',
+              'ephemeral',
+              'Packages',
+              'FlutterGeneratedPluginSwiftPackage',
+              'Package.swift',
+            ),
+          );
+          final bool swiftPackageManagerEnabled = generatedSwiftManifest.existsSync();
 
-          final String podsProjectContent = podsProject.readAsStringSync();
-          if (target == 'ios') {
-            // Plugins with versions lower than the app version should not have IPHONEOS_DEPLOYMENT_TARGET set.
-            // The plugintest plugin target should not have IPHONEOS_DEPLOYMENT_TARGET set since it has been lowered
-            // in _reduceDarwinPluginMinimumVersion to 10, which is below the target version of 11.
-            if (podsProjectContent.contains('IPHONEOS_DEPLOYMENT_TARGET = 10')) {
-              throw TaskResult.failure('Plugin build setting IPHONEOS_DEPLOYMENT_TARGET not removed');
+          if (!swiftPackageManagerEnabled) {
+            final File podsProject = File(
+              path.join(rootPath, target, 'Pods', 'Pods.xcodeproj', 'project.pbxproj'),
+            );
+            if (!podsProject.existsSync()) {
+              throw TaskResult.failure('Xcode Pods project file missing at ${podsProject.path}');
             }
-            // Transitive dependency AppAuth targeting too-low 8.0 was not fixed.
-            if (podsProjectContent.contains('IPHONEOS_DEPLOYMENT_TARGET = 8')) {
-              throw TaskResult.failure('Transitive dependency build setting IPHONEOS_DEPLOYMENT_TARGET=8 not removed');
-            }
-            if (!podsProjectContent.contains(r'"EXCLUDED_ARCHS[sdk=iphonesimulator*]" = "$(inherited) i386";')) {
-              throw TaskResult.failure(r'EXCLUDED_ARCHS is not "$(inherited) i386"');
-            }
-          } else if (target == 'macos') {
-            // Same for macOS deployment target, but 10.8.
-            // The plugintest target should not have MACOSX_DEPLOYMENT_TARGET set.
-            if (podsProjectContent.contains('MACOSX_DEPLOYMENT_TARGET = 10.8')) {
-              throw TaskResult.failure('Plugin build setting MACOSX_DEPLOYMENT_TARGET not removed');
-            }
-            // Transitive dependency AppAuth targeting too-low 10.9 was not fixed.
-            if (podsProjectContent.contains('MACOSX_DEPLOYMENT_TARGET = 10.9')) {
-              throw TaskResult.failure('Transitive dependency build setting MACOSX_DEPLOYMENT_TARGET=10.9 not removed');
-            }
-          }
 
-          if (localEngine != null) {
-            final RegExp localEngineSearchPath = RegExp('FRAMEWORK_SEARCH_PATHS\\s*=[^;]*${localEngine.path}');
-            if (!localEngineSearchPath.hasMatch(podsProjectContent)) {
-              throw TaskResult.failure('FRAMEWORK_SEARCH_PATHS does not contain the --local-engine path');
+            final String podsProjectContent = podsProject.readAsStringSync();
+            if (target == 'ios') {
+              // Plugins with versions lower than the app version should not have IPHONEOS_DEPLOYMENT_TARGET set.
+              // The plugintest plugin target should not have IPHONEOS_DEPLOYMENT_TARGET set since it has been lowered
+              // in _reduceDarwinPluginMinimumVersion to 10, which is below the target version of 11.
+              if (podsProjectContent.contains('IPHONEOS_DEPLOYMENT_TARGET = 10')) {
+                throw TaskResult.failure(
+                  'Plugin build setting IPHONEOS_DEPLOYMENT_TARGET not removed',
+                );
+              }
+              // Transitive dependency AppAuth targeting too-low 8.0 was not fixed.
+              if (podsProjectContent.contains('IPHONEOS_DEPLOYMENT_TARGET = 8')) {
+                throw TaskResult.failure(
+                  'Transitive dependency build setting IPHONEOS_DEPLOYMENT_TARGET=8 not removed',
+                );
+              }
+              if (!podsProjectContent.contains(
+                r'"EXCLUDED_ARCHS[sdk=iphonesimulator*]" = "$(inherited) i386";',
+              )) {
+                throw TaskResult.failure(r'EXCLUDED_ARCHS is not "$(inherited) i386"');
+              }
+            } else if (target == 'macos') {
+              // Same for macOS deployment target, but 10.8.
+              // The plugintest target should not have MACOSX_DEPLOYMENT_TARGET set.
+              if (podsProjectContent.contains('MACOSX_DEPLOYMENT_TARGET = 10.8')) {
+                throw TaskResult.failure(
+                  'Plugin build setting MACOSX_DEPLOYMENT_TARGET not removed',
+                );
+              }
+              // Transitive dependency AppAuth targeting too-low 10.9 was not fixed.
+              if (podsProjectContent.contains('MACOSX_DEPLOYMENT_TARGET = 10.9')) {
+                throw TaskResult.failure(
+                  'Transitive dependency build setting MACOSX_DEPLOYMENT_TARGET=10.9 not removed',
+                );
+              }
+            }
+
+            if (localEngine != null) {
+              final RegExp localEngineSearchPath = RegExp(
+                'FRAMEWORK_SEARCH_PATHS\\s*=[^;]*${localEngine.path}',
+              );
+              if (!localEngineSearchPath.hasMatch(podsProjectContent)) {
+                throw TaskResult.failure(
+                  'FRAMEWORK_SEARCH_PATHS does not contain the --local-engine path',
+                );
+              }
             }
           }
         }
@@ -475,8 +625,7 @@ s.dependency 'AppAuth', '1.6.0'
     if (Platform.isWindows) {
       // A running Gradle daemon might prevent us from deleting the project
       // folder on Windows.
-      final String wrapperPath =
-          path.absolute(path.join(rootPath, 'android', 'gradlew.bat'));
+      final String wrapperPath = path.absolute(path.join(rootPath, 'android', 'gradlew.bat'));
       if (File(wrapperPath).existsSync()) {
         await exec(wrapperPath, <String>['--stop'], canFail: true);
       }
