@@ -4,7 +4,7 @@
 
 import 'package:flutter/material.dart';
 
-String? unused;
+String? unused; // ignore: unreachable_from_main
 
 void main() {
   runApp(const MyApp());
@@ -17,10 +17,8 @@ class MyApp extends StatelessWidget {
   Widget build(BuildContext context) {
     return MaterialApp(
       title: 'Flutter Demo',
-      theme: ThemeData(
-        primarySwatch: Colors.blue,
-      ),
-      home: const Center(child: Text('hello, world'))
+      theme: ThemeData(primarySwatch: Colors.blue),
+      home: const Center(child: Text('hello, world')),
     );
   }
 }
