@@ -14,10 +14,7 @@ class CheckboxListTileApp extends StatelessWidget {
 
   @override
   Widget build(BuildContext context) {
-    return MaterialApp(
-      theme: ThemeData(useMaterial3: true),
-      home: const CheckboxListTileExample(),
-    );
+    return MaterialApp(theme: ThemeData(useMaterial3: true), home: const CheckboxListTileExample());
   }
 }
 
