@@ -4,17 +4,18 @@
 
 import 'dart:io';
 
-import 'package:ffigen/src/code_generator.dart';
-import 'package:ffigen/src/code_generator/utils.dart';
-import 'package:ffigen/src/header_parser/type_extractor/cxtypekindmap.dart';
 import 'package:file/local.dart';
 import 'package:glob/glob.dart';
 import 'package:logging/logging.dart';
 import 'package:package_config/package_config.dart';
 import 'package:path/path.dart' as p;
+import 'package:pub_semver/pub_semver.dart';
 import 'package:quiver/pattern.dart' as quiver;
 import 'package:yaml/yaml.dart';
 
+import '../code_generator.dart';
+import '../code_generator/utils.dart';
+import '../header_parser/type_extractor/cxtypekindmap.dart';
 import '../strings.dart' as strings;
 import 'config_types.dart';
 
@@ -29,23 +30,23 @@ String _replaceSeparators(String path) {
   }
 }
 
-/// Replaces the path separators according to current platform. If a relative
-/// path is passed in, it is resolved relative to the config path, and the
-/// absolute path is returned.
-String _normalizePath(String path, String? configFilename) {
-  final skipNormalization =
-      (configFilename == null) || p.isAbsolute(path) || path.startsWith("**");
-  return _replaceSeparators(
-      skipNormalization ? path : p.join(p.dirname(configFilename), path));
+/// Replaces the path separators according to current platform, and normalizes .
+/// and .. in the path. If a relative path is passed in, it is resolved relative
+/// to the config path, and the absolute path is returned.
+String normalizePath(String path, String? configFilename) {
+  final resolveInConfigDir =
+      (configFilename == null) || p.isAbsolute(path) || path.startsWith('**');
+  return _replaceSeparators(p.normalize(resolveInConfigDir
+      ? path
+      : p.absolute(p.join(p.dirname(configFilename), path))));
 }
 
 Map<String, LibraryImport> libraryImportsExtractor(
     Map<String, String>? typeMap) {
   final resultMap = <String, LibraryImport>{};
   if (typeMap != null) {
-    for (final typeName in typeMap.keys) {
-      resultMap[typeName] =
-          LibraryImport(typeName, typeMap[typeName] as String);
+    for (final kv in typeMap.entries) {
+      resultMap[kv.key] = LibraryImport(kv.key, kv.value);
     }
   }
   return resultMap;
@@ -57,8 +58,10 @@ void loadImportedTypes(YamlMap fileConfig,
   for (final key in symbols.keys) {
     final usr = key as String;
     final value = symbols[usr]! as YamlMap;
-    usrTypeMappings[usr] = ImportedType(
-        libraryImport, value['name'] as String, value['name'] as String);
+    final name = value[strings.name] as String;
+    final dartName = (value[strings.dartName] as String?) ?? name;
+    usrTypeMappings[usr] = ImportedType(libraryImport, name, dartName, name,
+        importedDartType: true);
   }
 }
 
@@ -66,7 +69,7 @@ YamlMap loadSymbolFile(String symbolFilePath, String? configFileName,
     PackageConfig? packageConfig) {
   final path = symbolFilePath.startsWith('package:')
       ? packageConfig!.resolve(Uri.parse(symbolFilePath))!.toFilePath()
-      : _normalizePath(symbolFilePath, configFileName);
+      : normalizePath(symbolFilePath, configFileName);
 
   return loadYaml(File(path).readAsStringSync()) as YamlMap;
 }
@@ -85,13 +88,14 @@ Map<String, ImportedType> symbolFileImportExtractor(
     final formatVersion = symbolFile[strings.formatVersion] as String;
     if (formatVersion.split('.')[0] !=
         strings.symbolFileFormatVersion.split('.')[0]) {
-      _logger.severe(
-          'Incompatible format versions for file $symbolFilePath: ${strings.symbolFileFormatVersion}(ours), $formatVersion(theirs).');
+      _logger.severe('Incompatible format versions for file $symbolFilePath: '
+          '${strings.symbolFileFormatVersion}(ours), $formatVersion(theirs).');
       exit(1);
     }
     final uniqueNamer = UniqueNamer(libraryImports.keys
         .followedBy([strings.defaultSymbolFileImportPrefix]).toSet());
-    for (final file in (symbolFile[strings.files] as YamlMap).keys) {
+    final files = symbolFile[strings.files] as YamlMap;
+    for (final file in files.keys) {
       final existingImports = libraryImports.values
           .where((element) => element.importPath(false) == file);
       if (existingImports.isEmpty) {
@@ -102,8 +106,7 @@ Map<String, ImportedType> symbolFileImportExtractor(
       final libraryImport = libraryImports.values.firstWhere(
         (element) => element.importPath(false) == file,
       );
-      loadImportedTypes(
-          symbolFile[strings.files][file] as YamlMap, resultMap, libraryImport);
+      loadImportedTypes(files[file] as YamlMap, resultMap, libraryImport);
     }
   }
   return resultMap;
@@ -134,14 +137,15 @@ Map<String, ImportedType> makeImportTypeMapping(
     final lib = rawTypeMappings[key]![0];
     final cType = rawTypeMappings[key]![1];
     final dartType = rawTypeMappings[key]![2];
+    final nativeType = key;
     if (strings.predefinedLibraryImports.containsKey(lib)) {
-      typeMappings[key] =
-          ImportedType(strings.predefinedLibraryImports[lib]!, cType, dartType);
+      typeMappings[key] = ImportedType(
+          strings.predefinedLibraryImports[lib]!, cType, dartType, nativeType);
     } else if (libraryImportsMap.containsKey(lib)) {
       typeMappings[key] =
-          ImportedType(libraryImportsMap[lib]!, cType, dartType);
+          ImportedType(libraryImportsMap[lib]!, cType, dartType, nativeType);
     } else {
-      throw Exception("Please declare $lib under library-imports.");
+      throw Exception('Please declare $lib under library-imports.');
     }
   }
   return typeMappings;
@@ -201,7 +205,7 @@ Type makeTypeFromRawVarArgType(
         throw Exception('Please declare $lib in library-imports.');
       }
       final typeName = rawVarArgTypeSplit[1].replaceAll(' ', '');
-      baseType = ImportedType(libraryImport, typeName, typeName);
+      baseType = ImportedType(libraryImport, typeName, typeName, typeName);
     } else {
       throw Exception(
           'Invalid type $rawVarArgType : Expected 0 or 1 .(dot) separators.');
@@ -259,20 +263,20 @@ List<String> compilerOptsToList(String compilerOpts) {
 
 List<String> compilerOptsExtractor(List<String> value) {
   final list = <String>[];
-  for (final el in (value)) {
+  for (final el in value) {
     list.addAll(compilerOptsToList(el));
   }
   return list;
 }
 
-Headers headersExtractor(
+YamlHeaders headersExtractor(
     Map<dynamic, List<String>> yamlConfig, String? configFilename) {
   final entryPoints = <String>[];
   final includeGlobs = <quiver.Glob>[];
   for (final key in yamlConfig.keys) {
     if (key == strings.entryPoints) {
-      for (final h in (yamlConfig[key]!)) {
-        final headerGlob = _normalizePath(h, configFilename);
+      for (final h in yamlConfig[key]!) {
+        final headerGlob = normalizePath(h, configFilename);
         // Add file directly to header if it's not a Glob but a File.
         if (File(headerGlob).existsSync()) {
           final osSpecificPath = headerGlob;
@@ -292,12 +296,12 @@ Headers headersExtractor(
     if (key == strings.includeDirectives) {
       for (final h in yamlConfig[key]!) {
         final headerGlob = h;
-        final fixedGlob = _normalizePath(headerGlob, configFilename);
+        final fixedGlob = normalizePath(headerGlob, configFilename);
         includeGlobs.add(quiver.Glob(fixedGlob));
       }
     }
   }
-  return Headers(
+  return YamlHeaders(
     entryPoints: entryPoints,
     includeFilter: GlobHeaderFilter(
       includeGlobs: includeGlobs,
@@ -415,15 +419,15 @@ String llvmPathExtractor(List<String> value) {
       return completeDylibPath;
     }
   }
-  _logger.fine(
-      "Couldn't find dynamic library under paths specified by ${strings.llvmPath}.");
+  _logger.fine("Couldn't find dynamic library under paths specified by "
+      '${strings.llvmPath}.');
   // Extract path from default locations.
   try {
     final res = findDylibAtDefaultLocations();
     return res;
   } catch (e) {
-    _logger.severe(
-        "Couldn't find ${p.join(strings.dynamicLibParentName, strings.dylibFileName)} in specified locations.");
+    final path = p.join(strings.dynamicLibParentName, strings.dylibFileName);
+    _logger.severe("Couldn't find $path in specified locations.");
     exit(1);
   }
 }
@@ -431,11 +435,14 @@ String llvmPathExtractor(List<String> value) {
 OutputConfig outputExtractor(
     dynamic value, String? configFilename, PackageConfig? packageConfig) {
   if (value is String) {
-    return OutputConfig(_normalizePath(value, configFilename), null);
+    return OutputConfig(normalizePath(value, configFilename), null, null);
   }
   value = value as Map;
   return OutputConfig(
-    _normalizePath((value)[strings.bindings] as String, configFilename),
+    normalizePath(value[strings.bindings] as String, configFilename),
+    value.containsKey(strings.objCBindings)
+        ? normalizePath(value[strings.objCBindings] as String, configFilename)
+        : null,
     value.containsKey(strings.symbolFile)
         ? symbolFileOutputExtractor(
             value[strings.symbolFile], configFilename, packageConfig)
@@ -446,18 +453,19 @@ OutputConfig outputExtractor(
 SymbolFile symbolFileOutputExtractor(
     dynamic value, String? configFilename, PackageConfig? packageConfig) {
   value = value as Map;
-  var output = value[strings.output] as String;
-  if (Uri.parse(output).scheme != "package") {
-    _logger.warning(
-        'Consider using a Package Uri for ${strings.symbolFile} -> ${strings.output}: $output so that external packages can use it.');
-    output = _normalizePath(output, configFilename);
+  var output = Uri.parse(value[strings.output] as String);
+  if (output.scheme != 'package') {
+    _logger.warning('Consider using a Package Uri for ${strings.symbolFile} -> '
+        '${strings.output}: $output so that external packages can use it.');
+    output = Uri.file(normalizePath(output.toFilePath(), configFilename));
   } else {
-    output = packageConfig!.resolve(Uri.parse(output))!.toFilePath();
+    output = packageConfig!.resolve(output)!;
   }
-  final importPath = value[strings.importPath] as String;
-  if (Uri.parse(importPath).scheme != "package") {
-    _logger.warning(
-        'Consider using a Package Uri for ${strings.symbolFile} -> ${strings.importPath}: $importPath so that external packages can use it.');
+  final importPath = Uri.parse(value[strings.importPath] as String);
+  if (importPath.scheme != 'package') {
+    _logger.warning('Consider using a Package Uri for ${strings.symbolFile} -> '
+        '${strings.importPath}: $importPath so that external packages '
+        'can use it.');
   }
   return SymbolFile(importPath, output);
 }
@@ -468,7 +476,7 @@ SymbolFile symbolFileOutputExtractor(
 bool isFullDeclarationName(String str) =>
     quiver.matchesFull(RegExp('[a-zA-Z_0-9]*'), str);
 
-Includer extractIncluderFromYaml(Map<dynamic, dynamic> yamlMap) {
+YamlIncluder extractIncluderFromYaml(Map<dynamic, dynamic> yamlMap) {
   final includeMatchers = <RegExp>[],
       includeFull = <String>{},
       excludeMatchers = <RegExp>[],
@@ -477,7 +485,7 @@ Includer extractIncluderFromYaml(Map<dynamic, dynamic> yamlMap) {
   final include = yamlMap[strings.include] as List<String>?;
   if (include != null) {
     if (include.isEmpty) {
-      return Includer.excludeByDefault();
+      return YamlIncluder.excludeByDefault();
     }
     for (final str in include) {
       if (isFullDeclarationName(str)) {
@@ -499,7 +507,7 @@ Includer extractIncluderFromYaml(Map<dynamic, dynamic> yamlMap) {
     }
   }
 
-  return Includer(
+  return YamlIncluder(
     includeMatchers: includeMatchers,
     includeFull: includeFull,
     excludeMatchers: excludeMatchers,
@@ -512,15 +520,15 @@ Map<String, List<RawVarArgFunction>> varArgFunctionConfigExtractor(
   final result = <String, List<RawVarArgFunction>>{};
   final configMap = yamlMap;
   for (final key in configMap.keys) {
-    final List<RawVarArgFunction> vafuncs = [];
-    for (final rawVaFunc in (configMap[key] as List)) {
+    final vafuncs = <RawVarArgFunction>[];
+    for (final rawVaFunc in configMap[key] as List) {
       if (rawVaFunc is List) {
         vafuncs.add(RawVarArgFunction(null, rawVaFunc.cast()));
       } else if (rawVaFunc is Map) {
         vafuncs.add(RawVarArgFunction(rawVaFunc[strings.postfix] as String?,
             (rawVaFunc[strings.types] as List).cast()));
       } else {
-        throw Exception("Unexpected type in variadic-argument config.");
+        throw Exception('Unexpected type in variadic-argument config.');
       }
     }
     result[key as String] = vafuncs;
@@ -529,15 +537,16 @@ Map<String, List<RawVarArgFunction>> varArgFunctionConfigExtractor(
   return result;
 }
 
-Declaration declarationConfigExtractor(Map<dynamic, dynamic> yamlMap) {
+YamlDeclarationFilters declarationConfigExtractor(
+    Map<dynamic, dynamic> yamlMap, bool excludeAllByDefault) {
   final renamePatterns = <RegExpRenamer>[];
   final renameFull = <String, String>{};
   final memberRenamePatterns = <RegExpMemberRenamer>[];
-  final memberRenamerFull = <String, Renamer>{};
+  final memberRenamerFull = <String, YamlRenamer>{};
 
   final includer = extractIncluderFromYaml(yamlMap);
 
-  final symbolIncluder = yamlMap[strings.symbolAddress] as Includer?;
+  final symbolIncluder = yamlMap[strings.symbolAddress] as YamlIncluder?;
 
   final rename = yamlMap[strings.rename] as Map<dynamic, String>?;
 
@@ -555,7 +564,6 @@ Declaration declarationConfigExtractor(Map<dynamic, dynamic> yamlMap) {
 
   final memberRename =
       yamlMap[strings.memberRename] as Map<dynamic, Map<dynamic, String>>?;
-
   if (memberRename != null) {
     for (final key in memberRename.keys) {
       final decl = key.toString();
@@ -573,7 +581,7 @@ Declaration declarationConfigExtractor(Map<dynamic, dynamic> yamlMap) {
         }
       }
       if (isFullDeclarationName(decl)) {
-        memberRenamerFull[decl] = Renamer(
+        memberRenamerFull[decl] = YamlRenamer(
           renameFull: renameFull,
           renamePatterns: renamePatterns,
         );
@@ -581,7 +589,7 @@ Declaration declarationConfigExtractor(Map<dynamic, dynamic> yamlMap) {
         memberRenamePatterns.add(
           RegExpMemberRenamer(
             RegExp(decl, dotAll: true),
-            Renamer(
+            YamlRenamer(
               renameFull: renameFull,
               renamePatterns: renamePatterns,
             ),
@@ -591,34 +599,88 @@ Declaration declarationConfigExtractor(Map<dynamic, dynamic> yamlMap) {
     }
   }
 
-  return Declaration(
+  final memberIncluderMatchers = <(RegExp, YamlIncluder)>[];
+  final memberIncluderFull = <String, YamlIncluder>{};
+  final memberFilter =
+      yamlMap[strings.memberFilter] as Map<dynamic, YamlIncluder>?;
+  if (memberFilter != null) {
+    for (final entry in memberFilter.entries) {
+      final decl = entry.key.toString();
+      if (isFullDeclarationName(decl)) {
+        memberIncluderFull[decl] = entry.value;
+      } else {
+        memberIncluderMatchers.add((RegExp(decl, dotAll: true), entry.value));
+      }
+    }
+  }
+
+  return YamlDeclarationFilters(
     includer: includer,
-    renamer: Renamer(
+    renamer: YamlRenamer(
       renameFull: renameFull,
       renamePatterns: renamePatterns,
     ),
-    memberRenamer: MemberRenamer(
+    memberRenamer: YamlMemberRenamer(
       memberRenameFull: memberRenamerFull,
       memberRenamePattern: memberRenamePatterns,
     ),
+    memberIncluder: YamlMemberIncluder(
+      memberIncluderFull: memberIncluderFull,
+      memberIncluderMatchers: memberIncluderMatchers,
+    ),
     symbolAddressIncluder: symbolIncluder,
+    excludeAllByDefault: excludeAllByDefault,
   );
 }
 
 StructPackingOverride structPackingOverrideExtractor(
     Map<dynamic, dynamic> value) {
-  final matcherMap = <RegExp, int?>{};
+  final matcherMap = <(RegExp, int?)>[];
   for (final key in value.keys) {
-    matcherMap[RegExp(key as String, dotAll: true)] =
-        strings.packingValuesMap[value[key]];
+    matcherMap.add((
+      RegExp(key as String, dotAll: true),
+      strings.packingValuesMap[value[key]]
+    ));
   }
-  return StructPackingOverride(matcherMap: matcherMap);
+  return StructPackingOverride(matcherMap);
 }
 
 FfiNativeConfig ffiNativeExtractor(dynamic yamlConfig) {
   final yamlMap = yamlConfig as Map?;
+
+  // Use the old 'assetId' key if present but give a deprecation warning
+  if (yamlMap != null &&
+      !yamlMap.containsKey(strings.ffiNativeAsset) &&
+      yamlMap.containsKey('assetId')) {
+    _logger.warning("DEPRECATION WARNING: use 'asset-id' instead of 'assetId'");
+    return FfiNativeConfig(
+      enabled: true,
+      assetId: yamlMap['assetId'] as String?,
+    );
+  }
+
   return FfiNativeConfig(
     enabled: true,
     assetId: yamlMap?[strings.ffiNativeAsset] as String?,
   );
 }
+
+ExternalVersions externalVersionsExtractor(Map<dynamic, dynamic>? yamlConfig) =>
+    ExternalVersions(
+      ios: versionsExtractor(yamlConfig?[strings.ios]),
+      macos: versionsExtractor(yamlConfig?[strings.macos]),
+    );
+
+Versions? versionsExtractor(dynamic yamlConfig) {
+  final yamlMap = yamlConfig as Map?;
+  if (yamlMap == null) return null;
+  return Versions(
+    min: versionExtractor(yamlMap[strings.externalVersionsMin]),
+  );
+}
+
+Version? versionExtractor(dynamic yamlVersion) {
+  final versionString = yamlVersion as String?;
+  if (versionString == null) return null;
+  return Version.parse(versionString);
+}
