@@ -81,14 +81,6 @@ class ToSourceVisitor implements AstVisitor<void> {
     _visitNode(node.rightHandSide);
   }
 
-  @override
-  void visitAugmentationImportDirective(AugmentationImportDirective node) {
-    _visitNodeList(node.metadata, separator: ' ', suffix: ' ');
-    sink.write('import augment ');
-    _visitNode(node.uri);
-    sink.write(';');
-  }
-
   @override
   void visitAugmentedExpression(AugmentedExpression node) {
     sink.write('augmented');
@@ -823,15 +815,6 @@ class ToSourceVisitor implements AstVisitor<void> {
     _visitNode(node.statement);
   }
 
-  @override
-  void visitLibraryAugmentationDirective(LibraryAugmentationDirective node) {
-    _visitNodeList(node.metadata, separator: ' ', suffix: ' ');
-    sink.write('augment ');
-    sink.write('library ');
-    _visitNode(node.uri);
-    sink.write(';');
-  }
-
   @override
   void visitLibraryDirective(LibraryDirective node) {
     _visitNodeList(node.metadata, separator: ' ', suffix: ' ');
@@ -984,6 +967,12 @@ class ToSourceVisitor implements AstVisitor<void> {
     sink.write(node.operator.lexeme);
   }
 
+  @override
+  void visitNullAwareElement(NullAwareElement node) {
+    sink.write(node.question.lexeme);
+    _visitNode(node.value);
+  }
+
   @override
   void visitNullCheckPattern(NullCheckPattern node) {
     _visitNode(node.pattern);
@@ -1029,6 +1018,7 @@ class ToSourceVisitor implements AstVisitor<void> {
     _visitNodeList(node.metadata, separator: ' ', suffix: ' ');
     sink.write('part ');
     _visitNode(node.uri);
+    _visitNodeList(node.configurations, prefix: ' ', separator: ' ');
     sink.write(';');
   }
 
