@@ -76,16 +76,15 @@ class TypeArgumentsVerifier {
         continue;
       }
 
-      bound = _libraryElement.toLegacyTypeIfOptOut(bound);
       bound = substitution.substituteType(bound);
 
       if (!_typeSystem.isSubtypeOf(typeArgument, bound)) {
         var errorNode =
             i < typeArgumentListLength ? typeArgumentList.arguments[i] : node;
-        _errorReporter.reportErrorForNode(
-          CompileTimeErrorCode.TYPE_ARGUMENT_NOT_MATCHING_BOUNDS,
+        _errorReporter.atNode(
           errorNode,
-          [typeArgument, typeParameter.name, bound],
+          CompileTimeErrorCode.TYPE_ARGUMENT_NOT_MATCHING_BOUNDS,
+          arguments: [typeArgument, typeParameter.name, bound],
         );
       }
     }
@@ -97,7 +96,7 @@ class TypeArgumentsVerifier {
       return;
     }
 
-    var enumElement = constructorElement.enclosingElement;
+    var enumElement = constructorElement.enclosingElement3;
     var typeParameters = enumElement.typeParameters;
 
     var typeArgumentList = node.arguments?.typeArguments;
@@ -105,10 +104,10 @@ class TypeArgumentsVerifier {
     if (typeArgumentList != null &&
         typeArgumentNodes != null &&
         typeArgumentNodes.length != typeParameters.length) {
-      _errorReporter.reportErrorForNode(
-        CompileTimeErrorCode.WRONG_NUMBER_OF_TYPE_ARGUMENTS_ENUM,
+      _errorReporter.atNode(
         typeArgumentList,
-        [typeParameters.length, typeArgumentNodes.length],
+        CompileTimeErrorCode.WRONG_NUMBER_OF_TYPE_ARGUMENTS_ENUM,
+        arguments: [typeParameters.length, typeArgumentNodes.length],
       );
     }
 
@@ -131,12 +130,11 @@ class TypeArgumentsVerifier {
       bound = substitution.substituteType(bound);
 
       if (!_typeSystem.isSubtypeOf(typeArgument, bound)) {
-        final errorTarget = typeArgumentNodes?[i] ?? node.name;
-        _errorReporter.reportErrorForOffset(
+        var errorTarget = typeArgumentNodes?[i] ?? node.name;
+        _errorReporter.atEntity(
+          errorTarget,
           CompileTimeErrorCode.TYPE_ARGUMENT_NOT_MATCHING_BOUNDS,
-          errorTarget.offset,
-          errorTarget.length,
-          [typeArgument, typeParameter.name, bound],
+          arguments: [typeArgument, typeParameter.name, bound],
         );
       }
     }
@@ -148,7 +146,6 @@ class TypeArgumentsVerifier {
       node.function.staticType,
       node.staticInvokeType,
     );
-    _checkForImplicitDynamicInvoke(node);
   }
 
   void checkFunctionReference(FunctionReference node) {
@@ -163,30 +160,32 @@ class TypeArgumentsVerifier {
     var typeArguments = node.typeArguments;
     if (typeArguments != null) {
       if (node.isConst) {
-        _checkTypeArgumentConst(
-          typeArguments.arguments,
-          CompileTimeErrorCode.INVALID_TYPE_ARGUMENT_IN_CONST_LIST,
-        );
+        for (var argument in typeArguments.arguments) {
+          _checkTypeArgumentConst(
+            argument,
+            CompileTimeErrorCode.INVALID_TYPE_ARGUMENT_IN_CONST_LIST,
+          );
+        }
       }
       _checkTypeArgumentCount(typeArguments, 1,
           CompileTimeErrorCode.EXPECTED_ONE_LIST_TYPE_ARGUMENTS);
     }
-    _checkForImplicitDynamicTypedLiteral(node);
   }
 
   void checkMapLiteral(SetOrMapLiteral node) {
     var typeArguments = node.typeArguments;
     if (typeArguments != null) {
       if (node.isConst) {
-        _checkTypeArgumentConst(
-          typeArguments.arguments,
-          CompileTimeErrorCode.INVALID_TYPE_ARGUMENT_IN_CONST_MAP,
-        );
+        for (var argument in typeArguments.arguments) {
+          _checkTypeArgumentConst(
+            argument,
+            CompileTimeErrorCode.INVALID_TYPE_ARGUMENT_IN_CONST_MAP,
+          );
+        }
       }
       _checkTypeArgumentCount(typeArguments, 2,
           CompileTimeErrorCode.EXPECTED_TWO_MAP_TYPE_ARGUMENTS);
     }
-    _checkForImplicitDynamicTypedLiteral(node);
   }
 
   void checkMethodInvocation(MethodInvocation node) {
@@ -195,7 +194,6 @@ class TypeArgumentsVerifier {
       node.function.staticType,
       node.staticInvokeType,
     );
-    _checkForImplicitDynamicInvoke(node);
   }
 
   void checkNamedType(NamedType node) {
@@ -211,71 +209,16 @@ class TypeArgumentsVerifier {
     var typeArguments = node.typeArguments;
     if (typeArguments != null) {
       if (node.isConst) {
-        _checkTypeArgumentConst(
-          typeArguments.arguments,
-          CompileTimeErrorCode.INVALID_TYPE_ARGUMENT_IN_CONST_SET,
-        );
+        for (var argument in typeArguments.arguments) {
+          _checkTypeArgumentConst(
+            argument,
+            CompileTimeErrorCode.INVALID_TYPE_ARGUMENT_IN_CONST_SET,
+          );
+        }
       }
       _checkTypeArgumentCount(typeArguments, 1,
           CompileTimeErrorCode.EXPECTED_ONE_SET_TYPE_ARGUMENTS);
     }
-    _checkForImplicitDynamicTypedLiteral(node);
-  }
-
-  void _checkForImplicitDynamicInvoke(InvocationExpression node) {
-    if (_options.implicitDynamic || node.typeArguments != null) {
-      return;
-    }
-    var invokeType = node.staticInvokeType;
-    var declaredType = node.function.staticType;
-    if (invokeType is FunctionType &&
-        declaredType is FunctionType &&
-        declaredType.typeFormals.isNotEmpty) {
-      List<DartType> typeArgs = node.typeArgumentTypes!;
-      if (typeArgs.any((t) => t is DynamicType)) {
-        // Issue an error depending on what we're trying to call.
-        Expression function = node.function;
-        if (function is Identifier) {
-          var element = function.staticElement;
-          if (element is MethodElement) {
-            _errorReporter.reportErrorForNode(
-                LanguageCode.IMPLICIT_DYNAMIC_METHOD,
-                node.function,
-                [element.displayName, element.typeParameters.join(', ')]);
-            return;
-          }
-
-          if (element is FunctionElement) {
-            _errorReporter.reportErrorForNode(
-                LanguageCode.IMPLICIT_DYNAMIC_FUNCTION,
-                node.function,
-                [element.displayName, element.typeParameters.join(', ')]);
-            return;
-          }
-        }
-
-        // The catch all case if neither of those matched.
-        // For example, invoking a function expression.
-        _errorReporter.reportErrorForNode(LanguageCode.IMPLICIT_DYNAMIC_INVOKE,
-            node.function, [declaredType]);
-      }
-    }
-  }
-
-  void _checkForImplicitDynamicTypedLiteral(TypedLiteral node) {
-    if (_options.implicitDynamic || node.typeArguments != null) {
-      return;
-    }
-    DartType type = node.typeOrThrow;
-    // It's an error if either the key or value was inferred as dynamic.
-    if (type is InterfaceType &&
-        type.typeArguments.any((t) => t is DynamicType)) {
-      // TODO(brianwilkerson) Add StrongModeCode.IMPLICIT_DYNAMIC_SET_LITERAL
-      ErrorCode errorCode = node is ListLiteral
-          ? LanguageCode.IMPLICIT_DYNAMIC_LIST_LITERAL
-          : LanguageCode.IMPLICIT_DYNAMIC_MAP_LITERAL;
-      _errorReporter.reportErrorForNode(errorCode, node);
-    }
   }
 
   /// Checks a type annotation for a raw generic type, and reports the
@@ -312,8 +255,11 @@ class TypeArgumentsVerifier {
         // Do not report a "Strict raw type" error in this case; too noisy.
         // See https://github.com/dart-lang/language/blob/master/resources/type-system/strict-raw-types.md#conditions-for-a-raw-type-hint
       } else {
-        _errorReporter
-            .reportErrorForNode(WarningCode.STRICT_RAW_TYPE, node, [type]);
+        _errorReporter.atNode(
+          node,
+          WarningCode.STRICT_RAW_TYPE,
+          arguments: [type],
+        );
       }
     }
   }
@@ -321,15 +267,15 @@ class TypeArgumentsVerifier {
   /// Verify that the type arguments in the given [namedType] are all within
   /// their bounds.
   void _checkForTypeArgumentNotMatchingBounds(NamedType namedType) {
-    final type = namedType.type;
+    var type = namedType.type;
     if (type == null) {
       return;
     }
 
-    final List<TypeParameterElement> typeParameters;
-    final String elementName;
-    final List<DartType> typeArguments;
-    final alias = type.alias;
+    List<TypeParameterElement> typeParameters;
+    String elementName;
+    List<DartType> typeArguments;
+    var alias = type.alias;
     if (alias != null) {
       elementName = alias.element.name;
       typeParameters = alias.element.typeParameters;
@@ -348,16 +294,16 @@ class TypeArgumentsVerifier {
 
     // Check for regular-bounded.
     List<_TypeArgumentIssue>? issues;
-    final substitution = Substitution.fromPairs(typeParameters, typeArguments);
+    var substitution = Substitution.fromPairs(typeParameters, typeArguments);
     for (var i = 0; i < typeArguments.length; i++) {
       var typeParameter = typeParameters[i];
       var typeArgument = typeArguments[i];
 
       if (typeArgument is FunctionType && typeArgument.typeFormals.isNotEmpty) {
         if (!_libraryElement.featureSet.isEnabled(Feature.generic_metadata)) {
-          _errorReporter.reportErrorForNode(
-            CompileTimeErrorCode.GENERIC_FUNCTION_TYPE_CANNOT_BE_TYPE_ARGUMENT,
+          _errorReporter.atNode(
             _typeArgumentErrorNode(namedType, i),
+            CompileTimeErrorCode.GENERIC_FUNCTION_TYPE_CANNOT_BE_TYPE_ARGUMENT,
           );
           continue;
         }
@@ -368,7 +314,6 @@ class TypeArgumentsVerifier {
         continue;
       }
 
-      bound = _libraryElement.toLegacyTypeIfOptOut(bound);
       bound = substitution.substituteType(bound);
 
       if (!_typeSystem.isSubtypeOf(typeArgument, bound)) {
@@ -387,7 +332,7 @@ class TypeArgumentsVerifier {
     List<DiagnosticMessage>? buildContextMessages({
       List<DartType>? invertedTypeArguments,
     }) {
-      final messages = <DiagnosticMessage>[];
+      var messages = <DiagnosticMessage>[];
 
       void addMessage(String message) {
         messages.add(
@@ -402,9 +347,7 @@ class TypeArgumentsVerifier {
       }
 
       String typeArgumentsToString(List<DartType> typeArguments) {
-        return typeArguments
-            .map((e) => e.getDisplayString(withNullability: true))
-            .join(', ');
+        return typeArguments.map((e) => e.getDisplayString()).join(', ');
       }
 
       if (namedType.typeArguments == null) {
@@ -430,20 +373,24 @@ class TypeArgumentsVerifier {
     // If not allowed to be super-bounded, report issues.
     if (!_shouldAllowSuperBoundedTypes(namedType)) {
       for (var issue in issues) {
-        _errorReporter.reportErrorForNode(
-          CompileTimeErrorCode.TYPE_ARGUMENT_NOT_MATCHING_BOUNDS,
+        _errorReporter.atNode(
           _typeArgumentErrorNode(namedType, issue.index),
-          [issue.argument, issue.parameter.name, issue.parameterBound],
-          buildContextMessages(),
+          CompileTimeErrorCode.TYPE_ARGUMENT_NOT_MATCHING_BOUNDS,
+          arguments: [
+            issue.argument,
+            issue.parameter.name,
+            issue.parameterBound
+          ],
+          contextMessages: buildContextMessages(),
         );
       }
       return;
     }
 
     // Prepare type arguments for checking for super-bounded.
-    final invertedType = _typeSystem.replaceTopAndBottom(type);
-    final List<DartType> invertedTypeArguments;
-    final invertedAlias = invertedType.alias;
+    var invertedType = _typeSystem.replaceTopAndBottom(type);
+    List<DartType> invertedTypeArguments;
+    var invertedAlias = invertedType.alias;
     if (invertedAlias != null) {
       invertedTypeArguments = invertedAlias.typeArguments;
     } else if (invertedType is InterfaceType) {
@@ -453,7 +400,7 @@ class TypeArgumentsVerifier {
     }
 
     // Check for super-bounded.
-    final invertedSubstitution = Substitution.fromPairs(
+    var invertedSubstitution = Substitution.fromPairs(
       typeParameters,
       invertedTypeArguments,
     );
@@ -466,15 +413,14 @@ class TypeArgumentsVerifier {
         continue;
       }
 
-      bound = _libraryElement.toLegacyTypeIfOptOut(bound);
       bound = invertedSubstitution.substituteType(bound);
 
       if (!_typeSystem.isSubtypeOf(typeArgument, bound)) {
-        _errorReporter.reportErrorForNode(
-          CompileTimeErrorCode.TYPE_ARGUMENT_NOT_MATCHING_BOUNDS,
+        _errorReporter.atNode(
           _typeArgumentErrorNode(namedType, i),
-          [typeArgument, typeParameter.name, bound],
-          buildContextMessages(
+          CompileTimeErrorCode.TYPE_ARGUMENT_NOT_MATCHING_BOUNDS,
+          arguments: [typeArgument, typeParameter.name, bound],
+          contextMessages: buildContextMessages(
             invertedTypeArguments: invertedTypeArguments,
           ),
         );
@@ -520,9 +466,9 @@ class TypeArgumentsVerifier {
 
       if (argType is FunctionType && argType.typeFormals.isNotEmpty) {
         if (!_libraryElement.featureSet.isEnabled(Feature.generic_metadata)) {
-          _errorReporter.reportErrorForNode(
-            CompileTimeErrorCode.GENERIC_FUNCTION_TYPE_CANNOT_BE_TYPE_ARGUMENT,
+          _errorReporter.atNode(
             typeArgumentList[i],
+            CompileTimeErrorCode.GENERIC_FUNCTION_TYPE_CANNOT_BE_TYPE_ARGUMENT,
           );
           continue;
         }
@@ -537,28 +483,63 @@ class TypeArgumentsVerifier {
       var substitution = Substitution.fromPairs(fnTypeParams, typeArgs);
       var bound = substitution.substituteType(rawBound);
       if (!_typeSystem.isSubtypeOf(argType, bound)) {
-        _errorReporter.reportErrorForNode(
-            CompileTimeErrorCode.TYPE_ARGUMENT_NOT_MATCHING_BOUNDS,
-            typeArgumentList[i],
-            [argType, fnTypeParam.name, bound]);
+        _errorReporter.atNode(
+          typeArgumentList[i],
+          CompileTimeErrorCode.TYPE_ARGUMENT_NOT_MATCHING_BOUNDS,
+          arguments: [argType, fnTypeParam.name, bound],
+        );
       }
     }
   }
 
-  /// Checks to ensure that the given list of type [arguments] does not have a
-  /// type parameter as a type argument. The [errorCode] is either
-  /// [CompileTimeErrorCode.INVALID_TYPE_ARGUMENT_IN_CONST_LIST] or
-  /// [CompileTimeErrorCode.INVALID_TYPE_ARGUMENT_IN_CONST_MAP].
+  /// Checks whether the given [typeAnnotation] contains a type parameter.
+  ///
+  /// The [errorCode] is either
+  /// [CompileTimeErrorCode.INVALID_TYPE_ARGUMENT_IN_CONST_LIST],
+  /// [CompileTimeErrorCode.INVALID_TYPE_ARGUMENT_IN_CONST_MAP], or
+  /// [CompileTimeErrorCode.INVALID_TYPE_ARGUMENT_IN_CONST_SET].
   void _checkTypeArgumentConst(
-      NodeList<TypeAnnotation> arguments, ErrorCode errorCode) {
-    for (TypeAnnotation type in arguments) {
-      if (type is NamedType && type.type is TypeParameterType) {
-        _errorReporter.reportErrorForNode(
-          errorCode,
-          type,
-          [type.name2.lexeme],
-        );
-      }
+      TypeAnnotation typeAnnotation, ErrorCode errorCode) {
+    switch (typeAnnotation) {
+      case NamedType(:var type, :var typeArguments):
+        if (type is TypeParameterType) {
+          _errorReporter.atNode(typeAnnotation, errorCode,
+              arguments: [typeAnnotation.name2.lexeme]);
+        } else if (typeArguments != null) {
+          for (var argument in typeArguments.arguments) {
+            _checkTypeArgumentConst(argument, errorCode);
+          }
+        }
+      case GenericFunctionType(:var returnType, :var parameters):
+        for (var parameter in parameters.parameters) {
+          if (parameter case SimpleFormalParameter(type: var typeAnnotation?)) {
+            if (typeAnnotation case TypeAnnotation(:TypeParameterType type)) {
+              _errorReporter
+                  .atNode(typeAnnotation, errorCode, arguments: [type]);
+            } else {
+              _checkTypeArgumentConst(typeAnnotation, errorCode);
+            }
+          }
+          // `parameter` cannot legally be a DefaultFormalParameter,
+          // FieldFormalParameter, FunctionTypedFormalParameter, or
+          // SuperFormalParameter.
+        }
+        if (returnType case TypeAnnotation(:var type)) {
+          if (type is TypeParameterType) {
+            _errorReporter.atNode(returnType, errorCode, arguments: [type]);
+          } else {
+            _checkTypeArgumentConst(returnType, errorCode);
+          }
+        }
+      case RecordTypeAnnotation(:var fields):
+        for (var field in fields) {
+          var typeAnnotation = field.type;
+          if (typeAnnotation case TypeAnnotation(:TypeParameterType type)) {
+            _errorReporter.atNode(typeAnnotation, errorCode, arguments: [type]);
+          } else {
+            _checkTypeArgumentConst(typeAnnotation, errorCode);
+          }
+        }
     }
   }
 
@@ -572,10 +553,10 @@ class TypeArgumentsVerifier {
   ) {
     int actualCount = typeArguments.arguments.length;
     if (actualCount != expectedCount) {
-      _errorReporter.reportErrorForNode(
-        errorCode,
+      _errorReporter.atNode(
         typeArguments,
-        [actualCount],
+        errorCode,
+        arguments: [actualCount],
       );
     }
   }
@@ -621,14 +602,21 @@ class TypeArgumentsVerifier {
   /// Determines if the given [namedType] occurs in a context where
   /// super-bounded types are allowed.
   bool _shouldAllowSuperBoundedTypes(NamedType namedType) {
-    var parent = namedType.parent;
-    if (parent is ExtendsClause) return false;
-    if (parent is OnClause) return false;
-    if (parent is ClassTypeAlias) return false;
-    if (parent is WithClause) return false;
-    if (parent is ConstructorName) return false;
-    if (parent is ImplementsClause) return false;
-    if (parent is GenericTypeAlias) return false;
+    switch (namedType.parent) {
+      case ClassTypeAlias _:
+      case ConstructorName _:
+      case ExtendsClause _:
+      case GenericTypeAlias _:
+      case ImplementsClause _:
+      case MixinOnClause _:
+      case WithClause _:
+        return false;
+    }
+
+    if (namedType.type?.element is ExtensionTypeElement) {
+      return false;
+    }
+
     return true;
   }
 
