@@ -2,6 +2,10 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
+/// @docImport 'paginated_data_table.dart';
+/// @docImport 'text_theme.dart';
+library;
+
 import 'dart:math' as math;
 
 import 'package:flutter/rendering.dart';
@@ -38,6 +42,7 @@ class DataColumn {
   /// Creates the configuration for a column of a [DataTable].
   const DataColumn({
     required this.label,
+    this.columnWidth,
     this.tooltip,
     this.numeric = false,
     this.onSort,
@@ -63,6 +68,22 @@ class DataColumn {
   /// The label should not include the sort indicator.
   final Widget label;
 
+  /// How the horizontal extents of this column of the table should be determined.
+  ///
+  /// The [FixedColumnWidth] class can be used to specify a specific width in
+  /// pixels. This is the cheapest way to size a table's columns.
+  ///
+  /// The layout performance of the table depends critically on which column
+  /// sizing algorithms are used here. In particular, [IntrinsicColumnWidth] is
+  /// quite expensive because it needs to measure each cell in the column to
+  /// determine the intrinsic size of the column.
+  ///
+  /// If this property is `null`, the table applies a default behavior:
+  /// - If the table has exactly one column identified as the only text column
+  ///   (i.e., all the rest are numeric), that column uses `IntrinsicColumnWidth(flex: 1.0)`.
+  /// - All other columns use `IntrinsicColumnWidth()`.
+  final TableColumnWidth? columnWidth;
+
   /// The column heading's tooltip.
   ///
   /// This is a longer description of the column heading, for cases
@@ -88,15 +109,15 @@ class DataColumn {
   /// The cursor for a mouse pointer when it enters or is hovering over the
   /// heading row.
   ///
-  /// [MaterialStateProperty.resolve] is used for the following [MaterialState]s:
+  /// [WidgetStateProperty.resolve] is used for the following [WidgetState]s:
   ///
-  ///  * [MaterialState.disabled].
+  ///  * [WidgetState.disabled].
   ///
   /// If this is null, then the value of [DataTableThemeData.headingCellCursor]
-  /// is used. If that's null, then [MaterialStateMouseCursor.clickable] is used.
+  /// is used. If that's null, then [WidgetStateMouseCursor.clickable] is used.
   ///
   /// See also:
-  ///  * [MaterialStateMouseCursor], which can be used to create a [MouseCursor].
+  ///  * [WidgetStateMouseCursor], which can be used to create a [MouseCursor].
   final MaterialStateProperty<MouseCursor?>? mouseCursor;
 
   /// Defines the horizontal layout of the [label] and sort indicator in the
@@ -200,7 +221,7 @@ class DataRow {
   /// By default, the color is transparent unless selected. Selected rows has
   /// a grey translucent color.
   ///
-  /// The effective color can depend on the [MaterialState] state, if the
+  /// The effective color can depend on the [WidgetState] state, if the
   /// row is selected, pressed, hovered, focused, disabled or enabled. The
   /// color is painted as an overlay to the row. To make sure that the row's
   /// [InkWell] is visible (when pressed, hovered and focused), it is
@@ -210,8 +231,8 @@ class DataRow {
   ///
   /// ```dart
   /// DataRow(
-  ///   color: MaterialStateProperty.resolveWith<Color?>((Set<MaterialState> states) {
-  ///     if (states.contains(MaterialState.selected)) {
+  ///   color: WidgetStateProperty.resolveWith<Color?>((Set<WidgetState> states) {
+  ///     if (states.contains(WidgetState.selected)) {
   ///       return Theme.of(context).colorScheme.primary.withOpacity(0.08);
   ///     }
   ///     return null;  // Use the default value.
@@ -232,18 +253,19 @@ class DataRow {
   /// The cursor for a mouse pointer when it enters or is hovering over the
   /// data row.
   ///
-  /// [MaterialStateProperty.resolve] is used for the following [MaterialState]s:
+  /// [WidgetStateProperty.resolve] is used for the following [WidgetState]s:
   ///
-  ///  * [MaterialState.selected].
+  ///  * [WidgetState.selected].
   ///
   /// If this is null, then the value of [DataTableThemeData.dataRowCursor]
-  /// is used. If that's null, then [MaterialStateMouseCursor.clickable] is used.
+  /// is used. If that's null, then [WidgetStateMouseCursor.clickable] is used.
   ///
   /// See also:
-  ///  * [MaterialStateMouseCursor], which can be used to create a [MouseCursor].
+  ///  * [WidgetStateMouseCursor], which can be used to create a [MouseCursor].
   final MaterialStateProperty<MouseCursor?>? mouseCursor;
 
-  bool get _debugInteractive => onSelectChanged != null || cells.any((DataCell cell) => cell._debugInteractive);
+  bool get _debugInteractive =>
+      onSelectChanged != null || cells.any((DataCell cell) => cell._debugInteractive);
 }
 
 /// The data for a cell of a [DataTable].
@@ -342,34 +364,37 @@ class DataCell {
   /// row (if [DataRow.onSelectChanged] is provided).
   final GestureTapCancelCallback? onTapCancel;
 
-  bool get _debugInteractive => onTap != null ||
+  bool get _debugInteractive =>
+      onTap != null ||
       onDoubleTap != null ||
       onLongPress != null ||
       onTapDown != null ||
       onTapCancel != null;
 }
 
-/// A Material Design data table.
+/// A data table that follows the
+/// [Material 2](https://material.io/go/design-data-tables)
+/// design specification.
 ///
 /// {@youtube 560 315 https://www.youtube.com/watch?v=ktTajqbhIcY}
 ///
-/// Displaying data in a table is expensive, because to lay out the
-/// table all the data must be measured twice, once to negotiate the
-/// dimensions to use for each column, and once to actually lay out
-/// the table given the results of the negotiation.
+/// ## Performance considerations
 ///
-/// For this reason, if you have a lot of data (say, more than a dozen
-/// rows with a dozen columns, though the precise limits depend on the
-/// target device), it is suggested that you use a
-/// [PaginatedDataTable] which automatically splits the data into
-/// multiple pages.
+/// Columns are sized automatically based on the table's contents.
+/// It's expensive to display large amounts of data with this widget,
+/// since it must be measured twice: once to negotiate each column's
+/// dimensions, and again when the table is laid out.
 ///
-/// ## Performance considerations when wrapping [DataTable] with [SingleChildScrollView]
+/// A [SingleChildScrollView] mounts and paints the entire child, even
+/// when only some of it is visible. For a table that effectively handles
+/// large amounts of data, here are some other options to consider:
 ///
-/// Wrapping a [DataTable] with [SingleChildScrollView] is expensive as [SingleChildScrollView]
-/// mounts and paints the entire [DataTable] even when only some rows are visible. If scrolling in
-/// one direction is necessary, then consider using a [CustomScrollView], otherwise use [PaginatedDataTable]
-/// to split the data into smaller pages.
+///  * `TableView`, a widget from the
+///    [two_dimensional_scrollables](https://pub.dev/packages/two_dimensional_scrollables)
+///    package.
+///  * [PaginatedDataTable], which automatically splits the data into
+///    multiple pages.
+///  * [CustomScrollView], for greater control over scrolling effects.
 ///
 /// {@tool dartpad}
 /// This sample shows how to display a [DataTable] with three columns: name, age, and
@@ -402,7 +427,10 @@ class DataCell {
 ///  * [DataCell], which contains the data for a single cell in the data table.
 ///  * [PaginatedDataTable], which shows part of the data in a data table and
 ///    provides controls for paging through the remainder of the data.
-///  * <https://material.io/design/components/data-tables.html>
+///  * `TableView` from the
+///    [two_dimensional_scrollables](https://pub.dev/packages/two_dimensional_scrollables)
+///    package, for displaying large amounts of data without pagination.
+///  * <https://material.io/go/design-data-tables>
 class DataTable extends StatelessWidget {
   /// Creates a widget describing a data table.
   ///
@@ -457,12 +485,23 @@ class DataTable extends StatelessWidget {
     this.border,
     this.clipBehavior = Clip.none,
   }) : assert(columns.isNotEmpty),
-       assert(sortColumnIndex == null || (sortColumnIndex >= 0 && sortColumnIndex < columns.length)),
-       assert(!rows.any((DataRow row) => row.cells.length != columns.length), 'All rows must have the same number of cells as there are header cells (${columns.length})'),
+       assert(
+         sortColumnIndex == null || (sortColumnIndex >= 0 && sortColumnIndex < columns.length),
+       ),
+       assert(
+         !rows.any((DataRow row) => row.cells.length != columns.length),
+         'All rows must have the same number of cells as there are header cells (${columns.length})',
+       ),
        assert(dividerThickness == null || dividerThickness >= 0),
-       assert(dataRowMinHeight == null || dataRowMaxHeight == null || dataRowMaxHeight >= dataRowMinHeight),
-       assert(dataRowHeight == null || (dataRowMinHeight == null && dataRowMaxHeight == null),
-         'dataRowHeight ($dataRowHeight) must not be set if dataRowMinHeight ($dataRowMinHeight) or dataRowMaxHeight ($dataRowMaxHeight) are set.'),
+       assert(
+         dataRowMinHeight == null ||
+             dataRowMaxHeight == null ||
+             dataRowMaxHeight >= dataRowMinHeight,
+       ),
+       assert(
+         dataRowHeight == null || (dataRowMinHeight == null && dataRowMaxHeight == null),
+         'dataRowHeight ($dataRowHeight) must not be set if dataRowMinHeight ($dataRowMinHeight) or dataRowMaxHeight ($dataRowMaxHeight) are set.',
+       ),
        dataRowMinHeight = dataRowHeight ?? dataRowMinHeight,
        dataRowMaxHeight = dataRowHeight ?? dataRowMaxHeight,
        _onlyTextColumn = _initOnlyTextColumn(columns);
@@ -522,7 +561,7 @@ class DataTable extends StatelessWidget {
   /// The background color for the data rows.
   ///
   /// The effective background color can be made to depend on the
-  /// [MaterialState] state, i.e. if the row is selected, pressed, hovered,
+  /// [WidgetState] state, i.e. if the row is selected, pressed, hovered,
   /// focused, disabled or enabled. The color is painted as an overlay to the
   /// row. To make sure that the row's [InkWell] is visible (when pressed,
   /// hovered and focused), it is recommended to use a translucent background
@@ -540,8 +579,8 @@ class DataTable extends StatelessWidget {
   /// {@template flutter.material.DataTable.dataRowColor}
   /// ```dart
   /// DataTable(
-  ///   dataRowColor: MaterialStateProperty.resolveWith<Color?>((Set<MaterialState> states) {
-  ///     if (states.contains(MaterialState.selected)) {
+  ///   dataRowColor: WidgetStateProperty.resolveWith<Color?>((Set<WidgetState> states) {
+  ///     if (states.contains(WidgetState.selected)) {
   ///       return Theme.of(context).colorScheme.primary.withOpacity(0.08);
   ///     }
   ///     return null;  // Use the default value.
@@ -602,7 +641,7 @@ class DataTable extends StatelessWidget {
   /// The background color for the heading row.
   ///
   /// The effective background color can be made to depend on the
-  /// [MaterialState] state, i.e. if the row is pressed, hovered, focused when
+  /// [WidgetState] state, i.e. if the row is pressed, hovered, focused when
   /// sorted. The color is painted as an overlay to the row. To make sure that
   /// the row's [InkWell] is visible (when pressed, hovered and focused), it is
   /// recommended to use a translucent color.
@@ -615,8 +654,8 @@ class DataTable extends StatelessWidget {
   /// DataTable(
   ///   columns: _columns,
   ///   rows: _rows,
-  ///   headingRowColor: MaterialStateProperty.resolveWith<Color?>((Set<MaterialState> states) {
-  ///     if (states.contains(MaterialState.hovered)) {
+  ///   headingRowColor: WidgetStateProperty.resolveWith<Color?>((Set<WidgetState> states) {
+  ///     if (states.contains(WidgetState.hovered)) {
   ///       return Theme.of(context).colorScheme.primary.withOpacity(0.08);
   ///     }
   ///     return null;  // Use the default value.
@@ -743,8 +782,8 @@ class DataTable extends StatelessWidget {
   }
 
   bool get _debugInteractive {
-    return columns.any((DataColumn column) => column._debugInteractive)
-        || rows.any((DataRow row) => row._debugInteractive);
+    return columns.any((DataColumn column) => column._debugInteractive) ||
+        rows.any((DataRow row) => row._debugInteractive);
   }
 
   static final LocalKey _headingRowKey = UniqueKey();
@@ -792,15 +831,16 @@ class DataTable extends StatelessWidget {
     MouseCursor? rowMouseCursor,
   }) {
     final ThemeData themeData = Theme.of(context);
-    final double effectiveHorizontalMargin = horizontalMargin
-      ?? themeData.dataTableTheme.horizontalMargin
-      ?? _horizontalMargin;
-    final double effectiveCheckboxHorizontalMarginStart = checkboxHorizontalMargin
-      ?? themeData.dataTableTheme.checkboxHorizontalMargin
-      ?? effectiveHorizontalMargin;
-    final double effectiveCheckboxHorizontalMarginEnd = checkboxHorizontalMargin
-      ?? themeData.dataTableTheme.checkboxHorizontalMargin
-      ?? effectiveHorizontalMargin / 2.0;
+    final double effectiveHorizontalMargin =
+        horizontalMargin ?? themeData.dataTableTheme.horizontalMargin ?? _horizontalMargin;
+    final double effectiveCheckboxHorizontalMarginStart =
+        checkboxHorizontalMargin ??
+        themeData.dataTableTheme.checkboxHorizontalMargin ??
+        effectiveHorizontalMargin;
+    final double effectiveCheckboxHorizontalMarginEnd =
+        checkboxHorizontalMargin ??
+        themeData.dataTableTheme.checkboxHorizontalMargin ??
+        effectiveHorizontalMargin / 2.0;
     Widget contents = Semantics(
       container: true,
       child: Padding(
@@ -809,11 +849,7 @@ class DataTable extends StatelessWidget {
           end: effectiveCheckboxHorizontalMarginEnd,
         ),
         child: Center(
-          child: Checkbox(
-            value: checked,
-            onChanged: onCheckboxChanged,
-            tristate: tristate,
-          ),
+          child: Checkbox(value: checked, onChanged: onCheckboxChanged, tristate: tristate),
         ),
       ),
     );
@@ -825,10 +861,7 @@ class DataTable extends StatelessWidget {
         child: contents,
       );
     }
-    return TableCell(
-      verticalAlignment: TableCellVerticalAlignment.fill,
-      child: contents,
-    );
+    return TableCell(verticalAlignment: TableCellVerticalAlignment.fill, child: contents);
   }
 
   Widget _buildHeadingCell({
@@ -853,26 +886,27 @@ class DataTable extends StatelessWidget {
         if (headingRowAlignment == MainAxisAlignment.center && onSort != null)
           const SizedBox(width: _SortArrowState._arrowIconSize + _sortArrowPadding),
         label,
-        if (onSort != null)
-          ...<Widget>[
-            _SortArrow(
-              visible: sorted,
-              up: sorted ? ascending : null,
-              duration: _sortArrowAnimationDuration,
-            ),
-            const SizedBox(width: _sortArrowPadding),
-          ],
+        if (onSort != null) ...<Widget>[
+          _SortArrow(
+            visible: sorted,
+            up: sorted ? ascending : null,
+            duration: _sortArrowAnimationDuration,
+          ),
+          const SizedBox(width: _sortArrowPadding),
+        ],
       ],
     );
 
-    final TextStyle effectiveHeadingTextStyle = headingTextStyle
-      ?? dataTableTheme.headingTextStyle
-      ?? themeData.dataTableTheme.headingTextStyle
-      ?? themeData.textTheme.titleSmall!;
-    final double effectiveHeadingRowHeight = headingRowHeight
-      ?? dataTableTheme.headingRowHeight
-      ?? themeData.dataTableTheme.headingRowHeight
-      ?? _headingRowHeight;
+    final TextStyle effectiveHeadingTextStyle =
+        headingTextStyle ??
+        dataTableTheme.headingTextStyle ??
+        themeData.dataTableTheme.headingTextStyle ??
+        themeData.textTheme.titleSmall!;
+    final double effectiveHeadingRowHeight =
+        headingRowHeight ??
+        dataTableTheme.headingRowHeight ??
+        themeData.dataTableTheme.headingRowHeight ??
+        _headingRowHeight;
     label = Container(
       padding: padding,
       height: effectiveHeadingRowHeight,
@@ -885,10 +919,7 @@ class DataTable extends StatelessWidget {
       ),
     );
     if (tooltip != null) {
-      label = Tooltip(
-        message: tooltip,
-        child: label,
-      );
+      label = Tooltip(message: tooltip, child: label);
     }
 
     // TODO(dkwingsmt): Only wrap Inkwell if onSort != null. Blocked by
@@ -926,30 +957,36 @@ class DataTable extends StatelessWidget {
       label = Expanded(child: label);
       label = Row(
         textDirection: numeric ? TextDirection.rtl : null,
-        children: <Widget>[ label, icon ],
+        children: <Widget>[label, icon],
       );
     }
 
-    final TextStyle effectiveDataTextStyle = dataTextStyle
-      ?? dataTableTheme.dataTextStyle
-      ?? themeData.dataTableTheme.dataTextStyle
-      ?? themeData.textTheme.bodyMedium!;
-    final double effectiveDataRowMinHeight = dataRowMinHeight
-      ?? dataTableTheme.dataRowMinHeight
-      ?? themeData.dataTableTheme.dataRowMinHeight
-      ?? kMinInteractiveDimension;
-    final double effectiveDataRowMaxHeight = dataRowMaxHeight
-      ?? dataTableTheme.dataRowMaxHeight
-      ?? themeData.dataTableTheme.dataRowMaxHeight
-      ?? kMinInteractiveDimension;
+    final TextStyle effectiveDataTextStyle =
+        dataTextStyle ??
+        dataTableTheme.dataTextStyle ??
+        themeData.dataTableTheme.dataTextStyle ??
+        themeData.textTheme.bodyMedium!;
+    final double effectiveDataRowMinHeight =
+        dataRowMinHeight ??
+        dataTableTheme.dataRowMinHeight ??
+        themeData.dataTableTheme.dataRowMinHeight ??
+        kMinInteractiveDimension;
+    final double effectiveDataRowMaxHeight =
+        dataRowMaxHeight ??
+        dataTableTheme.dataRowMaxHeight ??
+        themeData.dataTableTheme.dataRowMaxHeight ??
+        kMinInteractiveDimension;
     label = Container(
       padding: padding,
-      constraints: BoxConstraints(minHeight: effectiveDataRowMinHeight, maxHeight: effectiveDataRowMaxHeight),
+      constraints: BoxConstraints(
+        minHeight: effectiveDataRowMinHeight,
+        maxHeight: effectiveDataRowMaxHeight,
+      ),
       alignment: numeric ? Alignment.centerRight : AlignmentDirectional.centerStart,
       child: DefaultTextStyle(
         style: DefaultTextStyle.of(context).style
-          .merge(effectiveDataTextStyle)
-          .copyWith(color: placeholder ? effectiveDataTextStyle.color!.withOpacity(0.6) : null),
+            .merge(effectiveDataTextStyle)
+            .copyWith(color: placeholder ? effectiveDataTextStyle.color!.withOpacity(0.6) : null),
         child: DropdownButtonHideUnderline(child: label),
       ),
     );
@@ -985,70 +1022,81 @@ class DataTable extends StatelessWidget {
 
     final ThemeData theme = Theme.of(context);
     final DataTableThemeData dataTableTheme = DataTableTheme.of(context);
-    final MaterialStateProperty<Color?>? effectiveHeadingRowColor = headingRowColor
-      ?? dataTableTheme.headingRowColor
-      ?? theme.dataTableTheme.headingRowColor;
-    final MaterialStateProperty<Color?>? effectiveDataRowColor = dataRowColor
-      ?? dataTableTheme.dataRowColor
-      ?? theme.dataTableTheme.dataRowColor;
-    final MaterialStateProperty<Color?> defaultRowColor = MaterialStateProperty.resolveWith(
-      (Set<MaterialState> states) {
-        if (states.contains(MaterialState.selected)) {
-          return theme.colorScheme.primary.withOpacity(0.08);
-        }
-        return null;
-      },
-    );
+    final MaterialStateProperty<Color?>? effectiveHeadingRowColor =
+        headingRowColor ?? dataTableTheme.headingRowColor ?? theme.dataTableTheme.headingRowColor;
+    final MaterialStateProperty<Color?>? effectiveDataRowColor =
+        dataRowColor ?? dataTableTheme.dataRowColor ?? theme.dataTableTheme.dataRowColor;
+    final MaterialStateProperty<Color?> defaultRowColor = MaterialStateProperty.resolveWith((
+      Set<MaterialState> states,
+    ) {
+      if (states.contains(MaterialState.selected)) {
+        return theme.colorScheme.primary.withOpacity(0.08);
+      }
+      return null;
+    });
     final bool anyRowSelectable = rows.any((DataRow row) => row.onSelectChanged != null);
     final bool displayCheckboxColumn = showCheckboxColumn && anyRowSelectable;
-    final Iterable<DataRow> rowsWithCheckbox = displayCheckboxColumn ?
-      rows.where((DataRow row) => row.onSelectChanged != null) : <DataRow>[];
+    final Iterable<DataRow> rowsWithCheckbox =
+        displayCheckboxColumn
+            ? rows.where((DataRow row) => row.onSelectChanged != null)
+            : <DataRow>[];
     final Iterable<DataRow> rowsChecked = rowsWithCheckbox.where((DataRow row) => row.selected);
     final bool allChecked = displayCheckboxColumn && rowsChecked.length == rowsWithCheckbox.length;
     final bool anyChecked = displayCheckboxColumn && rowsChecked.isNotEmpty;
     final bool someChecked = anyChecked && !allChecked;
-    final double effectiveHorizontalMargin = horizontalMargin
-      ?? dataTableTheme.horizontalMargin
-      ?? theme.dataTableTheme.horizontalMargin
-      ?? _horizontalMargin;
-    final double effectiveCheckboxHorizontalMarginStart = checkboxHorizontalMargin
-      ?? dataTableTheme.checkboxHorizontalMargin
-      ?? theme.dataTableTheme.checkboxHorizontalMargin
-      ?? effectiveHorizontalMargin;
-    final double effectiveCheckboxHorizontalMarginEnd = checkboxHorizontalMargin
-      ?? dataTableTheme.checkboxHorizontalMargin
-      ?? theme.dataTableTheme.checkboxHorizontalMargin
-      ?? effectiveHorizontalMargin / 2.0;
-    final double effectiveColumnSpacing = columnSpacing
-      ?? dataTableTheme.columnSpacing
-      ?? theme.dataTableTheme.columnSpacing
-      ?? _columnSpacing;
+    final double effectiveHorizontalMargin =
+        horizontalMargin ??
+        dataTableTheme.horizontalMargin ??
+        theme.dataTableTheme.horizontalMargin ??
+        _horizontalMargin;
+    final double effectiveCheckboxHorizontalMarginStart =
+        checkboxHorizontalMargin ??
+        dataTableTheme.checkboxHorizontalMargin ??
+        theme.dataTableTheme.checkboxHorizontalMargin ??
+        effectiveHorizontalMargin;
+    final double effectiveCheckboxHorizontalMarginEnd =
+        checkboxHorizontalMargin ??
+        dataTableTheme.checkboxHorizontalMargin ??
+        theme.dataTableTheme.checkboxHorizontalMargin ??
+        effectiveHorizontalMargin / 2.0;
+    final double effectiveColumnSpacing =
+        columnSpacing ??
+        dataTableTheme.columnSpacing ??
+        theme.dataTableTheme.columnSpacing ??
+        _columnSpacing;
 
-    final List<TableColumnWidth> tableColumns = List<TableColumnWidth>.filled(columns.length + (displayCheckboxColumn ? 1 : 0), const _NullTableColumnWidth());
+    final List<TableColumnWidth> tableColumns = List<TableColumnWidth>.filled(
+      columns.length + (displayCheckboxColumn ? 1 : 0),
+      const _NullTableColumnWidth(),
+    );
     final List<TableRow> tableRows = List<TableRow>.generate(
       rows.length + 1, // the +1 is for the header row
       (int index) {
         final bool isSelected = index > 0 && rows[index - 1].selected;
-        final bool isDisabled = index > 0 && anyRowSelectable && rows[index - 1].onSelectChanged == null;
+        final bool isDisabled =
+            index > 0 && anyRowSelectable && rows[index - 1].onSelectChanged == null;
         final Set<MaterialState> states = <MaterialState>{
-          if (isSelected)
-            MaterialState.selected,
-          if (isDisabled)
-            MaterialState.disabled,
+          if (isSelected) MaterialState.selected,
+          if (isDisabled) MaterialState.disabled,
         };
-        final Color? resolvedDataRowColor = index > 0 ? (rows[index - 1].color ?? effectiveDataRowColor)?.resolve(states) : null;
+        final Color? resolvedDataRowColor =
+            index > 0 ? (rows[index - 1].color ?? effectiveDataRowColor)?.resolve(states) : null;
         final Color? resolvedHeadingRowColor = effectiveHeadingRowColor?.resolve(<MaterialState>{});
         final Color? rowColor = index > 0 ? resolvedDataRowColor : resolvedHeadingRowColor;
         final BorderSide borderSide = Divider.createBorderSide(
           context,
-          width: dividerThickness
-            ?? dataTableTheme.dividerThickness
-            ?? theme.dataTableTheme.dividerThickness
-            ?? _dividerThickness,
+          width:
+              dividerThickness ??
+              dataTableTheme.dividerThickness ??
+              theme.dataTableTheme.dividerThickness ??
+              _dividerThickness,
         );
-        final Border? border = showBottomBorder
-          ? Border(bottom: borderSide)
-          : index == 0 ? null : Border(top: borderSide);
+        final Border? border =
+            showBottomBorder
+                ? Border(bottom: borderSide)
+                : index == 0
+                ? null
+                : Border(top: borderSide);
         return TableRow(
           key: index == 0 ? _headingRowKey : rows[index - 1].key,
           decoration: BoxDecoration(
@@ -1064,7 +1112,11 @@ class DataTable extends StatelessWidget {
 
     int displayColumnIndex = 0;
     if (displayCheckboxColumn) {
-      tableColumns[0] = FixedColumnWidth(effectiveCheckboxHorizontalMarginStart + Checkbox.width + effectiveCheckboxHorizontalMarginEnd);
+      tableColumns[0] = FixedColumnWidth(
+        effectiveCheckboxHorizontalMarginStart +
+            Checkbox.width +
+            effectiveCheckboxHorizontalMarginEnd,
+      );
       tableRows[0].children[0] = _buildCheckbox(
         context: context,
         checked: someChecked ? null : allChecked,
@@ -1075,17 +1127,16 @@ class DataTable extends StatelessWidget {
       );
       rowIndex = 1;
       for (final DataRow row in rows) {
-        final Set<MaterialState> states = <MaterialState>{
-          if (row.selected)
-            MaterialState.selected,
-        };
+        final Set<MaterialState> states = <MaterialState>{if (row.selected) MaterialState.selected};
         tableRows[rowIndex].children[0] = _buildCheckbox(
           context: context,
           checked: row.selected,
-          onRowTap: row.onSelectChanged == null ? null : () => row.onSelectChanged?.call(!row.selected),
+          onRowTap:
+              row.onSelectChanged == null ? null : () => row.onSelectChanged?.call(!row.selected),
           onCheckboxChanged: row.onSelectChanged,
           overlayColor: row.color ?? effectiveDataRowColor,
-          rowMouseCursor: row.mouseCursor?.resolve(states) ?? dataTableTheme.dataRowCursor?.resolve(states),
+          rowMouseCursor:
+              row.mouseCursor?.resolve(states) ?? dataTableTheme.dataRowCursor?.resolve(states),
           tristate: false,
         );
         rowIndex += 1;
@@ -1097,7 +1148,8 @@ class DataTable extends StatelessWidget {
       final DataColumn column = columns[dataColumnIndex];
 
       final double paddingStart = switch (dataColumnIndex) {
-        0 when displayCheckboxColumn && checkboxHorizontalMargin == null => effectiveHorizontalMargin / 2.0,
+        0 when displayCheckboxColumn && checkboxHorizontalMargin == null =>
+          effectiveHorizontalMargin / 2.0,
         0 => effectiveHorizontalMargin,
         _ => effectiveColumnSpacing / 2.0,
       };
@@ -1113,14 +1165,16 @@ class DataTable extends StatelessWidget {
         start: paddingStart,
         end: paddingEnd,
       );
-      if (dataColumnIndex == _onlyTextColumn) {
+      if (column.columnWidth != null) {
+        tableColumns[displayColumnIndex] = column.columnWidth!;
+      } else if (dataColumnIndex == _onlyTextColumn) {
         tableColumns[displayColumnIndex] = const IntrinsicColumnWidth(flex: 1.0);
       } else {
         tableColumns[displayColumnIndex] = const IntrinsicColumnWidth();
       }
+
       final Set<MaterialState> headerStates = <MaterialState>{
-        if (column.onSort == null)
-          MaterialState.disabled,
+        if (column.onSort == null) MaterialState.disabled,
       };
       tableRows[0].children[displayColumnIndex] = _buildHeadingCell(
         context: context,
@@ -1128,19 +1182,27 @@ class DataTable extends StatelessWidget {
         label: column.label,
         tooltip: column.tooltip,
         numeric: column.numeric,
-        onSort: column.onSort != null ? () => column.onSort!(dataColumnIndex, sortColumnIndex != dataColumnIndex || !sortAscending) : null,
+        onSort:
+            column.onSort != null
+                ? () => column.onSort!(
+                  dataColumnIndex,
+                  sortColumnIndex != dataColumnIndex || !sortAscending,
+                )
+                : null,
         sorted: dataColumnIndex == sortColumnIndex,
         ascending: sortAscending,
         overlayColor: effectiveHeadingRowColor,
-        mouseCursor: column.mouseCursor?.resolve(headerStates) ?? dataTableTheme.headingCellCursor?.resolve(headerStates),
-        headingRowAlignment: column.headingRowAlignment ?? dataTableTheme.headingRowAlignment ?? MainAxisAlignment.start,
+        mouseCursor:
+            column.mouseCursor?.resolve(headerStates) ??
+            dataTableTheme.headingCellCursor?.resolve(headerStates),
+        headingRowAlignment:
+            column.headingRowAlignment ??
+            dataTableTheme.headingRowAlignment ??
+            MainAxisAlignment.start,
       );
       rowIndex = 1;
       for (final DataRow row in rows) {
-        final Set<MaterialState> states = <MaterialState>{
-          if (row.selected)
-            MaterialState.selected,
-        };
+        final Set<MaterialState> states = <MaterialState>{if (row.selected) MaterialState.selected};
         final DataCell cell = row.cells[dataColumnIndex];
         tableRows[rowIndex].children[displayColumnIndex] = _buildDataCell(
           context: context,
@@ -1154,10 +1216,12 @@ class DataTable extends StatelessWidget {
           onLongPress: cell.onLongPress,
           onTapCancel: cell.onTapCancel,
           onTapDown: cell.onTapDown,
-          onSelectChanged: row.onSelectChanged == null ? null : () => row.onSelectChanged?.call(!row.selected),
+          onSelectChanged:
+              row.onSelectChanged == null ? null : () => row.onSelectChanged?.call(!row.selected),
           overlayColor: row.color ?? effectiveDataRowColor,
           onRowLongPress: row.onLongPress,
-          mouseCursor: row.mouseCursor?.resolve(states) ?? dataTableTheme.dataRowCursor?.resolve(states),
+          mouseCursor:
+              row.mouseCursor?.resolve(states) ?? dataTableTheme.dataRowCursor?.resolve(states),
         );
         rowIndex += 1;
       }
@@ -1213,10 +1277,7 @@ class TableRowInkWell extends InkResponse {
     super.onSecondaryTapDown,
     super.overlayColor,
     super.mouseCursor,
-  }) : super(
-    containedInkWell: true,
-    highlightShape: BoxShape.rectangle,
-  );
+  }) : super(containedInkWell: true, highlightShape: BoxShape.rectangle);
 
   @override
   RectCallback getRectCallback(RenderBox referenceBox) {
@@ -1254,11 +1315,7 @@ class TableRowInkWell extends InkResponse {
 }
 
 class _SortArrow extends StatefulWidget {
-  const _SortArrow({
-    required this.visible,
-    required this.up,
-    required this.duration,
-  });
+  const _SortArrow({required this.visible, required this.up, required this.duration});
 
   final bool visible;
 
@@ -1280,29 +1337,25 @@ class _SortArrowState extends State<_SortArrow> with TickerProviderStateMixin {
 
   bool? _up;
 
-  static final Animatable<double> _turnTween = Tween<double>(begin: 0.0, end: math.pi)
-    .chain(CurveTween(curve: Curves.easeIn));
+  static final Animatable<double> _turnTween = Tween<double>(
+    begin: 0.0,
+    end: math.pi,
+  ).chain(CurveTween(curve: Curves.easeIn));
 
   @override
   void initState() {
     super.initState();
     _up = widget.up;
     _opacityAnimation = CurvedAnimation(
-      parent: _opacityController = AnimationController(
-        duration: widget.duration,
-        vsync: this,
-      ),
+      parent: _opacityController = AnimationController(duration: widget.duration, vsync: this),
       curve: Curves.fastOutSlowIn,
-    )
-    ..addListener(_rebuild);
+    )..addListener(_rebuild);
     _opacityController.value = widget.visible ? 1.0 : 0.0;
-    _orientationController = AnimationController(
-      duration: widget.duration,
-      vsync: this,
-    );
-    _orientationAnimation = _orientationController.drive(_turnTween)
-      ..addListener(_rebuild)
-      ..addStatusListener(_resetOrientationAnimation);
+    _orientationController = AnimationController(duration: widget.duration, vsync: this);
+    _orientationAnimation =
+        _orientationController.drive(_turnTween)
+          ..addListener(_rebuild)
+          ..addStatusListener(_resetOrientationAnimation);
     if (widget.visible) {
       _orientationOffset = widget.up! ? 0.0 : math.pi;
     }
@@ -1367,12 +1420,9 @@ class _SortArrowState extends State<_SortArrow> with TickerProviderStateMixin {
       opacity: _opacityAnimation,
       child: Transform(
         transform: Matrix4.rotationZ(_orientationOffset + _orientationAnimation.value)
-                             ..setTranslationRaw(0.0, _arrowIconBaselineOffset, 0.0),
+          ..setTranslationRaw(0.0, _arrowIconBaselineOffset, 0.0),
         alignment: Alignment.center,
-        child: const Icon(
-          Icons.arrow_upward,
-          size: _arrowIconSize,
-        ),
+        child: const Icon(Icons.arrow_upward, size: _arrowIconSize),
       ),
     );
   }
@@ -1382,10 +1432,12 @@ class _NullTableColumnWidth extends TableColumnWidth {
   const _NullTableColumnWidth();
 
   @override
-  double maxIntrinsicWidth(Iterable<RenderBox> cells, double containerWidth) => throw UnimplementedError();
+  double maxIntrinsicWidth(Iterable<RenderBox> cells, double containerWidth) =>
+      throw UnimplementedError();
 
   @override
-  double minIntrinsicWidth(Iterable<RenderBox> cells, double containerWidth) => throw UnimplementedError();
+  double minIntrinsicWidth(Iterable<RenderBox> cells, double containerWidth) =>
+      throw UnimplementedError();
 }
 
 class _NullWidget extends Widget {
