@@ -2,6 +2,10 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
+/// @docImport 'date_picker.dart';
+/// @docImport 'text_field.dart';
+library;
+
 import 'package:flutter/widgets.dart';
 
 import 'date.dart';
@@ -74,7 +78,9 @@ class InputDatePickerFormField extends StatefulWidget {
       'initialDate ${this.initialDate} must be on or before lastDate ${this.lastDate}.',
     );
     assert(
-      selectableDayPredicate == null || initialDate == null || selectableDayPredicate!(this.initialDate!),
+      selectableDayPredicate == null ||
+          initialDate == null ||
+          selectableDayPredicate!(this.initialDate!),
       'Provided initialDate ${this.initialDate} must satisfy provided selectableDayPredicate.',
     );
   }
@@ -189,10 +195,9 @@ class _InputDatePickerFormFieldState extends State<InputDatePickerFormField> {
       TextEditingValue textEditingValue = TextEditingValue(text: _inputText!);
       // Select the new text if we are auto focused and haven't selected the text before.
       if (widget.autofocus && !_autoSelected) {
-        textEditingValue = textEditingValue.copyWith(selection: TextSelection(
-          baseOffset: 0,
-          extentOffset: _inputText!.length,
-        ));
+        textEditingValue = textEditingValue.copyWith(
+          selection: TextSelection(baseOffset: 0, extentOffset: _inputText!.length),
+        );
         _autoSelected = true;
       }
       _controller.value = textEditingValue;
@@ -208,11 +213,10 @@ class _InputDatePickerFormFieldState extends State<InputDatePickerFormField> {
   }
 
   bool _isValidAcceptableDate(DateTime? date) {
-    return
-      date != null &&
-      !date.isBefore(widget.firstDate) &&
-      !date.isAfter(widget.lastDate) &&
-      (widget.selectableDayPredicate == null || widget.selectableDayPredicate!(date));
+    return date != null &&
+        !date.isBefore(widget.firstDate) &&
+        !date.isAfter(widget.lastDate) &&
+        (widget.selectableDayPredicate == null || widget.selectableDayPredicate!(date));
   }
 
   String? _validateDate(String? text) {
@@ -252,9 +256,10 @@ class _InputDatePickerFormFieldState extends State<InputDatePickerFormField> {
     final MaterialLocalizations localizations = MaterialLocalizations.of(context);
     final DatePickerThemeData datePickerTheme = theme.datePickerTheme;
     final InputDecorationTheme inputTheme = theme.inputDecorationTheme;
-    final InputBorder effectiveInputBorder =  datePickerTheme.inputDecorationTheme?.border
-      ?? theme.inputDecorationTheme.border
-      ?? (useMaterial3 ? const OutlineInputBorder() : const UnderlineInputBorder());
+    final InputBorder effectiveInputBorder =
+        datePickerTheme.inputDecorationTheme?.border ??
+        theme.inputDecorationTheme.border ??
+        (useMaterial3 ? const OutlineInputBorder() : const UnderlineInputBorder());
 
     return Semantics(
       container: true,
@@ -262,9 +267,10 @@ class _InputDatePickerFormFieldState extends State<InputDatePickerFormField> {
         decoration: InputDecoration(
           hintText: widget.fieldHintText ?? localizations.dateHelpText,
           labelText: widget.fieldLabelText ?? localizations.dateInputLabel,
-        ).applyDefaults(inputTheme
-          .merge(datePickerTheme.inputDecorationTheme)
-          .copyWith(border: effectiveInputBorder),
+        ).applyDefaults(
+          inputTheme
+              .merge(datePickerTheme.inputDecorationTheme)
+              .copyWith(border: effectiveInputBorder),
         ),
         validator: _validateDate,
         keyboardType: widget.keyboardType ?? TextInputType.datetime,
