@@ -2,6 +2,33 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
+/// @docImport 'package:flutter/services.dart';
+/// @docImport 'package:flutter_localizations/flutter_localizations.dart';
+///
+/// @docImport 'about.dart';
+/// @docImport 'action_buttons.dart';
+/// @docImport 'app.dart';
+/// @docImport 'app_bar.dart';
+/// @docImport 'bottom_sheet.dart';
+/// @docImport 'calendar_date_picker.dart';
+/// @docImport 'chip.dart';
+/// @docImport 'date_picker.dart';
+/// @docImport 'expand_icon.dart';
+/// @docImport 'expansion_tile.dart';
+/// @docImport 'input_date_picker_form_field.dart';
+/// @docImport 'paginated_data_table.dart';
+/// @docImport 'popup_menu.dart';
+/// @docImport 'refresh_indicator.dart';
+/// @docImport 'reorderable_list.dart';
+/// @docImport 'search_anchor.dart';
+/// @docImport 'tabs.dart';
+/// @docImport 'text_field.dart';
+/// @docImport 'text_theme.dart';
+/// @docImport 'theme_data.dart';
+/// @docImport 'time_picker.dart';
+/// @docImport 'user_accounts_drawer_header.dart';
+library;
+
 import 'package:flutter/foundation.dart';
 import 'package:flutter/widgets.dart';
 
@@ -86,7 +113,7 @@ abstract class MaterialLocalizations {
   /// there are, e.g. 'Tab 1 of 2' in United States English.
   ///
   /// `tabIndex` and `tabCount` must be greater than or equal to one.
-  String tabLabel({ required int tabIndex, required int tabCount });
+  String tabLabel({required int tabIndex, required int tabCount});
 
   /// Title for the [PaginatedDataTable]'s selected row count header.
   String selectedRowCountTitle(int selectedRowCount);
@@ -201,7 +228,7 @@ abstract class MaterialLocalizations {
   ///
   /// The documentation for [TimeOfDayFormat] enum values provides details on
   /// each supported layout.
-  TimeOfDayFormat timeOfDayFormat({ bool alwaysUse24HourFormat = false });
+  TimeOfDayFormat timeOfDayFormat({bool alwaysUse24HourFormat = false});
 
   /// Defines the localized [TextStyle] geometry for [ThemeData.textTheme].
   ///
@@ -224,7 +251,7 @@ abstract class MaterialLocalizations {
   ///
   /// If [alwaysUse24HourFormat] is true, formats hour using [HourFormat.HH]
   /// rather than the default for the current locale.
-  String formatHour(TimeOfDay timeOfDay, { bool alwaysUse24HourFormat = false });
+  String formatHour(TimeOfDay timeOfDay, {bool alwaysUse24HourFormat = false});
 
   /// Formats [TimeOfDay.minute] in the given time of day according to the value
   /// of [timeOfDayFormat].
@@ -236,7 +263,7 @@ abstract class MaterialLocalizations {
   /// rather than the default for the current locale. This value is usually
   /// passed from [MediaQueryData.alwaysUse24HourFormat], which has platform-
   /// specific behavior.
-  String formatTimeOfDay(TimeOfDay timeOfDay, { bool alwaysUse24HourFormat = false });
+  String formatTimeOfDay(TimeOfDay timeOfDay, {bool alwaysUse24HourFormat = false});
 
   /// Full unabbreviated year format, e.g. 2017 rather than 17.
   String formatYear(DateTime date);
@@ -450,7 +477,7 @@ abstract class MaterialLocalizations {
   /// list to the start of the list.
   @Deprecated(
     'Use the reorderItemToStart from WidgetsLocalizations instead. '
-    'This feature was deprecated after v3.10.0-2.0.pre.'
+    'This feature was deprecated after v3.10.0-2.0.pre.',
   )
   String get reorderItemToStart;
 
@@ -458,7 +485,7 @@ abstract class MaterialLocalizations {
   /// list to the end of the list.
   @Deprecated(
     'Use the reorderItemToEnd from WidgetsLocalizations instead. '
-    'This feature was deprecated after v3.10.0-2.0.pre.'
+    'This feature was deprecated after v3.10.0-2.0.pre.',
   )
   String get reorderItemToEnd;
 
@@ -466,7 +493,7 @@ abstract class MaterialLocalizations {
   /// list one space up the list.
   @Deprecated(
     'Use the reorderItemUp from WidgetsLocalizations instead. '
-    'This feature was deprecated after v3.10.0-2.0.pre.'
+    'This feature was deprecated after v3.10.0-2.0.pre.',
   )
   String get reorderItemUp;
 
@@ -474,7 +501,7 @@ abstract class MaterialLocalizations {
   /// list one space down the list.
   @Deprecated(
     'Use the reorderItemDown from WidgetsLocalizations instead. '
-    'This feature was deprecated after v3.10.0-2.0.pre.'
+    'This feature was deprecated after v3.10.0-2.0.pre.',
   )
   String get reorderItemDown;
 
@@ -482,7 +509,7 @@ abstract class MaterialLocalizations {
   /// list one space left in the list.
   @Deprecated(
     'Use the reorderItemLeft from WidgetsLocalizations instead. '
-    'This feature was deprecated after v3.10.0-2.0.pre.'
+    'This feature was deprecated after v3.10.0-2.0.pre.',
   )
   String get reorderItemLeft;
 
@@ -490,7 +517,7 @@ abstract class MaterialLocalizations {
   /// list one space right in the list.
   @Deprecated(
     'Use the reorderItemRight from WidgetsLocalizations instead. '
-    'This feature was deprecated after v3.10.0-2.0.pre.'
+    'This feature was deprecated after v3.10.0-2.0.pre.',
   )
   String get reorderItemRight;
 
@@ -746,15 +773,7 @@ class DefaultMaterialLocalizations implements MaterialLocalizations {
     'Sunday',
   ];
 
-  static const List<String> _narrowWeekdays = <String>[
-    'S',
-    'M',
-    'T',
-    'W',
-    'T',
-    'F',
-    'S',
-  ];
+  static const List<String> _narrowWeekdays = <String>['S', 'M', 'T', 'W', 'T', 'F', 'S'];
 
   static const List<String> _shortMonths = <String>[
     'Jan',
@@ -793,8 +812,7 @@ class DefaultMaterialLocalizations implements MaterialLocalizations {
   /// 1582. It will not give valid results for dates prior to that time.
   int _getDaysInMonth(int year, int month) {
     if (month == DateTime.february) {
-      final bool isLeapYear = (year % 4 == 0) && (year % 100 != 0) ||
-          (year % 400 == 0);
+      final bool isLeapYear = (year % 4 == 0) && (year % 100 != 0) || (year % 400 == 0);
       if (isLeapYear) {
         return 29;
       }
@@ -805,7 +823,7 @@ class DefaultMaterialLocalizations implements MaterialLocalizations {
   }
 
   @override
-  String formatHour(TimeOfDay timeOfDay, { bool alwaysUse24HourFormat = false }) {
+  String formatHour(TimeOfDay timeOfDay, {bool alwaysUse24HourFormat = false}) {
     final TimeOfDayFormat format = timeOfDayFormat(alwaysUse24HourFormat: alwaysUse24HourFormat);
     switch (format) {
       case TimeOfDayFormat.h_colon_mm_space_a:
@@ -1023,7 +1041,7 @@ class DefaultMaterialLocalizations implements MaterialLocalizations {
   }
 
   @override
-  String formatTimeOfDay(TimeOfDay timeOfDay, { bool alwaysUse24HourFormat = false }) {
+  String formatTimeOfDay(TimeOfDay timeOfDay, {bool alwaysUse24HourFormat = false}) {
     // Not using intl.DateFormat for two reasons:
     //
     // - DateFormat supports more formats than our material time picker does,
@@ -1143,15 +1161,15 @@ class DefaultMaterialLocalizations implements MaterialLocalizations {
   @override
   String pageRowsInfoTitle(int firstRow, int lastRow, int rowCount, bool rowCountIsApproximate) {
     return rowCountIsApproximate
-      ? '$firstRow–$lastRow of about $rowCount'
-      : '$firstRow–$lastRow of $rowCount';
+        ? '$firstRow–$lastRow of about $rowCount'
+        : '$firstRow–$lastRow of $rowCount';
   }
 
   @override
   String get rowsPerPageTitle => 'Rows per page:';
 
   @override
-  String tabLabel({ required int tabIndex, required int tabCount }) {
+  String tabLabel({required int tabIndex, required int tabCount}) {
     assert(tabIndex >= 1);
     assert(tabCount >= 1);
     return 'Tab $tabIndex of $tabCount';
@@ -1227,10 +1245,8 @@ class DefaultMaterialLocalizations implements MaterialLocalizations {
   ScriptCategory get scriptCategory => ScriptCategory.englishLike;
 
   @override
-  TimeOfDayFormat timeOfDayFormat({ bool alwaysUse24HourFormat = false }) {
-    return alwaysUse24HourFormat
-      ? TimeOfDayFormat.HH_colon_mm
-      : TimeOfDayFormat.h_colon_mm_space_a;
+  TimeOfDayFormat timeOfDayFormat({bool alwaysUse24HourFormat = false}) {
+    return alwaysUse24HourFormat ? TimeOfDayFormat.HH_colon_mm : TimeOfDayFormat.h_colon_mm_space_a;
   }
 
   @override
@@ -1302,7 +1318,8 @@ class DefaultMaterialLocalizations implements MaterialLocalizations {
   /// to create an instance of this class.
   ///
   /// [MaterialApp] automatically adds this value to [MaterialApp.localizationsDelegates].
-  static const LocalizationsDelegate<MaterialLocalizations> delegate = _MaterialLocalizationsDelegate();
+  static const LocalizationsDelegate<MaterialLocalizations> delegate =
+      _MaterialLocalizationsDelegate();
 
   @override
   String remainingTextFieldCharacterCount(int remaining) {
