@@ -86,6 +86,7 @@ const int _kDefaultSizeBytes = 100 << 20; // 100 MiB
 class ImageCache {
   final Map<Object, _PendingImage> _pendingImages = <Object, _PendingImage>{};
   final Map<Object, _CachedImage> _cache = <Object, _CachedImage>{};
+
   /// ImageStreamCompleters with at least one listener. These images may or may
   /// not fit into the _pendingImages or _cache objects.
   ///
@@ -98,6 +99,7 @@ class ImageCache {
   /// evicted when adding a new entry.
   int get maximumSize => _maximumSize;
   int _maximumSize = _kDefaultSize;
+
   /// Changes the maximum cache size.
   ///
   /// If the new size is smaller than the current number of elements, the
@@ -111,10 +113,9 @@ class ImageCache {
     }
     TimelineTask? debugTimelineTask;
     if (!kReleaseMode) {
-      debugTimelineTask = TimelineTask()..start(
-        'ImageCache.setMaximumSize',
-        arguments: <String, dynamic>{'value': value},
-      );
+      debugTimelineTask =
+          TimelineTask()
+            ..start('ImageCache.setMaximumSize', arguments: <String, dynamic>{'value': value});
     }
     _maximumSize = value;
     if (maximumSize == 0) {
@@ -137,6 +138,7 @@ class ImageCache {
   /// maximum bytes.
   int get maximumSizeBytes => _maximumSizeBytes;
   int _maximumSizeBytes = _kDefaultSizeBytes;
+
   /// Changes the maximum cache bytes.
   ///
   /// If the new size is smaller than the current size in bytes, the
@@ -150,10 +152,9 @@ class ImageCache {
     }
     TimelineTask? debugTimelineTask;
     if (!kReleaseMode) {
-      debugTimelineTask = TimelineTask()..start(
-        'ImageCache.setMaximumSizeBytes',
-        arguments: <String, dynamic>{'value': value},
-      );
+      debugTimelineTask =
+          TimelineTask()
+            ..start('ImageCache.setMaximumSizeBytes', arguments: <String, dynamic>{'value': value});
     }
     _maximumSizeBytes = value;
     if (_maximumSizeBytes == 0) {
@@ -242,7 +243,7 @@ class ImageCache {
   /// See also:
   ///
   ///  * [ImageProvider], for providing images to the [Image] widget.
-  bool evict(Object key, { bool includeLive = true }) {
+  bool evict(Object key, {bool includeLive = true}) {
     if (includeLive) {
       // Remove from live images - the cache will not be able to mark
       // it as complete, and it might be getting evicted because it
@@ -255,9 +256,7 @@ class ImageCache {
     final _PendingImage? pendingImage = _pendingImages.remove(key);
     if (pendingImage != null) {
       if (!kReleaseMode) {
-        Timeline.instantSync('ImageCache.evict', arguments: <String, dynamic>{
-          'type': 'pending',
-        });
+        Timeline.instantSync('ImageCache.evict', arguments: <String, dynamic>{'type': 'pending'});
       }
       pendingImage.removeListener();
       return true;
@@ -265,19 +264,17 @@ class ImageCache {
     final _CachedImage? image = _cache.remove(key);
     if (image != null) {
       if (!kReleaseMode) {
-        Timeline.instantSync('ImageCache.evict', arguments: <String, dynamic>{
-          'type': 'keepAlive',
-          'sizeInBytes': image.sizeBytes,
-        });
+        Timeline.instantSync(
+          'ImageCache.evict',
+          arguments: <String, dynamic>{'type': 'keepAlive', 'sizeInBytes': image.sizeBytes},
+        );
       }
       _currentSizeBytes -= image.sizeBytes!;
       image.dispose();
       return true;
     }
     if (!kReleaseMode) {
-      Timeline.instantSync('ImageCache.evict', arguments: <String, dynamic>{
-        'type': 'miss',
-      });
+      Timeline.instantSync('ImageCache.evict', arguments: <String, dynamic>{'type': 'miss'});
     }
     return false;
   }
@@ -300,18 +297,16 @@ class ImageCache {
   void _trackLiveImage(Object key, ImageStreamCompleter completer, int? sizeBytes) {
     // Avoid adding unnecessary callbacks to the completer.
     _liveImages.putIfAbsent(key, () {
-      // Even if no callers to ImageProvider.resolve have listened to the stream,
-      // the cache is listening to the stream and will remove itself once the
-      // image completes to move it from pending to keepAlive.
-      // Even if the cache size is 0, we still add this tracker, which will add
-      // a keep alive handle to the stream.
-      return _LiveImage(
-        completer,
-        () {
-          _liveImages.remove(key);
-        },
-      );
-    }).sizeBytes ??= sizeBytes;
+          // Even if no callers to ImageProvider.resolve have listened to the stream,
+          // the cache is listening to the stream and will remove itself once the
+          // image completes to move it from pending to keepAlive.
+          // Even if the cache size is 0, we still add this tracker, which will add
+          // a keep alive handle to the stream.
+          return _LiveImage(completer, () {
+            _liveImages.remove(key);
+          });
+        }).sizeBytes ??=
+        sizeBytes;
   }
 
   /// Returns the previously cached [ImageStream] for the given key, if available;
@@ -325,15 +320,16 @@ class ImageCache {
   ///
   /// Images that are larger than [maximumSizeBytes] are not cached, and do not
   /// cause other images in the cache to be evicted.
-  ImageStreamCompleter? putIfAbsent(Object key, ImageStreamCompleter Function() loader, { ImageErrorListener? onError }) {
+  ImageStreamCompleter? putIfAbsent(
+    Object key,
+    ImageStreamCompleter Function() loader, {
+    ImageErrorListener? onError,
+  }) {
     TimelineTask? debugTimelineTask;
     if (!kReleaseMode) {
-      debugTimelineTask = TimelineTask()..start(
-        'ImageCache.putIfAbsent',
-        arguments: <String, dynamic>{
-          'key': key.toString(),
-        },
-      );
+      debugTimelineTask =
+          TimelineTask()
+            ..start('ImageCache.putIfAbsent', arguments: <String, dynamic>{'key': key.toString()});
     }
     ImageStreamCompleter? result = _pendingImages[key]?.completer;
     // Nothing needs to be done because the image hasn't loaded yet.
@@ -354,11 +350,7 @@ class ImageCache {
       }
       // The image might have been keptAlive but had no listeners (so not live).
       // Make sure the cache starts tracking it as live again.
-      _trackLiveImage(
-        key,
-        image.completer,
-        image.sizeBytes,
-      );
+      _trackLiveImage(key, image.completer, image.sizeBytes);
       _cache[key] = image;
       return image.completer;
     }
@@ -367,10 +359,7 @@ class ImageCache {
     if (liveImage != null) {
       _touch(
         key,
-        _CachedImage(
-          liveImage.completer,
-          sizeBytes: liveImage.sizeBytes,
-        ),
+        _CachedImage(liveImage.completer, sizeBytes: liveImage.sizeBytes),
         debugTimelineTask,
       );
       if (!kReleaseMode) {
@@ -384,11 +373,13 @@ class ImageCache {
       _trackLiveImage(key, result, null);
     } catch (error, stackTrace) {
       if (!kReleaseMode) {
-        debugTimelineTask!.finish(arguments: <String, dynamic>{
-          'result': 'error',
-          'error': error.toString(),
-          'stackTrace': stackTrace.toString(),
-        });
+        debugTimelineTask!.finish(
+          arguments: <String, dynamic>{
+            'result': 'error',
+            'error': error.toString(),
+            'stackTrace': stackTrace.toString(),
+          },
+        );
       }
       if (onError != null) {
         onError(error, stackTrace);
@@ -417,10 +408,7 @@ class ImageCache {
         sizeBytes = info.sizeBytes;
         info.dispose();
       }
-      final _CachedImage image = _CachedImage(
-        result!,
-        sizeBytes: sizeBytes,
-      );
+      final _CachedImage image = _CachedImage(result!, sizeBytes: sizeBytes);
 
       _trackLiveImage(key, result, sizeBytes);
 
@@ -437,14 +425,13 @@ class ImageCache {
       }
       if (!kReleaseMode && !listenedOnce) {
         debugTimelineTask!
-          ..finish(arguments: <String, dynamic>{
-            'syncCall': syncCall,
-            'sizeInBytes': sizeBytes,
-          })
-          ..finish(arguments: <String, dynamic>{
-            'currentSizeBytes': currentSizeBytes,
-            'currentSize': currentSize,
-          });
+          ..finish(arguments: <String, dynamic>{'syncCall': syncCall, 'sizeInBytes': sizeBytes})
+          ..finish(
+            arguments: <String, dynamic>{
+              'currentSizeBytes': currentSizeBytes,
+              'currentSize': currentSize,
+            },
+          );
       }
       listenedOnce = true;
     }
@@ -552,11 +539,8 @@ class ImageCache {
 /// [ImageProvider.obtainCacheStatus].
 @immutable
 class ImageCacheStatus {
-  const ImageCacheStatus._({
-    this.pending = false,
-    this.keepAlive = false,
-    this.live = false,
-  }) : assert(!pending || !keepAlive);
+  const ImageCacheStatus._({this.pending = false, this.keepAlive = false, this.live = false})
+    : assert(!pending || !keepAlive);
 
   /// An image that has been submitted to [ImageCache.putIfAbsent], but
   /// not yet completed.
@@ -591,17 +575,18 @@ class ImageCacheStatus {
     if (other.runtimeType != runtimeType) {
       return false;
     }
-    return other is ImageCacheStatus
-        && other.pending == pending
-        && other.keepAlive == keepAlive
-        && other.live == live;
+    return other is ImageCacheStatus &&
+        other.pending == pending &&
+        other.keepAlive == keepAlive &&
+        other.live == live;
   }
 
   @override
   int get hashCode => Object.hash(pending, keepAlive, live);
 
   @override
-  String toString() => '${objectRuntimeType(this, 'ImageCacheStatus')}(pending: $pending, live: $live, keepAlive: $keepAlive)';
+  String toString() =>
+      '${objectRuntimeType(this, 'ImageCacheStatus')}(pending: $pending, live: $live, keepAlive: $keepAlive)';
 }
 
 /// Base class for [_CachedImage] and [_LiveImage].
@@ -609,10 +594,7 @@ class ImageCacheStatus {
 /// Exists primarily so that a [_LiveImage] cannot be added to the
 /// [ImageCache._cache].
 abstract class _CachedImageBase {
-  _CachedImageBase(
-    this.completer, {
-    this.sizeBytes,
-  }) : handle = completer.keepAlive() {
+  _CachedImageBase(this.completer, {this.sizeBytes}) : handle = completer.keepAlive() {
     // TODO(polina-c): stop duplicating code across disposables
     // https://github.com/flutter/flutter/issues/137435
     if (kFlutterMemoryAllocationsEnabled) {
@@ -650,7 +632,7 @@ class _CachedImage extends _CachedImageBase {
 
 class _LiveImage extends _CachedImageBase {
   _LiveImage(ImageStreamCompleter completer, VoidCallback handleRemove, {int? sizeBytes})
-      : super(completer, sizeBytes: sizeBytes) {
+    : super(completer, sizeBytes: sizeBytes) {
     _handleRemove = () {
       handleRemove();
       dispose();
