@@ -6,17 +6,19 @@
 library;
 
 import 'dart:math' show max;
-import 'dart:ui' as ui show
-  BoxHeightStyle,
-  BoxWidthStyle,
-  GlyphInfo,
-  LineMetrics,
-  Paragraph,
-  ParagraphBuilder,
-  ParagraphConstraints,
-  ParagraphStyle,
-  PlaceholderAlignment,
-  TextStyle;
+import 'dart:ui'
+    as ui
+    show
+        BoxHeightStyle,
+        BoxWidthStyle,
+        GlyphInfo,
+        LineMetrics,
+        Paragraph,
+        ParagraphBuilder,
+        ParagraphConstraints,
+        ParagraphStyle,
+        PlaceholderAlignment,
+        TextStyle;
 
 import 'package:flutter/foundation.dart';
 import 'package:flutter/services.dart';
@@ -82,7 +84,10 @@ class PlaceholderDimensions {
   });
 
   /// A constant representing an empty placeholder.
-  static const PlaceholderDimensions empty = PlaceholderDimensions(size: Size.zero, alignment: ui.PlaceholderAlignment.bottom);
+  static const PlaceholderDimensions empty = PlaceholderDimensions(
+    size: Size.zero,
+    alignment: ui.PlaceholderAlignment.bottom,
+  );
 
   /// Width and height dimensions of the placeholder.
   final Size size;
@@ -117,11 +122,11 @@ class PlaceholderDimensions {
     if (identical(this, other)) {
       return true;
     }
-    return other is PlaceholderDimensions
-        && other.size == size
-        && other.alignment == alignment
-        && other.baseline == baseline
-        && other.baselineOffset == baselineOffset;
+    return other is PlaceholderDimensions &&
+        other.size == size &&
+        other.alignment == alignment &&
+        other.baseline == baseline &&
+        other.baselineOffset == baselineOffset;
   }
 
   @override
@@ -135,7 +140,8 @@ class PlaceholderDimensions {
       ui.PlaceholderAlignment.middle ||
       ui.PlaceholderAlignment.aboveBaseline ||
       ui.PlaceholderAlignment.belowBaseline => 'PlaceholderDimensions($size, $alignment)',
-      ui.PlaceholderAlignment.baseline      => 'PlaceholderDimensions($size, $alignment($baselineOffset from top))',
+      ui.PlaceholderAlignment.baseline =>
+        'PlaceholderDimensions($size, $alignment($baselineOffset from top))',
     };
   }
 }
@@ -176,7 +182,8 @@ class WordBoundary extends TextBoundary {
   final ui.Paragraph _paragraph;
 
   @override
-  TextRange getTextBoundaryAt(int position) => _paragraph.getWordBoundary(TextPosition(offset: max(position, 0)));
+  TextRange getTextBoundaryAt(int position) =>
+      _paragraph.getWordBoundary(TextPosition(offset: max(position, 0)));
 
   // Combines two UTF-16 code units (high surrogate + low surrogate) into a
   // single code point that represents a supplementary character.
@@ -202,23 +209,27 @@ class WordBoundary extends TextBoundary {
     return switch (codeUnitAtIndex & 0xFC00) {
       0xD800 => _codePointFromSurrogates(codeUnitAtIndex, _text.codeUnitAt(index + 1)!),
       0xDC00 => _codePointFromSurrogates(_text.codeUnitAt(index - 1)!, codeUnitAtIndex),
-      _      => codeUnitAtIndex,
+      _ => codeUnitAtIndex,
     };
   }
 
   static bool _isNewline(int codePoint) {
     // Carriage Return is not treated as a hard line break.
     return switch (codePoint) {
-      0x000A ||       // Line Feed
-      0x0085 ||       // New Line
-      0x000B ||       // Form Feed
-      0x000C ||       // Vertical Feed
-      0x2028 ||       // Line Separator
+      0x000A || // Line Feed
+      0x0085 || // New Line
+      0x000B || // Form Feed
+      0x000C || // Vertical Feed
+      0x2028 || // Line Separator
       0x2029 => true, // Paragraph Separator
       _ => false,
     };
   }
 
+  static final RegExp _regExpSpaceSeparatorOrPunctuation = RegExp(
+    r'[\p{Space_Separator}\p{Punctuation}]',
+    unicode: true,
+  );
   bool _skipSpacesAndPunctuations(int offset, bool forward) {
     // Use code point since some punctuations are supplementary characters.
     // "inner" here refers to the code unit that's before the break in the
@@ -232,10 +243,15 @@ class WordBoundary extends TextBoundary {
     // https://unicode-org.github.io/icu/userguide/boundaryanalysis/break-rules.html#word-dictionaries
     //
     // WB1 & WB2: always break at the start or the end of the text.
-    final bool hardBreakRulesApply = innerCodePoint == null || outerCodeUnit == null
-    // WB3a & WB3b: always break before and after newlines.
-                                  || _isNewline(innerCodePoint) || _isNewline(outerCodeUnit);
-    return hardBreakRulesApply || !RegExp(r'[\p{Space_Separator}\p{Punctuation}]', unicode: true).hasMatch(String.fromCharCode(innerCodePoint));
+    final bool hardBreakRulesApply =
+        innerCodePoint == null ||
+        outerCodeUnit == null
+        // WB3a & WB3b: always break before and after newlines.
+        ||
+        _isNewline(innerCodePoint) ||
+        _isNewline(outerCodeUnit);
+    return hardBreakRulesApply ||
+        !_regExpSpaceSeparatorOrPunctuation.hasMatch(String.fromCharCode(innerCodePoint));
   }
 
   /// Returns a [TextBoundary] suitable for handling keyboard navigation
@@ -265,16 +281,14 @@ class _UntilTextBoundary extends TextBoundary {
     }
     final int? offset = _textBoundary.getLeadingTextBoundaryAt(position);
     return offset == null || _predicate(offset, false)
-      ? offset
-      : getLeadingTextBoundaryAt(offset - 1);
+        ? offset
+        : getLeadingTextBoundaryAt(offset - 1);
   }
 
   @override
   int? getTrailingTextBoundaryAt(int position) {
     final int? offset = _textBoundary.getTrailingTextBoundaryAt(max(position, 0));
-    return offset == null || _predicate(offset, true)
-      ? offset
-      : getTrailingTextBoundaryAt(offset);
+    return offset == null || _predicate(offset, true) ? offset : getTrailingTextBoundaryAt(offset);
   }
 }
 
@@ -332,6 +346,8 @@ class _TextLayout {
     };
   }
 
+  static final RegExp _regExpSpaceSeparators = RegExp(r'\p{Space_Separator}', unicode: true);
+
   /// The line caret metrics representing the end of text location.
   ///
   /// This is usually used when the caret is placed at the end of the text
@@ -356,15 +372,20 @@ class _TextLayout {
     // Luckily they have the same bidi embedding level as the paragraph as per
     // https://unicode.org/reports/tr9/#L1, so we can anchor the caret to the
     // last logical trailing space.
-    final bool hasTrailingSpaces = switch (rawString.codeUnitAt(rawString.length - 1)) {
-      0x9 ||        // horizontal tab
-      0x3000 ||     // ideographic space
-      0x20 => true, // space
-      _ => false,
+    // Whitespace character definitions refer to Java/ICU, not Unicode-Zs.
+    // https://github.com/unicode-org/icu/blob/23d9628f88a2d0127c564ad98297061c36d3ce77/icu4c/source/common/unicode/uchar.h#L3388-L3425
+    final String lastCodeUnit = rawString[rawString.length - 1];
+    final bool hasTrailingSpaces = switch (lastCodeUnit.codeUnitAt(0)) {
+      0x0009 => true, // horizontal tab
+      0x00A0 || // no-break space
+      0x2007 || // figure space
+      0x202F => false, // narrow no-break space
+      _ => _regExpSpaceSeparators.hasMatch(lastCodeUnit),
     };
 
     final double baseline = lineMetrics.baseline;
     final double dx;
+    final double height;
     late final ui.GlyphInfo? lastGlyph = _paragraph.getGlyphInfoAt(rawString.length - 1);
     // TODO(LongCatIsLooong): handle the case where maxLine is set to non-null
     // and the last line ends with trailing whitespaces.
@@ -375,13 +396,19 @@ class _TextLayout {
         TextDirection.ltr => glyphBounds.right,
         TextDirection.rtl => glyphBounds.left,
       };
+      height = glyphBounds.height;
     } else {
       dx = switch (writingDirection) {
         TextDirection.ltr => lineMetrics.left + lineMetrics.width,
         TextDirection.rtl => lineMetrics.left,
       };
+      height = lineMetrics.height;
     }
-    return _LineCaretMetrics(offset: Offset(dx, baseline), writingDirection: writingDirection);
+    return _LineCaretMetrics(
+      offset: Offset(dx, baseline),
+      writingDirection: writingDirection,
+      height: height,
+    );
   }
 
   double _contentWidthFor(double minWidth, double maxWidth, TextWidthBasis widthBasis) {
@@ -397,8 +424,12 @@ class _TextLayout {
 // depends on the current text layout, which will be invalidated as soon as the
 // text layout is invalidated.
 class _TextPainterLayoutCacheWithOffset {
-  _TextPainterLayoutCacheWithOffset(this.layout, this.textAlignment, this.layoutMaxWidth, this.contentWidth)
-    : assert(textAlignment >= 0.0 && textAlignment <= 1.0),
+  _TextPainterLayoutCacheWithOffset(
+    this.layout,
+    this.textAlignment,
+    this.layoutMaxWidth,
+    this.contentWidth,
+  ) : assert(textAlignment >= 0.0 && textAlignment <= 1.0),
       assert(!layoutMaxWidth.isNaN),
       assert(!contentWidth.isNaN);
 
@@ -470,8 +501,12 @@ class _TextPainterLayoutCacheWithOffset {
     final double maxIntrinsicWidth = paragraph.maxIntrinsicWidth;
     // Skip line breaking if the input width remains the same, of there will be
     // no soft breaks.
-    final bool skipLineBreaking = maxWidth == layoutMaxWidth  // Same input max width so relayout is unnecessary.
-      || ((paragraph.width - maxIntrinsicWidth) > -precisionErrorTolerance && (maxWidth - maxIntrinsicWidth) > -precisionErrorTolerance);
+    final bool skipLineBreaking =
+        maxWidth ==
+            layoutMaxWidth // Same input max width so relayout is unnecessary.
+            ||
+        ((paragraph.width - maxIntrinsicWidth) > -precisionErrorTolerance &&
+            (maxWidth - maxIntrinsicWidth) > -precisionErrorTolerance);
     if (skipLineBreaking) {
       // Adjust the content width in case the TextWidthBasis changed.
       contentWidth = layout._contentWidthFor(minWidth, maxWidth, widthBasis);
@@ -482,7 +517,8 @@ class _TextPainterLayoutCacheWithOffset {
 
   // ---- Cached Values ----
 
-  List<TextBox> get inlinePlaceholderBoxes => _cachedInlinePlaceholderBoxes ??= paragraph.getBoxesForPlaceholders();
+  List<TextBox> get inlinePlaceholderBoxes =>
+      _cachedInlinePlaceholderBoxes ??= paragraph.getBoxesForPlaceholders();
   List<TextBox>? _cachedInlinePlaceholderBoxes;
 
   List<ui.LineMetrics> get lineMetrics => _cachedLineMetrics ??= paragraph.computeLineMetrics();
@@ -495,8 +531,13 @@ class _TextPainterLayoutCacheWithOffset {
 /// The _CaretMetrics for carets located in a non-empty paragraph. Such carets
 /// are anchored to the trailing edge or the leading edge of a glyph, or a
 /// ligature component.
-final class _LineCaretMetrics {
-  const _LineCaretMetrics({required this.offset, required this.writingDirection});
+class _LineCaretMetrics {
+  const _LineCaretMetrics({
+    required this.offset,
+    required this.writingDirection,
+    required this.height,
+  });
+
   /// The offset from the top left corner of the paragraph to the caret's top
   /// start location.
   final Offset offset;
@@ -506,10 +547,17 @@ final class _LineCaretMetrics {
   /// right of [offset].
   final TextDirection writingDirection;
 
+  /// The recommended height of the caret.
+  final double height;
+
   _LineCaretMetrics shift(Offset offset) {
     return offset == Offset.zero
-      ? this
-      : _LineCaretMetrics(offset: offset + this.offset, writingDirection: writingDirection);
+        ? this
+        : _LineCaretMetrics(
+          offset: offset + this.offset,
+          writingDirection: writingDirection,
+          height: height,
+        );
   }
 }
 
@@ -565,11 +613,15 @@ class TextPainter {
     TextHeightBehavior? textHeightBehavior,
   }) : assert(text == null || text.debugAssertIsValid()),
        assert(maxLines == null || maxLines > 0),
-       assert(textScaleFactor == 1.0 || identical(textScaler, TextScaler.noScaling), 'Use textScaler instead.'),
+       assert(
+         textScaleFactor == 1.0 || identical(textScaler, TextScaler.noScaling),
+         'Use textScaler instead.',
+       ),
        _text = text,
        _textAlign = textAlign,
        _textDirection = textDirection,
-       _textScaler = textScaler == TextScaler.noScaling ? TextScaler.linear(textScaleFactor) : textScaler,
+       _textScaler =
+           textScaler == TextScaler.noScaling ? TextScaler.linear(textScaleFactor) : textScaler,
        _maxLines = maxLines,
        _ellipsis = ellipsis,
        _locale = locale,
@@ -623,7 +675,8 @@ class TextPainter {
       text: text,
       textAlign: textAlign,
       textDirection: textDirection,
-      textScaler: textScaler == TextScaler.noScaling ? TextScaler.linear(textScaleFactor) : textScaler,
+      textScaler:
+          textScaler == TextScaler.noScaling ? TextScaler.linear(textScaleFactor) : textScaler,
       maxLines: maxLines,
       ellipsis: ellipsis,
       locale: locale,
@@ -675,7 +728,8 @@ class TextPainter {
       text: text,
       textAlign: textAlign,
       textDirection: textDirection,
-      textScaler: textScaler == TextScaler.noScaling ? TextScaler.linear(textScaleFactor) : textScaler,
+      textScaler:
+          textScaler == TextScaler.noScaling ? TextScaler.linear(textScaleFactor) : textScaler,
       maxLines: maxLines,
       ellipsis: ellipsis,
       locale: locale,
@@ -710,8 +764,13 @@ class TextPainter {
     if (_layoutCache == null) {
       throw FlutterError.fromParts(<DiagnosticsNode>[
         ErrorSummary('Text layout not available'),
-        if (_debugMarkNeedsLayoutCallStack != null) DiagnosticsStackTrace('The calls that first invalidated the text layout were', _debugMarkNeedsLayoutCallStack)
-        else ErrorDescription('The TextPainter has never been laid out.')
+        if (_debugMarkNeedsLayoutCallStack != null)
+          DiagnosticsStackTrace(
+            'The calls that first invalidated the text layout were',
+            _debugMarkNeedsLayoutCallStack,
+          )
+        else
+          ErrorDescription('The TextPainter has never been laid out.'),
       ]);
     }
     return true;
@@ -756,9 +815,10 @@ class TextPainter {
       _layoutTemplate = null;
     }
 
-    final RenderComparison comparison = value == null
-      ? RenderComparison.layout
-      : _text?.compareTo(value) ?? RenderComparison.layout;
+    final RenderComparison comparison =
+        value == null
+            ? RenderComparison.layout
+            : _text?.compareTo(value) ?? RenderComparison.layout;
 
     _text = value;
     _cachedPlainText = null;
@@ -780,6 +840,7 @@ class TextPainter {
     _cachedPlainText ??= _text?.toPlainText(includeSemanticsLabels: false);
     return _cachedPlainText ?? '';
   }
+
   String? _cachedPlainText;
 
   /// How the text should be aligned horizontally.
@@ -918,6 +979,7 @@ class TextPainter {
   /// After this is set, you must call [layout] before the next call to [paint].
   int? get maxLines => _maxLines;
   int? _maxLines;
+
   /// The value may be null. If it is not null, then it must be greater than zero.
   set maxLines(int? value) {
     assert(value == null || value > 0);
@@ -959,7 +1021,9 @@ class TextPainter {
     if (_textWidthBasis == value) {
       return;
     }
-    assert(() { return _debugNeedsRelayout = true; }());
+    assert(() {
+      return _debugNeedsRelayout = true;
+    }());
     _textWidthBasis = value;
   }
 
@@ -1021,10 +1085,14 @@ class TextPainter {
     _placeholderDimensions = value;
     markNeedsLayout();
   }
+
   List<PlaceholderDimensions>? _placeholderDimensions;
 
-  ui.ParagraphStyle _createParagraphStyle([ TextAlign? textAlignOverride ]) {
-    assert(textDirection != null, 'TextPainter.textDirection must be set to a non-null value before using the TextPainter.');
+  ui.ParagraphStyle _createParagraphStyle([TextAlign? textAlignOverride]) {
+    assert(
+      textDirection != null,
+      'TextPainter.textDirection must be set to a non-null value before using the TextPainter.',
+    );
     final TextStyle baseStyle = _text?.style ?? const TextStyle();
     return baseStyle.getParagraphStyle(
       textAlign: textAlignOverride ?? textAlign,
@@ -1048,8 +1116,7 @@ class TextPainter {
       builder.pushStyle(textStyle);
     }
     builder.addText(' ');
-    return builder.build()
-      ..layout(const ui.ParagraphConstraints(width: double.infinity));
+    return builder.build()..layout(const ui.ParagraphConstraints(width: double.infinity));
   }
 
   ui.Paragraph _getOrCreateLayoutTemplate() => _layoutTemplate ??= _createLayoutTemplate();
@@ -1158,7 +1225,7 @@ class TextPainter {
   ///
   /// The [text] and [textDirection] properties must be non-null before this is
   /// called.
-  void layout({ double minWidth = 0.0, double maxWidth = double.infinity }) {
+  void layout({double minWidth = 0.0, double maxWidth = double.infinity}) {
     assert(!maxWidth.isNaN);
     assert(!minWidth.isNaN);
     assert(() {
@@ -1173,11 +1240,15 @@ class TextPainter {
 
     final InlineSpan? text = this.text;
     if (text == null) {
-      throw StateError('TextPainter.text must be set to a non-null value before using the TextPainter.');
+      throw StateError(
+        'TextPainter.text must be set to a non-null value before using the TextPainter.',
+      );
     }
     final TextDirection? textDirection = this.textDirection;
     if (textDirection == null) {
-      throw StateError('TextPainter.textDirection must be set to a non-null value before using the TextPainter.');
+      throw StateError(
+        'TextPainter.textDirection must be set to a non-null value before using the TextPainter.',
+      );
     }
 
     final double paintOffsetAlignment = _computePaintOffsetFraction(textAlign, textDirection);
@@ -1185,7 +1256,8 @@ class TextPainter {
     // when the text is not left-aligned, so we don't have to deal with an
     // infinite paint offset.
     final bool adjustMaxWidth = !maxWidth.isFinite && paintOffsetAlignment != 0;
-    final double? adjustedMaxWidth = !adjustMaxWidth ? maxWidth : cachedLayout?.layout.maxIntrinsicLineExtent;
+    final double? adjustedMaxWidth =
+        !adjustMaxWidth ? maxWidth : cachedLayout?.layout.maxIntrinsicLineExtent;
     final double layoutMaxWidth = adjustedMaxWidth ?? maxWidth;
 
     // Only rebuild the paragraph when there're layout changes, even when
@@ -1195,8 +1267,9 @@ class TextPainter {
     //    the paragraph rebuilds is unnecessary)
     // 2. the user could be measuring the text layout so `paint` will never be
     //    called.
-    final ui.Paragraph paragraph = (cachedLayout?.paragraph ?? _createParagraph(text))
-      ..layout(ui.ParagraphConstraints(width: layoutMaxWidth));
+    final ui.Paragraph paragraph =
+        (cachedLayout?.paragraph ?? _createParagraph(text))
+          ..layout(ui.ParagraphConstraints(width: layoutMaxWidth));
     final _TextLayout layout = _TextLayout._(paragraph, textDirection, this);
     final double contentWidth = layout._contentWidthFor(minWidth, maxWidth, textWidthBasis);
 
@@ -1208,9 +1281,19 @@ class TextPainter {
       assert(maxWidth.isInfinite);
       final double newInputWidth = layout.maxIntrinsicLineExtent;
       paragraph.layout(ui.ParagraphConstraints(width: newInputWidth));
-      newLayoutCache = _TextPainterLayoutCacheWithOffset(layout, paintOffsetAlignment, newInputWidth, contentWidth);
+      newLayoutCache = _TextPainterLayoutCacheWithOffset(
+        layout,
+        paintOffsetAlignment,
+        newInputWidth,
+        contentWidth,
+      );
     } else {
-      newLayoutCache = _TextPainterLayoutCacheWithOffset(layout, paintOffsetAlignment, layoutMaxWidth, contentWidth);
+      newLayoutCache = _TextPainterLayoutCacheWithOffset(
+        layout,
+        paintOffsetAlignment,
+        layoutMaxWidth,
+        contentWidth,
+      );
     }
     _layoutCache = newLayoutCache;
   }
@@ -1252,7 +1335,8 @@ class TextPainter {
       // no API to only make those updates so the paragraph has to be recreated
       // and re-laid out.
       assert(!layoutCache.layoutMaxWidth.isNaN);
-      layoutCache.layout._paragraph = _createParagraph(text!)..layout(ui.ParagraphConstraints(width: layoutCache.layoutMaxWidth));
+      layoutCache.layout._paragraph = _createParagraph(text!)
+        ..layout(ui.ParagraphConstraints(width: layoutCache.layoutMaxWidth));
       assert(paragraph.width == layoutCache.layout._paragraph.width);
       paragraph.dispose();
       assert(debugSize == size);
@@ -1338,20 +1422,28 @@ class TextPainter {
       // The full width is not (width - caretPrototype.width), because
       // RenderEditable reserves cursor width on the right. Ideally this
       // should be handled by RenderEditable instead.
-      final double dx = paintOffsetAlignment == 0 ? 0 : paintOffsetAlignment * layoutCache.contentWidth;
+      final double dx =
+          paintOffsetAlignment == 0 ? 0 : paintOffsetAlignment * layoutCache.contentWidth;
       return Offset(dx, 0.0);
     }
 
     final Offset rawOffset = switch (caretMetrics) {
       _LineCaretMetrics(writingDirection: TextDirection.ltr, :final Offset offset) => offset,
-      _LineCaretMetrics(writingDirection: TextDirection.rtl, :final Offset offset) => Offset(offset.dx - caretPrototype.width, offset.dy),
+      _LineCaretMetrics(writingDirection: TextDirection.rtl, :final Offset offset) => Offset(
+        offset.dx - caretPrototype.width,
+        offset.dy,
+      ),
     };
     // If offset.dx is outside of the advertised content area, then the associated
     // glyph belongs to a trailing whitespace character. Ideally the behavior
     // should be handled by higher-level implementations (for instance,
     // RenderEditable reserves width for showing the caret, it's best to handle
     // the clamping there).
-    final double adjustedDx = clampDouble(rawOffset.dx + layoutCache.paintOffset.dx, 0, layoutCache.contentWidth);
+    final double adjustedDx = clampDouble(
+      rawOffset.dx + layoutCache.paintOffset.dx,
+      0,
+      layoutCache.contentWidth,
+    );
     return Offset(adjustedDx, rawOffset.dy + layoutCache.paintOffset.dy);
   }
 
@@ -1361,12 +1453,27 @@ class TextPainter {
   ///
   /// Valid only after [layout] has been called.
   double getFullHeightForCaret(TextPosition position, Rect caretPrototype) {
-    final TextBox textBox = _getOrCreateLayoutTemplate().getBoxesForRange(0, 1, boxHeightStyle: ui.BoxHeightStyle.strut).single;
+    // The if condition is derived from
+    // https://github.com/google/skia/blob/0086a17e0d4cc676cf88cae671ba5ee967eb7241/modules/skparagraph/src/TextLine.cpp#L1244-L1246
+    // which is set here:
+    // https://github.com/flutter/engine/blob/a821b8790c9fd0e095013cd5bd1f20273bc1ee47/third_party/txt/src/skia/paragraph_builder_skia.cc#L134
+    if (strutStyle == null || strutStyle == StrutStyle.disabled || strutStyle?.fontSize == 0.0) {
+      final double? heightFromCaretMetrics = _computeCaretMetrics(position)?.height;
+      if (heightFromCaretMetrics != null) {
+        return heightFromCaretMetrics;
+      }
+    }
+    final TextBox textBox =
+        _getOrCreateLayoutTemplate()
+            .getBoxesForRange(0, 1, boxHeightStyle: ui.BoxHeightStyle.strut)
+            .single;
     return textBox.toRect().height;
   }
 
-  bool _isNewlineAtOffset(int offset) => 0 <= offset && offset < plainText.length
-                                      && WordBoundary._isNewline(plainText.codeUnitAt(offset));
+  bool _isNewlineAtOffset(int offset) =>
+      0 <= offset &&
+      offset < plainText.length &&
+      WordBoundary._isNewline(plainText.codeUnitAt(offset));
 
   // Cached caret metrics. This allows multiple invokes of [getOffsetForCaret] and
   // [getFullHeightForCaret] in a row without performing redundant and expensive
@@ -1429,10 +1536,15 @@ class TextPainter {
     }
 
     final (int offset, bool anchorToLeadingEdge) = switch (position) {
-      TextPosition(offset: 0) => (0, true), // As a special case, always anchor to the leading edge of the first grapheme regardless of the affinity.
+      TextPosition(offset: 0) => (
+        0,
+        true,
+      ), // As a special case, always anchor to the leading edge of the first grapheme regardless of the affinity.
       TextPosition(:final int offset, affinity: TextAffinity.downstream) => (offset, true),
-      TextPosition(:final int offset, affinity: TextAffinity.upstream) when _isNewlineAtOffset(offset - 1) => (offset, true),
-      TextPosition(:final int offset, affinity: TextAffinity.upstream) => (offset - 1, false)
+      TextPosition(:final int offset, affinity: TextAffinity.upstream)
+          when _isNewlineAtOffset(offset - 1) =>
+        (offset, true),
+      TextPosition(:final int offset, affinity: TextAffinity.upstream) => (offset - 1, false),
     };
 
     final int caretPositionCacheKey = anchorToLeadingEdge ? offset : -offset - 1;
@@ -1444,7 +1556,8 @@ class TextPainter {
 
     if (glyphInfo == null) {
       // If the glyph isn't laid out, then the position points to a character
-      // that is not laid out. Use the EOT caret.
+      // that is not laid out (the part of text is invisible due to maxLines or
+      // infinite paragraph x offset). Use the EOT caret.
       // TODO(LongCatIsLooong): assert when an invalid position is given.
       final ui.Paragraph template = _getOrCreateLayoutTemplate();
       assert(template.numberOfLines == 1);
@@ -1469,8 +1582,11 @@ class TextPainter {
     }
 
     final _LineCaretMetrics metrics;
-    final List<TextBox> boxes = cachedLayout.paragraph
-      .getBoxesForRange(graphemeRange.start, graphemeRange.end, boxHeightStyle: ui.BoxHeightStyle.strut);
+    final List<TextBox> boxes = cachedLayout.paragraph.getBoxesForRange(
+      graphemeRange.start,
+      graphemeRange.end,
+      boxHeightStyle: ui.BoxHeightStyle.strut,
+    );
 
     if (boxes.isNotEmpty) {
       final bool anchorToLeft = switch (glyphInfo.writingDirection) {
@@ -1481,6 +1597,7 @@ class TextPainter {
       metrics = _LineCaretMetrics(
         offset: Offset(anchorToLeft ? box.left : box.right, box.top),
         writingDirection: box.direction,
+        height: box.bottom - box.top,
       );
     } else {
       // Fall back to glyphInfo. This should only happen when using the HTML renderer.
@@ -1493,6 +1610,7 @@ class TextPainter {
       metrics = _LineCaretMetrics(
         offset: Offset(dx, graphemeBounds.top),
         writingDirection: glyphInfo.writingDirection,
+        height: graphemeBounds.height,
       );
     }
 
@@ -1538,8 +1656,8 @@ class TextPainter {
       boxWidthStyle: boxWidthStyle,
     );
     return offset == Offset.zero
-      ? boxes
-      : boxes.map((TextBox box) => _shiftTextBox(box, offset)).toList(growable: false);
+        ? boxes
+        : boxes.map((TextBox box) => _shiftTextBox(box, offset)).toList(growable: false);
   }
 
   /// Returns the [GlyphInfo] of the glyph closest to the given `offset` in the
@@ -1548,15 +1666,21 @@ class TextPainter {
   ///
   /// This method first finds the line closest to `offset.dy`, and then returns
   /// the [GlyphInfo] of the closest glyph(s) within that line.
-   ui.GlyphInfo? getClosestGlyphForOffset(Offset offset) {
+  ui.GlyphInfo? getClosestGlyphForOffset(Offset offset) {
     assert(_debugAssertTextLayoutIsValid);
     assert(!_debugNeedsRelayout);
     final _TextPainterLayoutCacheWithOffset cachedLayout = _layoutCache!;
-    final ui.GlyphInfo? rawGlyphInfo = cachedLayout.paragraph.getClosestGlyphInfoForOffset(offset - cachedLayout.paintOffset);
+    final ui.GlyphInfo? rawGlyphInfo = cachedLayout.paragraph.getClosestGlyphInfoForOffset(
+      offset - cachedLayout.paintOffset,
+    );
     if (rawGlyphInfo == null || cachedLayout.paintOffset == Offset.zero) {
       return rawGlyphInfo;
     }
-    return ui.GlyphInfo(rawGlyphInfo.graphemeClusterLayoutBounds.shift(cachedLayout.paintOffset), rawGlyphInfo.graphemeClusterCodeUnitRange, rawGlyphInfo.writingDirection);
+    return ui.GlyphInfo(
+      rawGlyphInfo.graphemeClusterLayoutBounds.shift(cachedLayout.paintOffset),
+      rawGlyphInfo.graphemeClusterCodeUnitRange,
+      rawGlyphInfo.writingDirection,
+    );
   }
 
   /// Returns the closest position within the text for the given pixel offset.
@@ -1650,8 +1774,10 @@ class TextPainter {
     }
     final List<ui.LineMetrics> rawMetrics = layout.lineMetrics;
     return offset == Offset.zero
-      ? rawMetrics
-      : rawMetrics.map((ui.LineMetrics metrics) => _shiftLineMetrics(metrics, offset)).toList(growable: false);
+        ? rawMetrics
+        : rawMetrics
+            .map((ui.LineMetrics metrics) => _shiftLineMetrics(metrics, offset))
+            .toList(growable: false);
   }
 
   bool _disposed = false;
