@@ -89,25 +89,23 @@ void main() {
 
   double textOpacity(WidgetTester tester, String textValue) {
     final FadeTransition opacityWidget = tester.widget<FadeTransition>(
-      find.ancestor(
-        of: find.text(textValue),
-        matching: find.byType(FadeTransition),
-      ).first,
+      find.ancestor(of: find.text(textValue), matching: find.byType(FadeTransition)).first,
     );
     return opacityWidget.opacity.value;
   }
 
   group('InputDatePickerFormField', () {
-
     testWidgets('Initial date is the default', (WidgetTester tester) async {
       final GlobalKey<FormState> formKey = GlobalKey<FormState>();
       final DateTime initialDate = DateTime(2016, DateTime.february, 21);
       DateTime? inputDate;
-      await tester.pumpWidget(inputDatePickerField(
-        initialDate: initialDate,
-        onDateSaved: (DateTime date) => inputDate = date,
-        formKey: formKey,
-      ));
+      await tester.pumpWidget(
+        inputDatePickerField(
+          initialDate: initialDate,
+          onDateSaved: (DateTime date) => inputDate = date,
+          formKey: formKey,
+        ),
+      );
       expect(textFieldController(tester).value.text, equals('02/21/2016'));
       formKey.currentState!.save();
       expect(inputDate, equals(initialDate));
@@ -116,14 +114,10 @@ void main() {
     testWidgets('Changing initial date is reflected in text value', (WidgetTester tester) async {
       final DateTime initialDate = DateTime(2016, DateTime.february, 21);
       final DateTime updatedInitialDate = DateTime(2016, DateTime.february, 23);
-      await tester.pumpWidget(inputDatePickerField(
-        initialDate: initialDate,
-      ));
+      await tester.pumpWidget(inputDatePickerField(initialDate: initialDate));
       expect(textFieldController(tester).value.text, equals('02/21/2016'));
 
-      await tester.pumpWidget(inputDatePickerField(
-        initialDate: updatedInitialDate,
-      ));
+      await tester.pumpWidget(inputDatePickerField(initialDate: updatedInitialDate));
       await tester.pumpAndSettle();
       expect(textFieldController(tester).value.text, equals('02/23/2016'));
     });
@@ -131,10 +125,9 @@ void main() {
     testWidgets('Valid date entry', (WidgetTester tester) async {
       final GlobalKey<FormState> formKey = GlobalKey<FormState>();
       DateTime? inputDate;
-      await tester.pumpWidget(inputDatePickerField(
-        onDateSaved: (DateTime date) => inputDate = date,
-        formKey: formKey,
-      ));
+      await tester.pumpWidget(
+        inputDatePickerField(onDateSaved: (DateTime date) => inputDate = date, formKey: formKey),
+      );
 
       textFieldController(tester).text = '02/21/2016';
       formKey.currentState!.save();
@@ -144,10 +137,9 @@ void main() {
     testWidgets('Invalid text entry shows errorFormat text', (WidgetTester tester) async {
       final GlobalKey<FormState> formKey = GlobalKey<FormState>();
       DateTime? inputDate;
-      await tester.pumpWidget(inputDatePickerField(
-        onDateSaved: (DateTime date) => inputDate = date,
-        formKey: formKey,
-      ));
+      await tester.pumpWidget(
+        inputDatePickerField(onDateSaved: (DateTime date) => inputDate = date, formKey: formKey),
+      );
       // Default errorFormat text
       expect(find.text('Invalid format.'), findsNothing);
       await tester.enterText(find.byType(TextField), 'foobar');
@@ -157,77 +149,91 @@ void main() {
       expect(find.text('Invalid format.'), findsOneWidget);
 
       // Change to a custom errorFormat text
-      await tester.pumpWidget(inputDatePickerField(
-        onDateSaved: (DateTime date) => inputDate = date,
-        errorFormatText: 'That is not a date.',
-        formKey: formKey,
-      ));
+      await tester.pumpWidget(
+        inputDatePickerField(
+          onDateSaved: (DateTime date) => inputDate = date,
+          errorFormatText: 'That is not a date.',
+          formKey: formKey,
+        ),
+      );
       expect(formKey.currentState!.validate(), isFalse);
       await tester.pumpAndSettle();
       expect(find.text('Invalid format.'), findsNothing);
       expect(find.text('That is not a date.'), findsOneWidget);
     });
 
-    testWidgets('Valid text entry, but date outside first or last date shows bounds shows errorInvalid text', (WidgetTester tester) async {
-      final GlobalKey<FormState> formKey = GlobalKey<FormState>();
-      DateTime? inputDate;
-      await tester.pumpWidget(inputDatePickerField(
-        firstDate: DateTime(1966, DateTime.february, 21),
-        lastDate: DateTime(2040, DateTime.february, 23),
-        onDateSaved: (DateTime date) => inputDate = date,
-        formKey: formKey,
-      ));
-      // Default errorInvalid text
-      expect(find.text('Out of range.'), findsNothing);
-      // Before first date
-      await tester.enterText(find.byType(TextField), '02/21/1950');
-      expect(formKey.currentState!.validate(), isFalse);
-      await tester.pumpAndSettle();
-      expect(inputDate, isNull);
-      expect(find.text('Out of range.'), findsOneWidget);
-      // After last date
-      await tester.enterText(find.byType(TextField), '02/23/2050');
-      expect(formKey.currentState!.validate(), isFalse);
-      await tester.pumpAndSettle();
-      expect(inputDate, isNull);
-      expect(find.text('Out of range.'), findsOneWidget);
+    testWidgets(
+      'Valid text entry, but date outside first or last date shows bounds shows errorInvalid text',
+      (WidgetTester tester) async {
+        final GlobalKey<FormState> formKey = GlobalKey<FormState>();
+        DateTime? inputDate;
+        await tester.pumpWidget(
+          inputDatePickerField(
+            firstDate: DateTime(1966, DateTime.february, 21),
+            lastDate: DateTime(2040, DateTime.february, 23),
+            onDateSaved: (DateTime date) => inputDate = date,
+            formKey: formKey,
+          ),
+        );
+        // Default errorInvalid text
+        expect(find.text('Out of range.'), findsNothing);
+        // Before first date
+        await tester.enterText(find.byType(TextField), '02/21/1950');
+        expect(formKey.currentState!.validate(), isFalse);
+        await tester.pumpAndSettle();
+        expect(inputDate, isNull);
+        expect(find.text('Out of range.'), findsOneWidget);
+        // After last date
+        await tester.enterText(find.byType(TextField), '02/23/2050');
+        expect(formKey.currentState!.validate(), isFalse);
+        await tester.pumpAndSettle();
+        expect(inputDate, isNull);
+        expect(find.text('Out of range.'), findsOneWidget);
 
-      await tester.pumpWidget(inputDatePickerField(
-        onDateSaved: (DateTime date) => inputDate = date,
-        errorInvalidText: 'Not in given range.',
-        formKey: formKey,
-      ));
-      expect(formKey.currentState!.validate(), isFalse);
-      await tester.pumpAndSettle();
-      expect(find.text('Out of range.'), findsNothing);
-      expect(find.text('Not in given range.'), findsOneWidget);
-    });
+        await tester.pumpWidget(
+          inputDatePickerField(
+            onDateSaved: (DateTime date) => inputDate = date,
+            errorInvalidText: 'Not in given range.',
+            formKey: formKey,
+          ),
+        );
+        expect(formKey.currentState!.validate(), isFalse);
+        await tester.pumpAndSettle();
+        expect(find.text('Out of range.'), findsNothing);
+        expect(find.text('Not in given range.'), findsOneWidget);
+      },
+    );
 
-    testWidgets('selectableDatePredicate will be used to show errorInvalid if date is not selectable', (WidgetTester tester) async {
-      final GlobalKey<FormState> formKey = GlobalKey<FormState>();
-      DateTime? inputDate;
-      await tester.pumpWidget(inputDatePickerField(
-        initialDate: DateTime(2016, DateTime.january, 16),
-        onDateSaved: (DateTime date) => inputDate = date,
-        selectableDayPredicate: (DateTime date) => date.day.isEven,
-        formKey: formKey,
-      ));
-      // Default errorInvalid text
-      expect(find.text('Out of range.'), findsNothing);
-      // Odd day shouldn't be valid
-      await tester.enterText(find.byType(TextField), '02/21/1966');
-      expect(formKey.currentState!.validate(), isFalse);
-      await tester.pumpAndSettle();
-      expect(inputDate, isNull);
-      expect(find.text('Out of range.'), findsOneWidget);
-      // Even day is valid
-      await tester.enterText(find.byType(TextField), '02/24/2030');
-      expect(formKey.currentState!.validate(), isTrue);
-      formKey.currentState!.save();
-      await tester.pumpAndSettle();
-      expect(inputDate, equals(DateTime(2030, DateTime.february, 24)));
-      expect(find.text('Out of range.'), findsNothing);
-    });
+    testWidgets(
+      'selectableDatePredicate will be used to show errorInvalid if date is not selectable',
+      (WidgetTester tester) async {
+        final GlobalKey<FormState> formKey = GlobalKey<FormState>();
+        DateTime? inputDate;
+        await tester.pumpWidget(
+          inputDatePickerField(
+            initialDate: DateTime(2016, DateTime.january, 16),
+            onDateSaved: (DateTime date) => inputDate = date,
+            selectableDayPredicate: (DateTime date) => date.day.isEven,
+            formKey: formKey,
+          ),
+        );
+        // Default errorInvalid text
+        expect(find.text('Out of range.'), findsNothing);
+        // Odd day shouldn't be valid
+        await tester.enterText(find.byType(TextField), '02/21/1966');
+        expect(formKey.currentState!.validate(), isFalse);
+        await tester.pumpAndSettle();
+        expect(inputDate, isNull);
+        expect(find.text('Out of range.'), findsOneWidget);
+        // Even day is valid
+        await tester.enterText(find.byType(TextField), '02/24/2030');
+        expect(formKey.currentState!.validate(), isTrue);
+        formKey.currentState!.save();
+        await tester.pumpAndSettle();
+        expect(inputDate, equals(DateTime(2030, DateTime.february, 24)));
+        expect(find.text('Out of range.'), findsNothing);
+      },
+    );
 
     testWidgets('Empty field shows hint text when focused', (WidgetTester tester) async {
       await tester.pumpWidget(inputDatePickerField());
@@ -257,9 +263,7 @@ void main() {
       // Default label
       expect(find.text('Enter Date'), findsOneWidget);
 
-      await tester.pumpWidget(inputDatePickerField(
-        fieldLabelText: 'Give me a date!',
-      ));
+      await tester.pumpWidget(inputDatePickerField(fieldLabelText: 'Give me a date!'));
       expect(find.text('Enter Date'), findsNothing);
       expect(find.text('Give me a date!'), findsOneWidget);
     });
@@ -269,52 +273,66 @@ void main() {
 
       // Fill the clipboard so that the Paste option is available in the text
       // selection menu.
-      tester.binding.defaultBinaryMessenger.setMockMethodCallHandler(SystemChannels.platform, mockClipboard.handleMethodCall);
+      tester.binding.defaultBinaryMessenger.setMockMethodCallHandler(
+        SystemChannels.platform,
+        mockClipboard.handleMethodCall,
+      );
       await Clipboard.setData(const ClipboardData(text: 'Clipboard data'));
-      addTearDown(() => tester.binding.defaultBinaryMessenger.setMockMethodCallHandler(SystemChannels.platform, null));
+      addTearDown(
+        () => tester.binding.defaultBinaryMessenger.setMockMethodCallHandler(
+          SystemChannels.platform,
+          null,
+        ),
+      );
 
       await tester.pumpWidget(inputDatePickerField(autofocus: true));
       await tester.pumpAndSettle();
 
-      expect(tester.getSemantics(find.byType(EditableText)), matchesSemantics(
-        label: 'Enter Date',
-        isTextField: true,
-        hasEnabledState: true,
-        isEnabled: true,
-        isFocused: true,
-        value: '01/15/2016',
-        hasTapAction: true,
-        hasSetTextAction: true,
-        hasSetSelectionAction: true,
-        hasCopyAction: true,
-        hasCutAction: true,
-        hasPasteAction: true,
-        hasMoveCursorBackwardByCharacterAction: true,
-        hasMoveCursorBackwardByWordAction: true,
-      ));
+      expect(
+        tester.getSemantics(find.byType(EditableText)),
+        matchesSemantics(
+          label: 'Enter Date',
+          isTextField: true,
+          hasEnabledState: true,
+          isEnabled: true,
+          isFocused: true,
+          value: '01/15/2016',
+          hasTapAction: true,
+          hasFocusAction: true,
+          hasSetTextAction: true,
+          hasSetSelectionAction: true,
+          hasCopyAction: true,
+          hasCutAction: true,
+          hasPasteAction: true,
+          hasMoveCursorBackwardByCharacterAction: true,
+          hasMoveCursorBackwardByWordAction: true,
+        ),
+      );
       semantics.dispose();
     });
 
     testWidgets('InputDecorationTheme is honored', (WidgetTester tester) async {
       const InputBorder border = InputBorder.none;
-      await tester.pumpWidget(inputDatePickerField(
-        theme: ThemeData.from(colorScheme: const ColorScheme.light()).copyWith(
-          inputDecorationTheme: const InputDecorationTheme(
-            border: border,
-          ),
+      await tester.pumpWidget(
+        inputDatePickerField(
+          theme: ThemeData.from(
+            colorScheme: const ColorScheme.light(),
+          ).copyWith(inputDecorationTheme: const InputDecorationTheme(border: border)),
         ),
-      ));
+      );
       await tester.pumpAndSettle();
 
       // Get the border and container color from the painter of the _BorderContainer
       // (this was cribbed from input_decorator_test.dart).
-      final CustomPaint customPaint = tester.widget(find.descendant(
-        of: find.byWidgetPredicate((Widget w) => '${w.runtimeType}' == '_BorderContainer'),
-        matching: find.byWidgetPredicate((Widget w) => w is CustomPaint),
-      ));
-      final dynamic/*_InputBorderPainter*/ inputBorderPainter = customPaint.foregroundPainter;
+      final CustomPaint customPaint = tester.widget(
+        find.descendant(
+          of: find.byWidgetPredicate((Widget w) => '${w.runtimeType}' == '_BorderContainer'),
+          matching: find.byWidgetPredicate((Widget w) => w is CustomPaint),
+        ),
+      );
+      final dynamic /*_InputBorderPainter*/ inputBorderPainter = customPaint.foregroundPainter;
       // ignore: avoid_dynamic_calls
-      final dynamic/*_InputBorderTween*/ inputBorderTween = inputBorderPainter.border;
+      final dynamic /*_InputBorderTween*/ inputBorderTween = inputBorderPainter.border;
       // ignore: avoid_dynamic_calls
       final Animation<double> animation = inputBorderPainter.borderAnimation as Animation<double>;
       // ignore: avoid_dynamic_calls
@@ -334,60 +352,58 @@ void main() {
         TestMaterialLocalizationsDelegate(),
         DefaultWidgetsLocalizations.delegate,
       ];
-      await tester.pumpWidget(
-        inputDatePickerField(
-          localizationsDelegates: delegates,
-        )
-      );
+      await tester.pumpWidget(inputDatePickerField(localizationsDelegates: delegates));
       await tester.enterText(find.byType(TextField), '01/01/2022');
       await tester.pumpAndSettle();
 
       // Verify that the widget can be updated to a new value after the
       // entered text was transformed by the localization formatter.
       await tester.pumpWidget(
-        inputDatePickerField(
-          initialDate: DateTime(2017),
-          localizationsDelegates: delegates,
-        )
+        inputDatePickerField(initialDate: DateTime(2017), localizationsDelegates: delegates),
       );
     });
 
-    testWidgets('when an empty date is entered and acceptEmptyDate is true, then errorFormatText is not shown', (WidgetTester tester) async {
-      final GlobalKey<FormState> formKey = GlobalKey<FormState>();
-      const String errorFormatText = 'That is not a date.';
-      await tester.pumpWidget(inputDatePickerField(
-        errorFormatText: errorFormatText,
-        formKey: formKey,
-        acceptEmptyDate: true,
-      ));
-      await tester.enterText(find.byType(TextField), '');
-      await tester.pumpAndSettle();
-      formKey.currentState!.validate();
-      await tester.pumpAndSettle();
-      expect(find.text(errorFormatText), findsNothing);
-    });
+    testWidgets(
+      'when an empty date is entered and acceptEmptyDate is true, then errorFormatText is not shown',
+      (WidgetTester tester) async {
+        final GlobalKey<FormState> formKey = GlobalKey<FormState>();
+        const String errorFormatText = 'That is not a date.';
+        await tester.pumpWidget(
+          inputDatePickerField(
+            errorFormatText: errorFormatText,
+            formKey: formKey,
+            acceptEmptyDate: true,
+          ),
+        );
+        await tester.enterText(find.byType(TextField), '');
+        await tester.pumpAndSettle();
+        formKey.currentState!.validate();
+        await tester.pumpAndSettle();
+        expect(find.text(errorFormatText), findsNothing);
+      },
+    );
 
-    testWidgets('when an empty date is entered and acceptEmptyDate is false, then errorFormatText is shown', (WidgetTester tester) async {
-      final GlobalKey<FormState> formKey = GlobalKey<FormState>();
-      const String errorFormatText = 'That is not a date.';
-      await tester.pumpWidget(inputDatePickerField(
-        errorFormatText: errorFormatText,
-        formKey: formKey,
-      ));
-      await tester.enterText(find.byType(TextField), '');
-      await tester.pumpAndSettle();
-      formKey.currentState!.validate();
-      await tester.pumpAndSettle();
-      expect(find.text(errorFormatText), findsOneWidget);
-    });
+    testWidgets(
+      'when an empty date is entered and acceptEmptyDate is false, then errorFormatText is shown',
+      (WidgetTester tester) async {
+        final GlobalKey<FormState> formKey = GlobalKey<FormState>();
+        const String errorFormatText = 'That is not a date.';
+        await tester.pumpWidget(
+          inputDatePickerField(errorFormatText: errorFormatText, formKey: formKey),
+        );
+        await tester.enterText(find.byType(TextField), '');
+        await tester.pumpAndSettle();
+        formKey.currentState!.validate();
+        await tester.pumpAndSettle();
+        expect(find.text(errorFormatText), findsOneWidget);
+      },
+    );
   });
 
   testWidgets('FocusNode can request focus', (WidgetTester tester) async {
     final FocusNode focusNode = FocusNode();
     addTearDown(focusNode.dispose);
-    await tester.pumpWidget(inputDatePickerField(
-      focusNode: focusNode,
-    ));
+    await tester.pumpWidget(inputDatePickerField(focusNode: focusNode));
     expect((tester.widget(find.byType(TextField)) as TextField).focusNode, focusNode);
     expect(focusNode.hasFocus, isFalse);
     focusNode.requestFocus();
