@@ -6,24 +6,28 @@ import 'package:flutter/material.dart';
 import 'package:flutter_test/flutter_test.dart';
 
 void main() {
+  TextStyle iconStyle(WidgetTester tester, IconData icon) {
+    final RichText iconRichText = tester.widget<RichText>(
+      find.descendant(of: find.byIcon(icon), matching: find.byType(RichText)),
+    );
+    return iconRichText.text.style!;
+  }
+
   test('TextButtonTheme lerp special cases', () {
     expect(TextButtonThemeData.lerp(null, null, 0), null);
     const TextButtonThemeData data = TextButtonThemeData();
     expect(identical(TextButtonThemeData.lerp(data, data, 0.5), data), true);
   });
 
-  testWidgets('Material3: Passing no TextButtonTheme returns defaults', (WidgetTester tester) async {
+  testWidgets('Material3: Passing no TextButtonTheme returns defaults', (
+    WidgetTester tester,
+  ) async {
     const ColorScheme colorScheme = ColorScheme.light();
     await tester.pumpWidget(
       MaterialApp(
         theme: ThemeData.from(useMaterial3: true, colorScheme: colorScheme),
         home: Scaffold(
-          body: Center(
-            child: TextButton(
-              onPressed: () { },
-              child: const Text('button'),
-            ),
-          ),
+          body: Center(child: TextButton(onPressed: () {}, child: const Text('button'))),
         ),
       ),
     );
@@ -45,22 +49,21 @@ void main() {
     expect(material.textStyle!.fontSize, 14);
     expect(material.textStyle!.fontWeight, FontWeight.w500);
 
-    final Align align = tester.firstWidget<Align>(find.ancestor(of: find.text('button'), matching: find.byType(Align)));
+    final Align align = tester.firstWidget<Align>(
+      find.ancestor(of: find.text('button'), matching: find.byType(Align)),
+    );
     expect(align.alignment, Alignment.center);
   });
 
-  testWidgets('Material2: Passing no TextButtonTheme returns defaults', (WidgetTester tester) async {
+  testWidgets('Material2: Passing no TextButtonTheme returns defaults', (
+    WidgetTester tester,
+  ) async {
     const ColorScheme colorScheme = ColorScheme.light();
     await tester.pumpWidget(
       MaterialApp(
         theme: ThemeData.from(useMaterial3: false, colorScheme: colorScheme),
         home: Scaffold(
-          body: Center(
-            child: TextButton(
-              onPressed: () { },
-              child: const Text('button'),
-            ),
-          ),
+          body: Center(child: TextButton(onPressed: () {}, child: const Text('button'))),
         ),
       ),
     );
@@ -76,13 +79,18 @@ void main() {
     expect(material.color, Colors.transparent);
     expect(material.elevation, 0.0);
     expect(material.shadowColor, const Color(0xff000000));
-    expect(material.shape, const RoundedRectangleBorder(borderRadius: BorderRadius.all(Radius.circular(4.0))));
+    expect(
+      material.shape,
+      const RoundedRectangleBorder(borderRadius: BorderRadius.all(Radius.circular(4.0))),
+    );
     expect(material.textStyle!.color, colorScheme.primary);
     expect(material.textStyle!.fontFamily, 'Roboto');
     expect(material.textStyle!.fontSize, 14);
     expect(material.textStyle!.fontWeight, FontWeight.w500);
 
-    final Align align = tester.firstWidget<Align>(find.ancestor(of: find.text('button'), matching: find.byType(Align)));
+    final Align align = tester.firstWidget<Align>(
+      find.ancestor(of: find.text('button'), matching: find.byType(Align)),
+    );
     expect(align.alignment, Alignment.center);
   });
 
@@ -96,7 +104,10 @@ void main() {
     const EdgeInsets padding = EdgeInsets.all(3);
     const Size minimumSize = Size(200, 200);
     const BorderSide side = BorderSide(color: Colors.green, width: 2);
-    const OutlinedBorder shape = RoundedRectangleBorder(side: side, borderRadius: BorderRadius.all(Radius.circular(2)));
+    const OutlinedBorder shape = RoundedRectangleBorder(
+      side: side,
+      borderRadius: BorderRadius.all(Radius.circular(2)),
+    );
     const MouseCursor enabledMouseCursor = SystemMouseCursors.text;
     const MouseCursor disabledMouseCursor = SystemMouseCursors.grab;
     const MaterialTapTargetSize tapTargetSize = MaterialTapTargetSize.shrinkWrap;
@@ -109,6 +120,7 @@ void main() {
     Widget backgroundBuilder(BuildContext context, Set<MaterialState> states, Widget? child) {
       return KeyedSubtree(key: backgroundKey, child: child!);
     }
+
     Widget foregroundBuilder(BuildContext context, Set<MaterialState> states, Widget? child) {
       return KeyedSubtree(key: foregroundKey, child: child!);
     }
@@ -135,28 +147,28 @@ void main() {
       foregroundBuilder: foregroundBuilder,
     );
 
-    Widget buildFrame({ ButtonStyle? buttonStyle, ButtonStyle? themeStyle, ButtonStyle? overallStyle }) {
+    Widget buildFrame({
+      ButtonStyle? buttonStyle,
+      ButtonStyle? themeStyle,
+      ButtonStyle? overallStyle,
+    }) {
       final Widget child = Builder(
         builder: (BuildContext context) {
-          return TextButton(
-            style: buttonStyle,
-            onPressed: () { },
-            child: const Text('button'),
-          );
+          return TextButton(style: buttonStyle, onPressed: () {}, child: const Text('button'));
         },
       );
       return MaterialApp(
-        theme: ThemeData.from(colorScheme: const ColorScheme.light()).copyWith(
-          textButtonTheme: TextButtonThemeData(style: overallStyle),
-        ),
+        theme: ThemeData.from(
+          colorScheme: const ColorScheme.light(),
+        ).copyWith(textButtonTheme: TextButtonThemeData(style: overallStyle)),
         home: Scaffold(
           body: Center(
             // If the TextButtonTheme widget is present, it's used
             // instead of the Theme's ThemeData.textButtonTheme.
-            child: themeStyle == null ? child : TextButtonTheme(
-              data: TextButtonThemeData(style: themeStyle),
-              child: child,
-            ),
+            child:
+                themeStyle == null
+                    ? child
+                    : TextButtonTheme(data: TextButtonThemeData(style: themeStyle), child: child),
           ),
         ),
       );
@@ -173,9 +185,9 @@ void main() {
     );
 
     const Set<MaterialState> enabled = <MaterialState>{};
-    const Set<MaterialState> disabled = <MaterialState>{ MaterialState.disabled };
-    const Set<MaterialState> hovered = <MaterialState>{ MaterialState.hovered };
-    const Set<MaterialState> focused = <MaterialState>{ MaterialState.focused };
+    const Set<MaterialState> disabled = <MaterialState>{MaterialState.disabled};
+    const Set<MaterialState> hovered = <MaterialState>{MaterialState.hovered};
+    const Set<MaterialState> focused = <MaterialState>{MaterialState.focused};
 
     void checkButton(WidgetTester tester) {
       final Material material = tester.widget<Material>(findMaterial);
@@ -185,8 +197,14 @@ void main() {
       expect(material.color, backgroundColor);
       expect(material.shadowColor, shadowColor);
       expect(material.elevation, elevation);
-      expect(MaterialStateProperty.resolveAs<MouseCursor?>(inkWell.mouseCursor, enabled), enabledMouseCursor);
-      expect(MaterialStateProperty.resolveAs<MouseCursor?>(inkWell.mouseCursor, disabled), disabledMouseCursor);
+      expect(
+        MaterialStateProperty.resolveAs<MouseCursor?>(inkWell.mouseCursor, enabled),
+        enabledMouseCursor,
+      );
+      expect(
+        MaterialStateProperty.resolveAs<MouseCursor?>(inkWell.mouseCursor, disabled),
+        disabledMouseCursor,
+      );
       expect(inkWell.overlayColor!.resolve(hovered), foregroundColor.withOpacity(0.08));
       expect(inkWell.overlayColor!.resolve(focused), foregroundColor.withOpacity(0.1));
       expect(inkWell.enableFeedback, enableFeedback);
@@ -194,9 +212,14 @@ void main() {
       expect(material.shape, shape);
       expect(material.animationDuration, animationDuration);
       expect(tester.getSize(find.byType(TextButton)), const Size(200, 200));
-      final Align align = tester.firstWidget<Align>(find.ancestor(of: find.text('button'), matching: find.byType(Align)));
+      final Align align = tester.firstWidget<Align>(
+        find.ancestor(of: find.text('button'), matching: find.byType(Align)),
+      );
       expect(align.alignment, alignment);
-      expect(find.descendant(of: findMaterial, matching: find.byKey(backgroundKey)), findsOneWidget);
+      expect(
+        find.descendant(of: findMaterial, matching: find.byKey(backgroundKey)),
+        findsOneWidget,
+      );
       expect(find.descendant(of: findInkWell, matching: find.byKey(foregroundKey)), findsOneWidget);
     }
 
@@ -220,31 +243,50 @@ void main() {
 
     // Same as the previous tests with empty ButtonStyle's instead of null.
 
-    testWidgets('Button style overrides defaults, empty theme and overall styles', (WidgetTester tester) async {
-      await tester.pumpWidget(buildFrame(buttonStyle: style, themeStyle: const ButtonStyle(), overallStyle: const ButtonStyle()));
+    testWidgets('Button style overrides defaults, empty theme and overall styles', (
+      WidgetTester tester,
+    ) async {
+      await tester.pumpWidget(
+        buildFrame(
+          buttonStyle: style,
+          themeStyle: const ButtonStyle(),
+          overallStyle: const ButtonStyle(),
+        ),
+      );
       await tester.pumpAndSettle(); // allow the animations to finish
       checkButton(tester);
     });
 
-    testWidgets('Button theme style overrides defaults, empty button and overall styles', (WidgetTester tester) async {
-      await tester.pumpWidget(buildFrame(buttonStyle: const ButtonStyle(), themeStyle: style, overallStyle: const ButtonStyle()));
+    testWidgets('Button theme style overrides defaults, empty button and overall styles', (
+      WidgetTester tester,
+    ) async {
+      await tester.pumpWidget(
+        buildFrame(
+          buttonStyle: const ButtonStyle(),
+          themeStyle: style,
+          overallStyle: const ButtonStyle(),
+        ),
+      );
       await tester.pumpAndSettle(); // allow the animations to finish
       checkButton(tester);
     });
 
-    testWidgets('Overall Theme button theme style overrides defaults, null theme and empty overall style', (WidgetTester tester) async {
-      await tester.pumpWidget(buildFrame(buttonStyle: const ButtonStyle(), overallStyle: style));
-      await tester.pumpAndSettle(); // allow the animations to finish
-      checkButton(tester);
-    });
+    testWidgets(
+      'Overall Theme button theme style overrides defaults, null theme and empty overall style',
+      (WidgetTester tester) async {
+        await tester.pumpWidget(buildFrame(buttonStyle: const ButtonStyle(), overallStyle: style));
+        await tester.pumpAndSettle(); // allow the animations to finish
+        checkButton(tester);
+      },
+    );
   });
 
-  testWidgets('Material3: Theme shadowColor', (WidgetTester tester) async {
+  testWidgets('Material3 - TextButton repsects Theme shadowColor', (WidgetTester tester) async {
     const ColorScheme colorScheme = ColorScheme.light();
     const Color shadowColor = Color(0xff000001);
     const Color overriddenColor = Color(0xff000002);
 
-    Widget buildFrame({ Color? overallShadowColor, Color? themeShadowColor, Color? shadowColor }) {
+    Widget buildFrame({Color? overallShadowColor, Color? themeShadowColor, Color? shadowColor}) {
       return MaterialApp(
         theme: ThemeData.from(
           useMaterial3: true,
@@ -253,18 +295,12 @@ void main() {
         home: Scaffold(
           body: Center(
             child: TextButtonTheme(
-              data: TextButtonThemeData(
-                style: TextButton.styleFrom(
-                  shadowColor: themeShadowColor,
-                ),
-              ),
+              data: TextButtonThemeData(style: TextButton.styleFrom(shadowColor: themeShadowColor)),
               child: Builder(
                 builder: (BuildContext context) {
                   return TextButton(
-                    style: TextButton.styleFrom(
-                      shadowColor: shadowColor,
-                    ),
-                    onPressed: () { },
+                    style: TextButton.styleFrom(shadowColor: shadowColor),
+                    onPressed: () {},
                     child: const Text('button'),
                   );
                 },
@@ -299,42 +335,41 @@ void main() {
     material = tester.widget<Material>(buttonMaterialFinder);
     expect(material.shadowColor, shadowColor);
 
-    await tester.pumpWidget(buildFrame(overallShadowColor: overriddenColor, themeShadowColor: shadowColor));
+    await tester.pumpWidget(
+      buildFrame(overallShadowColor: overriddenColor, themeShadowColor: shadowColor),
+    );
     await tester.pumpAndSettle(); // theme animation
     material = tester.widget<Material>(buttonMaterialFinder);
     expect(material.shadowColor, shadowColor);
 
-    await tester.pumpWidget(buildFrame(themeShadowColor: overriddenColor, shadowColor: shadowColor));
+    await tester.pumpWidget(
+      buildFrame(themeShadowColor: overriddenColor, shadowColor: shadowColor),
+    );
     await tester.pumpAndSettle(); // theme animation
     material = tester.widget<Material>(buttonMaterialFinder);
     expect(material.shadowColor, shadowColor);
   });
 
-  testWidgets('Material2: Theme shadowColor', (WidgetTester tester) async {
+  testWidgets('Material2 - TextButton repsects Theme shadowColor', (WidgetTester tester) async {
     const ColorScheme colorScheme = ColorScheme.light();
     const Color shadowColor = Color(0xff000001);
     const Color overriddenColor = Color(0xff000002);
 
-    Widget buildFrame({ Color? overallShadowColor, Color? themeShadowColor, Color? shadowColor }) {
+    Widget buildFrame({Color? overallShadowColor, Color? themeShadowColor, Color? shadowColor}) {
       return MaterialApp(
-        theme: ThemeData.from(useMaterial3: false, colorScheme: colorScheme).copyWith(
-          shadowColor: overallShadowColor,
-        ),
+        theme: ThemeData.from(
+          useMaterial3: false,
+          colorScheme: colorScheme,
+        ).copyWith(shadowColor: overallShadowColor),
         home: Scaffold(
           body: Center(
             child: TextButtonTheme(
-              data: TextButtonThemeData(
-                style: TextButton.styleFrom(
-                  shadowColor: themeShadowColor,
-                ),
-              ),
+              data: TextButtonThemeData(style: TextButton.styleFrom(shadowColor: themeShadowColor)),
               child: Builder(
                 builder: (BuildContext context) {
                   return TextButton(
-                    style: TextButton.styleFrom(
-                      shadowColor: shadowColor,
-                    ),
-                    onPressed: () { },
+                    style: TextButton.styleFrom(shadowColor: shadowColor),
+                    onPressed: () {},
                     child: const Text('button'),
                   );
                 },
@@ -369,14 +404,83 @@ void main() {
     material = tester.widget<Material>(buttonMaterialFinder);
     expect(material.shadowColor, shadowColor);
 
-    await tester.pumpWidget(buildFrame(overallShadowColor: overriddenColor, themeShadowColor: shadowColor));
+    await tester.pumpWidget(
+      buildFrame(overallShadowColor: overriddenColor, themeShadowColor: shadowColor),
+    );
     await tester.pumpAndSettle(); // theme animation
     material = tester.widget<Material>(buttonMaterialFinder);
     expect(material.shadowColor, shadowColor);
 
-    await tester.pumpWidget(buildFrame(themeShadowColor: overriddenColor, shadowColor: shadowColor));
+    await tester.pumpWidget(
+      buildFrame(themeShadowColor: overriddenColor, shadowColor: shadowColor),
+    );
     await tester.pumpAndSettle(); // theme animation
     material = tester.widget<Material>(buttonMaterialFinder);
     expect(material.shadowColor, shadowColor);
   });
+
+  testWidgets('TextButton.icon respects TextButtonTheme ButtonStyle.iconAlignment', (
+    WidgetTester tester,
+  ) async {
+    Widget buildButton({IconAlignment? iconAlignment}) {
+      return MaterialApp(
+        theme: ThemeData(
+          textButtonTheme: TextButtonThemeData(style: ButtonStyle(iconAlignment: iconAlignment)),
+        ),
+        home: Scaffold(
+          body: Center(
+            child: TextButton.icon(
+              onPressed: () {},
+              icon: const Icon(Icons.add),
+              label: const Text('button'),
+            ),
+          ),
+        ),
+      );
+    }
+
+    await tester.pumpWidget(buildButton());
+
+    final Offset buttonTopLeft = tester.getTopLeft(find.byType(Material).last);
+    final Offset iconTopLeft = tester.getTopLeft(find.byIcon(Icons.add));
+
+    expect(buttonTopLeft.dx, iconTopLeft.dx - 12.0);
+
+    await tester.pumpWidget(buildButton(iconAlignment: IconAlignment.end));
+    await tester.pumpAndSettle();
+
+    final Offset buttonTopRight = tester.getTopRight(find.byType(Material).last);
+    final Offset iconTopRight = tester.getTopRight(find.byIcon(Icons.add));
+
+    expect(buttonTopRight.dx, iconTopRight.dx + 16.0);
+  });
+
+  // Regression test for https://github.com/flutter/flutter/issues/162839.
+  testWidgets(
+    'TextButton icon uses provided TextButtonThemeData foregroundColor over default icon color',
+    (WidgetTester tester) async {
+      const Color foregroundColor = Color(0xFFFFA500);
+
+      await tester.pumpWidget(
+        MaterialApp(
+          theme: ThemeData(
+            textButtonTheme: TextButtonThemeData(
+              style: TextButton.styleFrom(foregroundColor: foregroundColor),
+            ),
+          ),
+          home: Material(
+            child: Center(
+              child: TextButton.icon(
+                onPressed: () {},
+                icon: const Icon(Icons.add),
+                label: const Text('Button'),
+              ),
+            ),
+          ),
+        ),
+      );
+
+      expect(iconStyle(tester, Icons.add).color, foregroundColor);
+    },
+  );
 }
