@@ -12,7 +12,8 @@ import 'package:flutter_test/flutter_test.dart';
 import 'scheduler_tester.dart';
 
 class TestSchedulerBinding extends BindingBase with SchedulerBinding, ServicesBinding {
-  final Map<String, List<Map<String, dynamic>>> eventsDispatched = <String, List<Map<String, dynamic>>>{};
+  final Map<String, List<Map<String, dynamic>>> eventsDispatched =
+      <String, List<Map<String, dynamic>>>{};
 
   VoidCallback? additionalHandleBeginFrame;
   VoidCallback? additionalHandleDrawFrame;
@@ -42,7 +43,7 @@ class TestSchedulerBinding extends BindingBase with SchedulerBinding, ServicesBi
 class TestStrategy {
   int allowedPriority = 10000;
 
-  bool shouldRunTaskWithPriority({ required int priority, required SchedulerBinding scheduler }) {
+  bool shouldRunTaskWithPriority({required int priority, required SchedulerBinding scheduler}) {
     return priority >= allowedPriority;
   }
 }
@@ -66,7 +67,9 @@ void main() {
     final List<int> executedTasks = <int>[];
 
     void scheduleAddingTask(int x) {
-      scheduler.scheduleTask(() { executedTasks.add(x); }, Priority.idle + x);
+      scheduler.scheduleTask(() {
+        executedTasks.add(x);
+      }, Priority.idle + x);
     }
 
     input.forEach(scheduleAddingTask);
@@ -158,10 +161,18 @@ void main() {
         // Run it twice without processing the queued tasks.
         scheduler.scheduleWarmUpFrame();
         scheduler.scheduleWarmUpFrame();
-        scheduler.scheduleTask(() { taskExecuted = true; }, Priority.touch);
+        scheduler.scheduleTask(() {
+          taskExecuted = true;
+        }, Priority.touch);
       },
       zoneSpecification: ZoneSpecification(
-        createTimer: (Zone self, ZoneDelegate parent, Zone zone, Duration duration, void Function() f) {
+        createTimer: (
+          Zone self,
+          ZoneDelegate parent,
+          Zone zone,
+          Duration duration,
+          void Function() f,
+        ) {
           // Don't actually run the tasks, just record that it was scheduled.
           timerQueueTasks.add(f);
           return DummyTimer();
@@ -247,7 +258,10 @@ void main() {
     timeDilation = 2;
     scheduler.scheduleFrameCallback(frameCallback);
     tick(const Duration(seconds: 6));
-    expect(lastTimeStamp, const Duration(seconds: 2)); // timeDilation calls SchedulerBinding.resetEpoch
+    expect(
+      lastTimeStamp,
+      const Duration(seconds: 2),
+    ); // timeDilation calls SchedulerBinding.resetEpoch
     expect(lastSystemTimeStamp, const Duration(seconds: 6));
 
     scheduler.scheduleFrameCallback(frameCallback);
@@ -262,7 +276,13 @@ void main() {
     expect(scheduler.schedulerPhase, SchedulerPhase.idle);
     final List<VoidCallback> timers = <VoidCallback>[];
     final ZoneSpecification timerInterceptor = ZoneSpecification(
-      createTimer: (Zone self, ZoneDelegate parent, Zone zone, Duration duration, void Function() callback) {
+      createTimer: (
+        Zone self,
+        ZoneDelegate parent,
+        Zone zone,
+        Duration duration,
+        void Function() callback,
+      ) {
         timers.add(callback);
         return DummyTimer();
       },
@@ -298,18 +318,15 @@ void main() {
     // `Future` is disallowed in this file due to the import of
     // scheduler_tester.dart so annotations cannot be specified.
     // ignore: always_specify_types
-    final result = scheduler.scheduleTask(
-      () async {
-        // Yield, so if awaiting `result` did not wait for completion of this
-        // task, the assertion on `isCompleted` will fail.
-        await null;
-        await null;
+    final result = scheduler.scheduleTask(() async {
+      // Yield, so if awaiting `result` did not wait for completion of this
+      // task, the assertion on `isCompleted` will fail.
+      await null;
+      await null;
 
-        isCompleted = true;
-        return 1;
-      },
-      Priority.idle,
-    );
+      isCompleted = true;
+      return 1;
+    }, Priority.idle);
 
     scheduler.handleEventLoopCallback();
     await result;
