@@ -2,6 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
+import 'dart:ui';
+
 import 'package:flutter/foundation.dart';
 import 'package:flutter/physics.dart';
 import 'package:flutter/rendering.dart';
@@ -10,7 +12,8 @@ import 'package:flutter_test/flutter_test.dart';
 export 'dart:ui' show SemanticsAction, SemanticsFlag;
 export 'package:flutter/rendering.dart' show SemanticsData;
 
-const String _matcherHelp = 'Try dumping the semantics with debugDumpSemanticsTree(DebugSemanticsDumpOrder.inverseHitTest) from the package:flutter/rendering.dart library to see what the semantics tree looks like.';
+const String _matcherHelp =
+    'Try dumping the semantics with debugDumpSemanticsTree(DebugSemanticsDumpOrder.inverseHitTest) from the package:flutter/rendering.dart library to see what the semantics tree looks like.';
 
 /// Test semantics data that is compared against real semantics tree.
 ///
@@ -38,6 +41,7 @@ class TestSemantics {
     this.label = '',
     this.value = '',
     this.tooltip = '',
+    this.headingLevel,
     this.increasedValue = '',
     this.decreasedValue = '',
     this.hint = '',
@@ -51,6 +55,7 @@ class TestSemantics {
     this.scrollIndex,
     this.scrollChildren,
     Iterable<SemanticsTag>? tags,
+    this.role = SemanticsRole.none,
   }) : assert(flags is int || flags is List<SemanticsFlag>),
        assert(actions is int || actions is List<SemanticsAction>),
        tags = tags?.toSet() ?? <SemanticsTag>{};
@@ -66,6 +71,7 @@ class TestSemantics {
     this.decreasedValue = '',
     this.hint = '',
     this.tooltip = '',
+    this.headingLevel,
     this.textDirection,
     this.transform,
     this.textSelection,
@@ -73,6 +79,7 @@ class TestSemantics {
     this.scrollIndex,
     this.scrollChildren,
     Iterable<SemanticsTag>? tags,
+    this.role = SemanticsRole.none,
   }) : id = 0,
        assert(flags is int || flags is List<SemanticsFlag>),
        assert(actions is int || actions is List<SemanticsAction>),
@@ -99,6 +106,7 @@ class TestSemantics {
     this.hint = '',
     this.value = '',
     this.tooltip = '',
+    this.headingLevel,
     this.increasedValue = '',
     this.decreasedValue = '',
     this.textDirection,
@@ -111,6 +119,7 @@ class TestSemantics {
     this.scrollIndex,
     this.scrollChildren,
     Iterable<SemanticsTag>? tags,
+    this.role = SemanticsRole.none,
   }) : assert(flags is int || flags is List<SemanticsFlag>),
        assert(actions is int || actions is List<SemanticsAction>),
        transform = _applyRootChildScale(transform),
@@ -237,6 +246,13 @@ class TestSemantics {
   /// The tags of this node.
   final Set<SemanticsTag> tags;
 
+  final int? headingLevel;
+
+  /// The expected role for the node.
+  ///
+  /// Defaults to SemanticsRole.none if not set.
+  final SemanticsRole role;
+
   bool _matches(
     SemanticsNode? node,
     Map<dynamic, dynamic> matchState, {
@@ -259,68 +275,121 @@ class TestSemantics {
 
     final SemanticsData nodeData = node.getSemanticsData();
 
-    final int flagsBitmask = flags is int
-      ? flags as int
-      : (flags as List<SemanticsFlag>).fold<int>(0, (int bitmask, SemanticsFlag flag) => bitmask | flag.index);
+    final int flagsBitmask =
+        flags is int
+            ? flags as int
+            : (flags as List<SemanticsFlag>).fold<int>(
+              0,
+              (int bitmask, SemanticsFlag flag) => bitmask | flag.index,
+            );
     if (flagsBitmask != nodeData.flags) {
       return fail('expected node id $id to have flags $flags but found flags ${nodeData.flags}.');
     }
 
-    final int actionsBitmask = actions is int
-        ? actions as int
-        : (actions as List<SemanticsAction>).fold<int>(0, (int bitmask, SemanticsAction action) => bitmask | action.index);
+    final int actionsBitmask =
+        actions is int
+            ? actions as int
+            : (actions as List<SemanticsAction>).fold<int>(
+              0,
+              (int bitmask, SemanticsAction action) => bitmask | action.index,
+            );
     if (actionsBitmask != nodeData.actions) {
-      return fail('expected node id $id to have actions $actions but found actions ${nodeData.actions}.');
+      return fail(
+        'expected node id $id to have actions $actions but found actions ${nodeData.actions}.',
+      );
     }
 
     if (label != nodeData.label) {
-      return fail('expected node id $id to have label "$label" but found label "${nodeData.label}".');
+      return fail(
+        'expected node id $id to have label "$label" but found label "${nodeData.label}".',
+      );
     }
     if (value != nodeData.value) {
-      return fail('expected node id $id to have value "$value" but found value "${nodeData.value}".');
+      return fail(
+        'expected node id $id to have value "$value" but found value "${nodeData.value}".',
+      );
     }
     if (increasedValue != nodeData.increasedValue) {
-      return fail('expected node id $id to have increasedValue "$increasedValue" but found value "${nodeData.increasedValue}".');
+      return fail(
+        'expected node id $id to have increasedValue "$increasedValue" but found value "${nodeData.increasedValue}".',
+      );
     }
     if (decreasedValue != nodeData.decreasedValue) {
-      return fail('expected node id $id to have decreasedValue "$decreasedValue" but found value "${nodeData.decreasedValue}".');
+      return fail(
+        'expected node id $id to have decreasedValue "$decreasedValue" but found value "${nodeData.decreasedValue}".',
+      );
     }
     if (hint != nodeData.hint) {
       return fail('expected node id $id to have hint "$hint" but found hint "${nodeData.hint}".');
     }
     if (tooltip != nodeData.tooltip) {
-      return fail('expected node id $id to have tooltip "$tooltip" but found hint "${nodeData.tooltip}".');
+      return fail(
+        'expected node id $id to have tooltip "$tooltip" but found hint "${nodeData.tooltip}".',
+      );
     }
     if (textDirection != null && textDirection != nodeData.textDirection) {
-      return fail('expected node id $id to have textDirection "$textDirection" but found "${nodeData.textDirection}".');
+      return fail(
+        'expected node id $id to have textDirection "$textDirection" but found "${nodeData.textDirection}".',
+      );
     }
-    if ((nodeData.label != '' || nodeData.value != '' || nodeData.hint != '' || node.increasedValue != '' || node.decreasedValue != '') && nodeData.textDirection == null) {
-      return fail('expected node id $id, which has a label, value, or hint, to have a textDirection, but it did not.');
+    if ((nodeData.label != '' ||
+            nodeData.value != '' ||
+            nodeData.hint != '' ||
+            node.increasedValue != '' ||
+            node.decreasedValue != '') &&
+        nodeData.textDirection == null) {
+      return fail(
+        'expected node id $id, which has a label, value, or hint, to have a textDirection, but it did not.',
+      );
     }
     if (!ignoreRect && rect != nodeData.rect) {
       return fail('expected node id $id to have rect $rect but found rect ${nodeData.rect}.');
     }
     if (!ignoreTransform && transform != nodeData.transform) {
-      return fail('expected node id $id to have transform $transform but found transform:\n${nodeData.transform}.');
+      return fail(
+        'expected node id $id to have transform $transform but found transform:\n${nodeData.transform}.',
+      );
     }
     if (elevation != null && elevation != nodeData.elevation) {
-      return fail('expected node id $id to have elevation $elevation but found elevation:\n${nodeData.elevation}.');
+      return fail(
+        'expected node id $id to have elevation $elevation but found elevation:\n${nodeData.elevation}.',
+      );
     }
     if (thickness != null && thickness != nodeData.thickness) {
-      return fail('expected node id $id to have thickness $thickness but found thickness:\n${nodeData.thickness}.');
+      return fail(
+        'expected node id $id to have thickness $thickness but found thickness:\n${nodeData.thickness}.',
+      );
     }
-    if (textSelection?.baseOffset != nodeData.textSelection?.baseOffset || textSelection?.extentOffset != nodeData.textSelection?.extentOffset) {
-      return fail('expected node id $id to have textSelection [${textSelection?.baseOffset}, ${textSelection?.end}] but found: [${nodeData.textSelection?.baseOffset}, ${nodeData.textSelection?.extentOffset}].');
+    if (textSelection?.baseOffset != nodeData.textSelection?.baseOffset ||
+        textSelection?.extentOffset != nodeData.textSelection?.extentOffset) {
+      return fail(
+        'expected node id $id to have textSelection [${textSelection?.baseOffset}, ${textSelection?.end}] but found: [${nodeData.textSelection?.baseOffset}, ${nodeData.textSelection?.extentOffset}].',
+      );
     }
     if (scrollIndex != null && scrollIndex != nodeData.scrollIndex) {
-      return fail('expected node id $id to have scrollIndex $scrollIndex but found scrollIndex ${nodeData.scrollIndex}.');
+      return fail(
+        'expected node id $id to have scrollIndex $scrollIndex but found scrollIndex ${nodeData.scrollIndex}.',
+      );
     }
     if (scrollChildren != null && scrollChildren != nodeData.scrollChildCount) {
-      return fail('expected node id $id to have scrollIndex $scrollChildren but found scrollIndex ${nodeData.scrollChildCount}.');
+      return fail(
+        'expected node id $id to have scrollIndex $scrollChildren but found scrollIndex ${nodeData.scrollChildCount}.',
+      );
     }
     final int childrenCount = node.mergeAllDescendantsIntoThisNode ? 0 : node.childrenCount;
     if (children.length != childrenCount) {
-      return fail('expected node id $id to have ${children.length} child${ children.length == 1 ? "" : "ren" } but found $childrenCount.');
+      return fail(
+        'expected node id $id to have ${children.length} child${children.length == 1 ? "" : "ren"} but found $childrenCount.',
+      );
+    }
+    if (headingLevel != null && headingLevel != node.headingLevel) {
+      return fail(
+        'expected node id $id to have headingLevel $headingLevel but found headingLevel ${node.headingLevel}',
+      );
+    }
+
+    if (role != node.role) {
+      return fail('expected node id $id to have role $role but found role ${node.role}');
     }
 
     if (children.isEmpty) {
@@ -350,18 +419,22 @@ class TestSemantics {
   }
 
   @override
-  String toString([ int indentAmount = 0 ]) {
+  String toString([int indentAmount = 0]) {
     final String indent = '  ' * indentAmount;
     final StringBuffer buf = StringBuffer();
     buf.writeln('$indent${objectRuntimeType(this, 'TestSemantics')}(');
     if (id != null) {
       buf.writeln('$indent  id: $id,');
     }
-    if (flags is int && flags != 0 || flags is List<SemanticsFlag> && (flags as List<SemanticsFlag>).isNotEmpty) {
+    if (flags is int && flags != 0 ||
+        flags is List<SemanticsFlag> && (flags as List<SemanticsFlag>).isNotEmpty) {
       buf.writeln('$indent  flags: ${SemanticsTester._flagsToSemanticsFlagExpression(flags)},');
     }
-    if (actions is int && actions != 0 || actions is List<SemanticsAction> && (actions as List<SemanticsAction>).isNotEmpty) {
-      buf.writeln('$indent  actions: ${SemanticsTester._actionsToSemanticsActionExpression(actions)},');
+    if (actions is int && actions != 0 ||
+        actions is List<SemanticsAction> && (actions as List<SemanticsAction>).isNotEmpty) {
+      buf.writeln(
+        '$indent  actions: ${SemanticsTester._actionsToSemanticsActionExpression(actions)},',
+      );
     }
     if (label != '') {
       buf.writeln("$indent  label: '$label',");
@@ -394,7 +467,9 @@ class TestSemantics {
       buf.writeln('$indent  rect: $rect,');
     }
     if (transform != null) {
-      buf.writeln('$indent  transform:\n${transform.toString().trim().split('\n').map<String>((String line) => '$indent    $line').join('\n')},');
+      buf.writeln(
+        '$indent  transform:\n${transform.toString().trim().split('\n').map<String>((String line) => '$indent    $line').join('\n')},',
+      );
     }
     if (elevation != null) {
       buf.writeln('$indent  elevation: $elevation,');
@@ -448,7 +523,8 @@ class SemanticsTester {
   }
 
   @override
-  String toString() => 'SemanticsTester for ${tester.binding.pipelineOwner.semanticsOwner?.rootSemanticsNode}';
+  String toString() =>
+      'SemanticsTester for ${tester.binding.pipelineOwner.semanticsOwner?.rootSemanticsNode}';
 
   bool _stringAttributesEqual(List<StringAttribute> first, List<StringAttribute> second) {
     if (first.length != second.length) {
@@ -456,14 +532,14 @@ class SemanticsTester {
     }
     for (int i = 0; i < first.length; i++) {
       if (first[i] is SpellOutStringAttribute &&
-          (second[i] is! SpellOutStringAttribute ||
-           second[i].range != first[i].range)) {
+          (second[i] is! SpellOutStringAttribute || second[i].range != first[i].range)) {
         return false;
       }
       if (first[i] is LocaleStringAttribute &&
           (second[i] is! LocaleStringAttribute ||
-           second[i].range != first[i].range ||
-           (second[i] as LocaleStringAttribute).locale != (second[i] as LocaleStringAttribute).locale)) {
+              second[i].range != first[i].range ||
+              (second[i] as LocaleStringAttribute).locale !=
+                  (second[i] as LocaleStringAttribute).locale)) {
         return false;
       }
     }
@@ -501,7 +577,10 @@ class SemanticsTester {
       }
       if (attributedLabel != null &&
           (attributedLabel.string != node.attributedLabel.string ||
-          !_stringAttributesEqual(attributedLabel.attributes, node.attributedLabel.attributes))) {
+              !_stringAttributesEqual(
+                attributedLabel.attributes,
+                node.attributedLabel.attributes,
+              ))) {
         return false;
       }
       if (value != null && node.value != value) {
@@ -509,7 +588,10 @@ class SemanticsTester {
       }
       if (attributedValue != null &&
           (attributedValue.string != node.attributedValue.string ||
-          !_stringAttributesEqual(attributedValue.attributes, node.attributedValue.attributes))) {
+              !_stringAttributesEqual(
+                attributedValue.attributes,
+                node.attributedValue.attributes,
+              ))) {
         return false;
       }
       if (hint != null && node.hint != hint) {
@@ -517,21 +599,28 @@ class SemanticsTester {
       }
       if (attributedHint != null &&
           (attributedHint.string != node.attributedHint.string ||
-          !_stringAttributesEqual(attributedHint.attributes, node.attributedHint.attributes))) {
+              !_stringAttributesEqual(attributedHint.attributes, node.attributedHint.attributes))) {
         return false;
       }
       if (textDirection != null && node.textDirection != textDirection) {
         return false;
       }
+
       if (actions != null) {
-        final int expectedActions = actions.fold<int>(0, (int value, SemanticsAction action) => value | action.index);
+        final int expectedActions = actions.fold<int>(
+          0,
+          (int value, SemanticsAction action) => value | action.index,
+        );
         final int actualActions = node.getSemanticsData().actions;
         if (expectedActions != actualActions) {
           return false;
         }
       }
       if (flags != null) {
-        final int expectedFlags = flags.fold<int>(0, (int value, SemanticsFlag flag) => value | flag.index);
+        final int expectedFlags = flags.fold<int>(
+          0,
+          (int value, SemanticsFlag flag) => value | flag.index,
+        );
         final int actualFlags = node.getSemanticsData().flags;
         if (expectedFlags != actualFlags) {
           return false;
@@ -569,11 +658,9 @@ class SemanticsTester {
       node.visitChildren(visit);
       return true;
     }
-    if (ancestor != null) {
-      visit(ancestor);
-    } else {
-      visit(tester.binding.pipelineOwner.semanticsOwner!.rootSemanticsNode!);
-    }
+
+    visit(ancestor ?? tester.binding.pipelineOwner.semanticsOwner!.rootSemanticsNode!);
+
     return result;
   }
 
@@ -625,7 +712,9 @@ class SemanticsTester {
   /// every time and ignore potential regressions. Make sure you do not
   /// over-test. Prefer breaking your widgets into smaller widgets and test them
   /// individually.
-  String generateTestSemanticsExpressionForCurrentSemanticsTree(DebugSemanticsDumpOrder childOrder) {
+  String generateTestSemanticsExpressionForCurrentSemanticsTree(
+    DebugSemanticsDumpOrder childOrder,
+  ) {
     final SemanticsNode? node = tester.binding.pipelineOwner.semanticsOwner?.rootSemanticsNode;
     return _generateSemanticsTestForNode(node, 0, childOrder);
   }
@@ -633,9 +722,7 @@ class SemanticsTester {
   static String _flagsToSemanticsFlagExpression(dynamic flags) {
     Iterable<SemanticsFlag> list;
     if (flags is int) {
-      // ignore: deprecated_member_use
-      list = SemanticsFlag.doNotUseWillBeDeletedWithoutWarningValuesAsList
-          .where((SemanticsFlag flag) => (flag.index & flags) != 0);
+      list = SemanticsFlag.values.where((SemanticsFlag flag) => (flag.index & flags) != 0);
     } else {
       list = flags as List<SemanticsFlag>;
     }
@@ -649,9 +736,9 @@ class SemanticsTester {
   static String _actionsToSemanticsActionExpression(dynamic actions) {
     Iterable<SemanticsAction> list;
     if (actions is int) {
-      // ignore: deprecated_member_use
-      list = SemanticsAction.doNotUseWillBeDeletedWithoutWarningValuesAsList
-          .where((SemanticsAction action) => (action.index & actions) != 0);
+      list = SemanticsAction.values.where(
+        (SemanticsAction action) => (action.index & actions) != 0,
+      );
     } else {
       list = actions as List<SemanticsAction>;
     }
@@ -660,7 +747,11 @@ class SemanticsTester {
 
   /// Recursively generates [TestSemantics] code for [node] and its children,
   /// indenting the expression by `indentAmount`.
-  static String _generateSemanticsTestForNode(SemanticsNode? node, int indentAmount, DebugSemanticsDumpOrder childOrder) {
+  static String _generateSemanticsTestForNode(
+    SemanticsNode? node,
+    int indentAmount,
+    DebugSemanticsDumpOrder childOrder,
+  ) {
     if (node == null) {
       return 'null';
     }
@@ -668,7 +759,7 @@ class SemanticsTester {
     final StringBuffer buf = StringBuffer();
     final SemanticsData nodeData = node.getSemanticsData();
     final bool isRoot = node.id == 0;
-    buf.writeln('TestSemantics${isRoot ? '.root': ''}(');
+    buf.writeln('TestSemantics${isRoot ? '.root' : ''}(');
     if (!isRoot) {
       buf.writeln('  id: ${node.id},');
     }
@@ -683,7 +774,10 @@ class SemanticsTester {
     }
     if (node.label.isNotEmpty) {
       // Escape newlines and text directionality control characters.
-      final String escapedLabel = node.label.replaceAll('\n', r'\n').replaceAll('\u202a', r'\u202a').replaceAll('\u202c', r'\u202c');
+      final String escapedLabel = node.label
+          .replaceAll('\n', r'\n')
+          .replaceAll('\u202a', r'\u202a')
+          .replaceAll('\u202c', r'\u202c');
       buf.writeln("  label: '$escapedLabel',");
     }
     if (node.value.isNotEmpty) {
@@ -701,6 +795,9 @@ class SemanticsTester {
     if (node.textDirection != null) {
       buf.writeln('  textDirection: ${node.textDirection},');
     }
+    if (node.role != SemanticsRole.none) {
+      buf.writeln('  role: ${node.role},');
+    }
     if (node.hasChildren) {
       buf.writeln('  children: <TestSemantics>[');
       for (final SemanticsNode child in node.debugListChildrenInOrder(childOrder)) {
@@ -742,10 +839,13 @@ class _HasSemantics extends Matcher {
       childOrder: childOrder,
     );
     if (!doesMatch) {
-      matchState['would-match'] = item.generateTestSemanticsExpressionForCurrentSemanticsTree(childOrder);
+      matchState['would-match'] = item.generateTestSemanticsExpressionForCurrentSemanticsTree(
+        childOrder,
+      );
     }
     if (item.tester.binding.pipelineOwner.semanticsOwner == null) {
-      matchState['additional-notes'] = '(Check that the SemanticsTester has not been disposed early.)';
+      matchState['additional-notes'] =
+          '(Check that the SemanticsTester has not been disposed early.)';
     }
     return doesMatch;
   }
@@ -756,22 +856,36 @@ class _HasSemantics extends Matcher {
   }
 
   String _indent(String? text) {
-    return text.toString().trimRight().split('\n').map<String>((String line) => '  $line').join('\n');
+    return text
+        .toString()
+        .trimRight()
+        .split('\n')
+        .map<String>((String line) => '  $line')
+        .join('\n');
   }
 
   @override
-  Description describeMismatch(dynamic item, Description mismatchDescription, Map<dynamic, dynamic> matchState, bool verbose) {
+  Description describeMismatch(
+    dynamic item,
+    Description mismatchDescription,
+    Map<dynamic, dynamic> matchState,
+    bool verbose,
+  ) {
     Description result = mismatchDescription
-      .add('${matchState[TestSemantics]}\n')
-      .add('Current SemanticsNode tree:\n')
-      .add(_indent(RendererBinding.instance.renderView.debugSemantics?.toStringDeep(childOrder: childOrder)))
-      .add('\n')
-      .add('The semantics tree would have matched the following configuration:\n')
-      .add(_indent(matchState['would-match'] as String));
-    if (matchState.containsKey('additional-notes')) {
-      result = result
+        .add('${matchState[TestSemantics]}\n')
+        .add('Current SemanticsNode tree:\n')
+        .add(
+          _indent(
+            RendererBinding.instance.renderView.debugSemantics?.toStringDeep(
+              childOrder: childOrder,
+            ),
+          ),
+        )
         .add('\n')
-        .add(matchState['additional-notes'] as String);
+        .add('The semantics tree would have matched the following configuration:\n')
+        .add(_indent(matchState['would-match'] as String));
+    if (matchState.containsKey('additional-notes')) {
+      result = result.add('\n').add(matchState['additional-notes'] as String);
     }
     return result;
   }
@@ -812,17 +926,17 @@ class _IncludesNodeWith extends Matcher {
     this.maxValueLength,
     this.currentValueLength,
   }) : assert(
-       label != null ||
-       value != null ||
-       actions != null ||
-       flags != null ||
-       tags != null ||
-       scrollPosition != null ||
-       scrollExtentMax != null ||
-       scrollExtentMin != null ||
-       maxValueLength != null ||
-       currentValueLength != null,
-     );
+         label != null ||
+             value != null ||
+             actions != null ||
+             flags != null ||
+             tags != null ||
+             scrollPosition != null ||
+             scrollExtentMax != null ||
+             scrollExtentMin != null ||
+             maxValueLength != null ||
+             currentValueLength != null,
+       );
   final AttributedString? attributedLabel;
   final AttributedString? attributedValue;
   final AttributedString? attributedHint;
@@ -841,23 +955,25 @@ class _IncludesNodeWith extends Matcher {
 
   @override
   bool matches(covariant SemanticsTester item, Map<dynamic, dynamic> matchState) {
-    return item.nodesWith(
-      attributedLabel: attributedLabel,
-      attributedValue: attributedValue,
-      attributedHint: attributedHint,
-      label: label,
-      value: value,
-      hint: hint,
-      textDirection: textDirection,
-      actions: actions,
-      flags: flags,
-      tags: tags,
-      scrollPosition: scrollPosition,
-      scrollExtentMax: scrollExtentMax,
-      scrollExtentMin: scrollExtentMin,
-      currentValueLength: currentValueLength,
-      maxValueLength: maxValueLength,
-    ).isNotEmpty;
+    return item
+        .nodesWith(
+          attributedLabel: attributedLabel,
+          attributedValue: attributedValue,
+          attributedHint: attributedHint,
+          label: label,
+          value: value,
+          hint: hint,
+          textDirection: textDirection,
+          actions: actions,
+          flags: flags,
+          tags: tags,
+          scrollPosition: scrollPosition,
+          scrollExtentMax: scrollExtentMax,
+          scrollExtentMin: scrollExtentMin,
+          currentValueLength: currentValueLength,
+          maxValueLength: maxValueLength,
+        )
+        .isNotEmpty;
   }
 
   @override
@@ -866,7 +982,12 @@ class _IncludesNodeWith extends Matcher {
   }
 
   @override
-  Description describeMismatch(dynamic item, Description mismatchDescription, Map<dynamic, dynamic> matchState, bool verbose) {
+  Description describeMismatch(
+    dynamic item,
+    Description mismatchDescription,
+    Map<dynamic, dynamic> matchState,
+    bool verbose,
+  ) {
     return mismatchDescription.add('could not find node with $_configAsString.\n$_matcherHelp');
   }
 
