@@ -21,7 +21,9 @@ void main() {
 
       expect(GlobalMaterialLocalizations.delegate.isSupported(locale), isTrue);
 
-      final MaterialLocalizations localizations = await GlobalMaterialLocalizations.delegate.load(locale);
+      final MaterialLocalizations localizations = await GlobalMaterialLocalizations.delegate.load(
+        locale,
+      );
 
       expect(localizations.openAppDrawerTooltip, isNotNull);
       expect(localizations.backButtonTooltip, isNotNull);
@@ -63,9 +65,18 @@ void main() {
       expect(localizations.remainingTextFieldCharacterCount(0), isNotNull);
       expect(localizations.remainingTextFieldCharacterCount(1), isNotNull);
       expect(localizations.remainingTextFieldCharacterCount(10), isNotNull);
-      expect(localizations.remainingTextFieldCharacterCount(0), isNot(contains(r'$remainingCount')));
-      expect(localizations.remainingTextFieldCharacterCount(1), isNot(contains(r'$remainingCount')));
-      expect(localizations.remainingTextFieldCharacterCount(10), isNot(contains(r'$remainingCount')));
+      expect(
+        localizations.remainingTextFieldCharacterCount(0),
+        isNot(contains(r'$remainingCount')),
+      );
+      expect(
+        localizations.remainingTextFieldCharacterCount(1),
+        isNot(contains(r'$remainingCount')),
+      );
+      expect(
+        localizations.remainingTextFieldCharacterCount(10),
+        isNot(contains(r'$remainingCount')),
+      );
 
       expect(localizations.aboutListTileTitle('FOO'), isNotNull);
       expect(localizations.aboutListTileTitle('FOO'), contains('FOO'));
@@ -125,13 +136,17 @@ void main() {
   testWidgets('translations spot check expansionTileExpandedHint', (WidgetTester tester) async {
     const Locale locale = Locale.fromSubtags(languageCode: 'en');
     expect(GlobalMaterialLocalizations.delegate.isSupported(locale), isTrue);
-    final MaterialLocalizations localizations = await GlobalMaterialLocalizations.delegate.load(locale);
+    final MaterialLocalizations localizations = await GlobalMaterialLocalizations.delegate.load(
+      locale,
+    );
     expect(localizations, isA<MaterialLocalizationEn>());
     expect(localizations.expansionTileExpandedHint, 'double tap to collapse');
   });
 
   testWidgets('spot check selectedRowCount translations', (WidgetTester tester) async {
-    MaterialLocalizations localizations = await GlobalMaterialLocalizations.delegate.load(const Locale('en'));
+    MaterialLocalizations localizations = await GlobalMaterialLocalizations.delegate.load(
+      const Locale('en'),
+    );
     expect(localizations.selectedRowCountTitle(0), 'No items selected');
     expect(localizations.selectedRowCountTitle(1), '1 item selected');
     expect(localizations.selectedRowCountTitle(2), '2 items selected');
@@ -178,8 +193,12 @@ void main() {
     expect(localizations.selectedRowCountTitle(123456789), 'បាន​ជ្រើស​រើស​ធាតុ 123,456,789');
   });
 
-  testWidgets('spot check formatMediumDate(), formatFullDate() translations', (WidgetTester tester) async {
-    MaterialLocalizations localizations = await GlobalMaterialLocalizations.delegate.load(const Locale('en'));
+  testWidgets('spot check formatMediumDate(), formatFullDate() translations', (
+    WidgetTester tester,
+  ) async {
+    MaterialLocalizations localizations = await GlobalMaterialLocalizations.delegate.load(
+      const Locale('en'),
+    );
     expect(localizations.formatMediumDate(DateTime(2015, 7, 23)), 'Thu, Jul 23');
     expect(localizations.formatFullDate(DateTime(2015, 7, 23)), 'Thursday, July 23, 2015');
 
@@ -506,13 +525,10 @@ void main() {
 
   // Regression test for https://github.com/flutter/flutter/issues/36704.
   testWidgets('kn arb file should be properly Unicode escaped', (WidgetTester tester) async {
-    final File file = File(
-      path.join(rootDirectoryPath, 'lib', 'src', 'l10n', 'material_kn.arb'),
-    );
+    final File file = File(path.join(rootDirectoryPath, 'lib', 'src', 'l10n', 'material_kn.arb'));
 
-    final Map<String, dynamic> bundle = json.decode(
-      file.readAsStringSync(),
-    ) as Map<String, dynamic>;
+    final Map<String, dynamic> bundle =
+        json.decode(file.readAsStringSync()) as Map<String, dynamic>;
 
     // Encodes the arb resource values if they have not already been
     // encoded.
@@ -537,7 +553,9 @@ void main() {
   testWidgets('Finnish translation for tab label', (WidgetTester tester) async {
     const Locale locale = Locale('fi');
     expect(GlobalMaterialLocalizations.delegate.isSupported(locale), isTrue);
-    final MaterialLocalizations localizations = await GlobalMaterialLocalizations.delegate.load(locale);
+    final MaterialLocalizations localizations = await GlobalMaterialLocalizations.delegate.load(
+      locale,
+    );
     expect(localizations, isA<MaterialLocalizationFi>());
     expect(localizations.tabLabel(tabIndex: 1, tabCount: 2), 'Välilehti 1 kautta 2');
   });
@@ -546,7 +564,9 @@ void main() {
   testWidgets('Share button label on Material', (WidgetTester tester) async {
     const Locale locale = Locale('en');
     expect(GlobalMaterialLocalizations.delegate.isSupported(locale), isTrue);
-    final MaterialLocalizations localizations = await GlobalMaterialLocalizations.delegate.load(locale);
+    final MaterialLocalizations localizations = await GlobalMaterialLocalizations.delegate.load(
+      locale,
+    );
     expect(localizations, isA<MaterialLocalizationEn>());
     expect(localizations.shareButtonLabel, 'Share');
   });
@@ -555,8 +575,25 @@ void main() {
   testWidgets('zh-CN translation for look up label', (WidgetTester tester) async {
     const Locale locale = Locale('zh');
     expect(GlobalCupertinoLocalizations.delegate.isSupported(locale), isTrue);
-    final MaterialLocalizations localizations = await GlobalMaterialLocalizations.delegate.load(locale);
+    final MaterialLocalizations localizations = await GlobalMaterialLocalizations.delegate.load(
+      locale,
+    );
     expect(localizations, isA<MaterialLocalizationZh>());
     expect(localizations.lookUpButtonLabel, '查询');
   });
+
+  // Regression test for https://github.com/flutter/flutter/pull/151364
+  testWidgets('ko-KR translation for cut, copy, paste label in ButtonLabel', (
+    WidgetTester tester,
+  ) async {
+    const Locale locale = Locale('ko');
+    expect(GlobalCupertinoLocalizations.delegate.isSupported(locale), isTrue);
+    final MaterialLocalizations localizations = await GlobalMaterialLocalizations.delegate.load(
+      locale,
+    );
+    expect(localizations, isA<MaterialLocalizationKo>());
+    expect(localizations.cutButtonLabel, '잘라내기');
+    expect(localizations.copyButtonLabel, '복사');
+    expect(localizations.pasteButtonLabel, '붙여넣기');
+  });
 }
