@@ -15,7 +15,8 @@ import 'cache.dart';
 import 'convert.dart';
 import 'globals.dart' as globals;
 
-const String _unknownFrameworkVersion = '0.0.0-unknown';
+/// The default version when a version could not be determined.
+const String kUnknownFrameworkVersion = '0.0.0-unknown';
 
 /// A git shortcut for the branch that is being tracked by the current one.
 ///
@@ -29,25 +30,13 @@ const String kUserBranch = '[user-branch]';
 ///
 /// For example, in 2021 we deprecated the "dev" channel and transitioned "dev"
 /// users to the "beta" channel.
-const Map<String, String> kObsoleteBranches = <String, String>{
-  'dev': 'beta',
-};
+const Map<String, String> kObsoleteBranches = <String, String>{'dev': 'beta'};
 
 /// The names of each channel/branch in order of increasing stability.
-enum Channel {
-  master,
-  main,
-  beta,
-  stable,
-}
+enum Channel { master, main, beta, stable }
 
 // Beware: Keep order in accordance with stability
-const Set<String> kOfficialChannels = <String>{
-  'master',
-  'main',
-  'beta',
-  'stable',
-};
+const Set<String> kOfficialChannels = <String>{'master', 'main', 'beta', 'stable'};
 
 const Map<String, String> kChannelDescriptions = <String, String>{
   'master': 'latest development branch, for contributors',
@@ -56,10 +45,7 @@ const Map<String, String> kChannelDescriptions = <String, String>{
   'stable': 'updated quarterly, for new users and for production app releases',
 };
 
-const Set<String> kDevelopmentChannels = <String>{
-  'master',
-  'main',
-};
+const Set<String> kDevelopmentChannels = <String>{'master', 'main'};
 
 /// Retrieve a human-readable name for a given [channel].
 ///
@@ -86,8 +72,7 @@ abstract class FlutterVersion {
     SystemClock clock = const SystemClock(),
     required FileSystem fs,
     required String flutterRoot,
-    @protected
-    bool fetchTags = false,
+    @protected bool fetchTags = false,
   }) {
     final File versionFile = getVersionFile(fs, flutterRoot);
 
@@ -125,11 +110,8 @@ abstract class FlutterVersion {
     );
   }
 
-  FlutterVersion._({
-    required SystemClock clock,
-    required this.flutterRoot,
-    required this.fs,
-  }) : _clock = clock;
+  FlutterVersion._({required SystemClock clock, required this.flutterRoot, required this.fs})
+    : _clock = clock;
 
   factory FlutterVersion.fromRevision({
     SystemClock clock = const SystemClock(),
@@ -163,21 +145,14 @@ abstract class FlutterVersion {
   ///
   /// This is a method and not a factory constructor so that test classes can
   /// override it.
-  FlutterVersion fetchTagsAndGetVersion({
-    SystemClock clock = const SystemClock(),
-  }) {
+  FlutterVersion fetchTagsAndGetVersion({SystemClock clock = const SystemClock()}) {
     // We don't need to fetch tags on beta and stable to calculate the version,
     // we should already exactly be on a tag that was pushed when this release
     // was published.
     if (channel != 'master' && channel != 'main') {
       return this;
     }
-    return FlutterVersion(
-      clock: clock,
-      flutterRoot: flutterRoot,
-      fs: fs,
-      fetchTags: true,
-    );
+    return FlutterVersion(clock: clock, flutterRoot: flutterRoot, fs: fs, fetchTags: true);
   }
 
   final FileSystem fs;
@@ -228,9 +203,12 @@ abstract class FlutterVersion {
 
   @override
   String toString() {
-    final String versionText = frameworkVersion == _unknownFrameworkVersion ? '' : ' $frameworkVersion';
-    final String flutterText = 'Flutter$versionText • channel $channel • ${repositoryUrl ?? 'unknown source'}';
-    final String frameworkText = 'Framework • revision $frameworkRevisionShort ($frameworkAge) • $frameworkCommitDate';
+    final String versionText =
+        frameworkVersion == kUnknownFrameworkVersion ? '' : ' $frameworkVersion';
+    final String flutterText =
+        'Flutter$versionText • channel $channel • ${repositoryUrl ?? 'unknown source'}';
+    final String frameworkText =
+        'Framework • revision $frameworkRevisionShort ($frameworkAge) • $frameworkCommitDate';
     final String engineText = 'Engine • revision $engineRevisionShort';
     final String toolsText = 'Tools • Dart $dartSdkVersion • DevTools $devToolsVersion';
 
@@ -304,7 +282,10 @@ abstract class FlutterVersion {
   /// unable to reach the server to get the latest version.
   Future<DateTime?> _getLatestAvailableFlutterDate() async {
     globals.cache.checkLockAcquired();
-    final VersionCheckStamp versionCheckStamp = await VersionCheckStamp.load(globals.cache, globals.logger);
+    final VersionCheckStamp versionCheckStamp = await VersionCheckStamp.load(
+      globals.cache,
+      globals.logger,
+    );
 
     final DateTime now = _clock.now();
     if (versionCheckStamp.lastTimeVersionWasChecked != null) {
@@ -335,9 +316,7 @@ abstract class FlutterVersion {
       globals.printTrace('Failed to check Flutter version in the remote repository: $error');
       // Still update the timestamp to avoid us hitting the server on every single
       // command if for some reason we cannot connect (eg. we may be offline).
-      await versionCheckStamp.store(
-        newTimeVersionWasChecked: now,
-      );
+      await versionCheckStamp.store(newTimeVersionWasChecked: now);
       return null;
     }
   }
@@ -358,8 +337,8 @@ abstract class FlutterVersion {
   }
 
   /// Return a short string for the version (e.g. `master/0.0.59-pre.92`, `scroll_refactor/a76bc8e22b`).
-  String getVersionString({ bool redactUnknownBranches = false }) {
-    if (frameworkVersion != _unknownFrameworkVersion) {
+  String getVersionString({bool redactUnknownBranches = false}) {
+    if (frameworkVersion != kUnknownFrameworkVersion) {
       return '${getBranchName(redactUnknownBranches: redactUnknownBranches)}/$frameworkVersion';
     }
     return '${getBranchName(redactUnknownBranches: redactUnknownBranches)}/$frameworkRevisionShort';
@@ -374,9 +353,13 @@ abstract class FlutterVersion {
   ///
   /// If [redactUnknownBranches] is true and the branch is unknown,
   /// the branch name will be returned as `'[user-branch]'` ([kUserBranch]).
-  String getBranchName({ bool redactUnknownBranches = false }) {
+  String getBranchName({bool redactUnknownBranches = false}) {
     _branch ??= () {
-      final String branch = _runGit('git symbolic-ref --short HEAD', globals.processUtils, flutterRoot);
+      final String branch = _runGit(
+        'git symbolic-ref --short HEAD',
+        globals.processUtils,
+        flutterRoot,
+      );
       return branch == 'HEAD' ? '' : branch;
     }();
     if (redactUnknownBranches || _branch!.isEmpty) {
@@ -396,9 +379,7 @@ abstract class FlutterVersion {
   /// channel doesn't linger.
   static Future<void> resetFlutterVersionFreshnessCheck() async {
     try {
-      await globals.cache.getStampFileFor(
-        VersionCheckStamp.flutterVersionCheckStampFile,
-      ).delete();
+      await globals.cache.getStampFileFor(VersionCheckStamp.flutterVersionCheckStampFile).delete();
     } on FileSystemException {
       // Ignore, since we don't mind if the file didn't exist in the first place.
     }
@@ -433,16 +414,14 @@ String _gitCommitDate({
   try {
     // Don't plumb 'lenient' through directly so that we can print an error
     // if something goes wrong.
-    return _runSync(
-      args,
-      lenient: false,
-      workingDirectory: workingDirectory,
-    );
+    return _runSync(args, lenient: false, workingDirectory: workingDirectory);
   } on VersionCheckError catch (e) {
     if (lenient) {
       final DateTime dummyDate = DateTime.fromMillisecondsSinceEpoch(0);
-      globals.printError('Failed to find the latest git commit date: $e\n'
-        'Returning $dummyDate instead.');
+      globals.printError(
+        'Failed to find the latest git commit date: $e\n'
+        'Returning $dummyDate instead.',
+      );
       // Return something that DateTime.parse() can parse.
       return dummyDate.toString();
     } else {
@@ -535,11 +514,7 @@ class _FlutterVersionFromFile extends FlutterVersion {
 
   @override
   void ensureVersionFile() {
-    _ensureLegacyVersionFile(
-      fs: fs,
-      flutterRoot: flutterRoot,
-      frameworkVersion: frameworkVersion,
-    );
+    _ensureLegacyVersionFile(fs: fs, flutterRoot: flutterRoot, frameworkVersion: frameworkVersion);
   }
 }
 
@@ -601,17 +576,18 @@ class _FlutterVersionGit extends FlutterVersion {
   @override
   String get channel {
     final String channel = getBranchName(redactUnknownBranches: true);
-    assert(kOfficialChannels.contains(channel) || kObsoleteBranches.containsKey(channel) || channel == kUserBranch, 'Potential PII leak in channel name: "$channel"');
+    assert(
+      kOfficialChannels.contains(channel) ||
+          kObsoleteBranches.containsKey(channel) ||
+          channel == kUserBranch,
+      'Potential PII leak in channel name: "$channel"',
+    );
     return channel;
   }
 
   @override
   void ensureVersionFile() {
-    _ensureLegacyVersionFile(
-      fs: fs,
-      flutterRoot: flutterRoot,
-      frameworkVersion: frameworkVersion,
-    );
+    _ensureLegacyVersionFile(fs: fs, flutterRoot: flutterRoot, frameworkVersion: frameworkVersion);
 
     const JsonEncoder encoder = JsonEncoder.withIndent('  ');
     final File newVersionFile = FlutterVersion.getVersionFile(fs, flutterRoot);
@@ -647,10 +623,7 @@ void _ensureLegacyVersionFile({
 /// This also prevents unnecessary freshness check from a forked repo unless the
 /// user explicitly configures the environment to do so.
 class VersionUpstreamValidator {
-  VersionUpstreamValidator({
-    required this.version,
-    required this.platform,
-  });
+  VersionUpstreamValidator({required this.version, required this.platform});
 
   final Platform platform;
   final FlutterVersion version;
@@ -658,24 +631,27 @@ class VersionUpstreamValidator {
   /// Performs the validation against the tracking remote of the [version].
   ///
   /// Returns [VersionCheckError] if the tracking remote is not standard.
-  VersionCheckError? run(){
+  VersionCheckError? run() {
     final String? flutterGit = platform.environment['FLUTTER_GIT_URL'];
     final String? repositoryUrl = version.repositoryUrl;
 
     if (repositoryUrl == null) {
       return VersionCheckError(
         'The tool could not determine the remote upstream which is being '
-        'tracked by the SDK.'
+        'tracked by the SDK.',
       );
     }
 
     // Strip `.git` suffix before comparing the remotes
-    final List<String> sanitizedStandardRemotes = <String>[
-      // If `FLUTTER_GIT_URL` is set, use that as standard remote.
-      if (flutterGit != null) flutterGit
-      // Else use the predefined standard remotes.
-      else ..._standardRemotes,
-    ].map((String remote) => stripDotGit(remote)).toList();
+    final List<String> sanitizedStandardRemotes =
+        <String>[
+          // If `FLUTTER_GIT_URL` is set, use that as standard remote.
+          if (flutterGit != null)
+            flutterGit
+          // Else use the predefined standard remotes.
+          else
+            ..._standardRemotes,
+        ].map((String remote) => stripDotGit(remote)).toList();
 
     final String sanitizedRepositoryUrl = stripDotGit(repositoryUrl);
 
@@ -690,7 +666,7 @@ class VersionUpstreamValidator {
           'Either remove "FLUTTER_GIT_URL" from the environment or set it to '
           '"$repositoryUrl". '
           'If this is intentional, it is recommended to use "git" directly to '
-          'manage the SDK.'
+          'manage the SDK.',
         );
       }
       // If `FLUTTER_GIT_URL` is unset, inform to set the environment variable.
@@ -699,7 +675,7 @@ class VersionUpstreamValidator {
         'Set the environment variable "FLUTTER_GIT_URL" to '
         '"$repositoryUrl". '
         'If this is intentional, it is recommended to use "git" directly to '
-        'manage the SDK.'
+        'manage the SDK.',
       );
     }
     return null;
@@ -717,11 +693,7 @@ class VersionUpstreamValidator {
   // URLs without ".git" suffix will remain unaffected.
   static final RegExp _patternUrlDotGit = RegExp(r'(.*)(\.git)$');
   static String stripDotGit(String url) {
-    final RegExpMatch? match = _patternUrlDotGit.firstMatch(url);
-    if (match == null) {
-      return url;
-    }
-    return match.group(1)!;
+    return _patternUrlDotGit.firstMatch(url)?.group(1)! ?? url;
   }
 }
 
@@ -799,7 +771,10 @@ class VersionCheckStamp {
     }
 
     const JsonEncoder prettyJsonEncoder = JsonEncoder.withIndent('  ');
-    (cache ?? globals.cache).setStampFor(flutterVersionCheckStampFile, prettyJsonEncoder.convert(jsonData));
+    (cache ?? globals.cache).setStampFor(
+      flutterVersionCheckStampFile,
+      prettyJsonEncoder.convert(jsonData),
+    );
   }
 
   Map<String, String> toJson({
@@ -835,7 +810,6 @@ class VersionCheckStamp {
 /// when the installation is not git-based (e.g. a user clones the repo but
 /// then removes .git).
 class VersionCheckError implements Exception {
-
   VersionCheckError(this.message);
 
   final String message;
@@ -848,11 +822,7 @@ class VersionCheckError implements Exception {
 ///
 /// If [lenient] is true and the command fails, returns an empty string.
 /// Otherwise, throws a [ToolExit] exception.
-String _runSync(
-  List<String> command, {
-  bool lenient = true,
-  required String? workingDirectory,
-}) {
+String _runSync(List<String> command, {bool lenient = true, required String? workingDirectory}) {
   final ProcessResult results = globals.processManager.runSync(
     command,
     workingDirectory: workingDirectory,
@@ -866,7 +836,7 @@ String _runSync(
     throw VersionCheckError(
       'Command exited with code ${results.exitCode}: ${command.join(' ')}\n'
       'Standard out: ${results.stdout}\n'
-      'Standard error: ${results.stderr}'
+      'Standard error: ${results.stderr}',
     );
   }
 
@@ -874,10 +844,7 @@ String _runSync(
 }
 
 String _runGit(String command, ProcessUtils processUtils, String? workingDirectory) {
-  return processUtils.runSync(
-    command.split(' '),
-    workingDirectory: workingDirectory,
-  ).stdout.trim();
+  return processUtils.runSync(command.split(' '), workingDirectory: workingDirectory).stdout.trim();
 }
 
 /// Runs [command] in the root of the Flutter installation and returns the
@@ -885,7 +852,10 @@ String _runGit(String command, ProcessUtils processUtils, String? workingDirecto
 ///
 /// If the command fails, throws a [ToolExit] exception.
 Future<String> _run(List<String> command) async {
-  final ProcessResult results = await globals.processManager.run(command, workingDirectory: Cache.flutterRoot);
+  final ProcessResult results = await globals.processManager.run(
+    command,
+    workingDirectory: Cache.flutterRoot,
+  );
 
   if (results.exitCode == 0) {
     return (results.stdout as String).trim();
@@ -893,7 +863,7 @@ Future<String> _run(List<String> command) async {
 
   throw VersionCheckError(
     'Command exited with code ${results.exitCode}: ${command.join(' ')}\n'
-    'Standard error: ${results.stderr}'
+    'Standard error: ${results.stderr}',
   );
 }
 
@@ -960,20 +930,28 @@ class GitTagVersion {
     Platform platform, {
     String? workingDirectory,
     bool fetchTags = false,
-    String gitRef = 'HEAD'
+    String gitRef = 'HEAD',
   }) {
     if (fetchTags) {
-      final String channel = _runGit('git symbolic-ref --short HEAD', processUtils, workingDirectory);
+      final String channel = _runGit(
+        'git symbolic-ref --short HEAD',
+        processUtils,
+        workingDirectory,
+      );
       if (!kDevelopmentChannels.contains(channel) && kOfficialChannels.contains(channel)) {
         globals.printTrace('Skipping request to fetchTags - on well known channel $channel.');
       } else {
-        final String flutterGit = platform.environment['FLUTTER_GIT_URL'] ?? 'https://github.com/flutter/flutter.git';
+        final String flutterGit =
+            platform.environment['FLUTTER_GIT_URL'] ?? 'https://github.com/flutter/flutter.git';
         _runGit('git fetch $flutterGit --tags -f', processUtils, workingDirectory);
       }
     }
     // find all tags attached to the given [gitRef]
     final List<String> tags = _runGit(
-      'git tag --points-at $gitRef', processUtils, workingDirectory).trim().split('\n');
+      'git tag --points-at $gitRef',
+      processUtils,
+      workingDirectory,
+    ).trim().split('\n');
 
     // Check first for a stable tag
     final RegExp stableTagPattern = RegExp(r'^\d+\.\d+\.\d+$');
@@ -993,11 +971,7 @@ class GitTagVersion {
     // If we're not currently on a tag, use git describe to find the most
     // recent tag and number of commits past.
     return parse(
-      _runGit(
-        'git describe --match *.*.* --long --tags $gitRef',
-        processUtils,
-        workingDirectory,
-      )
+      _runGit('git describe --match *.*.* --long --tags $gitRef', processUtils, workingDirectory),
     );
   }
 
@@ -1009,7 +983,8 @@ class GitTagVersion {
   /// return '1.2.3-4.5.pre-6-gabc123').
   static GitTagVersion parseVersion(String version) {
     final RegExp versionPattern = RegExp(
-      r'^(\d+)\.(\d+)\.(\d+)(-\d+\.\d+\.pre)?(?:-(\d+)-g([a-f0-9]+))?$');
+      r'^(\d+)\.(\d+)\.(\d+)(-\d+\.\d+\.pre)?(?:-(\d+)-g([a-f0-9]+))?$',
+    );
     final Match? match = versionPattern.firstMatch(version.trim());
     if (match == null) {
       return const GitTagVersion.unknown();
@@ -1022,8 +997,7 @@ class GitTagVersion {
     final String? devString = matchGroups[3];
     int? devVersion, devPatch;
     if (devString != null) {
-      final Match? devMatch = RegExp(r'^-(\d+)\.(\d+)\.pre$')
-        .firstMatch(devString);
+      final Match? devMatch = RegExp(r'^-(\d+)\.(\d+)\.pre$').firstMatch(devString);
       final List<String?>? devGroups = devMatch?.groups(<int>[1, 2]);
       devVersion = devGroups?[0] == null ? null : int.tryParse(devGroups![0]!);
       devPatch = devGroups?[1] == null ? null : int.tryParse(devGroups![1]!);
@@ -1057,7 +1031,7 @@ class GitTagVersion {
 
   String frameworkVersionFor(String revision) {
     if (x == null || y == null || z == null || (hash != null && !revision.startsWith(hash!))) {
-      return _unknownFrameworkVersion;
+      return kUnknownFrameworkVersion;
     }
     if (commits == 0 && gitTag != null) {
       return gitTag!;
@@ -1079,8 +1053,10 @@ enum VersionCheckResult {
   /// Unable to check whether a new version is available, possibly due to
   /// a connectivity issue.
   unknown,
+
   /// The current version is up to date.
   versionIsCurrent,
+
   /// A newer version is available.
   newVersionAvailable,
 }
@@ -1148,7 +1124,8 @@ class VersionFreshnessValidator {
   // couldn't tell but the local version is outdated.
   @visibleForTesting
   bool canShowWarning(VersionCheckResult remoteVersionStatus) {
-    final bool installationSeemsOutdated = frameworkAge > versionAgeConsideredUpToDate(version.channel);
+    final bool installationSeemsOutdated =
+        frameworkAge > versionAgeConsideredUpToDate(version.channel);
     if (remoteVersionStatus == VersionCheckResult.newVersionAvailable) {
       return true;
     }
@@ -1167,14 +1144,11 @@ class VersionFreshnessValidator {
   /// beta releases happen approximately every month.
   @visibleForTesting
   static Duration versionAgeConsideredUpToDate(String channel) {
-    switch (channel) {
-      case 'stable':
-        return const Duration(days: 365 ~/ 2); // Six months
-      case 'beta':
-        return const Duration(days: 7 * 8); // Eight weeks
-      default:
-        return const Duration(days: 7 * 3); // Three weeks
-    }
+    return switch (channel) {
+      'stable' => const Duration(days: 365 ~/ 2), // Six months
+      'beta' => const Duration(days: 7 * 8), // Eight weeks
+      _ => const Duration(days: 7 * 3), // Three weeks
+    };
   }
 
   /// Execute validations and print warning to [logger] if necessary.
@@ -1196,8 +1170,10 @@ class VersionFreshnessValidator {
 
     // Do not load the stamp before the above server check as it may modify the stamp file.
     final VersionCheckStamp stamp = await VersionCheckStamp.load(cache, logger);
-    final DateTime lastTimeWarningWasPrinted = stamp.lastTimeWarningWasPrinted ?? clock.ago(maxTimeSinceLastWarning * 2);
-    final bool beenAWhileSinceWarningWasPrinted = now.difference(lastTimeWarningWasPrinted) > maxTimeSinceLastWarning;
+    final DateTime lastTimeWarningWasPrinted =
+        stamp.lastTimeWarningWasPrinted ?? clock.ago(maxTimeSinceLastWarning * 2);
+    final bool beenAWhileSinceWarningWasPrinted =
+        now.difference(lastTimeWarningWasPrinted) > maxTimeSinceLastWarning;
     if (!beenAWhileSinceWarningWasPrinted) {
       return;
     }
@@ -1220,10 +1196,7 @@ class VersionFreshnessValidator {
 
     logger.printBox(updateMessage);
     await Future.wait<void>(<Future<void>>[
-      stamp.store(
-        newTimeWarningWasPrinted: now,
-        cache: cache,
-      ),
+      stamp.store(newTimeWarningWasPrinted: now, cache: cache),
       Future<void>.delayed(pauseTime),
     ]);
   }
