@@ -7,7 +7,7 @@ import 'package:flutter_tools/src/base/file_system.dart';
 import 'package:flutter_tools/src/base/io.dart';
 import 'package:flutter_tools/src/base/platform.dart';
 import 'package:flutter_tools/src/build_info.dart';
-import 'package:flutter_tools/src/build_system/targets/shader_compiler.dart';
+import 'package:flutter_tools/src/build_system/tools/shader_compiler.dart';
 import 'package:flutter_tools/src/compile.dart';
 import 'package:flutter_tools/src/devfs.dart';
 import 'package:flutter_tools/src/device.dart';
@@ -24,25 +24,30 @@ import '../src/context.dart';
 
 void main() {
   testUsingContext('Exits with code 2 when HttpException is thrown '
-    'during VM service connection', () async {
+      'during VM service connection', () async {
     final FakeResidentCompiler residentCompiler = FakeResidentCompiler();
-    final FakeDevice device = FakeDevice()
-      ..supportsHotReload = true
-      ..supportsHotRestart = false;
+    final FakeDevice device =
+        FakeDevice()
+          ..supportsHotReload = true
+          ..supportsHotRestart = false;
 
     final List<FlutterDevice> devices = <FlutterDevice>[
       TestFlutterDevice(
         device: device,
         generator: residentCompiler,
-        exception: const HttpException('Connection closed before full header was received, '
-            'uri = http://127.0.0.1:63394/5ZmLv8A59xY=/ws'),
+        exception: const HttpException(
+          'Connection closed before full header was received, '
+          'uri = http://127.0.0.1:63394/5ZmLv8A59xY=/ws',
+        ),
       ),
     ];
 
-    final int exitCode = await ColdRunner(devices,
-      debuggingOptions: DebuggingOptions.enabled(BuildInfo.debug),
-      target: 'main.dart',
-    ).attach();
+    final int exitCode =
+        await ColdRunner(
+          devices,
+          debuggingOptions: DebuggingOptions.enabled(BuildInfo.debug),
+          target: 'main.dart',
+        ).attach();
     expect(exitCode, 2);
   });
 
@@ -55,7 +60,8 @@ void main() {
 
       final List<FlutterDevice> devices = <FlutterDevice>[flutterDevice1, flutterDevice2];
 
-      await ColdRunner(devices,
+      await ColdRunner(
+        devices,
         debuggingOptions: DebuggingOptions.enabled(BuildInfo.debug),
         target: 'main.dart',
       ).cleanupAtFinish();
@@ -78,63 +84,85 @@ void main() {
 
     testUsingContext('calls runCold on attached device', () async {
       final FakeDevice device = FakeDevice();
-      final FakeFlutterDevice flutterDevice = FakeFlutterDevice(device)
-        ..runColdCode = 1;
+      final FakeFlutterDevice flutterDevice = FakeFlutterDevice(device)..runColdCode = 1;
       final List<FlutterDevice> devices = <FlutterDevice>[flutterDevice];
       final File applicationBinary = MemoryFileSystem.test().file('binary');
-      final int result = await ColdRunner(
-        devices,
-        applicationBinary: applicationBinary,
-        debuggingOptions: DebuggingOptions.enabled(BuildInfo.debug),
-        target: 'main.dart',
-      ).run();
+      final int result =
+          await ColdRunner(
+            devices,
+            applicationBinary: applicationBinary,
+            debuggingOptions: DebuggingOptions.enabled(BuildInfo.debug),
+            target: 'main.dart',
+          ).run();
 
       expect(result, 1);
     });
 
-    testUsingContext('with traceStartup, no env variable', () async {
-      final FakeDevice device = FakeDevice();
-      final FakeFlutterDevice flutterDevice = FakeFlutterDevice(device);
-      final List<FlutterDevice> devices = <FlutterDevice>[flutterDevice];
-      final File applicationBinary = MemoryFileSystem.test().file('binary');
-      final int result = await ColdRunner(
-        devices,
-        applicationBinary: applicationBinary,
-        debuggingOptions: DebuggingOptions.disabled(BuildInfo.debug),
-        target: 'main.dart',
-        traceStartup: true,
-      ).run();
+    testUsingContext(
+      'with traceStartup, no env variable',
+      () async {
+        final FakeDevice device = FakeDevice();
+        final FakeFlutterDevice flutterDevice = FakeFlutterDevice(device);
+        final List<FlutterDevice> devices = <FlutterDevice>[flutterDevice];
+        final File applicationBinary = MemoryFileSystem.test().file('binary');
+        final int result =
+            await ColdRunner(
+              devices,
+              applicationBinary: applicationBinary,
+              debuggingOptions: DebuggingOptions.disabled(BuildInfo.debug),
+              target: 'main.dart',
+              traceStartup: true,
+            ).run();
 
-      expect(result, 0);
-      expect(memoryFileSystem.directory(getBuildDirectory()).childFile('start_up_info.json').existsSync(), true);
-    }, overrides: <Type, Generator>{
-      FileSystem: () => memoryFileSystem,
-      ProcessManager: () => FakeProcessManager.any(),
-      Platform: () => fakePlatform,
-    });
+        expect(result, 0);
+        expect(
+          memoryFileSystem
+              .directory(getBuildDirectory())
+              .childFile('start_up_info.json')
+              .existsSync(),
+          true,
+        );
+      },
+      overrides: <Type, Generator>{
+        FileSystem: () => memoryFileSystem,
+        ProcessManager: () => FakeProcessManager.any(),
+        Platform: () => fakePlatform,
+      },
+    );
 
-    testUsingContext('with traceStartup, env variable', () async {
-      fakePlatform.environment[kFlutterTestOutputsDirEnvName] = 'test_output_dir';
+    testUsingContext(
+      'with traceStartup, env variable',
+      () async {
+        fakePlatform.environment[kFlutterTestOutputsDirEnvName] = 'test_output_dir';
 
-      final FakeDevice device = FakeDevice();
-      final FakeFlutterDevice flutterDevice = FakeFlutterDevice(device);
-      final List<FlutterDevice> devices = <FlutterDevice>[flutterDevice];
-      final File applicationBinary = MemoryFileSystem.test().file('binary');
-      final int result = await ColdRunner(
-        devices,
-        applicationBinary: applicationBinary,
-        debuggingOptions: DebuggingOptions.disabled(BuildInfo.debug),
-        target: 'main.dart',
-        traceStartup: true,
-      ).run();
+        final FakeDevice device = FakeDevice();
+        final FakeFlutterDevice flutterDevice = FakeFlutterDevice(device);
+        final List<FlutterDevice> devices = <FlutterDevice>[flutterDevice];
+        final File applicationBinary = MemoryFileSystem.test().file('binary');
+        final int result =
+            await ColdRunner(
+              devices,
+              applicationBinary: applicationBinary,
+              debuggingOptions: DebuggingOptions.disabled(BuildInfo.debug),
+              target: 'main.dart',
+              traceStartup: true,
+            ).run();
 
-      expect(result, 0);
-      expect(memoryFileSystem.directory('test_output_dir').childFile('start_up_info.json').existsSync(), true);
-    }, overrides: <Type, Generator>{
-      FileSystem: () => memoryFileSystem,
-      ProcessManager: () => FakeProcessManager.any(),
-      Platform: () => fakePlatform,
-    });
+        expect(result, 0);
+        expect(
+          memoryFileSystem
+              .directory('test_output_dir')
+              .childFile('start_up_info.json')
+              .existsSync(),
+          true,
+        );
+      },
+      overrides: <Type, Generator>{
+        FileSystem: () => memoryFileSystem,
+        ProcessManager: () => FakeProcessManager.any(),
+        Platform: () => fakePlatform,
+      },
+    );
   });
 }
 
@@ -163,9 +191,6 @@ class FakeFlutterDevice extends Fake implements FlutterDevice {
   Future<int> runCold({ColdRunner? coldRunner, String? route}) async {
     return runColdCode;
   }
-
-  @override
-  Future<void> initLogReader() async { }
 }
 
 class FakeDevice extends Fake implements Device {
@@ -184,6 +209,9 @@ class FakeDevice extends Fake implements Device {
   @override
   String get name => 'test';
 
+  @override
+  String get displayName => name;
+
   @override
   Future<TargetPlatform> get targetPlatform async => TargetPlatform.tester;
 
@@ -200,7 +228,12 @@ class TestFlutterDevice extends FlutterDevice {
     required Device device,
     required this.exception,
     required ResidentCompiler generator,
-  })  : super(device, buildInfo: BuildInfo.debug, generator: generator, developmentShaderCompiler: const FakeShaderCompiler());
+  }) : super(
+         device,
+         buildInfo: BuildInfo.debug,
+         generator: generator,
+         developmentShaderCompiler: const FakeShaderCompiler(),
+       );
 
   /// The exception to throw when the connect method is called.
   final Exception exception;
@@ -213,26 +246,25 @@ class TestFlutterDevice extends FlutterDevice {
     GetSkSLMethod? getSkSLMethod,
     FlutterProject? flutterProject,
     PrintStructuredErrorLogMethod? printStructuredErrorLogMethod,
-    bool enableDds = true,
-    bool cacheStartupProfile = false,
-    bool disableServiceAuthCodes = false,
+    required DebuggingOptions debuggingOptions,
     int? hostVmServicePort,
-    int? ddsPort,
-    bool? ipv6 = false,
-    bool allowExistingDdsInstance = false,
+    required bool allowExistingDdsInstance,
   }) async {
     throw exception;
   }
 }
 
-class FakeResidentCompiler extends Fake implements ResidentCompiler { }
+class FakeResidentCompiler extends Fake implements ResidentCompiler {}
 
 class FakeFlutterVmService extends Fake implements FlutterVmService {
   @override
   VmService get service => FakeVmService();
 
   @override
-  Future<List<FlutterView>> getFlutterViews({bool returnEarly = false, Duration delay = const Duration(milliseconds: 50)}) async {
+  Future<List<FlutterView>> getFlutterViews({
+    bool returnEarly = false,
+    Duration delay = const Duration(milliseconds: 50),
+  }) async {
     return <FlutterView>[];
   }
 
@@ -243,18 +275,9 @@ class FakeFlutterVmService extends Fake implements FlutterVmService {
   Future<Response?> getTimeline() async {
     return Response.parse(<String, dynamic>{
       'traceEvents': <dynamic>[
-        <String, dynamic>{
-          'name': kFlutterEngineMainEnterEventName,
-          'ts': 123,
-        },
-        <String, dynamic>{
-          'name': kFirstFrameBuiltEventName,
-          'ts': 124,
-        },
-        <String, dynamic>{
-          'name': kFirstFrameRasterizedEventName,
-          'ts': 124,
-        },
+        <String, dynamic>{'name': kFlutterEngineMainEnterEventName, 'ts': 123},
+        <String, dynamic>{'name': kFirstFrameBuiltEventName, 'ts': 124},
+        <String, dynamic>{'name': kFirstFrameRasterizedEventName, 'ts': 124},
       ],
     });
   }
@@ -279,10 +302,7 @@ class FakeShaderCompiler implements DevelopmentShaderCompiler {
   const FakeShaderCompiler();
 
   @override
-  void configureCompiler(
-    TargetPlatform? platform, {
-    required ImpellerStatus impellerStatus,
-  }) { }
+  void configureCompiler(TargetPlatform? platform) {}
 
   @override
   Future<DevFSContent> recompileShader(DevFSContent inputShader) {
