@@ -4,6 +4,7 @@
 
 import 'dart:async';
 
+import 'package:fake_async/fake_async.dart';
 import 'package:file/memory.dart';
 import 'package:flutter_tools/src/application_package.dart';
 import 'package:flutter_tools/src/base/file_system.dart';
@@ -14,12 +15,13 @@ import 'package:flutter_tools/src/desktop_device.dart';
 import 'package:flutter_tools/src/devfs.dart';
 import 'package:flutter_tools/src/device.dart';
 import 'package:flutter_tools/src/device_port_forwarder.dart';
+import 'package:flutter_tools/src/macos/macos_device.dart';
 import 'package:flutter_tools/src/project.dart';
 
 import 'package:test/fake.dart';
 
 import '../src/common.dart';
-import '../src/fake_process_manager.dart';
+import '../src/context.dart';
 
 void main() {
   group('Basic info', () {
@@ -85,8 +87,14 @@ void main() {
           completer: completer,
         ),
       ]);
-      final FakeDesktopDevice device = setUpDesktopDevice(processManager: processManager, fileSystem: fileSystem);
-      final String? executableName = device.executablePathForDevice(FakeApplicationPackage(), BuildInfo.debug);
+      final FakeDesktopDevice device = setUpDesktopDevice(
+        processManager: processManager,
+        fileSystem: fileSystem,
+      );
+      final String? executableName = device.executablePathForDevice(
+        FakeApplicationPackage(),
+        BuildInfo.debug,
+      );
       fileSystem.file(executableName).writeAsStringSync('\n');
       final FakeApplicationPackage package = FakeApplicationPackage();
       final LaunchResult result = await device.startApp(
@@ -101,7 +109,10 @@ void main() {
 
     testWithoutContext('Null executable path fails gracefully', () async {
       final BufferLogger logger = BufferLogger.test();
-      final DesktopDevice device = setUpDesktopDevice(nullExecutablePathForDevice: true, logger: logger);
+      final DesktopDevice device = setUpDesktopDevice(
+        nullExecutablePathForDevice: true,
+        logger: logger,
+      );
       final FakeApplicationPackage package = FakeApplicationPackage();
       final LaunchResult result = await device.startApp(
         package,
@@ -135,101 +146,107 @@ void main() {
     });
   });
 
-  testWithoutContext('startApp supports DebuggingOptions through FLUTTER_ENGINE_SWITCH environment variables', () async {
-    final Completer<void> completer = Completer<void>();
-    final FakeProcessManager processManager = FakeProcessManager.list(<FakeCommand>[
-      FakeCommand(
-        command: const <String>['debug'],
-        stdout: 'The Dart VM service is listening on http://127.0.0.1/0\n',
-        completer: completer,
-        environment: const <String, String>{
-          'FLUTTER_ENGINE_SWITCH_1': 'enable-dart-profiling=true',
-          'FLUTTER_ENGINE_SWITCH_2': 'trace-startup=true',
-          'FLUTTER_ENGINE_SWITCH_3': 'enable-software-rendering=true',
-          'FLUTTER_ENGINE_SWITCH_4': 'skia-deterministic-rendering=true',
-          'FLUTTER_ENGINE_SWITCH_5': 'trace-skia=true',
-          'FLUTTER_ENGINE_SWITCH_6': 'trace-allowlist=foo,bar',
-          'FLUTTER_ENGINE_SWITCH_7': 'trace-skia-allowlist=skia.a,skia.b',
-          'FLUTTER_ENGINE_SWITCH_8': 'trace-systrace=true',
-          'FLUTTER_ENGINE_SWITCH_9': 'endless-trace-buffer=true',
-          'FLUTTER_ENGINE_SWITCH_10': 'dump-skp-on-shader-compilation=true',
-          'FLUTTER_ENGINE_SWITCH_11': 'cache-sksl=true',
-          'FLUTTER_ENGINE_SWITCH_12': 'purge-persistent-cache=true',
-          'FLUTTER_ENGINE_SWITCH_13': 'enable-checked-mode=true',
-          'FLUTTER_ENGINE_SWITCH_14': 'verify-entry-points=true',
-          'FLUTTER_ENGINE_SWITCH_15': 'start-paused=true',
-          'FLUTTER_ENGINE_SWITCH_16': 'disable-service-auth-codes=true',
-          'FLUTTER_ENGINE_SWITCH_17': 'dart-flags=--null_assertions',
-          'FLUTTER_ENGINE_SWITCH_18': 'use-test-fonts=true',
-          'FLUTTER_ENGINE_SWITCH_19': 'verbose-logging=true',
-          'FLUTTER_ENGINE_SWITCHES': '19',
-        }
-      ),
-    ]);
-    final FakeDesktopDevice device = setUpDesktopDevice(processManager: processManager);
-    final FakeApplicationPackage package = FakeApplicationPackage();
-    final LaunchResult result = await device.startApp(
-      package,
-      prebuiltApplication: true,
-      platformArgs: <String, Object>{
-        'trace-startup': true,
-      },
-      debuggingOptions: DebuggingOptions.enabled(
-        BuildInfo.debug,
-        startPaused: true,
-        disableServiceAuthCodes: true,
-        enableSoftwareRendering: true,
-        skiaDeterministicRendering: true,
-        traceSkia: true,
-        traceAllowlist: 'foo,bar',
-        traceSkiaAllowlist: 'skia.a,skia.b',
-        traceSystrace: true,
-        endlessTraceBuffer: true,
-        dumpSkpOnShaderCompilation: true,
-        cacheSkSL: true,
-        purgePersistentCache: true,
-        useTestFonts: true,
-        verboseSystemLogs: true,
-        nullAssertions: true,
-      ),
-    );
+  testWithoutContext(
+    'startApp supports DebuggingOptions through FLUTTER_ENGINE_SWITCH environment variables',
+    () async {
+      final Completer<void> completer = Completer<void>();
+      final FakeProcessManager processManager = FakeProcessManager.list(<FakeCommand>[
+        FakeCommand(
+          command: const <String>['debug'],
+          stdout: 'The Dart VM service is listening on http://127.0.0.1/0\n',
+          completer: completer,
+          environment: const <String, String>{
+            'FLUTTER_ENGINE_SWITCH_1': 'enable-dart-profiling=true',
+            'FLUTTER_ENGINE_SWITCH_2': 'trace-startup=true',
+            'FLUTTER_ENGINE_SWITCH_3': 'enable-software-rendering=true',
+            'FLUTTER_ENGINE_SWITCH_4': 'skia-deterministic-rendering=true',
+            'FLUTTER_ENGINE_SWITCH_5': 'trace-skia=true',
+            'FLUTTER_ENGINE_SWITCH_6': 'trace-allowlist=foo,bar',
+            'FLUTTER_ENGINE_SWITCH_7': 'trace-skia-allowlist=skia.a,skia.b',
+            'FLUTTER_ENGINE_SWITCH_8': 'trace-systrace=true',
+            'FLUTTER_ENGINE_SWITCH_9': 'trace-to-file=path/to/trace.binpb',
+            'FLUTTER_ENGINE_SWITCH_10': 'endless-trace-buffer=true',
+            'FLUTTER_ENGINE_SWITCH_11': 'dump-skp-on-shader-compilation=true',
+            'FLUTTER_ENGINE_SWITCH_12': 'cache-sksl=true',
+            'FLUTTER_ENGINE_SWITCH_13': 'purge-persistent-cache=true',
+            'FLUTTER_ENGINE_SWITCH_14': 'enable-impeller=false',
+            'FLUTTER_ENGINE_SWITCH_15': 'enable-checked-mode=true',
+            'FLUTTER_ENGINE_SWITCH_16': 'verify-entry-points=true',
+            'FLUTTER_ENGINE_SWITCH_17': 'start-paused=true',
+            'FLUTTER_ENGINE_SWITCH_18': 'disable-service-auth-codes=true',
+            'FLUTTER_ENGINE_SWITCH_19': 'dart-flags=--null_assertions',
+            'FLUTTER_ENGINE_SWITCH_20': 'use-test-fonts=true',
+            'FLUTTER_ENGINE_SWITCH_21': 'verbose-logging=true',
+            'FLUTTER_ENGINE_SWITCHES': '21',
+          },
+        ),
+      ]);
+      final FakeDesktopDevice device = setUpDesktopDevice(processManager: processManager);
+      final FakeApplicationPackage package = FakeApplicationPackage();
+      final LaunchResult result = await device.startApp(
+        package,
+        prebuiltApplication: true,
+        platformArgs: <String, Object>{'trace-startup': true},
+        debuggingOptions: DebuggingOptions.enabled(
+          BuildInfo.debug,
+          startPaused: true,
+          disableServiceAuthCodes: true,
+          enableSoftwareRendering: true,
+          skiaDeterministicRendering: true,
+          traceSkia: true,
+          traceAllowlist: 'foo,bar',
+          traceSkiaAllowlist: 'skia.a,skia.b',
+          traceSystrace: true,
+          traceToFile: 'path/to/trace.binpb',
+          endlessTraceBuffer: true,
+          dumpSkpOnShaderCompilation: true,
+          cacheSkSL: true,
+          purgePersistentCache: true,
+          useTestFonts: true,
+          verboseSystemLogs: true,
+          nullAssertions: true,
+        ),
+      );
 
-    expect(result.started, true);
-  });
+      expect(result.started, true);
+    },
+  );
 
-  testWithoutContext('startApp supports DebuggingOptions through FLUTTER_ENGINE_SWITCH environment variables when debugging is disabled', () async {
-    final Completer<void> completer = Completer<void>();
-    final FakeProcessManager processManager = FakeProcessManager.list(<FakeCommand>[
-      FakeCommand(
-        command: const <String>['debug'],
-        stdout: 'The Dart VM service is listening on http://127.0.0.1/0\n',
-        completer: completer,
-        environment: const <String, String>{
-          'FLUTTER_ENGINE_SWITCH_1': 'enable-dart-profiling=true',
-          'FLUTTER_ENGINE_SWITCH_2': 'trace-startup=true',
-          'FLUTTER_ENGINE_SWITCH_3': 'trace-allowlist=foo,bar',
-          'FLUTTER_ENGINE_SWITCH_4': 'cache-sksl=true',
-          'FLUTTER_ENGINE_SWITCHES': '4',
-        }
-      ),
-    ]);
-    final FakeDesktopDevice device = setUpDesktopDevice(processManager: processManager);
-    final FakeApplicationPackage package = FakeApplicationPackage();
-    final LaunchResult result = await device.startApp(
-      package,
-      prebuiltApplication: true,
-      platformArgs: <String, Object>{
-        'trace-startup': true,
-      },
-      debuggingOptions: DebuggingOptions.disabled(
-        BuildInfo.debug,
-        traceAllowlist: 'foo,bar',
-        cacheSkSL: true,
-      ),
-    );
+  testWithoutContext(
+    'startApp supports DebuggingOptions through FLUTTER_ENGINE_SWITCH environment variables when debugging is disabled',
+    () async {
+      final Completer<void> completer = Completer<void>();
+      final FakeProcessManager processManager = FakeProcessManager.list(<FakeCommand>[
+        FakeCommand(
+          command: const <String>['debug'],
+          stdout: 'The Dart VM service is listening on http://127.0.0.1/0\n',
+          completer: completer,
+          environment: const <String, String>{
+            'FLUTTER_ENGINE_SWITCH_1': 'enable-dart-profiling=true',
+            'FLUTTER_ENGINE_SWITCH_2': 'trace-startup=true',
+            'FLUTTER_ENGINE_SWITCH_3': 'trace-allowlist=foo,bar',
+            'FLUTTER_ENGINE_SWITCH_4': 'cache-sksl=true',
+            'FLUTTER_ENGINE_SWITCH_5': 'enable-impeller=false',
+            'FLUTTER_ENGINE_SWITCHES': '5',
+          },
+        ),
+      ]);
+      final FakeDesktopDevice device = setUpDesktopDevice(processManager: processManager);
+      final FakeApplicationPackage package = FakeApplicationPackage();
+      final LaunchResult result = await device.startApp(
+        package,
+        prebuiltApplication: true,
+        platformArgs: <String, Object>{'trace-startup': true},
+        debuggingOptions: DebuggingOptions.disabled(
+          BuildInfo.debug,
+          traceAllowlist: 'foo,bar',
+          cacheSkSL: true,
+        ),
+      );
 
-    expect(result.started, true);
-  });
+      expect(result.started, true);
+    },
+  );
 
   testWithoutContext('Port forwarder is a no-op', () async {
     final FakeDesktopDevice device = setUpDesktopDevice();
@@ -280,12 +297,12 @@ void main() {
         outputFollowsExit: true,
       ),
     ]);
-    final FakeDesktopDevice device = setUpDesktopDevice(
-      processManager: processManager,
+    final FakeDesktopDevice device = setUpDesktopDevice(processManager: processManager);
+    unawaited(
+      Future<void>(() {
+        exitCompleter.complete();
+      }),
     );
-    unawaited(Future<void>(() {
-      exitCompleter.complete();
-    }));
 
     // Start looking for 'Oops' in the stream before starting the app.
     expect(device.getLogReader().logLines, emits('Oops'));
@@ -301,7 +318,7 @@ void main() {
     );
   });
 
-  testWithoutContext('Desktop devices that support impeller pass through the enable-impeller flag', () async {
+  testWithoutContext('Desktop devices pass through the enable-impeller flag', () async {
     final FakeProcessManager processManager = FakeProcessManager.list(<FakeCommand>[
       const FakeCommand(
         command: <String>['debug'],
@@ -311,14 +328,11 @@ void main() {
           'FLUTTER_ENGINE_SWITCH_2': 'enable-impeller=true',
           'FLUTTER_ENGINE_SWITCH_3': 'enable-checked-mode=true',
           'FLUTTER_ENGINE_SWITCH_4': 'verify-entry-points=true',
-          'FLUTTER_ENGINE_SWITCHES': '4'
-        }
+          'FLUTTER_ENGINE_SWITCHES': '4',
+        },
       ),
     ]);
-    final FakeDesktopDevice device = setUpDesktopDevice(
-      processManager: processManager,
-      supportsImpeller: true,
-    );
+    final FakeDesktopDevice device = setUpDesktopDevice(processManager: processManager);
 
     final FakeApplicationPackage package = FakeApplicationPackage();
     await device.startApp(
@@ -332,22 +346,21 @@ void main() {
     );
   });
 
-  testWithoutContext('Desktop devices that do not support impeller ignore the enable-impeller flag', () async {
+  testWithoutContext('Desktop devices pass through the --no-enable-impeller flag', () async {
     final FakeProcessManager processManager = FakeProcessManager.list(<FakeCommand>[
       const FakeCommand(
         command: <String>['debug'],
         exitCode: -1,
         environment: <String, String>{
           'FLUTTER_ENGINE_SWITCH_1': 'enable-dart-profiling=true',
-          'FLUTTER_ENGINE_SWITCH_2': 'enable-checked-mode=true',
-          'FLUTTER_ENGINE_SWITCH_3': 'verify-entry-points=true',
-          'FLUTTER_ENGINE_SWITCHES': '3'
-        }
+          'FLUTTER_ENGINE_SWITCH_2': 'enable-impeller=false',
+          'FLUTTER_ENGINE_SWITCH_3': 'enable-checked-mode=true',
+          'FLUTTER_ENGINE_SWITCH_4': 'verify-entry-points=true',
+          'FLUTTER_ENGINE_SWITCHES': '4',
+        },
       ),
     ]);
-    final FakeDesktopDevice device = setUpDesktopDevice(
-      processManager: processManager,
-    );
+    final FakeDesktopDevice device = setUpDesktopDevice(processManager: processManager);
 
     final FakeApplicationPackage package = FakeApplicationPackage();
     await device.startApp(
@@ -355,11 +368,44 @@ void main() {
       prebuiltApplication: true,
       debuggingOptions: DebuggingOptions.enabled(
         BuildInfo.debug,
-        enableImpeller: ImpellerStatus.enabled,
+        enableImpeller: ImpellerStatus.disabled,
         dartEntrypointArgs: <String>[],
       ),
     );
   });
+
+  testUsingContext(
+    'macOS devices print warning if Dart VM not found within timeframe in CI',
+    () async {
+      final BufferLogger logger = BufferLogger.test();
+      final FakeMacOSDevice device = FakeMacOSDevice(
+        fileSystem: MemoryFileSystem.test(),
+        processManager: FakeProcessManager.any(),
+        operatingSystemUtils: FakeOperatingSystemUtils(),
+        logger: logger,
+      );
+
+      final FakeApplicationPackage package = FakeApplicationPackage();
+
+      FakeAsync().run((FakeAsync fakeAsync) {
+        device.startApp(
+          package,
+          prebuiltApplication: true,
+          debuggingOptions: DebuggingOptions.enabled(
+            BuildInfo.debug,
+            enableImpeller: ImpellerStatus.disabled,
+            dartEntrypointArgs: <String>[],
+            usingCISystem: true,
+          ),
+        );
+        fakeAsync.flushTimers();
+        expect(
+          logger.errorText,
+          contains('Ensure sandboxing is disabled by checking the set CODE_SIGN_ENTITLEMENTS'),
+        );
+      });
+    },
+  );
 }
 
 FakeDesktopDevice setUpDesktopDevice({
@@ -368,7 +414,6 @@ FakeDesktopDevice setUpDesktopDevice({
   ProcessManager? processManager,
   OperatingSystemUtils? operatingSystemUtils,
   bool nullExecutablePathForDevice = false,
-  bool supportsImpeller = false,
 }) {
   return FakeDesktopDevice(
     fileSystem: fileSystem ?? MemoryFileSystem.test(),
@@ -376,7 +421,6 @@ FakeDesktopDevice setUpDesktopDevice({
     processManager: processManager ?? FakeProcessManager.any(),
     operatingSystemUtils: operatingSystemUtils ?? FakeOperatingSystemUtils(),
     nullExecutablePathForDevice: nullExecutablePathForDevice,
-    supportsImpeller: supportsImpeller,
   );
 }
 
@@ -388,16 +432,15 @@ class FakeDesktopDevice extends DesktopDevice {
     required FileSystem fileSystem,
     required OperatingSystemUtils operatingSystemUtils,
     this.nullExecutablePathForDevice = false,
-    this.supportsImpeller = false,
   }) : super(
-      'dummy',
-      platformType: PlatformType.linux,
-      ephemeral: false,
-      processManager: processManager,
-      logger: logger,
-      fileSystem: fileSystem,
-      operatingSystemUtils: operatingSystemUtils,
-  );
+         'dummy',
+         platformType: PlatformType.linux,
+         ephemeral: false,
+         processManager: processManager,
+         logger: logger,
+         fileSystem: fileSystem,
+         operatingSystemUtils: operatingSystemUtils,
+       );
 
   /// The [mainPath] last passed to [buildForDevice].
   String? lastBuiltMainPath;
@@ -407,9 +450,6 @@ class FakeDesktopDevice extends DesktopDevice {
 
   final bool nullExecutablePathForDevice;
 
-  @override
-  final bool supportsImpeller;
-
   @override
   String get name => 'dummy';
 
@@ -426,6 +466,7 @@ class FakeDesktopDevice extends DesktopDevice {
   Future<void> buildForDevice({
     String? mainPath,
     BuildInfo? buildInfo,
+    bool usingCISystem = false,
   }) async {
     lastBuiltMainPath = mainPath;
     lastBuildInfo = buildInfo;
@@ -441,8 +482,43 @@ class FakeDesktopDevice extends DesktopDevice {
   }
 }
 
-class FakeApplicationPackage extends Fake implements ApplicationPackage { }
+class FakeApplicationPackage extends Fake implements ApplicationPackage {}
+
 class FakeOperatingSystemUtils extends Fake implements OperatingSystemUtils {
   @override
   String get name => 'Example';
 }
+
+class FakeMacOSDevice extends MacOSDevice {
+  FakeMacOSDevice({
+    required super.processManager,
+    required super.logger,
+    required super.fileSystem,
+    required super.operatingSystemUtils,
+  });
+
+  @override
+  String get name => 'dummy';
+
+  @override
+  Future<TargetPlatform> get targetPlatform async => TargetPlatform.tester;
+
+  @override
+  bool isSupported() => true;
+
+  @override
+  bool isSupportedForProject(FlutterProject flutterProject) => true;
+
+  @override
+  Future<void> buildForDevice({
+    String? mainPath,
+    BuildInfo? buildInfo,
+    bool usingCISystem = false,
+  }) async {}
+
+  // Dummy implementation that just returns the build mode name.
+  @override
+  String? executablePathForDevice(ApplicationPackage package, BuildInfo buildInfo) {
+    return buildInfo.mode.cliName;
+  }
+}
