@@ -5,10 +5,13 @@
 import 'package:file/memory.dart';
 import 'package:flutter_tools/src/base/file_system.dart';
 import 'package:flutter_tools/src/base/logger.dart';
+import 'package:flutter_tools/src/features.dart';
 import 'package:flutter_tools/src/flutter_project_metadata.dart';
 import 'package:flutter_tools/src/project.dart';
 
 import '../src/common.dart';
+import '../src/context.dart';
+import '../src/fakes.dart';
 
 void main() {
   late FileSystem fileSystem;
@@ -58,11 +61,14 @@ version:
 project_type: plugin
       ''');
     final FlutterProjectMetadata projectMetadata = FlutterProjectMetadata(metadataFile, logger);
-    expect(projectMetadata.projectType, FlutterProjectType.plugin);
+    expect(projectMetadata.projectType, FlutterTemplateType.plugin);
     expect(projectMetadata.versionChannel, isNull);
     expect(projectMetadata.versionRevision, isNull);
 
-    expect(logger.traceText, contains('The value of key `version` in .metadata was expected to be YamlMap but was Null'));
+    expect(
+      logger.traceText,
+      contains('The value of key `version` in .metadata was expected to be YamlMap but was Null'),
+    );
   });
 
   testWithoutContext('projectType is populated when version is malformed', () {
@@ -73,11 +79,14 @@ version: STRING INSTEAD OF MAP
 project_type: plugin
       ''');
     final FlutterProjectMetadata projectMetadata = FlutterProjectMetadata(metadataFile, logger);
-    expect(projectMetadata.projectType, FlutterProjectType.plugin);
+    expect(projectMetadata.projectType, FlutterTemplateType.plugin);
     expect(projectMetadata.versionChannel, isNull);
     expect(projectMetadata.versionRevision, isNull);
 
-    expect(logger.traceText, contains('The value of key `version` in .metadata was expected to be YamlMap but was String'));
+    expect(
+      logger.traceText,
+      contains('The value of key `version` in .metadata was expected to be YamlMap but was String'),
+    );
   });
 
   testWithoutContext('version is populated when projectType is malformed', () {
@@ -94,7 +103,12 @@ project_type: {}
     expect(projectMetadata.versionChannel, 'stable');
     expect(projectMetadata.versionRevision, 'b59b226a49391949247e3d6122e34bb001049ae4');
 
-    expect(logger.traceText, contains('The value of key `project_type` in .metadata was expected to be String but was YamlMap'));
+    expect(
+      logger.traceText,
+      contains(
+        'The value of key `project_type` in .metadata was expected to be String but was YamlMap',
+      ),
+    );
   });
 
   testWithoutContext('migrate config is populated when version is malformed', () {
@@ -115,12 +129,26 @@ migration:
       ''');
     final FlutterProjectMetadata projectMetadata = FlutterProjectMetadata(metadataFile, logger);
     expect(projectMetadata.projectType, isNull);
-    expect(projectMetadata.migrateConfig.platformConfigs[SupportedPlatform.root]?.createRevision, 'abcdefg');
-    expect(projectMetadata.migrateConfig.platformConfigs[SupportedPlatform.root]?.baseRevision, 'baserevision');
+    expect(
+      projectMetadata.migrateConfig.platformConfigs[SupportedPlatform.root]?.createRevision,
+      'abcdefg',
+    );
+    expect(
+      projectMetadata.migrateConfig.platformConfigs[SupportedPlatform.root]?.baseRevision,
+      'baserevision',
+    );
     expect(projectMetadata.migrateConfig.unmanagedFiles[0], 'file1');
 
-    expect(logger.traceText, contains('The value of key `version` in .metadata was expected to be YamlMap but was String'));
-    expect(logger.traceText, contains('The value of key `project_type` in .metadata was expected to be String but was YamlMap'));
+    expect(
+      logger.traceText,
+      contains('The value of key `version` in .metadata was expected to be YamlMap but was String'),
+    );
+    expect(
+      logger.traceText,
+      contains(
+        'The value of key `project_type` in .metadata was expected to be String but was YamlMap',
+      ),
+    );
   });
 
   testWithoutContext('migrate config is populated when unmanaged_files is malformed', () {
@@ -141,13 +169,24 @@ migration:
   unmanaged_files: {}
       ''');
     final FlutterProjectMetadata projectMetadata = FlutterProjectMetadata(metadataFile, logger);
-    expect(projectMetadata.projectType, FlutterProjectType.app);
-    expect(projectMetadata.migrateConfig.platformConfigs[SupportedPlatform.root]?.createRevision, 'abcdefg');
-    expect(projectMetadata.migrateConfig.platformConfigs[SupportedPlatform.root]?.baseRevision, 'baserevision');
+    expect(projectMetadata.projectType, FlutterTemplateType.app);
+    expect(
+      projectMetadata.migrateConfig.platformConfigs[SupportedPlatform.root]?.createRevision,
+      'abcdefg',
+    );
+    expect(
+      projectMetadata.migrateConfig.platformConfigs[SupportedPlatform.root]?.baseRevision,
+      'baserevision',
+    );
     // Tool uses default unmanaged files list when malformed.
     expect(projectMetadata.migrateConfig.unmanagedFiles[0], 'lib/main.dart');
 
-    expect(logger.traceText, contains('The value of key `unmanaged_files` in .metadata was expected to be YamlList but was YamlMap'));
+    expect(
+      logger.traceText,
+      contains(
+        'The value of key `unmanaged_files` in .metadata was expected to be YamlList but was YamlMap',
+      ),
+    );
   });
 
   testWithoutContext('platforms is populated with a malformed entry', () {
@@ -174,14 +213,55 @@ migration:
     - 'file1'
       ''');
     final FlutterProjectMetadata projectMetadata = FlutterProjectMetadata(metadataFile, logger);
-    expect(projectMetadata.projectType, FlutterProjectType.app);
-    expect(projectMetadata.migrateConfig.platformConfigs[SupportedPlatform.root]?.createRevision, 'abcdefg');
-    expect(projectMetadata.migrateConfig.platformConfigs[SupportedPlatform.root]?.baseRevision, 'baserevision');
-    expect(projectMetadata.migrateConfig.platformConfigs[SupportedPlatform.ios]?.createRevision, 'abcdefg');
-    expect(projectMetadata.migrateConfig.platformConfigs[SupportedPlatform.ios]?.baseRevision, 'baserevision');
-    expect(projectMetadata.migrateConfig.platformConfigs.containsKey(SupportedPlatform.android), false);
+    expect(projectMetadata.projectType, FlutterTemplateType.app);
+    expect(
+      projectMetadata.migrateConfig.platformConfigs[SupportedPlatform.root]?.createRevision,
+      'abcdefg',
+    );
+    expect(
+      projectMetadata.migrateConfig.platformConfigs[SupportedPlatform.root]?.baseRevision,
+      'baserevision',
+    );
+    expect(
+      projectMetadata.migrateConfig.platformConfigs[SupportedPlatform.ios]?.createRevision,
+      'abcdefg',
+    );
+    expect(
+      projectMetadata.migrateConfig.platformConfigs[SupportedPlatform.ios]?.baseRevision,
+      'baserevision',
+    );
+    expect(
+      projectMetadata.migrateConfig.platformConfigs.containsKey(SupportedPlatform.android),
+      false,
+    );
     expect(projectMetadata.migrateConfig.unmanagedFiles[0], 'file1');
 
     expect(logger.traceText, contains('The key `create_revision` was not found'));
   });
+
+  testUsingContext('enabledValues does not contain packageFfi if native-assets not enabled', () {
+    expect(
+      ParsedFlutterTemplateType.enabledValues(featureFlags),
+      isNot(contains(FlutterTemplateType.packageFfi)),
+    );
+    expect(
+      ParsedFlutterTemplateType.enabledValues(featureFlags),
+      contains(FlutterTemplateType.plugin),
+    );
+  });
+
+  testUsingContext(
+    'enabledValues contains packageFfi if natives-assets enabled',
+    () {
+      expect(
+        ParsedFlutterTemplateType.enabledValues(featureFlags),
+        contains(FlutterTemplateType.packageFfi),
+      );
+      expect(
+        ParsedFlutterTemplateType.enabledValues(featureFlags),
+        contains(FlutterTemplateType.plugin),
+      );
+    },
+    overrides: <Type, Generator>{FeatureFlags: () => TestFeatureFlags(isNativeAssetsEnabled: true)},
+  );
 }
