@@ -10,6 +10,7 @@ import 'package:file/file.dart';
 import 'package:flutter_tools/src/base/file_system.dart';
 import 'package:flutter_tools/src/base/io.dart';
 import 'package:flutter_tools/src/base/utils.dart';
+import 'package:meta/meta.dart';
 import 'package:process/process.dart';
 import 'package:vm_service/vm_service.dart';
 import 'package:vm_service/vm_service_io.dart';
@@ -35,11 +36,9 @@ const Duration defaultTimeout = Duration(seconds: 5);
 const Duration appStartTimeout = Duration(seconds: 120);
 const Duration quitTimeout = Duration(seconds: 10);
 
-abstract class FlutterTestDriver {
-  FlutterTestDriver(
-    this._projectFolder, {
-    String? logPrefix,
-  }) : _logPrefix = logPrefix != null ? '$logPrefix: ' : '';
+abstract final class FlutterTestDriver {
+  FlutterTestDriver(this._projectFolder, {String? logPrefix})
+    : _logPrefix = logPrefix != null ? '$logPrefix: ' : '';
 
   final Directory _projectFolder;
   final String _logPrefix;
@@ -63,9 +62,10 @@ abstract class FlutterTestDriver {
   Uri? get vmServiceWsUri => _vmServiceWsUri;
 
   String lastTime = '';
-  void _debugPrint(String message, { String topic = '' }) {
+  void _debugPrint(String message, {String topic = ''}) {
     const int maxLength = 2500;
-    final String truncatedMessage = message.length > maxLength ? '${message.substring(0, maxLength)}...' : message;
+    final String truncatedMessage =
+        message.length > maxLength ? '${message.substring(0, maxLength)}...' : message;
     final String line = '${topic.padRight(10)} $truncatedMessage';
     _allMessages.add(line);
     final int timeInSeconds = DateTime.now().difference(startTime).inSeconds;
@@ -86,17 +86,21 @@ abstract class FlutterTestDriver {
     }
   }
 
+  @mustCallSuper
   Future<void> _setupProcess(
     List<String> arguments, {
     String? script,
     bool withDebugger = false,
-    bool singleWidgetReloads = false,
+    bool verbose = false,
   }) async {
-    final String flutterBin = fileSystem.path.join(getFlutterRoot(), 'bin', 'flutter');
+    if (_process != null && !_hasExited) {
+      throw StateError('Cannot start another process while the previous runs');
+    }
+
     if (withDebugger) {
       arguments.add('--start-paused');
     }
-    if (_printDebugOutputToStdOut) {
+    if (verbose || _printDebugOutputToStdOut) {
       arguments.add('--verbose');
     }
     if (script != null) {
@@ -106,25 +110,23 @@ abstract class FlutterTestDriver {
 
     const ProcessManager processManager = LocalProcessManager();
     _process = await processManager.start(
-      <String>[flutterBin]
-        .followedBy(arguments)
-        .toList(),
+      <String>[flutterBin].followedBy(arguments).toList(),
       workingDirectory: _projectFolder.path,
       // The web environment variable has the same effect as `flutter config --enable-web`.
-      environment: <String, String>{
-        'FLUTTER_TEST': 'true',
-        'FLUTTER_WEB': 'true',
-        if (singleWidgetReloads)
-          'FLUTTER_SINGLE_WIDGET_RELOAD': 'true',
-      },
+      environment: <String, String>{'FLUTTER_TEST': 'true', 'FLUTTER_WEB': 'true'},
     );
 
     // This class doesn't use the result of the future. It's made available
     // via a getter for external uses.
-    unawaited(_process!.exitCode.then((int code) {
-      _debugPrint('Process exited ($code)');
-      _hasExited = true;
-    }));
+    unawaited(
+      _process!.exitCode.then((int code) {
+        _debugPrint('Process exited ($code)');
+        // The timing of this signal is important to the implementation of the
+        // "quit" method, so only change how this is implemented by careful
+        // testing of tests that use FlutterTestDriver.
+        _hasExited = true;
+      }),
+    );
     transformToLines(_process!.stdout).listen(_stdout.add);
     transformToLines(_process!.stderr).listen(_stderr.add);
 
@@ -138,7 +140,7 @@ abstract class FlutterTestDriver {
 
   Future<void> get done async => _process?.exitCode;
 
-  Future<void> connectToVmService({ bool pauseOnExceptions = false }) async {
+  Future<void> connectToVmService({bool pauseOnExceptions = false}) async {
     _vmService = await vmServiceConnectUri('$_vmServiceWsUri');
     _vmService!.onSend.listen((String s) => _debugPrint(s, topic: '=vm=>'));
     _vmService!.onReceive.listen((String s) => _debugPrint(s, topic: '<=vm='));
@@ -179,15 +181,27 @@ abstract class FlutterTestDriver {
     final int? port = _vmServiceWsUri != null ? vmServicePort : _attachPort;
     final VmService vmService = await vmServiceConnectUri('ws://localhost:$port/ws');
     final Isolate isolate = await waitForExtension(vmService, extension);
-    return vmService.callServiceExtension(
-      extension,
-      isolateId: isolate.id,
-      args: args,
-    );
+    return vmService.callServiceExtension(extension, isolateId: isolate.id, args: args);
   }
 
-  Future<int> quit() => _killGracefully();
+  /// Quits the currently running process.
+  @nonVirtual
+  Future<void> quit() async {
+    final int result = await _killGracefully();
+    if (result != 0) {
+      _debugPrint('Expected process to terminate gracefully, got exit code $result.');
+    }
 
+    // The _hasExited signal could be on the microtask queue. Waiting for a
+    // Future(...) queues an event similar to Timer.run(Duration.zero), which
+    // guarantees the current queue has elapsed before moving on.
+    await Future<void>(() {});
+    if (!_hasExited) {
+      throw StateError('Process did not exit');
+    }
+  }
+
+  @nonVirtual
   Future<int> _killGracefully() async {
     if (_processPid == null) {
       return -1;
@@ -195,7 +209,8 @@ abstract class FlutterTestDriver {
     // If we try to kill the process while it's paused, we'll end up terminating
     // it forcefully and it won't terminate child processes, so we need to ensure
     // it's running before terminating.
-    await resume().timeout(defaultTimeout)
+    await resume()
+        .timeout(defaultTimeout)
         .then(
           (Isolate? isolate) => isolate,
           onError: (Object e) {
@@ -256,17 +271,20 @@ abstract class FlutterTestDriver {
     );
   }
 
-  Future<Event> subscribeToPauseEvent(String isolateId) => subscribeToDebugEvent('Pause', isolateId);
-  Future<Event> subscribeToResumeEvent(String isolateId) => subscribeToDebugEvent('Resume', isolateId);
+  Future<Event> subscribeToPauseEvent(String isolateId) =>
+      subscribeToDebugEvent('Pause', isolateId);
+  Future<Event> subscribeToResumeEvent(String isolateId) =>
+      subscribeToDebugEvent('Resume', isolateId);
 
   Future<Isolate> waitForPauseEvent(String isolateId, Future<Event> event) =>
       waitForDebugEvent('Pause', isolateId, event);
   Future<Isolate> waitForResumeEvent(String isolateId, Future<Event> event) =>
       waitForDebugEvent('Resume', isolateId, event);
 
-  Future<Isolate> waitForPause() async => subscribeAndWaitForDebugEvent('Pause', await _getFlutterIsolateId());
-  Future<Isolate> waitForResume() async => subscribeAndWaitForDebugEvent('Resume', await _getFlutterIsolateId());
-
+  Future<Isolate> waitForPause() async =>
+      subscribeAndWaitForDebugEvent('Pause', await _getFlutterIsolateId());
+  Future<Isolate> waitForResume() async =>
+      subscribeAndWaitForDebugEvent('Resume', await _getFlutterIsolateId());
 
   Future<Isolate> subscribeAndWaitForDebugEvent(String kind, String isolateId) {
     final Future<Event> event = subscribeToDebugEvent(kind, isolateId);
@@ -288,50 +306,49 @@ abstract class FlutterTestDriver {
   Future<Event> subscribeToDebugEvent(String kind, String isolateId) {
     _debugPrint('Start listening for $kind events');
 
-    return _vmService!.onDebugEvent
-      .where((Event event) {
-        return event.isolate?.id == isolateId
-            && (event.kind?.startsWith(kind) ?? false);
-      }).first;
+    return _vmService!.onDebugEvent.where((Event event) {
+      return event.isolate?.id == isolateId && (event.kind?.startsWith(kind) ?? false);
+    }).first;
   }
 
   /// Wait for the [event] if needed.
   ///
   /// Return immediately if the isolate is already in the desired state.
   Future<Isolate> waitForDebugEvent(String kind, String isolateId, Future<Event> event) {
-    return _timeoutWithMessages<Isolate>(
-      () async {
-        // But also check if the isolate was already at the state we need (only after we've
-        // set up the subscription) to avoid races. If it already in the desired state, we
-        // don't need to wait for the event.
-        final VmService vmService = _vmService!;
-        final Isolate isolate = await vmService.getIsolate(isolateId);
-        if (isolate.pauseEvent?.kind?.startsWith(kind) ?? false) {
-          _debugPrint('Isolate was already at "$kind" (${isolate.pauseEvent!.kind}).');
-          event.ignore();
-        } else {
-          _debugPrint('Waiting for "$kind" event to arrive...');
-          await event;
-        }
+    return _timeoutWithMessages<Isolate>(() async {
+      // But also check if the isolate was already at the state we need (only after we've
+      // set up the subscription) to avoid races. If it already in the desired state, we
+      // don't need to wait for the event.
+      final VmService vmService = _vmService!;
+      final Isolate isolate = await vmService.getIsolate(isolateId);
+      if (isolate.pauseEvent?.kind?.startsWith(kind) ?? false) {
+        _debugPrint('Isolate was already at "$kind" (${isolate.pauseEvent!.kind}).');
+        event.ignore();
+      } else {
+        _debugPrint('Waiting for "$kind" event to arrive...');
+        await event;
+      }
 
-        return vmService.getIsolate(isolateId);
-      },
-      task: 'Waiting for isolate to $kind',
-    );
+      return vmService.getIsolate(isolateId);
+    }, task: 'Waiting for isolate to $kind');
   }
 
-  Future<Isolate?> resume({ bool waitForNextPause = false }) => _resume(null, waitForNextPause);
-  Future<Isolate?> stepOver({ bool waitForNextPause = true }) => _resume(StepOption.kOver, waitForNextPause);
-  Future<Isolate?> stepOverAsync({ bool waitForNextPause = true }) => _resume(StepOption.kOverAsyncSuspension, waitForNextPause);
-  Future<Isolate?> stepInto({ bool waitForNextPause = true }) => _resume(StepOption.kInto, waitForNextPause);
-  Future<Isolate?> stepOut({ bool waitForNextPause = true }) => _resume(StepOption.kOut, waitForNextPause);
+  Future<Isolate?> resume({bool waitForNextPause = false}) => _resume(null, waitForNextPause);
+  Future<Isolate?> stepOver({bool waitForNextPause = true}) =>
+      _resume(StepOption.kOver, waitForNextPause);
+  Future<Isolate?> stepOverAsync({bool waitForNextPause = true}) =>
+      _resume(StepOption.kOverAsyncSuspension, waitForNextPause);
+  Future<Isolate?> stepInto({bool waitForNextPause = true}) =>
+      _resume(StepOption.kInto, waitForNextPause);
+  Future<Isolate?> stepOut({bool waitForNextPause = true}) =>
+      _resume(StepOption.kOut, waitForNextPause);
 
   Future<bool> isAtAsyncSuspension() async {
     final Isolate isolate = await getFlutterIsolate();
     return isolate.pauseEvent?.atAsyncSuspension ?? false;
   }
 
-  Future<Isolate?> stepOverOrOverAsyncSuspension({ bool waitForNextPause = true }) async {
+  Future<Isolate?> stepOverOrOverAsyncSuspension({bool waitForNextPause = true}) async {
     if (await isAtAsyncSuspension()) {
       return stepOverAsync(waitForNextPause: waitForNextPause);
     }
@@ -354,14 +371,16 @@ abstract class FlutterTestDriver {
 
   Future<ObjRef> evaluateInFrame(String expression) async {
     return _timeoutWithMessages<ObjRef>(
-      () async => await _vmService!.evaluateInFrame(await _getFlutterIsolateId(), 0, expression) as ObjRef,
+      () async =>
+          await _vmService!.evaluateInFrame(await _getFlutterIsolateId(), 0, expression) as ObjRef,
       task: 'Evaluating expression ($expression)',
     );
   }
 
   Future<ObjRef> evaluate(String targetId, String expression) async {
     return _timeoutWithMessages<ObjRef>(
-      () async => await _vmService!.evaluate(await _getFlutterIsolateId(), targetId, expression) as ObjRef,
+      () async =>
+          await _vmService!.evaluate(await _getFlutterIsolateId(), targetId, expression) as ObjRef,
       task: 'Evaluating expression ($expression for $targetId)',
     );
   }
@@ -379,7 +398,8 @@ abstract class FlutterTestDriver {
   Future<SourcePosition?> getSourceLocation() async {
     final String flutterIsolateId = await _getFlutterIsolateId();
     final Frame frame = await getTopStackFrame();
-    final Script script = await _vmService!.getObject(flutterIsolateId, frame.location!.script!.id!) as Script;
+    final Script script =
+        await _vmService!.getObject(flutterIsolateId, frame.location!.script!.id!) as Script;
     return _lookupTokenPos(script.tokenPosTable!, frame.location!.tokenPos!);
   }
 
@@ -415,24 +435,22 @@ abstract class FlutterTestDriver {
       if (json == null) {
         return;
       }
-      if ((event != null && json['event'] == event) ||
-          (id != null && json['id'] == id)) {
+      if ((event != null && json['event'] == event) || (id != null && json['id'] == id)) {
         await subscription?.cancel();
         _debugPrint('OK ($interestingOccurrence)');
         response.complete(json);
       } else if (!ignoreAppStopEvent && json['event'] == 'app.stop') {
         await subscription?.cancel();
         final StringBuffer error = StringBuffer();
-        error.write('Received app.stop event while waiting for $interestingOccurrence\n\n$_errorBuffer');
+        error.write(
+          'Received app.stop event while waiting for $interestingOccurrence\n\n$_errorBuffer',
+        );
         final Object? jsonParams = json['params'];
-        if (jsonParams is Map<String, Object?>) {
-          if (jsonParams['error'] != null) {
-            error.write('${jsonParams['error']}\n\n');
-          }
-          final Object? trace = jsonParams['trace'];
-          if (trace != null) {
-            error.write('$trace\n\n');
-          }
+        if (jsonParams case {'error': final Object errorObject}) {
+          error.write('$errorObject\n\n');
+        }
+        if (jsonParams case {'trace': final Object trace}) {
+          error.write('$trace\n\n');
         }
         response.completeError(Exception(error.toString()));
       }
@@ -450,10 +468,12 @@ abstract class FlutterTestDriver {
     required String task,
     Duration timeout = defaultTimeout,
   }) {
-
     if (_printDebugOutputToStdOut) {
       _debugPrint('$task...');
-      final Timer longWarning = Timer(timeout, () => _debugPrint('$task is taking longer than usual...'));
+      final Timer longWarning = Timer(
+        timeout,
+        () => _debugPrint('$task is taking longer than usual...'),
+      );
       return callback().whenComplete(longWarning.cancel);
     }
 
@@ -468,6 +488,7 @@ abstract class FlutterTestDriver {
       final String formattedLine = '[+ ${ms.toString().padLeft(5)}] $logLine';
       messages.writeln(formattedLine);
     }
+
     final StreamSubscription<String> subscription = _allMessages.stream.listen(logMessage);
 
     final Timer longWarning = Timer(timeout, () {
@@ -477,25 +498,23 @@ abstract class FlutterTestDriver {
     });
     final Future<T> future = callback().whenComplete(longWarning.cancel);
 
-    return future.then(
-      (T t) => t,
-      onError: (Object error) {
-        if (!timeoutExpired) {
-          timeoutExpired = true;
-          _debugPrint(messages.toString());
-        }
-        throw error; // ignore: only_throw_errors
-      },
-    ).whenComplete(() => subscription.cancel());
+    return future
+        .then(
+          (T t) => t,
+          onError: (Object error) {
+            if (!timeoutExpired) {
+              timeoutExpired = true;
+              _debugPrint(messages.toString());
+            }
+            throw error; // ignore: only_throw_errors
+          },
+        )
+        .whenComplete(() => subscription.cancel());
   }
 }
 
-class FlutterRunTestDriver extends FlutterTestDriver {
-  FlutterRunTestDriver(
-    super.projectFolder, {
-    super.logPrefix,
-    this.spawnDdsInstance = true,
-  });
+final class FlutterRunTestDriver extends FlutterTestDriver {
+  FlutterRunTestDriver(super.projectFolder, {super.logPrefix, this.spawnDdsInstance = true});
 
   String? _currentRunningAppId;
   String? _currentRunningDeviceId;
@@ -511,38 +530,36 @@ class FlutterRunTestDriver extends FlutterTestDriver {
     bool chrome = false,
     bool expressionEvaluation = true,
     bool structuredErrors = false,
-    bool singleWidgetReloads = false,
     bool serveObservatory = false,
+    bool noDevtools = false,
+    bool verbose = false,
     String? script,
     List<String>? additionalCommandArgs,
   }) async {
     await _setupProcess(
       <String>[
         'run',
-        if (!chrome)
-          '--disable-service-auth-codes',
+        if (!chrome) '--disable-service-auth-codes',
         '--machine',
         if (!spawnDdsInstance) '--no-dds',
+        if (noDevtools) '--no-devtools',
         '--${serveObservatory ? '' : 'no-'}serve-observatory',
         ...getLocalEngineArguments(),
         '-d',
-        if (chrome)
-          ...<String>[
-            'chrome',
-            '--web-run-headless',
-            if (!expressionEvaluation) '--no-web-enable-expression-evaluation',
-          ]
-        else
+        if (chrome) ...<String>[
+          'chrome',
+          '--web-run-headless',
+          if (!expressionEvaluation) '--no-web-enable-expression-evaluation',
+        ] else
           'flutter-tester',
-        if (structuredErrors)
-          '--dart-define=flutter.inspector.structuredErrors=true',
+        if (structuredErrors) '--dart-define=flutter.inspector.structuredErrors=true',
         ...?additionalCommandArgs,
       ],
       withDebugger: withDebugger,
       startPaused: startPaused,
       pauseOnExceptions: pauseOnExceptions,
       script: script,
-      singleWidgetReloads: singleWidgetReloads,
+      verbose: verbose,
     );
   }
 
@@ -551,7 +568,6 @@ class FlutterRunTestDriver extends FlutterTestDriver {
     bool withDebugger = false,
     bool startPaused = false,
     bool pauseOnExceptions = false,
-    bool singleWidgetReloads = false,
     bool serveObservatory = false,
     List<String>? additionalCommandArgs,
   }) async {
@@ -561,8 +577,7 @@ class FlutterRunTestDriver extends FlutterTestDriver {
         'attach',
         ...getLocalEngineArguments(),
         '--machine',
-        if (!spawnDdsInstance)
-          '--no-dds',
+        if (!spawnDdsInstance) '--no-dds',
         '--${serveObservatory ? '' : 'no-'}serve-observatory',
         '-d',
         'flutter-tester',
@@ -573,7 +588,6 @@ class FlutterRunTestDriver extends FlutterTestDriver {
       withDebugger: withDebugger,
       startPaused: startPaused,
       pauseOnExceptions: pauseOnExceptions,
-      singleWidgetReloads: singleWidgetReloads,
       attachPort: port,
     );
   }
@@ -585,16 +599,11 @@ class FlutterRunTestDriver extends FlutterTestDriver {
     bool withDebugger = false,
     bool startPaused = false,
     bool pauseOnExceptions = false,
-    bool singleWidgetReloads = false,
+    bool verbose = false,
     int? attachPort,
   }) async {
     assert(!startPaused || withDebugger);
-    await super._setupProcess(
-      args,
-      script: script,
-      withDebugger: withDebugger,
-      singleWidgetReloads: singleWidgetReloads,
-    );
+    await super._setupProcess(args, script: script, withDebugger: withDebugger, verbose: verbose);
 
     final Completer<void> prematureExitGuard = Completer<void>();
 
@@ -602,11 +611,15 @@ class FlutterRunTestDriver extends FlutterTestDriver {
     // exited prematurely. This causes the currently suspended `await` to
     // deadlock until the test times out. Instead, this causes the test to fail
     // fast.
-    unawaited(_process?.exitCode.then((_) {
-      if (!prematureExitGuard.isCompleted) {
-        prematureExitGuard.completeError(Exception('Process exited prematurely: ${args.join(' ')}: $_errorBuffer'));
-      }
-    }));
+    unawaited(
+      _process?.exitCode.then((_) {
+        if (!prematureExitGuard.isCompleted) {
+          prematureExitGuard.completeError(
+            Exception('Process exited prematurely: ${args.join(' ')}: $_errorBuffer'),
+          );
+        }
+      }),
+    );
 
     unawaited(() async {
       try {
@@ -618,12 +631,22 @@ class FlutterRunTestDriver extends FlutterTestDriver {
 
         // Set this up now, but we don't wait it yet. We want to make sure we don't
         // miss it while waiting for debugPort below.
-        final Future<Map<String, Object?>> start = _waitFor(event: 'app.start', timeout: appStartTimeout);
-        final Future<Map<String, Object?>> started = _waitFor(event: 'app.started', timeout: appStartTimeout);
+        final Future<Map<String, Object?>> start = _waitFor(
+          event: 'app.start',
+          timeout: appStartTimeout,
+        );
+        final Future<Map<String, Object?>> started = _waitFor(
+          event: 'app.started',
+          timeout: appStartTimeout,
+        );
 
         if (withDebugger) {
-          final Map<String, Object?> debugPort = await _waitFor(event: 'app.debugPort', timeout: appStartTimeout);
-          final String wsUriString = (debugPort['params']! as Map<String, Object?>)['wsUri']! as String;
+          final Map<String, Object?> debugPort = await _waitFor(
+            event: 'app.debugPort',
+            timeout: appStartTimeout,
+          );
+          final String wsUriString =
+              (debugPort['params']! as Map<String, Object?>)['wsUri']! as String;
           _vmServiceWsUri = Uri.parse(wsUriString);
           await connectToVmService(pauseOnExceptions: pauseOnExceptions);
           if (!startPaused) {
@@ -641,7 +664,8 @@ class FlutterRunTestDriver extends FlutterTestDriver {
         // Now await the start/started events; if it had already happened the future will
         // have already completed.
         final Map<String, Object?>? startParams = (await start)['params'] as Map<String, Object?>?;
-        final Map<String, Object?>? startedParams = (await started)['params'] as Map<String, Object?>?;
+        final Map<String, Object?>? startedParams =
+            (await started)['params'] as Map<String, Object?>?;
         _currentRunningAppId = startedParams?['appId'] as String?;
         _currentRunningDeviceId = startParams?['deviceId'] as String?;
         _currentRunningMode = startParams?['mode'] as String?;
@@ -654,30 +678,43 @@ class FlutterRunTestDriver extends FlutterTestDriver {
     return prematureExitGuard.future;
   }
 
-  Future<void> hotRestart({ bool pause = false, bool debounce = false}) => _restart(fullRestart: true, pause: pause);
-  Future<void> hotReload({ bool debounce = false, int? debounceDurationOverrideMs }) =>
+  Future<void> hotRestart({bool pause = false, bool debounce = false}) =>
+      _restart(fullRestart: true, pause: pause);
+  Future<void> hotReload({bool debounce = false, int? debounceDurationOverrideMs}) =>
       _restart(debounce: debounce, debounceDurationOverrideMs: debounceDurationOverrideMs);
 
   Future<void> scheduleFrame() async {
     if (_currentRunningAppId == null) {
       throw Exception('App has not started yet');
     }
-    await _sendRequest(
-      'app.callServiceExtension',
-      <String, Object?>{'appId': _currentRunningAppId, 'methodName': 'ext.ui.window.scheduleFrame'},
-    );
+    await _sendRequest('app.callServiceExtension', <String, Object?>{
+      'appId': _currentRunningAppId,
+      'methodName': 'ext.ui.window.scheduleFrame',
+    });
   }
 
-  Future<void> _restart({ bool fullRestart = false, bool pause = false, bool debounce = false, int? debounceDurationOverrideMs }) async {
+  Future<void> _restart({
+    bool fullRestart = false,
+    bool pause = false,
+    bool debounce = false,
+    int? debounceDurationOverrideMs,
+  }) async {
     if (_currentRunningAppId == null) {
       throw Exception('App has not started yet');
     }
 
-    _debugPrint('Performing ${ pause ? "paused " : "" }${ fullRestart ? "hot restart" : "hot reload" }...');
-    final Map<String, Object?>? hotReloadResponse = await _sendRequest(
-      'app.restart',
-      <String, Object?>{'appId': _currentRunningAppId, 'fullRestart': fullRestart, 'pause': pause, 'debounce': debounce, 'debounceDurationOverrideMs': debounceDurationOverrideMs},
-    ) as Map<String, Object?>?;
+    _debugPrint(
+      'Performing ${pause ? "paused " : ""}${fullRestart ? "hot restart" : "hot reload"}...',
+    );
+    final Map<String, Object?>? hotReloadResponse =
+        await _sendRequest('app.restart', <String, Object?>{
+              'appId': _currentRunningAppId,
+              'fullRestart': fullRestart,
+              'pause': pause,
+              'debounce': debounce,
+              'debounceDurationOverrideMs': debounceDurationOverrideMs,
+            })
+            as Map<String, Object?>?;
     _debugPrint('${fullRestart ? "Hot restart" : "Hot reload"} complete.');
 
     if (hotReloadResponse == null || hotReloadResponse['code'] != 0) {
@@ -699,13 +736,12 @@ class FlutterRunTestDriver extends FlutterTestDriver {
       _debugPrint('Detaching from app...');
       await Future.any<void>(<Future<void>>[
         process.exitCode,
-        _sendRequest(
-          'app.detach',
-          <String, Object?>{'appId': _currentRunningAppId},
-        ),
+        _sendRequest('app.detach', <String, Object?>{'appId': _currentRunningAppId}),
       ]).timeout(
         quitTimeout,
-        onTimeout: () { _debugPrint('app.detach did not return within $quitTimeout'); },
+        onTimeout: () {
+          _debugPrint('app.detach did not return within $quitTimeout');
+        },
       );
       _currentRunningAppId = null;
     }
@@ -724,13 +760,12 @@ class FlutterRunTestDriver extends FlutterTestDriver {
       _debugPrint('Stopping application...');
       await Future.any<void>(<Future<void>>[
         process!.exitCode,
-        _sendRequest(
-          'app.stop',
-          <String, Object?>{'appId': _currentRunningAppId},
-        ),
+        _sendRequest('app.stop', <String, Object?>{'appId': _currentRunningAppId}),
       ]).timeout(
         quitTimeout,
-        onTimeout: () { _debugPrint('app.stop did not return within $quitTimeout'); },
+        onTimeout: () {
+          _debugPrint('app.stop did not return within $quitTimeout');
+        },
       );
       _currentRunningAppId = null;
     }
@@ -776,7 +811,7 @@ class FlutterRunTestDriver extends FlutterTestDriver {
   final bool spawnDdsInstance;
 }
 
-class FlutterTestTestDriver extends FlutterTestDriver {
+final class FlutterTestTestDriver extends FlutterTestDriver {
   FlutterTestTestDriver(super.projectFolder, {super.logPrefix});
 
   Future<void> test({
@@ -787,16 +822,20 @@ class FlutterTestTestDriver extends FlutterTestDriver {
     bool coverage = false,
     Future<void> Function()? beforeStart,
   }) async {
-    await _setupProcess(<String>[
-      'test',
-      ...getLocalEngineArguments(),
-      '--disable-service-auth-codes',
-      '--machine',
-      if (coverage)
-        '--coverage',
-      if (deviceId != null)
-        ...<String>['-d', deviceId],
-    ], script: testFile, withDebugger: withDebugger, pauseOnExceptions: pauseOnExceptions, beforeStart: beforeStart);
+    await _setupProcess(
+      <String>[
+        'test',
+        ...getLocalEngineArguments(),
+        '--disable-service-auth-codes',
+        '--machine',
+        if (coverage) '--coverage',
+        if (deviceId != null) ...<String>['-d', deviceId],
+      ],
+      script: testFile,
+      withDebugger: withDebugger,
+      pauseOnExceptions: pauseOnExceptions,
+      beforeStart: beforeStart,
+    );
   }
 
   @override
@@ -805,15 +844,10 @@ class FlutterTestTestDriver extends FlutterTestDriver {
     String? script,
     bool withDebugger = false,
     bool pauseOnExceptions = false,
+    bool verbose = false,
     Future<void> Function()? beforeStart,
-    bool singleWidgetReloads = false,
   }) async {
-    await super._setupProcess(
-      args,
-      script: script,
-      withDebugger: withDebugger,
-      singleWidgetReloads: singleWidgetReloads,
-    );
+    await super._setupProcess(args, script: script, withDebugger: withDebugger, verbose: verbose);
 
     // Stash the PID so that we can terminate the VM more reliably than using
     // _proc.kill() (because _proc is a shell, because `flutter` is a shell
@@ -823,7 +857,8 @@ class FlutterTestTestDriver extends FlutterTestDriver {
 
     if (withDebugger) {
       final Map<String, Object?> startedProcessParams =
-          (await _waitFor(event: 'test.startedProcess', timeout: appStartTimeout))['params']! as Map<String, Object?>;
+          (await _waitFor(event: 'test.startedProcess', timeout: appStartTimeout))['params']!
+              as Map<String, Object?>;
       final String vmServiceHttpString = startedProcessParams['vmServiceUri']! as String;
       _vmServiceWsUri = Uri.parse(vmServiceHttpString).replace(scheme: 'ws', path: '/ws');
       await connectToVmService(pauseOnExceptions: pauseOnExceptions);
@@ -835,11 +870,10 @@ class FlutterTestTestDriver extends FlutterTestDriver {
     }
   }
 
-  Future<Map<String, Object?>?> _waitForJson({
-    Duration timeout = defaultTimeout,
-  }) async {
+  Future<Map<String, Object?>?> _waitForJson({Duration timeout = defaultTimeout}) async {
     return _timeoutWithMessages<Map<String, Object?>?>(
-      () => _stdout.stream.map<Map<String, Object?>?>(_parseJsonResponse)
+      () => _stdout.stream
+          .map<Map<String, Object?>?>(_parseJsonResponse)
           .firstWhere((Map<String, Object?>? output) => output != null),
       timeout: timeout,
       task: 'Waiting for JSON',
@@ -859,18 +893,16 @@ class FlutterTestTestDriver extends FlutterTestDriver {
     final Completer<bool> done = Completer<bool>();
     // Waiting for `{"success":true,"type":"done",...}` line indicating
     // end of test run.
-    final StreamSubscription<String> subscription = _stdout.stream.listen(
-        (String line) async {
-          final Map<String, Object?>? json = _parseJsonResponse(line);
-          if (json != null && json['type'] != null && json['success'] != null) {
-            done.complete(json['type'] == 'done' && json['success'] == true);
-          }
-        });
+    final StreamSubscription<String> subscription = _stdout.stream.listen((String line) async {
+      final Map<String, Object?>? json = _parseJsonResponse(line);
+      if (json != null && json['type'] != null && json['success'] != null) {
+        done.complete(json['type'] == 'done' && json['success'] == true);
+      }
+    });
 
     await resume();
 
-    final Future<void> timeoutFuture =
-        Future<void>.delayed(defaultTimeout);
+    final Future<void> timeoutFuture = Future<void>.delayed(defaultTimeout);
     await Future.any<void>(<Future<void>>[done.future, timeoutFuture]);
     await subscription.cancel();
     if (!done.isCompleted) {
@@ -886,7 +918,9 @@ Stream<String> transformToLines(Stream<List<int>> byteStream) {
 Map<String, Object?>? parseFlutterResponse(String line) {
   if (line.startsWith('[') && line.endsWith(']') && line.length > 2) {
     try {
-      final Map<String, Object?>? response = castStringKeyedMap((json.decode(line) as List<Object?>)[0]);
+      final Map<String, Object?>? response = castStringKeyedMap(
+        (json.decode(line) as List<Object?>)[0],
+      );
       return response;
     } on FormatException {
       // Not valid JSON, so likely some other output that was surrounded by [brackets]
