@@ -18,6 +18,7 @@ import 'package:flutter_tools/src/base/template.dart';
 import 'package:flutter_tools/src/base/terminal.dart';
 import 'package:flutter_tools/src/base/time.dart';
 import 'package:flutter_tools/src/base/version.dart';
+import 'package:flutter_tools/src/build_system/build_targets.dart';
 import 'package:flutter_tools/src/cache.dart';
 import 'package:flutter_tools/src/context_runner.dart';
 import 'package:flutter_tools/src/dart/pub.dart';
@@ -28,6 +29,7 @@ import 'package:flutter_tools/src/globals.dart' as globals;
 import 'package:flutter_tools/src/ios/plist_parser.dart';
 import 'package:flutter_tools/src/ios/simulators.dart';
 import 'package:flutter_tools/src/ios/xcodeproj.dart';
+import 'package:flutter_tools/src/isolated/build_targets.dart';
 import 'package:flutter_tools/src/isolated/mustache_template.dart';
 import 'package:flutter_tools/src/persistent_tool_state.dart';
 import 'package:flutter_tools/src/project.dart';
@@ -60,13 +62,14 @@ void testUsingContext(
   Map<Type, Generator> overrides = const <Type, Generator>{},
   bool initializeFlutterRoot = true,
   String? testOn,
-  bool? skip, // should default to `false`, but https://github.com/dart-lang/test/issues/545 doesn't allow this
+  bool?
+  skip, // should default to `false`, but https://github.com/dart-lang/test/issues/545 doesn't allow this
 }) {
   if (overrides[FileSystem] != null && overrides[ProcessManager] == null) {
     throw StateError(
       'If you override the FileSystem context you must also provide a ProcessManager, '
       'otherwise the processes you launch will not be dealing with the same file system '
-      'that you are dealing with in your test.'
+      'that you are dealing with in your test.',
     );
   }
   if (overrides.containsKey(ProcessUtils)) {
@@ -84,88 +87,110 @@ void testUsingContext(
   });
   Config buildConfig(FileSystem fs) {
     configDir ??= globals.fs.systemTempDirectory.createTempSync('flutter_config_dir_test.');
-    return Config.test(
-      name: Config.kFlutterSettings,
-      directory: configDir,
-      logger: globals.logger,
-    );
-  }
-  PersistentToolState buildPersistentToolState(FileSystem fs) {
-    configDir ??= globals.fs.systemTempDirectory.createTempSync('flutter_config_dir_test.');
-    return PersistentToolState.test(
-      directory: configDir!,
-      logger: globals.logger,
-    );
+    return Config.test(name: Config.kFlutterSettings, directory: configDir, logger: globals.logger);
   }
 
-  test(description, () async {
-    await runInContext<dynamic>(() {
-      return context.run<dynamic>(
-        name: 'mocks',
-        overrides: <Type, Generator>{
-          AnsiTerminal: () => AnsiTerminal(platform: globals.platform, stdio: globals.stdio),
-          Config: () => buildConfig(globals.fs),
-          DeviceManager: () => FakeDeviceManager(),
-          Doctor: () => FakeDoctor(globals.logger),
-          FlutterVersion: () => FakeFlutterVersion(),
-          HttpClient: () => FakeHttpClient.any(),
-          IOSSimulatorUtils: () => const NoopIOSSimulatorUtils(),
-          OutputPreferences: () => OutputPreferences.test(),
-          Logger: () => BufferLogger.test(),
-          OperatingSystemUtils: () => FakeOperatingSystemUtils(),
-          PersistentToolState: () => buildPersistentToolState(globals.fs),
-          Usage: () => TestUsage(),
-          XcodeProjectInterpreter: () => FakeXcodeProjectInterpreter(),
-          FileSystem: () => LocalFileSystemBlockingSetCurrentDirectory(),
-          PlistParser: () => FakePlistParser(),
-          Signals: () => FakeSignals(),
-          Pub: () => ThrowingPub(), // prevent accidentally using pub.
-          CrashReporter: () => const NoopCrashReporter(),
-          TemplateRenderer: () => const MustacheTemplateRenderer(),
-          Analytics: () => NoOpAnalytics(),
-        },
-        body: () {
-          return runZonedGuarded<Future<dynamic>>(() {
-            try {
-              return context.run<dynamic>(
-                // Apply the overrides to the test context in the zone since their
-                // instantiation may reference items already stored on the context.
-                overrides: overrides,
-                name: 'test-specific overrides',
-                body: () async {
-                  if (initializeFlutterRoot) {
-                    // Provide a sane default for the flutterRoot directory. Individual
-                    // tests can override this either in the test or during setup.
-                    Cache.flutterRoot ??= getFlutterRoot();
+  PersistentToolState buildPersistentToolState(FileSystem fs) {
+    configDir ??= globals.fs.systemTempDirectory.createTempSync('flutter_config_dir_test.');
+    return PersistentToolState.test(directory: configDir!, logger: globals.logger);
+  }
+
+  test(
+    description,
+    () async {
+      await runInContext<dynamic>(
+        () {
+          return context.run<dynamic>(
+            name: 'mocks',
+            overrides: <Type, Generator>{
+              AnsiTerminal: () => AnsiTerminal(platform: globals.platform, stdio: globals.stdio),
+              Config: () => buildConfig(globals.fs),
+              DeviceManager: () => FakeDeviceManager(),
+              Doctor: () => FakeDoctor(globals.logger),
+              FlutterVersion: () => FakeFlutterVersion(),
+              HttpClient: () => FakeHttpClient.any(),
+              IOSSimulatorUtils: () => const NoopIOSSimulatorUtils(),
+              OutputPreferences: () => OutputPreferences.test(),
+              Logger: () => BufferLogger.test(),
+              OperatingSystemUtils: () => FakeOperatingSystemUtils(),
+              PersistentToolState: () => buildPersistentToolState(globals.fs),
+              Usage: () => TestUsage(),
+              XcodeProjectInterpreter: () => FakeXcodeProjectInterpreter(),
+              FileSystem: () => LocalFileSystemBlockingSetCurrentDirectory(),
+              PlistParser: () => FakePlistParser(),
+              Signals: () => FakeSignals(),
+              Pub: () => const ThrowingPub(), // prevent accidentally using pub.
+              CrashReporter: () => const NoopCrashReporter(),
+              TemplateRenderer: () => const MustacheTemplateRenderer(),
+              BuildTargets: () => const BuildTargetsImpl(),
+              Analytics: () => const NoOpAnalytics(),
+              Stdio: () => FakeStdio(),
+            },
+            body: () {
+              // To catch all errors thrown by the test, even uncaught async errors, we use a zone.
+              //
+              // Zones introduce their own event loop, so we do not await futures created inside
+              // the zone from outside the zone. Instead, we create a Completer outside the zone,
+              // and have the test complete it when the test ends (in success or failure), and we
+              // await that.
+              final Completer<void> completer = Completer<void>();
+              runZonedGuarded<Future<dynamic>>(
+                () async {
+                  try {
+                    return await context.run<dynamic>(
+                      // Apply the overrides to the test context in the zone since their
+                      // instantiation may reference items already stored on the context.
+                      overrides: overrides,
+                      name: 'test-specific overrides',
+                      body: () async {
+                        if (initializeFlutterRoot) {
+                          // Provide a sane default for the flutterRoot directory. Individual
+                          // tests can override this either in the test or during setup.
+                          Cache.flutterRoot ??= getFlutterRoot();
+                        }
+                        return await testMethod();
+                      },
+                    );
+                  } finally {
+                    // We do not need a catch { ... } block because the error zone
+                    // will catch all errors and send them to the completer below.
+                    //
+                    // See https://github.com/flutter/flutter/pull/141821/files#r1462288131.
+                    if (!completer.isCompleted) {
+                      completer.complete();
+                    }
                   }
-                  return await testMethod();
+                },
+                (Object error, StackTrace stackTrace) {
+                  // When things fail, it's ok to print to the console!
+                  print(error); // ignore: avoid_print
+                  print(stackTrace); // ignore: avoid_print
+                  _printBufferedErrors(context);
+                  if (!completer.isCompleted) {
+                    completer.completeError(error, stackTrace);
+                  }
+                  throw error; //ignore: only_throw_errors
                 },
               );
-            // This catch rethrows, so doesn't need to catch only Exception.
-            } catch (error) { // ignore: avoid_catches_without_on_clauses
-              _printBufferedErrors(context);
-              rethrow;
-            }
-          }, (Object error, StackTrace stackTrace) {
-            // When things fail, it's ok to print to the console!
-            print(error); // ignore: avoid_print
-            print(stackTrace); // ignore: avoid_print
-            _printBufferedErrors(context);
-            throw error; //ignore: only_throw_errors
-          });
+              return completer.future;
+            },
+          );
+        },
+        overrides: <Type, Generator>{
+          // This has to go here so that runInContext will pick it up when it tries
+          // to do bot detection before running the closure. This is important
+          // because the test may be giving us a fake HttpClientFactory, which may
+          // throw in unexpected/abnormal ways.
+          // If a test needs a BotDetector that does not always return true, it
+          // can provide the AlwaysFalseBotDetector in the overrides, or its own
+          // BotDetector implementation in the overrides.
+          BotDetector: overrides[BotDetector] ?? () => const FakeBotDetector(true),
         },
       );
-    }, overrides: <Type, Generator>{
-      // This has to go here so that runInContext will pick it up when it tries
-      // to do bot detection before running the closure. This is important
-      // because the test may be giving us a fake HttpClientFactory, which may
-      // throw in unexpected/abnormal ways.
-      // If a test needs a BotDetector that does not always return true, it
-      // can provide the AlwaysFalseBotDetector in the overrides, or its own
-      // BotDetector implementation in the overrides.
-      BotDetector: overrides[BotDetector] ?? () => const FakeBotDetector(true),
-    });
-  }, testOn: testOn, skip: skip);
+    },
+    testOn: testOn,
+    skip: skip,
+  );
   // We don't support "timeout"; see ../../dart_test.yaml which
   // configures all tests to have a 15 minute timeout which should
   // definitely be enough.
@@ -211,9 +236,8 @@ class FakeDeviceManager implements DeviceManager {
   }
 
   @override
-  Future<List<Device>> getAllDevices({
-    DeviceDiscoveryFilter? filter,
-  }) async => filteredDevices(filter);
+  Future<List<Device>> getAllDevices({DeviceDiscoveryFilter? filter}) async =>
+      filteredDevices(filter);
 
   @override
   Future<List<Device>> refreshAllDevices({
@@ -272,13 +296,11 @@ class FakeDeviceManager implements DeviceManager {
   Device? getSingleEphemeralDevice(List<Device> devices) => null;
 
   List<Device> filteredDevices(DeviceDiscoveryFilter? filter) {
-    if (filter?.deviceConnectionInterface == DeviceConnectionInterface.attached) {
-      return attachedDevices;
-    }
-    if (filter?.deviceConnectionInterface == DeviceConnectionInterface.wireless) {
-      return wirelessDevices;
-    }
-    return attachedDevices + wirelessDevices;
+    return switch (filter?.deviceConnectionInterface) {
+      DeviceConnectionInterface.attached => attachedDevices,
+      DeviceConnectionInterface.wireless => wirelessDevices,
+      null => attachedDevices + wirelessDevices,
+    };
   }
 }
 
@@ -292,8 +314,7 @@ class FakeAndroidLicenseValidator extends Fake implements AndroidLicenseValidato
 }
 
 class FakeDoctor extends Doctor {
-  FakeDoctor(Logger logger, {super.clock = const SystemClock()})
-      : super(logger: logger);
+  FakeDoctor(Logger logger, {super.clock = const SystemClock()}) : super(logger: logger);
 
   // True for testing.
   @override
@@ -352,23 +373,20 @@ class FakeXcodeProjectInterpreter implements XcodeProjectInterpreter {
 
   @override
   Future<String> pluginsBuildSettingsOutput(
-      Directory podXcodeProject, {
-        Duration timeout = const Duration(minutes: 1),
-      }) async {
+    Directory podXcodeProject, {
+    Duration timeout = const Duration(minutes: 1),
+  }) async {
     return '';
   }
 
   @override
-  Future<void> cleanWorkspace(String workspacePath, String scheme, { bool verbose = false }) async { }
+  Future<void> cleanWorkspace(String workspacePath, String scheme, {bool verbose = false}) async {}
 
   @override
   Future<XcodeProjectInfo> getInfo(String projectPath, {String? projectFilename}) async {
-    return XcodeProjectInfo(
-      <String>['Runner'],
-      <String>['Debug', 'Release'],
-      <String>['Runner'],
-      BufferLogger.test(),
-    );
+    return XcodeProjectInfo(<String>['Runner'], <String>['Debug', 'Release'], <String>[
+      'Runner',
+    ], BufferLogger.test());
   }
 
   @override
@@ -380,7 +398,7 @@ class NoopCrashReporter implements CrashReporter {
   const NoopCrashReporter();
 
   @override
-  Future<void> informUser(CrashDetails details, File crashFile) async { }
+  Future<void> informUser(CrashDetails details, File crashFile) async {}
 }
 
 class LocalFileSystemBlockingSetCurrentDirectory extends LocalFileSystem {
@@ -390,10 +408,12 @@ class LocalFileSystemBlockingSetCurrentDirectory extends LocalFileSystem {
 
   @override
   set currentDirectory(dynamic value) {
-    throw Exception('globals.fs.currentDirectory should not be set on the local file system during '
-          'tests as this can cause race conditions with concurrent tests. '
-          'Consider using a MemoryFileSystem for testing if possible or refactor '
-          'code to not require setting globals.fs.currentDirectory.');
+    throw Exception(
+      'globals.fs.currentDirectory should not be set on the local file system during '
+      'tests as this can cause race conditions with concurrent tests. '
+      'Consider using a MemoryFileSystem for testing if possible or refactor '
+      'code to not require setting globals.fs.currentDirectory.',
+    );
   }
 }
 
