@@ -6,15 +6,21 @@ import 'package:analyzer/dart/analysis/results.dart';
 import 'package:analyzer/dart/analysis/session.dart';
 import 'package:analyzer/dart/ast/ast.dart';
 import 'package:analyzer/dart/element/element.dart';
+import 'package:analyzer/file_system/file_system.dart';
+import 'package:analyzer/src/dart/element/element.dart';
+import 'package:analyzer/src/utilities/extensions/file_system.dart';
+import 'package:analyzer_utilities/testing/tree_string_sink.dart';
 import 'package:test/test.dart';
 import 'package:test_reflective_loader/test_reflective_loader.dart';
 
 import '../resolution/context_collection_resolution.dart';
+import '../resolution/node_text_expectations.dart';
 
 main() {
   defineReflectiveSuite(() {
     defineReflectiveTests(AnalysisSessionImplTest);
     defineReflectiveTests(AnalysisSessionImpl_BlazeWorkspaceTest);
+    defineReflectiveTests(UpdateNodeTextExpectations);
   });
 }
 
@@ -25,21 +31,21 @@ class AnalysisSessionImpl_BlazeWorkspaceTest
     var relPath = 'dart/my/lib/a.dart';
     newFile('$workspaceRootPath/blaze-bin/$relPath', '');
 
-    final file = getFile('$workspaceRootPath/$relPath');
+    var file = getFile('$workspaceRootPath/$relPath');
     var session = contextFor(file).currentSession;
     var result = await session.getErrors(file.path);
     expect(result, isA<NotPathOfUriResult>());
   }
 
   void test_getErrors_valid() async {
-    var file = newFile(
+    var a = newFile(
       '$workspaceRootPath/dart/my/lib/a.dart',
       'var x = 0',
     );
 
-    var session = contextFor(file).currentSession;
-    var result = await session.getErrorsValid(file.path);
-    expect(result.path, file.path);
+    var session = contextFor(a).currentSession;
+    var result = await session.getErrorsValid(a);
+    expect(result.path, a.path);
     expect(result.errors, hasLength(1));
     expect(result.uri.toString(), 'package:dart.my/a.dart');
   }
@@ -48,7 +54,7 @@ class AnalysisSessionImpl_BlazeWorkspaceTest
     var relPath = 'dart/my/lib/a.dart';
     newFile('$workspaceRootPath/blaze-bin/$relPath', '');
 
-    final file = getFile('$workspaceRootPath/$relPath');
+    var file = getFile('$workspaceRootPath/$relPath');
     var session = contextFor(file).currentSession;
     var result = session.getParsedLibrary(file.path);
     expect(result, isA<NotPathOfUriResult>());
@@ -58,7 +64,7 @@ class AnalysisSessionImpl_BlazeWorkspaceTest
     var relPath = 'dart/my/lib/a.dart';
     newFile('$workspaceRootPath/blaze-bin/$relPath', '');
 
-    final file = getFile('$workspaceRootPath/$relPath');
+    var file = getFile('$workspaceRootPath/$relPath');
     var session = contextFor(file).currentSession;
     var result = await session.getResolvedLibrary(file.path);
     expect(result, isA<NotPathOfUriResult>());
@@ -68,7 +74,7 @@ class AnalysisSessionImpl_BlazeWorkspaceTest
     var relPath = 'dart/my/lib/a.dart';
     newFile('$workspaceRootPath/blaze-bin/$relPath', '');
 
-    final file = getFile('$workspaceRootPath/$relPath');
+    var file = getFile('$workspaceRootPath/$relPath');
     var session = contextFor(file).currentSession;
     var result = await session.getResolvedUnit(file.path);
     expect(result, isA<NotPathOfUriResult>());
@@ -102,7 +108,7 @@ class AnalysisSessionImpl_BlazeWorkspaceTest
     var relPath = 'dart/my/lib/a.dart';
     newFile('$workspaceRootPath/blaze-bin/$relPath', '');
 
-    final file = getFile('$workspaceRootPath/$relPath');
+    var file = getFile('$workspaceRootPath/$relPath');
     var session = contextFor(file).currentSession;
     var result = await session.getUnitElement(file.path);
     expect(result, isA<NotPathOfUriResult>());
@@ -115,7 +121,7 @@ class AnalysisSessionImpl_BlazeWorkspaceTest
     );
 
     var session = contextFor(file).currentSession;
-    var result = await session.getUnitElementValid(file.path);
+    var result = await session.getUnitElementValid(file);
     expect(result.path, file.path);
     expect(result.element.classes, hasLength(1));
     expect(result.uri.toString(), 'package:dart.my/a.dart');
@@ -125,11 +131,11 @@ class AnalysisSessionImpl_BlazeWorkspaceTest
 @reflectiveTest
 class AnalysisSessionImplTest extends PubPackageResolutionTest {
   test_applyPendingFileChanges_getFile() async {
-    final a = newFile('$testPackageLibPath/a.dart', '');
-    final analysisContext = contextFor(a);
+    var a = newFile('$testPackageLibPath/a.dart', '');
+    var analysisContext = contextFor(a);
 
     int lineCount_in_a() {
-      final result = analysisContext.currentSession.getFileValid(a.path);
+      var result = analysisContext.currentSession.getFileValid(a);
       return result.lineInfo.lineCount;
     }
 
@@ -144,12 +150,12 @@ class AnalysisSessionImplTest extends PubPackageResolutionTest {
   }
 
   test_applyPendingFileChanges_getParsedLibrary() async {
-    final a = newFile('$testPackageLibPath/a.dart', '');
-    final analysisContext = contextFor(a);
+    var a = newFile('$testPackageLibPath/a.dart', '');
+    var analysisContext = contextFor(a);
 
     int lineCount_in_a() {
-      final analysisSession = analysisContext.currentSession;
-      final result = analysisSession.getParsedLibraryValid(a.path);
+      var analysisSession = analysisContext.currentSession;
+      var result = analysisSession.getParsedLibraryValid(a);
       return result.units.first.lineInfo.lineCount;
     }
 
@@ -164,11 +170,11 @@ class AnalysisSessionImplTest extends PubPackageResolutionTest {
   }
 
   test_applyPendingFileChanges_getParsedUnit() async {
-    final a = newFile('$testPackageLibPath/a.dart', '');
-    final analysisContext = contextFor(a);
+    var a = newFile('$testPackageLibPath/a.dart', '');
+    var analysisContext = contextFor(a);
 
     int lineCount_in_a() {
-      final result = analysisContext.currentSession.getParsedUnitValid(a.path);
+      var result = analysisContext.currentSession.getParsedUnitValid(a);
       return result.lineInfo.lineCount;
     }
 
@@ -183,12 +189,12 @@ class AnalysisSessionImplTest extends PubPackageResolutionTest {
   }
 
   test_getErrors() async {
-    var test = newFile(testFile.path, 'class C {');
+    newFile(testFile.path, 'class C {');
 
     var session = contextFor(testFile).currentSession;
-    var errorsResult = await session.getErrorsValid(test.path);
+    var errorsResult = await session.getErrorsValid(testFile);
     expect(errorsResult.session, session);
-    expect(errorsResult.path, test.path);
+    expect(errorsResult.path, testFile.path);
     expect(errorsResult.errors, isNotEmpty);
   }
 
@@ -225,22 +231,28 @@ class AnalysisSessionImplTest extends PubPackageResolutionTest {
   }
 
   test_getFile_library() async {
-    var a = newFile('$testPackageLibPath/a.dart', '');
+    var content = 'class A {}';
+    var a = newFile('$testPackageLibPath/a.dart', content);
 
     var session = contextFor(testFile).currentSession;
-    var file = session.getFileValid(a.path);
+    var file = session.getFileValid(a);
     expect(file.path, a.path);
     expect(file.uri.toString(), 'package:test/a.dart');
+    expect(file.content, content);
+    expect(file.isLibrary, isTrue);
     expect(file.isPart, isFalse);
   }
 
   test_getFile_part() async {
-    var a = newFile('$testPackageLibPath/a.dart', 'part of lib;');
+    var content = 'part of lib;';
+    var a = newFile('$testPackageLibPath/a.dart', content);
 
     var session = contextFor(testFile).currentSession;
-    var file = session.getFileValid(a.path);
+    var file = session.getFileValid(a);
     expect(file.path, a.path);
     expect(file.uri.toString(), 'package:test/a.dart');
+    expect(file.content, content);
+    expect(file.isLibrary, isFalse);
     expect(file.isPart, isTrue);
   }
 
@@ -268,23 +280,13 @@ class B {}
     );
   }
 
-  test_getLibraryByUri_notLibrary_augmentation() async {
-    newFile(testFile.path, r'''
-library augment 'a.dart';
-''');
-
-    final session = contextFor(testFile).currentSession;
-    final result = await session.getLibraryByUri('package:test/test.dart');
-    expect(result, isA<NotLibraryButAugmentationResult>());
-  }
-
   test_getLibraryByUri_notLibrary_part() async {
     newFile(testFile.path, r'''
 part of 'a.dart';
 ''');
 
-    final session = contextFor(testFile).currentSession;
-    final result = await session.getLibraryByUri('package:test/test.dart');
+    var session = contextFor(testFile).currentSession;
+    var result = await session.getLibraryByUri('package:test/test.dart');
     expect(result, isA<NotLibraryButPartResult>());
   }
 
@@ -301,7 +303,7 @@ class B {}
 ''');
 
     var session = contextFor(testFile).currentSession;
-    var parsedLibrary = session.getParsedLibraryValid(test.path);
+    var parsedLibrary = session.getParsedLibraryValid(test);
     expect(parsedLibrary.session, session);
 
     expect(parsedLibrary.units, hasLength(1));
@@ -315,7 +317,7 @@ class B {}
   }
 
   test_getParsedLibrary_getElementDeclaration_class() async {
-    var test = newFile(testFile.path, r'''
+    newFile(testFile.path, r'''
 class A {}
 class B {}
 ''');
@@ -324,7 +326,7 @@ class B {}
     var libraryResult = await session.getLibraryByUriValid(
       'package:test/test.dart',
     );
-    var parsedLibrary = session.getParsedLibraryValid(test.path);
+    var parsedLibrary = session.getParsedLibraryValid(testFile);
 
     var element = libraryResult.element.getClass('A')!;
     var declaration = parsedLibrary.getElementDeclaration(element)!;
@@ -335,15 +337,15 @@ class B {}
   }
 
   test_getParsedLibrary_getElementDeclaration_notThisLibrary() async {
-    var test = newFile(testFile.path, '');
+    newFile(testFile.path, '');
 
     var session = contextFor(testFile).currentSession;
     var resolvedUnit =
-        await session.getResolvedUnit(test.path) as ResolvedUnitResult;
+        await session.getResolvedUnit(testFile.path) as ResolvedUnitResult;
     var typeProvider = resolvedUnit.typeProvider;
     var intClass = typeProvider.intType.element;
 
-    var parsedLibrary = session.getParsedLibraryValid(test.path);
+    var parsedLibrary = session.getParsedLibraryValid(testFile);
 
     expect(() {
       parsedLibrary.getElementDeclaration(intClass);
@@ -351,14 +353,14 @@ class B {}
   }
 
   test_getParsedLibrary_getElementDeclaration_synthetic() async {
-    var test = newFile(testFile.path, r'''
+    newFile(testFile.path, r'''
 int foo = 0;
 ''');
 
     var session = contextFor(testFile).currentSession;
-    var parsedLibrary = session.getParsedLibraryValid(test.path);
+    var parsedLibrary = session.getParsedLibraryValid(testFile);
 
-    var unitResult = await session.getUnitElementValid(test.path);
+    var unitResult = await session.getUnitElementValid(testFile);
     var fooElement = unitResult.element.topLevelVariables[0];
     expect(fooElement.name, 'foo');
 
@@ -385,14 +387,14 @@ int foo = 0;
   }
 
   test_getParsedLibrary_invalidPartUri() async {
-    var test = newFile(testFile.path, r'''
+    newFile(testFile.path, r'''
 part 'a.dart';
 part ':[invalid uri].dart';
 part 'c.dart';
 ''');
 
     var session = contextFor(testFile).currentSession;
-    var parsedLibrary = session.getParsedLibraryValid(test.path);
+    var parsedLibrary = session.getParsedLibraryValid(testFile);
 
     expect(parsedLibrary.units, hasLength(1));
     expect(
@@ -413,16 +415,6 @@ part 'c.dart';
     expect(session.getParsedLibrary(test.path), isA<NotLibraryButPartResult>());
   }
 
-  test_getParsedLibrary_notLibrary_augmentation() async {
-    newFile(testFile.path, r'''
-library augment 'a.dart';
-''');
-
-    final session = contextFor(testFile).currentSession;
-    final result = session.getParsedLibrary(testFile.path);
-    expect(result, isA<NotLibraryButAugmentationResult>());
-  }
-
   test_getParsedLibrary_parts() async {
     var aContent = r'''
 part 'b.dart';
@@ -451,7 +443,7 @@ class C3 {}
     var c = newFile('$testPackageLibPath/c.dart', cContent);
 
     var session = contextFor(testFile).currentSession;
-    var parsedLibrary = session.getParsedLibraryValid(a.path);
+    var parsedLibrary = session.getParsedLibraryValid(a);
     expect(parsedLibrary.units, hasLength(3));
 
     {
@@ -506,7 +498,7 @@ class C3 {}
     );
     var element = libraryResult.element;
 
-    final aaaFile = getFile('$workspaceRootPath/aaa/lib/a.dart');
+    var aaaFile = getFile('$workspaceRootPath/aaa/lib/a.dart');
     var aaaSession = contextFor(aaaFile).currentSession;
 
     var result = aaaSession.getParsedLibraryByElement(element);
@@ -514,15 +506,15 @@ class C3 {}
   }
 
   test_getParsedUnit() async {
-    var test = newFile(testFile.path, r'''
+    newFile(testFile.path, r'''
 class A {}
 class B {}
 ''');
 
     var session = contextFor(testFile).currentSession;
-    var unitResult = session.getParsedUnitValid(test.path);
+    var unitResult = session.getParsedUnitValid(testFile);
     expect(unitResult.session, session);
-    expect(unitResult.path, test.path);
+    expect(unitResult.path, testFile.path);
     expect(unitResult.uri, Uri.parse('package:test/test.dart'));
     expect(unitResult.unit.declarations, hasLength(2));
   }
@@ -560,7 +552,7 @@ class B2 extends X {}
     var b = newFile('$testPackageLibPath/b.dart', bContent);
 
     var session = contextFor(testFile).currentSession;
-    var resolvedLibrary = await session.getResolvedLibraryValid(a.path);
+    var resolvedLibrary = await session.getResolvedLibraryValid(a);
     expect(resolvedLibrary.session, session);
 
     var typeProvider = resolvedLibrary.typeProvider;
@@ -606,10 +598,10 @@ class B2 extends X {}
   }
 
   test_getResolvedLibrary_getElementDeclaration_notThisLibrary() async {
-    var test = newFile(testFile.path, '');
+    newFile(testFile.path, '');
 
     var session = contextFor(testFile).currentSession;
-    var resolvedLibrary = await session.getResolvedLibraryValid(test.path);
+    var resolvedLibrary = await session.getResolvedLibraryValid(testFile);
 
     expect(() {
       var intClass = resolvedLibrary.typeProvider.intType.element;
@@ -618,12 +610,12 @@ class B2 extends X {}
   }
 
   test_getResolvedLibrary_getElementDeclaration_synthetic() async {
-    var test = newFile(testFile.path, r'''
+    newFile(testFile.path, r'''
 int foo = 0;
 ''');
 
     var session = contextFor(testFile).currentSession;
-    var resolvedLibrary = await session.getResolvedLibraryValid(test.path);
+    var resolvedLibrary = await session.getResolvedLibraryValid(testFile);
     var unitElement = resolvedLibrary.element.definingCompilationUnit;
 
     var fooElement = unitElement.topLevelVariables[0];
@@ -653,14 +645,14 @@ int foo = 0;
   }
 
   test_getResolvedLibrary_invalidPartUri() async {
-    var test = newFile(testFile.path, r'''
+    newFile(testFile.path, r'''
 part 'a.dart';
 part ':[invalid uri].dart';
 part 'c.dart';
 ''');
 
     var session = contextFor(testFile).currentSession;
-    var resolvedLibrary = await session.getResolvedLibraryValid(test.path);
+    var resolvedLibrary = await session.getResolvedLibraryValid(testFile);
 
     expect(resolvedLibrary.units, hasLength(1));
     expect(
@@ -675,16 +667,6 @@ part 'c.dart';
     expect(result, isA<InvalidPathResult>());
   }
 
-  test_getResolvedLibrary_notLibrary_augmentation() async {
-    newFile(testFile.path, r'''
-library augment of 'a.dart';
-''');
-
-    final session = contextFor(testFile).currentSession;
-    final result = await session.getResolvedLibrary(testFile.path);
-    expect(result, isA<NotLibraryButAugmentationResult>());
-  }
-
   test_getResolvedLibrary_notLibrary_part() async {
     var test = newFile(testFile.path, 'part of "a.dart";');
 
@@ -719,7 +701,7 @@ library augment of 'a.dart';
     );
     var element = libraryResult.element;
 
-    final aaaFile = getFile('$workspaceRootPath/aaa/lib/a.dart');
+    var aaaFile = getFile('$workspaceRootPath/aaa/lib/a.dart');
     var aaaSession = contextFor(aaaFile).currentSession;
 
     var result = await aaaSession.getResolvedLibraryByElement(element);
@@ -753,20 +735,6 @@ class B {}
     );
   }
 
-  test_getUnitElement() async {
-    var test = newFile(testFile.path, r'''
-class A {}
-class B {}
-''');
-
-    var session = contextFor(testFile).currentSession;
-    var unitResult = await session.getUnitElementValid(test.path);
-    expect(unitResult.session, session);
-    expect(unitResult.path, test.path);
-    expect(unitResult.uri, Uri.parse('package:test/test.dart'));
-    expect(unitResult.element.classes, hasLength(2));
-  }
-
   test_getUnitElement_inconsistent() async {
     var test = newFile(testFile.path, '');
     var session = contextFor(test).currentSession;
@@ -777,35 +745,203 @@ class B {}
     );
   }
 
+  test_getUnitElement_libraryUnit() async {
+    newFile(testFile.path, r'''
+class A {}
+class B {}
+''');
+
+    await _assertFileUnitElementResultText(testFile, r'''
+unitElementResult
+  path: /home/test/lib/test.dart
+  uri: package:test/test.dart
+  element
+    reference: root::package:test/test.dart::@fragment::package:test/test.dart
+    library: root::package:test/test.dart
+    classes: A, B
+''');
+  }
+
+  test_getUnitElement_partOfUriKnown_inLibrary() async {
+    var a = newFile('$testPackageLibPath/a.dart', r'''
+part of 'test.dart';
+class A {}
+class B {}
+''');
+
+    newFile(testFile.path, r'''
+part 'a.dart';
+''');
+
+    await _assertFileUnitElementResultText(a, r'''
+unitElementResult
+  path: /home/test/lib/a.dart
+  uri: package:test/a.dart
+  element
+    reference: root::package:test/test.dart::@fragment::package:test/a.dart
+    library: root::package:test/test.dart
+    classes: A, B
+''');
+  }
+
+  test_getUnitElement_partOfUriKnown_notInLibrary() async {
+    var a = newFile('$testPackageLibPath/a.dart', r'''
+part of 'test.dart';
+class A {}
+class B {}
+''');
+
+    await _assertFileUnitElementResultText(a, r'''
+unitElementResult
+  path: /home/test/lib/a.dart
+  uri: package:test/a.dart
+  element
+    reference: root::package:test/a.dart::@fragment::package:test/a.dart
+    library: root::package:test/a.dart
+    classes: A, B
+''');
+  }
+
+  test_getUnitElement_partOfUriName_inLibrary() async {
+    var a = newFile('$testPackageLibPath/a.dart', r'''
+part of my_lib;
+class A {}
+class B {}
+''');
+
+    newFile(testFile.path, r'''
+library my_lib;
+part 'a.dart';
+''');
+
+    await _assertFileUnitElementResultText(a, r'''
+unitElementResult
+  path: /home/test/lib/a.dart
+  uri: package:test/a.dart
+  element
+    reference: root::package:test/test.dart::@fragment::package:test/a.dart
+    library: root::package:test/test.dart
+    classes: A, B
+''');
+  }
+
+  test_getUnitElement_partOfUriName_notInLibrary() async {
+    var a = newFile('$testPackageLibPath/a.dart', r'''
+part of my_lib;
+class A {}
+class B {}
+''');
+
+    await _assertFileUnitElementResultText(a, r'''
+unitElementResult
+  path: /home/test/lib/a.dart
+  uri: package:test/a.dart
+  element
+    reference: root::package:test/a.dart::@fragment::package:test/a.dart
+    library: root::package:test/a.dart
+    classes: A, B
+''');
+  }
+
+  test_getUnitElement_partOfUriUnknown() async {
+    var a = newFile('$testPackageLibPath/a.dart', r'''
+part of 'foo:bar';
+class A {}
+class B {}
+''');
+
+    await _assertFileUnitElementResultText(a, r'''
+unitElementResult
+  path: /home/test/lib/a.dart
+  uri: package:test/a.dart
+  element
+    reference: root::package:test/a.dart::@fragment::package:test/a.dart
+    library: root::package:test/a.dart
+    classes: A, B
+''');
+  }
+
   test_resourceProvider() async {
     var session = contextFor(testFile).currentSession;
     expect(session.resourceProvider, resourceProvider);
   }
+
+  Future<void> _assertFileUnitElementResultText(
+    File file,
+    String expected,
+  ) async {
+    var session = contextFor(file).currentSession;
+    var unitResult = await session.getUnitElementValid(file);
+    _assertUnitElementResultText(unitResult, expected);
+  }
+
+  void _assertUnitElementResultText(
+    UnitElementResult result,
+    String expected,
+  ) {
+    var actual = _getElementUnitResultText(result);
+    if (actual != expected) {
+      print('-------- Actual --------');
+      print('$actual------------------------');
+      NodeTextExpectationsCollector.add(actual);
+    }
+    expect(actual, expected);
+  }
+
+  String _getElementUnitResultText(UnitElementResult result) {
+    var buffer = StringBuffer();
+    var sink = TreeStringSink(sink: buffer, indent: '');
+
+    sink.writelnWithIndent('unitElementResult');
+    sink.withIndent(() {
+      // We could print it, but currently it is always the current.
+      expect(result.session, contextFor(testFile).currentSession);
+
+      var file = result.file;
+      sink.writelnWithIndent('path: ${file.posixPath}');
+
+      sink.writelnWithIndent('uri: ${result.uri}');
+
+      sink.writelnWithIndent('element');
+      sink.withIndent(() {
+        var element = result.element as CompilationUnitElementImpl;
+        sink.writelnWithIndent('reference: ${element.reference}');
+
+        var library = element.library;
+        sink.writelnWithIndent('library: ${library.reference}');
+
+        var classListStr = element.classes.map((e) => e.name).join(', ');
+        sink.writelnWithIndent('classes: $classListStr');
+      });
+    });
+
+    return buffer.toString();
+  }
 }
 
 extension on AnalysisSession {
-  Future<ErrorsResult> getErrorsValid(String path) async {
-    return await getErrors(path) as ErrorsResult;
+  Future<ErrorsResult> getErrorsValid(File file) async {
+    return await getErrors(file.path) as ErrorsResult;
   }
 
-  FileResult getFileValid(String path) {
-    return getFile(path) as FileResult;
+  FileResult getFileValid(File file) {
+    return getFile(file.path) as FileResult;
   }
 
-  Future<LibraryElementResult> getLibraryByUriValid(String path) async {
-    return await getLibraryByUri(path) as LibraryElementResult;
+  Future<LibraryElementResult> getLibraryByUriValid(String uriStr) async {
+    return await getLibraryByUri(uriStr) as LibraryElementResult;
   }
 
   ParsedLibraryResult getParsedLibraryByElementValid(LibraryElement element) {
     return getParsedLibraryByElement(element) as ParsedLibraryResult;
   }
 
-  ParsedLibraryResult getParsedLibraryValid(String path) {
-    return getParsedLibrary(path) as ParsedLibraryResult;
+  ParsedLibraryResult getParsedLibraryValid(File file) {
+    return getParsedLibrary(file.path) as ParsedLibraryResult;
   }
 
-  ParsedUnitResult getParsedUnitValid(String path) {
-    return getParsedUnit(path) as ParsedUnitResult;
+  ParsedUnitResult getParsedUnitValid(File file) {
+    return getParsedUnit(file.path) as ParsedUnitResult;
   }
 
   Future<ResolvedLibraryResult> getResolvedLibraryByElementValid(
@@ -813,11 +949,11 @@ extension on AnalysisSession {
     return await getResolvedLibraryByElement(element) as ResolvedLibraryResult;
   }
 
-  Future<ResolvedLibraryResult> getResolvedLibraryValid(String path) async {
-    return await getResolvedLibrary(path) as ResolvedLibraryResult;
+  Future<ResolvedLibraryResult> getResolvedLibraryValid(File file) async {
+    return await getResolvedLibrary(file.path) as ResolvedLibraryResult;
   }
 
-  Future<UnitElementResult> getUnitElementValid(String path) async {
-    return await getUnitElement(path) as UnitElementResult;
+  Future<UnitElementResult> getUnitElementValid(File file) async {
+    return await getUnitElement(file.path) as UnitElementResult;
   }
 }
